!function(t){function e(r){if(n[r])return n[r].exports;var o=n[r]={exports:{},id:r,loaded:!1};return t[r].call(o.exports,o,o.exports,e),o.loaded=!0,o.exports}var n={};return e.m=t,e.c=n,e.p="",e(0)}([function(t,e,n){t.exports=n(1)},function(t,e,n){(function(t){"use strict";function e(t){return t&&t.__esModule?t:{default:t}}function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function o(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function i(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}var a=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),s=n(3),l=e(s),u=n(30),c=e(u),f=n(168),d=n(317),p=function(e){function n(t){r(this,n);var e=o(this,(n.__proto__||Object.getPrototypeOf(n)).call(this,t));return e.state={layouts:[],navlinks:[],brand:""},e}return i(n,e),a(n,[{key:"get_layout",value:function(){var e=window.location.pathname.replace("/","");e=e.length>0?e:"antiquing",t.get(this.props.url.concat(e,"/"),function(t){this.setState({layouts:t.layouts})}.bind(this))}},{key:"get_paths",value:function(){t.get(this.props.url,function(t){this.setState({navlinks:t.navlinks,brand:t.brand})}.bind(this))}},{key:"componentWillMount",value:function(){this.get_layout(),this.get_paths()}},{key:"render",value:function(){var t=this.props.children,e=t&&l.default.cloneElement(l.default.Children.only(t),this.state);return l.default.createElement("div",null,l.default.createElement(f.Navs,{navlinks:this.state.navlinks,brand:this.state.brand}),l.default.createElement("div",{className:"container"},e))}}]),n}(l.default.Component);p.defaultProps={url:"/api/props/"},c.default.render(l.default.createElement(p,null,l.default.createElement(d.ChartManager,null)),document.getElementById("component_id"))}).call(e,n(2))},function(t,e,n){var r,o;/*!
	 * jQuery JavaScript Library v2.2.4
	 * http://jquery.com/
	 *
	 * Includes Sizzle.js
	 * http://sizzlejs.com/
	 *
	 * Copyright jQuery Foundation and other contributors
	 * Released under the MIT license
	 * http://jquery.org/license
	 *
	 * Date: 2016-05-20T17:23Z
	 */
!function(e,n){"object"==typeof t&&"object"==typeof t.exports?t.exports=e.document?n(e,!0):function(t){if(!t.document)throw new Error("jQuery requires a window with a document");return n(t)}:n(e)}("undefined"!=typeof window?window:this,function(n,i){function a(t){var e=!!t&&"length"in t&&t.length,n=ut.type(t);return"function"!==n&&!ut.isWindow(t)&&("array"===n||0===e||"number"==typeof e&&e>0&&e-1 in t)}function s(t,e,n){if(ut.isFunction(e))return ut.grep(t,function(t,r){return!!e.call(t,r,t)!==n});if(e.nodeType)return ut.grep(t,function(t){return t===e!==n});if("string"==typeof e){if(bt.test(e))return ut.filter(e,t,n);e=ut.filter(e,t)}return ut.grep(t,function(t){return rt.call(e,t)>-1!==n})}function l(t,e){for(;(t=t[e])&&1!==t.nodeType;);return t}function u(t){var e={};return ut.each(t.match(kt)||[],function(t,n){e[n]=!0}),e}function c(){Q.removeEventListener("DOMContentLoaded",c),n.removeEventListener("load",c),ut.ready()}function f(){this.expando=ut.expando+f.uid++}function d(t,e,n){var r;if(void 0===n&&1===t.nodeType)if(r="data-"+e.replace(Ot,"-$&").toLowerCase(),n=t.getAttribute(r),"string"==typeof n){try{n="true"===n||"false"!==n&&("null"===n?null:+n+""===n?+n:At.test(n)?ut.parseJSON(n):n)}catch(t){}Nt.set(t,e,n)}else n=void 0;return n}function p(t,e,n,r){var o,i=1,a=20,s=r?function(){return r.cur()}:function(){return ut.css(t,e,"")},l=s(),u=n&&n[3]||(ut.cssNumber[e]?"":"px"),c=(ut.cssNumber[e]||"px"!==u&&+l)&&It.exec(ut.css(t,e));if(c&&c[3]!==u){u=u||c[3],n=n||[],c=+l||1;do i=i||".5",c/=i,ut.style(t,e,c+u);while(i!==(i=s()/l)&&1!==i&&--a)}return n&&(c=+c||+l||0,o=n[1]?c+(n[1]+1)*n[2]:+n[2],r&&(r.unit=u,r.start=c,r.end=o)),o}function h(t,e){var n="undefined"!=typeof t.getElementsByTagName?t.getElementsByTagName(e||"*"):"undefined"!=typeof t.querySelectorAll?t.querySelectorAll(e||"*"):[];return void 0===e||e&&ut.nodeName(t,e)?ut.merge([t],n):n}function g(t,e){for(var n=0,r=t.length;n<r;n++)Mt.set(t[n],"globalEval",!e||Mt.get(e[n],"globalEval"))}function v(t,e,n,r,o){for(var i,a,s,l,u,c,f=e.createDocumentFragment(),d=[],p=0,v=t.length;p<v;p++)if(i=t[p],i||0===i)if("object"===ut.type(i))ut.merge(d,i.nodeType?[i]:i);else if(Ht.test(i)){for(a=a||f.appendChild(e.createElement("div")),s=(jt.exec(i)||["",""])[1].toLowerCase(),l=Ut[s]||Ut._default,a.innerHTML=l[1]+ut.htmlPrefilter(i)+l[2],c=l[0];c--;)a=a.lastChild;ut.merge(d,a.childNodes),a=f.firstChild,a.textContent=""}else d.push(e.createTextNode(i));for(f.textContent="",p=0;i=d[p++];)if(r&&ut.inArray(i,r)>-1)o&&o.push(i);else if(u=ut.contains(i.ownerDocument,i),a=h(f.appendChild(i),"script"),u&&g(a),n)for(c=0;i=a[c++];)Bt.test(i.type||"")&&n.push(i);return f}function m(){return!0}function y(){return!1}function b(){try{return Q.activeElement}catch(t){}}function x(t,e,n,r,o,i){var a,s;if("object"==typeof e){"string"!=typeof n&&(r=r||n,n=void 0);for(s in e)x(t,s,n,r,e[s],i);return t}if(null==r&&null==o?(o=n,r=n=void 0):null==o&&("string"==typeof n?(o=r,r=void 0):(o=r,r=n,n=void 0)),o===!1)o=y;else if(!o)return t;return 1===i&&(a=o,o=function(t){return ut().off(t),a.apply(this,arguments)},o.guid=a.guid||(a.guid=ut.guid++)),t.each(function(){ut.event.add(this,e,o,r,n)})}function _(t,e){return ut.nodeName(t,"table")&&ut.nodeName(11!==e.nodeType?e:e.firstChild,"tr")?t.getElementsByTagName("tbody")[0]||t.appendChild(t.ownerDocument.createElement("tbody")):t}function w(t){return t.type=(null!==t.getAttribute("type"))+"/"+t.type,t}function T(t){var e=Gt.exec(t.type);return e?t.type=e[1]:t.removeAttribute("type"),t}function C(t,e){var n,r,o,i,a,s,l,u;if(1===e.nodeType){if(Mt.hasData(t)&&(i=Mt.access(t),a=Mt.set(e,i),u=i.events)){delete a.handle,a.events={};for(o in u)for(n=0,r=u[o].length;n<r;n++)ut.event.add(e,o,u[o][n])}Nt.hasData(t)&&(s=Nt.access(t),l=ut.extend({},s),Nt.set(e,l))}}function k(t,e){var n=e.nodeName.toLowerCase();"input"===n&&Ft.test(t.type)?e.checked=t.checked:"input"!==n&&"textarea"!==n||(e.defaultValue=t.defaultValue)}function E(t,e,n,r){e=et.apply([],e);var o,i,a,s,l,u,c=0,f=t.length,d=f-1,p=e[0],g=ut.isFunction(p);if(g||f>1&&"string"==typeof p&&!st.checkClone&&Yt.test(p))return t.each(function(o){var i=t.eq(o);g&&(e[0]=p.call(this,o,i.html())),E(i,e,n,r)});if(f&&(o=v(e,t[0].ownerDocument,!1,t,r),i=o.firstChild,1===o.childNodes.length&&(o=i),i||r)){for(a=ut.map(h(o,"script"),w),s=a.length;c<f;c++)l=o,c!==d&&(l=ut.clone(l,!0,!0),s&&ut.merge(a,h(l,"script"))),n.call(t[c],l,c);if(s)for(u=a[a.length-1].ownerDocument,ut.map(a,T),c=0;c<s;c++)l=a[c],Bt.test(l.type||"")&&!Mt.access(l,"globalEval")&&ut.contains(u,l)&&(l.src?ut._evalUrl&&ut._evalUrl(l.src):ut.globalEval(l.textContent.replace(Xt,"")))}return t}function P(t,e,n){for(var r,o=e?ut.filter(e,t):t,i=0;null!=(r=o[i]);i++)n||1!==r.nodeType||ut.cleanData(h(r)),r.parentNode&&(n&&ut.contains(r.ownerDocument,r)&&g(h(r,"script")),r.parentNode.removeChild(r));return t}function S(t,e){var n=ut(e.createElement(t)).appendTo(e.body),r=ut.css(n[0],"display");return n.detach(),r}function M(t){var e=Q,n=Zt[t];return n||(n=S(t,e),"none"!==n&&n||($t=($t||ut("<iframe frameborder='0' width='0' height='0'/>")).appendTo(e.documentElement),e=$t[0].contentDocument,e.write(),e.close(),n=S(t,e),$t.detach()),Zt[t]=n),n}function N(t,e,n){var r,o,i,a,s=t.style;return n=n||te(t),a=n?n.getPropertyValue(e)||n[e]:void 0,""!==a&&void 0!==a||ut.contains(t.ownerDocument,t)||(a=ut.style(t,e)),n&&!st.pixelMarginRight()&&Qt.test(a)&&Jt.test(e)&&(r=s.width,o=s.minWidth,i=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=r,s.minWidth=o,s.maxWidth=i),void 0!==a?a+"":a}function A(t,e){return{get:function(){return t()?void delete this.get:(this.get=e).apply(this,arguments)}}}function O(t){if(t in se)return t;for(var e=t[0].toUpperCase()+t.slice(1),n=ae.length;n--;)if(t=ae[n]+e,t in se)return t}function D(t,e,n){var r=It.exec(e);return r?Math.max(0,r[2]-(n||0))+(r[3]||"px"):e}function I(t,e,n,r,o){for(var i=n===(r?"border":"content")?4:"width"===e?1:0,a=0;i<4;i+=2)"margin"===n&&(a+=ut.css(t,n+Rt[i],!0,o)),r?("content"===n&&(a-=ut.css(t,"padding"+Rt[i],!0,o)),"margin"!==n&&(a-=ut.css(t,"border"+Rt[i]+"Width",!0,o))):(a+=ut.css(t,"padding"+Rt[i],!0,o),"padding"!==n&&(a+=ut.css(t,"border"+Rt[i]+"Width",!0,o)));return a}function R(t,e,n){var r=!0,o="width"===e?t.offsetWidth:t.offsetHeight,i=te(t),a="border-box"===ut.css(t,"boxSizing",!1,i);if(o<=0||null==o){if(o=N(t,e,i),(o<0||null==o)&&(o=t.style[e]),Qt.test(o))return o;r=a&&(st.boxSizingReliable()||o===t.style[e]),o=parseFloat(o)||0}return o+I(t,e,n||(a?"border":"content"),r,i)+"px"}function L(t,e){for(var n,r,o,i=[],a=0,s=t.length;a<s;a++)r=t[a],r.style&&(i[a]=Mt.get(r,"olddisplay"),n=r.style.display,e?(i[a]||"none"!==n||(r.style.display=""),""===r.style.display&&Lt(r)&&(i[a]=Mt.access(r,"olddisplay",M(r.nodeName)))):(o=Lt(r),"none"===n&&o||Mt.set(r,"olddisplay",o?n:ut.css(r,"display"))));for(a=0;a<s;a++)r=t[a],r.style&&(e&&"none"!==r.style.display&&""!==r.style.display||(r.style.display=e?i[a]||"":"none"));return t}function F(t,e,n,r,o){return new F.prototype.init(t,e,n,r,o)}function j(){return n.setTimeout(function(){le=void 0}),le=ut.now()}function B(t,e){var n,r=0,o={height:t};for(e=e?1:0;r<4;r+=2-e)n=Rt[r],o["margin"+n]=o["padding"+n]=t;return e&&(o.opacity=o.width=t),o}function U(t,e,n){for(var r,o=(W.tweeners[e]||[]).concat(W.tweeners["*"]),i=0,a=o.length;i<a;i++)if(r=o[i].call(n,e,t))return r}function H(t,e,n){var r,o,i,a,s,l,u,c,f=this,d={},p=t.style,h=t.nodeType&&Lt(t),g=Mt.get(t,"fxshow");n.queue||(s=ut._queueHooks(t,"fx"),null==s.unqueued&&(s.unqueued=0,l=s.empty.fire,s.empty.fire=function(){s.unqueued||l()}),s.unqueued++,f.always(function(){f.always(function(){s.unqueued--,ut.queue(t,"fx").length||s.empty.fire()})})),1===t.nodeType&&("height"in e||"width"in e)&&(n.overflow=[p.overflow,p.overflowX,p.overflowY],u=ut.css(t,"display"),c="none"===u?Mt.get(t,"olddisplay")||M(t.nodeName):u,"inline"===c&&"none"===ut.css(t,"float")&&(p.display="inline-block")),n.overflow&&(p.overflow="hidden",f.always(function(){p.overflow=n.overflow[0],p.overflowX=n.overflow[1],p.overflowY=n.overflow[2]}));for(r in e)if(o=e[r],ce.exec(o)){if(delete e[r],i=i||"toggle"===o,o===(h?"hide":"show")){if("show"!==o||!g||void 0===g[r])continue;h=!0}d[r]=g&&g[r]||ut.style(t,r)}else u=void 0;if(ut.isEmptyObject(d))"inline"===("none"===u?M(t.nodeName):u)&&(p.display=u);else{g?"hidden"in g&&(h=g.hidden):g=Mt.access(t,"fxshow",{}),i&&(g.hidden=!h),h?ut(t).show():f.done(function(){ut(t).hide()}),f.done(function(){var e;Mt.remove(t,"fxshow");for(e in d)ut.style(t,e,d[e])});for(r in d)a=U(h?g[r]:0,r,f),r in g||(g[r]=a.start,h&&(a.end=a.start,a.start="width"===r||"height"===r?1:0))}}function z(t,e){var n,r,o,i,a;for(n in t)if(r=ut.camelCase(n),o=e[r],i=t[n],ut.isArray(i)&&(o=i[1],i=t[n]=i[0]),n!==r&&(t[r]=i,delete t[n]),a=ut.cssHooks[r],a&&"expand"in a){i=a.expand(i),delete t[r];for(n in i)n in t||(t[n]=i[n],e[n]=o)}else e[r]=o}function W(t,e,n){var r,o,i=0,a=W.prefilters.length,s=ut.Deferred().always(function(){delete l.elem}),l=function(){if(o)return!1;for(var e=le||j(),n=Math.max(0,u.startTime+u.duration-e),r=n/u.duration||0,i=1-r,a=0,l=u.tweens.length;a<l;a++)u.tweens[a].run(i);return s.notifyWith(t,[u,i,n]),i<1&&l?n:(s.resolveWith(t,[u]),!1)},u=s.promise({elem:t,props:ut.extend({},e),opts:ut.extend(!0,{specialEasing:{},easing:ut.easing._default},n),originalProperties:e,originalOptions:n,startTime:le||j(),duration:n.duration,tweens:[],createTween:function(e,n){var r=ut.Tween(t,u.opts,e,n,u.opts.specialEasing[e]||u.opts.easing);return u.tweens.push(r),r},stop:function(e){var n=0,r=e?u.tweens.length:0;if(o)return this;for(o=!0;n<r;n++)u.tweens[n].run(1);return e?(s.notifyWith(t,[u,1,0]),s.resolveWith(t,[u,e])):s.rejectWith(t,[u,e]),this}}),c=u.props;for(z(c,u.opts.specialEasing);i<a;i++)if(r=W.prefilters[i].call(u,t,c,u.opts))return ut.isFunction(r.stop)&&(ut._queueHooks(u.elem,u.opts.queue).stop=ut.proxy(r.stop,r)),r;return ut.map(c,U,u),ut.isFunction(u.opts.start)&&u.opts.start.call(t,u),ut.fx.timer(ut.extend(l,{elem:t,anim:u,queue:u.opts.queue})),u.progress(u.opts.progress).done(u.opts.done,u.opts.complete).fail(u.opts.fail).always(u.opts.always)}function q(t){return t.getAttribute&&t.getAttribute("class")||""}function V(t){return function(e,n){"string"!=typeof e&&(n=e,e="*");var r,o=0,i=e.toLowerCase().match(kt)||[];if(ut.isFunction(n))for(;r=i[o++];)"+"===r[0]?(r=r.slice(1)||"*",(t[r]=t[r]||[]).unshift(n)):(t[r]=t[r]||[]).push(n)}}function K(t,e,n,r){function o(s){var l;return i[s]=!0,ut.each(t[s]||[],function(t,s){var u=s(e,n,r);return"string"!=typeof u||a||i[u]?a?!(l=u):void 0:(e.dataTypes.unshift(u),o(u),!1)}),l}var i={},a=t===Ne;return o(e.dataTypes[0])||!i["*"]&&o("*")}function Y(t,e){var n,r,o=ut.ajaxSettings.flatOptions||{};for(n in e)void 0!==e[n]&&((o[n]?t:r||(r={}))[n]=e[n]);return r&&ut.extend(!0,t,r),t}function G(t,e,n){for(var r,o,i,a,s=t.contents,l=t.dataTypes;"*"===l[0];)l.shift(),void 0===r&&(r=t.mimeType||e.getResponseHeader("Content-Type"));if(r)for(o in s)if(s[o]&&s[o].test(r)){l.unshift(o);break}if(l[0]in n)i=l[0];else{for(o in n){if(!l[0]||t.converters[o+" "+l[0]]){i=o;break}a||(a=o)}i=i||a}if(i)return i!==l[0]&&l.unshift(i),n[i]}function X(t,e,n,r){var o,i,a,s,l,u={},c=t.dataTypes.slice();if(c[1])for(a in t.converters)u[a.toLowerCase()]=t.converters[a];for(i=c.shift();i;)if(t.responseFields[i]&&(n[t.responseFields[i]]=e),!l&&r&&t.dataFilter&&(e=t.dataFilter(e,t.dataType)),l=i,i=c.shift())if("*"===i)i=l;else if("*"!==l&&l!==i){if(a=u[l+" "+i]||u["* "+i],!a)for(o in u)if(s=o.split(" "),s[1]===i&&(a=u[l+" "+s[0]]||u["* "+s[0]])){a===!0?a=u[o]:u[o]!==!0&&(i=s[0],c.unshift(s[1]));break}if(a!==!0)if(a&&t.throws)e=a(e);else try{e=a(e)}catch(t){return{state:"parsererror",error:a?t:"No conversion from "+l+" to "+i}}}return{state:"success",data:e}}function $(t,e,n,r){var o;if(ut.isArray(e))ut.each(e,function(e,o){n||Ie.test(t)?r(t,o):$(t+"["+("object"==typeof o&&null!=o?e:"")+"]",o,n,r)});else if(n||"object"!==ut.type(e))r(t,e);else for(o in e)$(t+"["+o+"]",e[o],n,r)}function Z(t){return ut.isWindow(t)?t:9===t.nodeType&&t.defaultView}var J=[],Q=n.document,tt=J.slice,et=J.concat,nt=J.push,rt=J.indexOf,ot={},it=ot.toString,at=ot.hasOwnProperty,st={},lt="2.2.4",ut=function(t,e){return new ut.fn.init(t,e)},ct=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,ft=/^-ms-/,dt=/-([\da-z])/gi,pt=function(t,e){return e.toUpperCase()};ut.fn=ut.prototype={jquery:lt,constructor:ut,selector:"",length:0,toArray:function(){return tt.call(this)},get:function(t){return null!=t?t<0?this[t+this.length]:this[t]:tt.call(this)},pushStack:function(t){var e=ut.merge(this.constructor(),t);return e.prevObject=this,e.context=this.context,e},each:function(t){return ut.each(this,t)},map:function(t){return this.pushStack(ut.map(this,function(e,n){return t.call(e,n,e)}))},slice:function(){return this.pushStack(tt.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(t){var e=this.length,n=+t+(t<0?e:0);return this.pushStack(n>=0&&n<e?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:nt,sort:J.sort,splice:J.splice},ut.extend=ut.fn.extend=function(){var t,e,n,r,o,i,a=arguments[0]||{},s=1,l=arguments.length,u=!1;for("boolean"==typeof a&&(u=a,a=arguments[s]||{},s++),"object"==typeof a||ut.isFunction(a)||(a={}),s===l&&(a=this,s--);s<l;s++)if(null!=(t=arguments[s]))for(e in t)n=a[e],r=t[e],a!==r&&(u&&r&&(ut.isPlainObject(r)||(o=ut.isArray(r)))?(o?(o=!1,i=n&&ut.isArray(n)?n:[]):i=n&&ut.isPlainObject(n)?n:{},a[e]=ut.extend(u,i,r)):void 0!==r&&(a[e]=r));return a},ut.extend({expando:"jQuery"+(lt+Math.random()).replace(/\D/g,""),isReady:!0,error:function(t){throw new Error(t)},noop:function(){},isFunction:function(t){return"function"===ut.type(t)},isArray:Array.isArray,isWindow:function(t){return null!=t&&t===t.window},isNumeric:function(t){var e=t&&t.toString();return!ut.isArray(t)&&e-parseFloat(e)+1>=0},isPlainObject:function(t){var e;if("object"!==ut.type(t)||t.nodeType||ut.isWindow(t))return!1;if(t.constructor&&!at.call(t,"constructor")&&!at.call(t.constructor.prototype||{},"isPrototypeOf"))return!1;for(e in t);return void 0===e||at.call(t,e)},isEmptyObject:function(t){var e;for(e in t)return!1;return!0},type:function(t){return null==t?t+"":"object"==typeof t||"function"==typeof t?ot[it.call(t)]||"object":typeof t},globalEval:function(t){var e,n=eval;t=ut.trim(t),t&&(1===t.indexOf("use strict")?(e=Q.createElement("script"),e.text=t,Q.head.appendChild(e).parentNode.removeChild(e)):n(t))},camelCase:function(t){return t.replace(ft,"ms-").replace(dt,pt)},nodeName:function(t,e){return t.nodeName&&t.nodeName.toLowerCase()===e.toLowerCase()},each:function(t,e){var n,r=0;if(a(t))for(n=t.length;r<n&&e.call(t[r],r,t[r])!==!1;r++);else for(r in t)if(e.call(t[r],r,t[r])===!1)break;return t},trim:function(t){return null==t?"":(t+"").replace(ct,"")},makeArray:function(t,e){var n=e||[];return null!=t&&(a(Object(t))?ut.merge(n,"string"==typeof t?[t]:t):nt.call(n,t)),n},inArray:function(t,e,n){return null==e?-1:rt.call(e,t,n)},merge:function(t,e){for(var n=+e.length,r=0,o=t.length;r<n;r++)t[o++]=e[r];return t.length=o,t},grep:function(t,e,n){for(var r,o=[],i=0,a=t.length,s=!n;i<a;i++)r=!e(t[i],i),r!==s&&o.push(t[i]);return o},map:function(t,e,n){var r,o,i=0,s=[];if(a(t))for(r=t.length;i<r;i++)o=e(t[i],i,n),null!=o&&s.push(o);else for(i in t)o=e(t[i],i,n),null!=o&&s.push(o);return et.apply([],s)},guid:1,proxy:function(t,e){var n,r,o;if("string"==typeof e&&(n=t[e],e=t,t=n),ut.isFunction(t))return r=tt.call(arguments,2),o=function(){return t.apply(e||this,r.concat(tt.call(arguments)))},o.guid=t.guid=t.guid||ut.guid++,o},now:Date.now,support:st}),"function"==typeof Symbol&&(ut.fn[Symbol.iterator]=J[Symbol.iterator]),ut.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(t,e){ot["[object "+e+"]"]=e.toLowerCase()});var ht=/*!
	 * Sizzle CSS Selector Engine v2.2.1
	 * http://sizzlejs.com/
	 *
	 * Copyright jQuery Foundation and other contributors
	 * Released under the MIT license
	 * http://jquery.org/license
	 *
	 * Date: 2015-10-17
	 */
function(t){function e(t,e,n,r){var o,i,a,s,l,u,f,p,h=e&&e.ownerDocument,g=e?e.nodeType:9;if(n=n||[],"string"!=typeof t||!t||1!==g&&9!==g&&11!==g)return n;if(!r&&((e?e.ownerDocument||e:U)!==O&&A(e),e=e||O,I)){if(11!==g&&(u=mt.exec(t)))if(o=u[1]){if(9===g){if(!(a=e.getElementById(o)))return n;if(a.id===o)return n.push(a),n}else if(h&&(a=h.getElementById(o))&&j(e,a)&&a.id===o)return n.push(a),n}else{if(u[2])return J.apply(n,e.getElementsByTagName(t)),n;if((o=u[3])&&_.getElementsByClassName&&e.getElementsByClassName)return J.apply(n,e.getElementsByClassName(o)),n}if(_.qsa&&!V[t+" "]&&(!R||!R.test(t))){if(1!==g)h=e,p=t;else if("object"!==e.nodeName.toLowerCase()){for((s=e.getAttribute("id"))?s=s.replace(bt,"\\$&"):e.setAttribute("id",s=B),f=k(t),i=f.length,l=dt.test(s)?"#"+s:"[id='"+s+"']";i--;)f[i]=l+" "+d(f[i]);p=f.join(","),h=yt.test(t)&&c(e.parentNode)||e}if(p)try{return J.apply(n,h.querySelectorAll(p)),n}catch(t){}finally{s===B&&e.removeAttribute("id")}}}return P(t.replace(st,"$1"),e,n,r)}function n(){function t(n,r){return e.push(n+" ")>w.cacheLength&&delete t[e.shift()],t[n+" "]=r}var e=[];return t}function r(t){return t[B]=!0,t}function o(t){var e=O.createElement("div");try{return!!t(e)}catch(t){return!1}finally{e.parentNode&&e.parentNode.removeChild(e),e=null}}function i(t,e){for(var n=t.split("|"),r=n.length;r--;)w.attrHandle[n[r]]=e}function a(t,e){var n=e&&t,r=n&&1===t.nodeType&&1===e.nodeType&&(~e.sourceIndex||Y)-(~t.sourceIndex||Y);if(r)return r;if(n)for(;n=n.nextSibling;)if(n===e)return-1;return t?1:-1}function s(t){return function(e){var n=e.nodeName.toLowerCase();return"input"===n&&e.type===t}}function l(t){return function(e){var n=e.nodeName.toLowerCase();return("input"===n||"button"===n)&&e.type===t}}function u(t){return r(function(e){return e=+e,r(function(n,r){for(var o,i=t([],n.length,e),a=i.length;a--;)n[o=i[a]]&&(n[o]=!(r[o]=n[o]))})})}function c(t){return t&&"undefined"!=typeof t.getElementsByTagName&&t}function f(){}function d(t){for(var e=0,n=t.length,r="";e<n;e++)r+=t[e].value;return r}function p(t,e,n){var r=e.dir,o=n&&"parentNode"===r,i=z++;return e.first?function(e,n,i){for(;e=e[r];)if(1===e.nodeType||o)return t(e,n,i)}:function(e,n,a){var s,l,u,c=[H,i];if(a){for(;e=e[r];)if((1===e.nodeType||o)&&t(e,n,a))return!0}else for(;e=e[r];)if(1===e.nodeType||o){if(u=e[B]||(e[B]={}),l=u[e.uniqueID]||(u[e.uniqueID]={}),(s=l[r])&&s[0]===H&&s[1]===i)return c[2]=s[2];if(l[r]=c,c[2]=t(e,n,a))return!0}}}function h(t){return t.length>1?function(e,n,r){for(var o=t.length;o--;)if(!t[o](e,n,r))return!1;return!0}:t[0]}function g(t,n,r){for(var o=0,i=n.length;o<i;o++)e(t,n[o],r);return r}function v(t,e,n,r,o){for(var i,a=[],s=0,l=t.length,u=null!=e;s<l;s++)(i=t[s])&&(n&&!n(i,r,o)||(a.push(i),u&&e.push(s)));return a}function m(t,e,n,o,i,a){return o&&!o[B]&&(o=m(o)),i&&!i[B]&&(i=m(i,a)),r(function(r,a,s,l){var u,c,f,d=[],p=[],h=a.length,m=r||g(e||"*",s.nodeType?[s]:s,[]),y=!t||!r&&e?m:v(m,d,t,s,l),b=n?i||(r?t:h||o)?[]:a:y;if(n&&n(y,b,s,l),o)for(u=v(b,p),o(u,[],s,l),c=u.length;c--;)(f=u[c])&&(b[p[c]]=!(y[p[c]]=f));if(r){if(i||t){if(i){for(u=[],c=b.length;c--;)(f=b[c])&&u.push(y[c]=f);i(null,b=[],u,l)}for(c=b.length;c--;)(f=b[c])&&(u=i?tt(r,f):d[c])>-1&&(r[u]=!(a[u]=f))}}else b=v(b===a?b.splice(h,b.length):b),i?i(null,a,b,l):J.apply(a,b)})}function y(t){for(var e,n,r,o=t.length,i=w.relative[t[0].type],a=i||w.relative[" "],s=i?1:0,l=p(function(t){return t===e},a,!0),u=p(function(t){return tt(e,t)>-1},a,!0),c=[function(t,n,r){var o=!i&&(r||n!==S)||((e=n).nodeType?l(t,n,r):u(t,n,r));return e=null,o}];s<o;s++)if(n=w.relative[t[s].type])c=[p(h(c),n)];else{if(n=w.filter[t[s].type].apply(null,t[s].matches),n[B]){for(r=++s;r<o&&!w.relative[t[r].type];r++);return m(s>1&&h(c),s>1&&d(t.slice(0,s-1).concat({value:" "===t[s-2].type?"*":""})).replace(st,"$1"),n,s<r&&y(t.slice(s,r)),r<o&&y(t=t.slice(r)),r<o&&d(t))}c.push(n)}return h(c)}function b(t,n){var o=n.length>0,i=t.length>0,a=function(r,a,s,l,u){var c,f,d,p=0,h="0",g=r&&[],m=[],y=S,b=r||i&&w.find.TAG("*",u),x=H+=null==y?1:Math.random()||.1,_=b.length;for(u&&(S=a===O||a||u);h!==_&&null!=(c=b[h]);h++){if(i&&c){for(f=0,a||c.ownerDocument===O||(A(c),s=!I);d=t[f++];)if(d(c,a||O,s)){l.push(c);break}u&&(H=x)}o&&((c=!d&&c)&&p--,r&&g.push(c))}if(p+=h,o&&h!==p){for(f=0;d=n[f++];)d(g,m,a,s);if(r){if(p>0)for(;h--;)g[h]||m[h]||(m[h]=$.call(l));m=v(m)}J.apply(l,m),u&&!r&&m.length>0&&p+n.length>1&&e.uniqueSort(l)}return u&&(H=x,S=y),g};return o?r(a):a}var x,_,w,T,C,k,E,P,S,M,N,A,O,D,I,R,L,F,j,B="sizzle"+1*new Date,U=t.document,H=0,z=0,W=n(),q=n(),V=n(),K=function(t,e){return t===e&&(N=!0),0},Y=1<<31,G={}.hasOwnProperty,X=[],$=X.pop,Z=X.push,J=X.push,Q=X.slice,tt=function(t,e){for(var n=0,r=t.length;n<r;n++)if(t[n]===e)return n;return-1},et="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",nt="[\\x20\\t\\r\\n\\f]",rt="(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",ot="\\["+nt+"*("+rt+")(?:"+nt+"*([*^$|!~]?=)"+nt+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+rt+"))|)"+nt+"*\\]",it=":("+rt+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+ot+")*)|.*)\\)|)",at=new RegExp(nt+"+","g"),st=new RegExp("^"+nt+"+|((?:^|[^\\\\])(?:\\\\.)*)"+nt+"+$","g"),lt=new RegExp("^"+nt+"*,"+nt+"*"),ut=new RegExp("^"+nt+"*([>+~]|"+nt+")"+nt+"*"),ct=new RegExp("="+nt+"*([^\\]'\"]*?)"+nt+"*\\]","g"),ft=new RegExp(it),dt=new RegExp("^"+rt+"$"),pt={ID:new RegExp("^#("+rt+")"),CLASS:new RegExp("^\\.("+rt+")"),TAG:new RegExp("^("+rt+"|[*])"),ATTR:new RegExp("^"+ot),PSEUDO:new RegExp("^"+it),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+nt+"*(even|odd|(([+-]|)(\\d*)n|)"+nt+"*(?:([+-]|)"+nt+"*(\\d+)|))"+nt+"*\\)|)","i"),bool:new RegExp("^(?:"+et+")$","i"),needsContext:new RegExp("^"+nt+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+nt+"*((?:-\\d)?\\d*)"+nt+"*\\)|)(?=[^-]|$)","i")},ht=/^(?:input|select|textarea|button)$/i,gt=/^h\d$/i,vt=/^[^{]+\{\s*\[native \w/,mt=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,yt=/[+~]/,bt=/'|\\/g,xt=new RegExp("\\\\([\\da-f]{1,6}"+nt+"?|("+nt+")|.)","ig"),_t=function(t,e,n){var r="0x"+e-65536;return r!==r||n?e:r<0?String.fromCharCode(r+65536):String.fromCharCode(r>>10|55296,1023&r|56320)},wt=function(){A()};try{J.apply(X=Q.call(U.childNodes),U.childNodes),X[U.childNodes.length].nodeType}catch(t){J={apply:X.length?function(t,e){Z.apply(t,Q.call(e))}:function(t,e){for(var n=t.length,r=0;t[n++]=e[r++];);t.length=n-1}}}_=e.support={},C=e.isXML=function(t){var e=t&&(t.ownerDocument||t).documentElement;return!!e&&"HTML"!==e.nodeName},A=e.setDocument=function(t){var e,n,r=t?t.ownerDocument||t:U;return r!==O&&9===r.nodeType&&r.documentElement?(O=r,D=O.documentElement,I=!C(O),(n=O.defaultView)&&n.top!==n&&(n.addEventListener?n.addEventListener("unload",wt,!1):n.attachEvent&&n.attachEvent("onunload",wt)),_.attributes=o(function(t){return t.className="i",!t.getAttribute("className")}),_.getElementsByTagName=o(function(t){return t.appendChild(O.createComment("")),!t.getElementsByTagName("*").length}),_.getElementsByClassName=vt.test(O.getElementsByClassName),_.getById=o(function(t){return D.appendChild(t).id=B,!O.getElementsByName||!O.getElementsByName(B).length}),_.getById?(w.find.ID=function(t,e){if("undefined"!=typeof e.getElementById&&I){var n=e.getElementById(t);return n?[n]:[]}},w.filter.ID=function(t){var e=t.replace(xt,_t);return function(t){return t.getAttribute("id")===e}}):(delete w.find.ID,w.filter.ID=function(t){var e=t.replace(xt,_t);return function(t){var n="undefined"!=typeof t.getAttributeNode&&t.getAttributeNode("id");return n&&n.value===e}}),w.find.TAG=_.getElementsByTagName?function(t,e){return"undefined"!=typeof e.getElementsByTagName?e.getElementsByTagName(t):_.qsa?e.querySelectorAll(t):void 0}:function(t,e){var n,r=[],o=0,i=e.getElementsByTagName(t);if("*"===t){for(;n=i[o++];)1===n.nodeType&&r.push(n);return r}return i},w.find.CLASS=_.getElementsByClassName&&function(t,e){if("undefined"!=typeof e.getElementsByClassName&&I)return e.getElementsByClassName(t)},L=[],R=[],(_.qsa=vt.test(O.querySelectorAll))&&(o(function(t){D.appendChild(t).innerHTML="<a id='"+B+"'></a><select id='"+B+"-\r\\' msallowcapture=''><option selected=''></option></select>",t.querySelectorAll("[msallowcapture^='']").length&&R.push("[*^$]="+nt+"*(?:''|\"\")"),t.querySelectorAll("[selected]").length||R.push("\\["+nt+"*(?:value|"+et+")"),t.querySelectorAll("[id~="+B+"-]").length||R.push("~="),t.querySelectorAll(":checked").length||R.push(":checked"),t.querySelectorAll("a#"+B+"+*").length||R.push(".#.+[+~]")}),o(function(t){var e=O.createElement("input");e.setAttribute("type","hidden"),t.appendChild(e).setAttribute("name","D"),t.querySelectorAll("[name=d]").length&&R.push("name"+nt+"*[*^$|!~]?="),t.querySelectorAll(":enabled").length||R.push(":enabled",":disabled"),t.querySelectorAll("*,:x"),R.push(",.*:")})),(_.matchesSelector=vt.test(F=D.matches||D.webkitMatchesSelector||D.mozMatchesSelector||D.oMatchesSelector||D.msMatchesSelector))&&o(function(t){_.disconnectedMatch=F.call(t,"div"),F.call(t,"[s!='']:x"),L.push("!=",it)}),R=R.length&&new RegExp(R.join("|")),L=L.length&&new RegExp(L.join("|")),e=vt.test(D.compareDocumentPosition),j=e||vt.test(D.contains)?function(t,e){var n=9===t.nodeType?t.documentElement:t,r=e&&e.parentNode;return t===r||!(!r||1!==r.nodeType||!(n.contains?n.contains(r):t.compareDocumentPosition&&16&t.compareDocumentPosition(r)))}:function(t,e){if(e)for(;e=e.parentNode;)if(e===t)return!0;return!1},K=e?function(t,e){if(t===e)return N=!0,0;var n=!t.compareDocumentPosition-!e.compareDocumentPosition;return n?n:(n=(t.ownerDocument||t)===(e.ownerDocument||e)?t.compareDocumentPosition(e):1,1&n||!_.sortDetached&&e.compareDocumentPosition(t)===n?t===O||t.ownerDocument===U&&j(U,t)?-1:e===O||e.ownerDocument===U&&j(U,e)?1:M?tt(M,t)-tt(M,e):0:4&n?-1:1)}:function(t,e){if(t===e)return N=!0,0;var n,r=0,o=t.parentNode,i=e.parentNode,s=[t],l=[e];if(!o||!i)return t===O?-1:e===O?1:o?-1:i?1:M?tt(M,t)-tt(M,e):0;if(o===i)return a(t,e);for(n=t;n=n.parentNode;)s.unshift(n);for(n=e;n=n.parentNode;)l.unshift(n);for(;s[r]===l[r];)r++;return r?a(s[r],l[r]):s[r]===U?-1:l[r]===U?1:0},O):O},e.matches=function(t,n){return e(t,null,null,n)},e.matchesSelector=function(t,n){if((t.ownerDocument||t)!==O&&A(t),n=n.replace(ct,"='$1']"),_.matchesSelector&&I&&!V[n+" "]&&(!L||!L.test(n))&&(!R||!R.test(n)))try{var r=F.call(t,n);if(r||_.disconnectedMatch||t.document&&11!==t.document.nodeType)return r}catch(t){}return e(n,O,null,[t]).length>0},e.contains=function(t,e){return(t.ownerDocument||t)!==O&&A(t),j(t,e)},e.attr=function(t,e){(t.ownerDocument||t)!==O&&A(t);var n=w.attrHandle[e.toLowerCase()],r=n&&G.call(w.attrHandle,e.toLowerCase())?n(t,e,!I):void 0;return void 0!==r?r:_.attributes||!I?t.getAttribute(e):(r=t.getAttributeNode(e))&&r.specified?r.value:null},e.error=function(t){throw new Error("Syntax error, unrecognized expression: "+t)},e.uniqueSort=function(t){var e,n=[],r=0,o=0;if(N=!_.detectDuplicates,M=!_.sortStable&&t.slice(0),t.sort(K),N){for(;e=t[o++];)e===t[o]&&(r=n.push(o));for(;r--;)t.splice(n[r],1)}return M=null,t},T=e.getText=function(t){var e,n="",r=0,o=t.nodeType;if(o){if(1===o||9===o||11===o){if("string"==typeof t.textContent)return t.textContent;for(t=t.firstChild;t;t=t.nextSibling)n+=T(t)}else if(3===o||4===o)return t.nodeValue}else for(;e=t[r++];)n+=T(e);return n},w=e.selectors={cacheLength:50,createPseudo:r,match:pt,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(t){return t[1]=t[1].replace(xt,_t),t[3]=(t[3]||t[4]||t[5]||"").replace(xt,_t),"~="===t[2]&&(t[3]=" "+t[3]+" "),t.slice(0,4)},CHILD:function(t){return t[1]=t[1].toLowerCase(),"nth"===t[1].slice(0,3)?(t[3]||e.error(t[0]),t[4]=+(t[4]?t[5]+(t[6]||1):2*("even"===t[3]||"odd"===t[3])),t[5]=+(t[7]+t[8]||"odd"===t[3])):t[3]&&e.error(t[0]),t},PSEUDO:function(t){var e,n=!t[6]&&t[2];return pt.CHILD.test(t[0])?null:(t[3]?t[2]=t[4]||t[5]||"":n&&ft.test(n)&&(e=k(n,!0))&&(e=n.indexOf(")",n.length-e)-n.length)&&(t[0]=t[0].slice(0,e),t[2]=n.slice(0,e)),t.slice(0,3))}},filter:{TAG:function(t){var e=t.replace(xt,_t).toLowerCase();return"*"===t?function(){return!0}:function(t){return t.nodeName&&t.nodeName.toLowerCase()===e}},CLASS:function(t){var e=W[t+" "];return e||(e=new RegExp("(^|"+nt+")"+t+"("+nt+"|$)"))&&W(t,function(t){return e.test("string"==typeof t.className&&t.className||"undefined"!=typeof t.getAttribute&&t.getAttribute("class")||"")})},ATTR:function(t,n,r){return function(o){var i=e.attr(o,t);return null==i?"!="===n:!n||(i+="","="===n?i===r:"!="===n?i!==r:"^="===n?r&&0===i.indexOf(r):"*="===n?r&&i.indexOf(r)>-1:"$="===n?r&&i.slice(-r.length)===r:"~="===n?(" "+i.replace(at," ")+" ").indexOf(r)>-1:"|="===n&&(i===r||i.slice(0,r.length+1)===r+"-"))}},CHILD:function(t,e,n,r,o){var i="nth"!==t.slice(0,3),a="last"!==t.slice(-4),s="of-type"===e;return 1===r&&0===o?function(t){return!!t.parentNode}:function(e,n,l){var u,c,f,d,p,h,g=i!==a?"nextSibling":"previousSibling",v=e.parentNode,m=s&&e.nodeName.toLowerCase(),y=!l&&!s,b=!1;if(v){if(i){for(;g;){for(d=e;d=d[g];)if(s?d.nodeName.toLowerCase()===m:1===d.nodeType)return!1;h=g="only"===t&&!h&&"nextSibling"}return!0}if(h=[a?v.firstChild:v.lastChild],a&&y){for(d=v,f=d[B]||(d[B]={}),c=f[d.uniqueID]||(f[d.uniqueID]={}),u=c[t]||[],p=u[0]===H&&u[1],b=p&&u[2],d=p&&v.childNodes[p];d=++p&&d&&d[g]||(b=p=0)||h.pop();)if(1===d.nodeType&&++b&&d===e){c[t]=[H,p,b];break}}else if(y&&(d=e,f=d[B]||(d[B]={}),c=f[d.uniqueID]||(f[d.uniqueID]={}),u=c[t]||[],p=u[0]===H&&u[1],b=p),b===!1)for(;(d=++p&&d&&d[g]||(b=p=0)||h.pop())&&((s?d.nodeName.toLowerCase()!==m:1!==d.nodeType)||!++b||(y&&(f=d[B]||(d[B]={}),c=f[d.uniqueID]||(f[d.uniqueID]={}),c[t]=[H,b]),d!==e)););return b-=o,b===r||b%r===0&&b/r>=0}}},PSEUDO:function(t,n){var o,i=w.pseudos[t]||w.setFilters[t.toLowerCase()]||e.error("unsupported pseudo: "+t);return i[B]?i(n):i.length>1?(o=[t,t,"",n],w.setFilters.hasOwnProperty(t.toLowerCase())?r(function(t,e){for(var r,o=i(t,n),a=o.length;a--;)r=tt(t,o[a]),t[r]=!(e[r]=o[a])}):function(t){return i(t,0,o)}):i}},pseudos:{not:r(function(t){var e=[],n=[],o=E(t.replace(st,"$1"));return o[B]?r(function(t,e,n,r){for(var i,a=o(t,null,r,[]),s=t.length;s--;)(i=a[s])&&(t[s]=!(e[s]=i))}):function(t,r,i){return e[0]=t,o(e,null,i,n),e[0]=null,!n.pop()}}),has:r(function(t){return function(n){return e(t,n).length>0}}),contains:r(function(t){return t=t.replace(xt,_t),function(e){return(e.textContent||e.innerText||T(e)).indexOf(t)>-1}}),lang:r(function(t){return dt.test(t||"")||e.error("unsupported lang: "+t),t=t.replace(xt,_t).toLowerCase(),function(e){var n;do if(n=I?e.lang:e.getAttribute("xml:lang")||e.getAttribute("lang"))return n=n.toLowerCase(),n===t||0===n.indexOf(t+"-");while((e=e.parentNode)&&1===e.nodeType);return!1}}),target:function(e){var n=t.location&&t.location.hash;return n&&n.slice(1)===e.id},root:function(t){return t===D},focus:function(t){return t===O.activeElement&&(!O.hasFocus||O.hasFocus())&&!!(t.type||t.href||~t.tabIndex)},enabled:function(t){return t.disabled===!1},disabled:function(t){return t.disabled===!0},checked:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&!!t.checked||"option"===e&&!!t.selected},selected:function(t){return t.parentNode&&t.parentNode.selectedIndex,t.selected===!0},empty:function(t){for(t=t.firstChild;t;t=t.nextSibling)if(t.nodeType<6)return!1;return!0},parent:function(t){return!w.pseudos.empty(t)},header:function(t){return gt.test(t.nodeName)},input:function(t){return ht.test(t.nodeName)},button:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&"button"===t.type||"button"===e},text:function(t){var e;return"input"===t.nodeName.toLowerCase()&&"text"===t.type&&(null==(e=t.getAttribute("type"))||"text"===e.toLowerCase())},first:u(function(){return[0]}),last:u(function(t,e){return[e-1]}),eq:u(function(t,e,n){return[n<0?n+e:n]}),even:u(function(t,e){for(var n=0;n<e;n+=2)t.push(n);return t}),odd:u(function(t,e){for(var n=1;n<e;n+=2)t.push(n);return t}),lt:u(function(t,e,n){for(var r=n<0?n+e:n;--r>=0;)t.push(r);return t}),gt:u(function(t,e,n){for(var r=n<0?n+e:n;++r<e;)t.push(r);return t})}},w.pseudos.nth=w.pseudos.eq;for(x in{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})w.pseudos[x]=s(x);for(x in{submit:!0,reset:!0})w.pseudos[x]=l(x);return f.prototype=w.filters=w.pseudos,w.setFilters=new f,k=e.tokenize=function(t,n){var r,o,i,a,s,l,u,c=q[t+" "];if(c)return n?0:c.slice(0);for(s=t,l=[],u=w.preFilter;s;){r&&!(o=lt.exec(s))||(o&&(s=s.slice(o[0].length)||s),l.push(i=[])),r=!1,(o=ut.exec(s))&&(r=o.shift(),i.push({value:r,type:o[0].replace(st," ")}),s=s.slice(r.length));for(a in w.filter)!(o=pt[a].exec(s))||u[a]&&!(o=u[a](o))||(r=o.shift(),i.push({value:r,type:a,matches:o}),s=s.slice(r.length));if(!r)break}return n?s.length:s?e.error(t):q(t,l).slice(0)},E=e.compile=function(t,e){var n,r=[],o=[],i=V[t+" "];if(!i){for(e||(e=k(t)),n=e.length;n--;)i=y(e[n]),i[B]?r.push(i):o.push(i);i=V(t,b(o,r)),i.selector=t}return i},P=e.select=function(t,e,n,r){var o,i,a,s,l,u="function"==typeof t&&t,f=!r&&k(t=u.selector||t);if(n=n||[],1===f.length){if(i=f[0]=f[0].slice(0),i.length>2&&"ID"===(a=i[0]).type&&_.getById&&9===e.nodeType&&I&&w.relative[i[1].type]){if(e=(w.find.ID(a.matches[0].replace(xt,_t),e)||[])[0],!e)return n;u&&(e=e.parentNode),t=t.slice(i.shift().value.length)}for(o=pt.needsContext.test(t)?0:i.length;o--&&(a=i[o],!w.relative[s=a.type]);)if((l=w.find[s])&&(r=l(a.matches[0].replace(xt,_t),yt.test(i[0].type)&&c(e.parentNode)||e))){if(i.splice(o,1),t=r.length&&d(i),!t)return J.apply(n,r),n;break}}return(u||E(t,f))(r,e,!I,n,!e||yt.test(t)&&c(e.parentNode)||e),n},_.sortStable=B.split("").sort(K).join("")===B,_.detectDuplicates=!!N,A(),_.sortDetached=o(function(t){return 1&t.compareDocumentPosition(O.createElement("div"))}),o(function(t){return t.innerHTML="<a href='#'></a>","#"===t.firstChild.getAttribute("href")})||i("type|href|height|width",function(t,e,n){if(!n)return t.getAttribute(e,"type"===e.toLowerCase()?1:2)}),_.attributes&&o(function(t){return t.innerHTML="<input/>",t.firstChild.setAttribute("value",""),""===t.firstChild.getAttribute("value")})||i("value",function(t,e,n){if(!n&&"input"===t.nodeName.toLowerCase())return t.defaultValue}),o(function(t){return null==t.getAttribute("disabled")})||i(et,function(t,e,n){var r;if(!n)return t[e]===!0?e.toLowerCase():(r=t.getAttributeNode(e))&&r.specified?r.value:null}),e}(n);ut.find=ht,ut.expr=ht.selectors,ut.expr[":"]=ut.expr.pseudos,ut.uniqueSort=ut.unique=ht.uniqueSort,ut.text=ht.getText,ut.isXMLDoc=ht.isXML,ut.contains=ht.contains;var gt=function(t,e,n){for(var r=[],o=void 0!==n;(t=t[e])&&9!==t.nodeType;)if(1===t.nodeType){if(o&&ut(t).is(n))break;r.push(t)}return r},vt=function(t,e){for(var n=[];t;t=t.nextSibling)1===t.nodeType&&t!==e&&n.push(t);return n},mt=ut.expr.match.needsContext,yt=/^<([\w-]+)\s*\/?>(?:<\/\1>|)$/,bt=/^.[^:#\[\.,]*$/;ut.filter=function(t,e,n){var r=e[0];return n&&(t=":not("+t+")"),1===e.length&&1===r.nodeType?ut.find.matchesSelector(r,t)?[r]:[]:ut.find.matches(t,ut.grep(e,function(t){return 1===t.nodeType}))},ut.fn.extend({find:function(t){var e,n=this.length,r=[],o=this;if("string"!=typeof t)return this.pushStack(ut(t).filter(function(){for(e=0;e<n;e++)if(ut.contains(o[e],this))return!0}));for(e=0;e<n;e++)ut.find(t,o[e],r);return r=this.pushStack(n>1?ut.unique(r):r),r.selector=this.selector?this.selector+" "+t:t,r},filter:function(t){return this.pushStack(s(this,t||[],!1))},not:function(t){return this.pushStack(s(this,t||[],!0))},is:function(t){return!!s(this,"string"==typeof t&&mt.test(t)?ut(t):t||[],!1).length}});var xt,_t=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,wt=ut.fn.init=function(t,e,n){var r,o;if(!t)return this;if(n=n||xt,"string"==typeof t){if(r="<"===t[0]&&">"===t[t.length-1]&&t.length>=3?[null,t,null]:_t.exec(t),!r||!r[1]&&e)return!e||e.jquery?(e||n).find(t):this.constructor(e).find(t);if(r[1]){if(e=e instanceof ut?e[0]:e,ut.merge(this,ut.parseHTML(r[1],e&&e.nodeType?e.ownerDocument||e:Q,!0)),yt.test(r[1])&&ut.isPlainObject(e))for(r in e)ut.isFunction(this[r])?this[r](e[r]):this.attr(r,e[r]);return this}return o=Q.getElementById(r[2]),o&&o.parentNode&&(this.length=1,this[0]=o),this.context=Q,this.selector=t,this}return t.nodeType?(this.context=this[0]=t,this.length=1,this):ut.isFunction(t)?void 0!==n.ready?n.ready(t):t(ut):(void 0!==t.selector&&(this.selector=t.selector,this.context=t.context),ut.makeArray(t,this))};wt.prototype=ut.fn,xt=ut(Q);var Tt=/^(?:parents|prev(?:Until|All))/,Ct={children:!0,contents:!0,next:!0,prev:!0};ut.fn.extend({has:function(t){var e=ut(t,this),n=e.length;return this.filter(function(){for(var t=0;t<n;t++)if(ut.contains(this,e[t]))return!0})},closest:function(t,e){for(var n,r=0,o=this.length,i=[],a=mt.test(t)||"string"!=typeof t?ut(t,e||this.context):0;r<o;r++)for(n=this[r];n&&n!==e;n=n.parentNode)if(n.nodeType<11&&(a?a.index(n)>-1:1===n.nodeType&&ut.find.matchesSelector(n,t))){i.push(n);break}return this.pushStack(i.length>1?ut.uniqueSort(i):i)},index:function(t){return t?"string"==typeof t?rt.call(ut(t),this[0]):rt.call(this,t.jquery?t[0]:t):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(t,e){return this.pushStack(ut.uniqueSort(ut.merge(this.get(),ut(t,e))))},addBack:function(t){return this.add(null==t?this.prevObject:this.prevObject.filter(t))}}),ut.each({parent:function(t){var e=t.parentNode;return e&&11!==e.nodeType?e:null},parents:function(t){return gt(t,"parentNode")},parentsUntil:function(t,e,n){return gt(t,"parentNode",n)},next:function(t){return l(t,"nextSibling")},prev:function(t){return l(t,"previousSibling")},nextAll:function(t){return gt(t,"nextSibling")},prevAll:function(t){return gt(t,"previousSibling")},nextUntil:function(t,e,n){return gt(t,"nextSibling",n)},prevUntil:function(t,e,n){return gt(t,"previousSibling",n)},siblings:function(t){return vt((t.parentNode||{}).firstChild,t)},children:function(t){return vt(t.firstChild)},contents:function(t){return t.contentDocument||ut.merge([],t.childNodes)}},function(t,e){ut.fn[t]=function(n,r){var o=ut.map(this,e,n);return"Until"!==t.slice(-5)&&(r=n),r&&"string"==typeof r&&(o=ut.filter(r,o)),this.length>1&&(Ct[t]||ut.uniqueSort(o),Tt.test(t)&&o.reverse()),this.pushStack(o)}});var kt=/\S+/g;ut.Callbacks=function(t){t="string"==typeof t?u(t):ut.extend({},t);var e,n,r,o,i=[],a=[],s=-1,l=function(){for(o=t.once,r=e=!0;a.length;s=-1)for(n=a.shift();++s<i.length;)i[s].apply(n[0],n[1])===!1&&t.stopOnFalse&&(s=i.length,n=!1);t.memory||(n=!1),e=!1,o&&(i=n?[]:"")},c={add:function(){return i&&(n&&!e&&(s=i.length-1,a.push(n)),function e(n){ut.each(n,function(n,r){ut.isFunction(r)?t.unique&&c.has(r)||i.push(r):r&&r.length&&"string"!==ut.type(r)&&e(r)})}(arguments),n&&!e&&l()),this},remove:function(){return ut.each(arguments,function(t,e){for(var n;(n=ut.inArray(e,i,n))>-1;)i.splice(n,1),n<=s&&s--}),this},has:function(t){return t?ut.inArray(t,i)>-1:i.length>0},empty:function(){return i&&(i=[]),this},disable:function(){return o=a=[],i=n="",this},disabled:function(){return!i},lock:function(){return o=a=[],n||(i=n=""),this},locked:function(){return!!o},fireWith:function(t,n){return o||(n=n||[],n=[t,n.slice?n.slice():n],a.push(n),e||l()),this},fire:function(){return c.fireWith(this,arguments),this},fired:function(){return!!r}};return c},ut.extend({Deferred:function(t){var e=[["resolve","done",ut.Callbacks("once memory"),"resolved"],["reject","fail",ut.Callbacks("once memory"),"rejected"],["notify","progress",ut.Callbacks("memory")]],n="pending",r={state:function(){return n},always:function(){return o.done(arguments).fail(arguments),this},then:function(){var t=arguments;return ut.Deferred(function(n){ut.each(e,function(e,i){var a=ut.isFunction(t[e])&&t[e];o[i[1]](function(){var t=a&&a.apply(this,arguments);t&&ut.isFunction(t.promise)?t.promise().progress(n.notify).done(n.resolve).fail(n.reject):n[i[0]+"With"](this===r?n.promise():this,a?[t]:arguments)})}),t=null}).promise()},promise:function(t){return null!=t?ut.extend(t,r):r}},o={};return r.pipe=r.then,ut.each(e,function(t,i){var a=i[2],s=i[3];r[i[1]]=a.add,s&&a.add(function(){n=s},e[1^t][2].disable,e[2][2].lock),o[i[0]]=function(){return o[i[0]+"With"](this===o?r:this,arguments),this},o[i[0]+"With"]=a.fireWith}),r.promise(o),t&&t.call(o,o),o},when:function(t){var e,n,r,o=0,i=tt.call(arguments),a=i.length,s=1!==a||t&&ut.isFunction(t.promise)?a:0,l=1===s?t:ut.Deferred(),u=function(t,n,r){return function(o){n[t]=this,r[t]=arguments.length>1?tt.call(arguments):o,r===e?l.notifyWith(n,r):--s||l.resolveWith(n,r)}};if(a>1)for(e=new Array(a),n=new Array(a),r=new Array(a);o<a;o++)i[o]&&ut.isFunction(i[o].promise)?i[o].promise().progress(u(o,n,e)).done(u(o,r,i)).fail(l.reject):--s;return s||l.resolveWith(r,i),l.promise()}});var Et;ut.fn.ready=function(t){return ut.ready.promise().done(t),this},ut.extend({isReady:!1,readyWait:1,holdReady:function(t){t?ut.readyWait++:ut.ready(!0)},ready:function(t){(t===!0?--ut.readyWait:ut.isReady)||(ut.isReady=!0,t!==!0&&--ut.readyWait>0||(Et.resolveWith(Q,[ut]),ut.fn.triggerHandler&&(ut(Q).triggerHandler("ready"),ut(Q).off("ready"))))}}),ut.ready.promise=function(t){return Et||(Et=ut.Deferred(),"complete"===Q.readyState||"loading"!==Q.readyState&&!Q.documentElement.doScroll?n.setTimeout(ut.ready):(Q.addEventListener("DOMContentLoaded",c),n.addEventListener("load",c))),Et.promise(t)},ut.ready.promise();var Pt=function(t,e,n,r,o,i,a){var s=0,l=t.length,u=null==n;if("object"===ut.type(n)){o=!0;for(s in n)Pt(t,e,s,n[s],!0,i,a)}else if(void 0!==r&&(o=!0,ut.isFunction(r)||(a=!0),u&&(a?(e.call(t,r),e=null):(u=e,e=function(t,e,n){return u.call(ut(t),n)})),e))for(;s<l;s++)e(t[s],n,a?r:r.call(t[s],s,e(t[s],n)));return o?t:u?e.call(t):l?e(t[0],n):i},St=function(t){return 1===t.nodeType||9===t.nodeType||!+t.nodeType};f.uid=1,f.prototype={register:function(t,e){var n=e||{};return t.nodeType?t[this.expando]=n:Object.defineProperty(t,this.expando,{value:n,writable:!0,configurable:!0}),t[this.expando]},cache:function(t){if(!St(t))return{};var e=t[this.expando];return e||(e={},St(t)&&(t.nodeType?t[this.expando]=e:Object.defineProperty(t,this.expando,{value:e,configurable:!0}))),e},set:function(t,e,n){var r,o=this.cache(t);if("string"==typeof e)o[e]=n;else for(r in e)o[r]=e[r];return o},get:function(t,e){return void 0===e?this.cache(t):t[this.expando]&&t[this.expando][e]},access:function(t,e,n){var r;return void 0===e||e&&"string"==typeof e&&void 0===n?(r=this.get(t,e),void 0!==r?r:this.get(t,ut.camelCase(e))):(this.set(t,e,n),void 0!==n?n:e)},remove:function(t,e){var n,r,o,i=t[this.expando];if(void 0!==i){if(void 0===e)this.register(t);else{ut.isArray(e)?r=e.concat(e.map(ut.camelCase)):(o=ut.camelCase(e),e in i?r=[e,o]:(r=o,r=r in i?[r]:r.match(kt)||[])),n=r.length;for(;n--;)delete i[r[n]]}(void 0===e||ut.isEmptyObject(i))&&(t.nodeType?t[this.expando]=void 0:delete t[this.expando])}},hasData:function(t){var e=t[this.expando];return void 0!==e&&!ut.isEmptyObject(e)}};var Mt=new f,Nt=new f,At=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,Ot=/[A-Z]/g;ut.extend({hasData:function(t){return Nt.hasData(t)||Mt.hasData(t)},data:function(t,e,n){return Nt.access(t,e,n)},removeData:function(t,e){Nt.remove(t,e)},_data:function(t,e,n){return Mt.access(t,e,n)},_removeData:function(t,e){Mt.remove(t,e)}}),ut.fn.extend({data:function(t,e){var n,r,o,i=this[0],a=i&&i.attributes;if(void 0===t){if(this.length&&(o=Nt.get(i),1===i.nodeType&&!Mt.get(i,"hasDataAttrs"))){for(n=a.length;n--;)a[n]&&(r=a[n].name,0===r.indexOf("data-")&&(r=ut.camelCase(r.slice(5)),d(i,r,o[r])));Mt.set(i,"hasDataAttrs",!0)}return o}return"object"==typeof t?this.each(function(){Nt.set(this,t)}):Pt(this,function(e){var n,r;if(i&&void 0===e){if(n=Nt.get(i,t)||Nt.get(i,t.replace(Ot,"-$&").toLowerCase()),void 0!==n)return n;if(r=ut.camelCase(t),n=Nt.get(i,r),void 0!==n)return n;if(n=d(i,r,void 0),void 0!==n)return n}else r=ut.camelCase(t),this.each(function(){var n=Nt.get(this,r);Nt.set(this,r,e),t.indexOf("-")>-1&&void 0!==n&&Nt.set(this,t,e)})},null,e,arguments.length>1,null,!0)},removeData:function(t){return this.each(function(){Nt.remove(this,t)})}}),ut.extend({queue:function(t,e,n){var r;if(t)return e=(e||"fx")+"queue",r=Mt.get(t,e),n&&(!r||ut.isArray(n)?r=Mt.access(t,e,ut.makeArray(n)):r.push(n)),r||[]},dequeue:function(t,e){e=e||"fx";var n=ut.queue(t,e),r=n.length,o=n.shift(),i=ut._queueHooks(t,e),a=function(){ut.dequeue(t,e)};"inprogress"===o&&(o=n.shift(),r--),o&&("fx"===e&&n.unshift("inprogress"),delete i.stop,o.call(t,a,i)),!r&&i&&i.empty.fire()},_queueHooks:function(t,e){var n=e+"queueHooks";return Mt.get(t,n)||Mt.access(t,n,{empty:ut.Callbacks("once memory").add(function(){Mt.remove(t,[e+"queue",n])})})}}),ut.fn.extend({queue:function(t,e){var n=2;return"string"!=typeof t&&(e=t,t="fx",n--),arguments.length<n?ut.queue(this[0],t):void 0===e?this:this.each(function(){var n=ut.queue(this,t,e);ut._queueHooks(this,t),"fx"===t&&"inprogress"!==n[0]&&ut.dequeue(this,t)})},dequeue:function(t){return this.each(function(){ut.dequeue(this,t)})},clearQueue:function(t){return this.queue(t||"fx",[])},promise:function(t,e){var n,r=1,o=ut.Deferred(),i=this,a=this.length,s=function(){--r||o.resolveWith(i,[i])};for("string"!=typeof t&&(e=t,t=void 0),t=t||"fx";a--;)n=Mt.get(i[a],t+"queueHooks"),n&&n.empty&&(r++,n.empty.add(s));return s(),o.promise(e)}});var Dt=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,It=new RegExp("^(?:([+-])=|)("+Dt+")([a-z%]*)$","i"),Rt=["Top","Right","Bottom","Left"],Lt=function(t,e){return t=e||t,"none"===ut.css(t,"display")||!ut.contains(t.ownerDocument,t)},Ft=/^(?:checkbox|radio)$/i,jt=/<([\w:-]+)/,Bt=/^$|\/(?:java|ecma)script/i,Ut={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};Ut.optgroup=Ut.option,Ut.tbody=Ut.tfoot=Ut.colgroup=Ut.caption=Ut.thead,Ut.th=Ut.td;var Ht=/<|&#?\w+;/;!function(){var t=Q.createDocumentFragment(),e=t.appendChild(Q.createElement("div")),n=Q.createElement("input");n.setAttribute("type","radio"),n.setAttribute("checked","checked"),n.setAttribute("name","t"),e.appendChild(n),st.checkClone=e.cloneNode(!0).cloneNode(!0).lastChild.checked,e.innerHTML="<textarea>x</textarea>",st.noCloneChecked=!!e.cloneNode(!0).lastChild.defaultValue}();var zt=/^key/,Wt=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,qt=/^([^.]*)(?:\.(.+)|)/;ut.event={global:{},add:function(t,e,n,r,o){var i,a,s,l,u,c,f,d,p,h,g,v=Mt.get(t);if(v)for(n.handler&&(i=n,n=i.handler,o=i.selector),n.guid||(n.guid=ut.guid++),(l=v.events)||(l=v.events={}),(a=v.handle)||(a=v.handle=function(e){return"undefined"!=typeof ut&&ut.event.triggered!==e.type?ut.event.dispatch.apply(t,arguments):void 0}),e=(e||"").match(kt)||[""],u=e.length;u--;)s=qt.exec(e[u])||[],p=g=s[1],h=(s[2]||"").split(".").sort(),p&&(f=ut.event.special[p]||{},p=(o?f.delegateType:f.bindType)||p,f=ut.event.special[p]||{},c=ut.extend({type:p,origType:g,data:r,handler:n,guid:n.guid,selector:o,needsContext:o&&ut.expr.match.needsContext.test(o),namespace:h.join(".")},i),(d=l[p])||(d=l[p]=[],d.delegateCount=0,f.setup&&f.setup.call(t,r,h,a)!==!1||t.addEventListener&&t.addEventListener(p,a)),f.add&&(f.add.call(t,c),c.handler.guid||(c.handler.guid=n.guid)),o?d.splice(d.delegateCount++,0,c):d.push(c),ut.event.global[p]=!0)},remove:function(t,e,n,r,o){var i,a,s,l,u,c,f,d,p,h,g,v=Mt.hasData(t)&&Mt.get(t);if(v&&(l=v.events)){for(e=(e||"").match(kt)||[""],u=e.length;u--;)if(s=qt.exec(e[u])||[],p=g=s[1],h=(s[2]||"").split(".").sort(),p){for(f=ut.event.special[p]||{},p=(r?f.delegateType:f.bindType)||p,d=l[p]||[],s=s[2]&&new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=i=d.length;i--;)c=d[i],!o&&g!==c.origType||n&&n.guid!==c.guid||s&&!s.test(c.namespace)||r&&r!==c.selector&&("**"!==r||!c.selector)||(d.splice(i,1),
c.selector&&d.delegateCount--,f.remove&&f.remove.call(t,c));a&&!d.length&&(f.teardown&&f.teardown.call(t,h,v.handle)!==!1||ut.removeEvent(t,p,v.handle),delete l[p])}else for(p in l)ut.event.remove(t,p+e[u],n,r,!0);ut.isEmptyObject(l)&&Mt.remove(t,"handle events")}},dispatch:function(t){t=ut.event.fix(t);var e,n,r,o,i,a=[],s=tt.call(arguments),l=(Mt.get(this,"events")||{})[t.type]||[],u=ut.event.special[t.type]||{};if(s[0]=t,t.delegateTarget=this,!u.preDispatch||u.preDispatch.call(this,t)!==!1){for(a=ut.event.handlers.call(this,t,l),e=0;(o=a[e++])&&!t.isPropagationStopped();)for(t.currentTarget=o.elem,n=0;(i=o.handlers[n++])&&!t.isImmediatePropagationStopped();)t.rnamespace&&!t.rnamespace.test(i.namespace)||(t.handleObj=i,t.data=i.data,r=((ut.event.special[i.origType]||{}).handle||i.handler).apply(o.elem,s),void 0!==r&&(t.result=r)===!1&&(t.preventDefault(),t.stopPropagation()));return u.postDispatch&&u.postDispatch.call(this,t),t.result}},handlers:function(t,e){var n,r,o,i,a=[],s=e.delegateCount,l=t.target;if(s&&l.nodeType&&("click"!==t.type||isNaN(t.button)||t.button<1))for(;l!==this;l=l.parentNode||this)if(1===l.nodeType&&(l.disabled!==!0||"click"!==t.type)){for(r=[],n=0;n<s;n++)i=e[n],o=i.selector+" ",void 0===r[o]&&(r[o]=i.needsContext?ut(o,this).index(l)>-1:ut.find(o,this,null,[l]).length),r[o]&&r.push(i);r.length&&a.push({elem:l,handlers:r})}return s<e.length&&a.push({elem:this,handlers:e.slice(s)}),a},props:"altKey bubbles cancelable ctrlKey currentTarget detail eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),fixHooks:{},keyHooks:{props:"char charCode key keyCode".split(" "),filter:function(t,e){return null==t.which&&(t.which=null!=e.charCode?e.charCode:e.keyCode),t}},mouseHooks:{props:"button buttons clientX clientY offsetX offsetY pageX pageY screenX screenY toElement".split(" "),filter:function(t,e){var n,r,o,i=e.button;return null==t.pageX&&null!=e.clientX&&(n=t.target.ownerDocument||Q,r=n.documentElement,o=n.body,t.pageX=e.clientX+(r&&r.scrollLeft||o&&o.scrollLeft||0)-(r&&r.clientLeft||o&&o.clientLeft||0),t.pageY=e.clientY+(r&&r.scrollTop||o&&o.scrollTop||0)-(r&&r.clientTop||o&&o.clientTop||0)),t.which||void 0===i||(t.which=1&i?1:2&i?3:4&i?2:0),t}},fix:function(t){if(t[ut.expando])return t;var e,n,r,o=t.type,i=t,a=this.fixHooks[o];for(a||(this.fixHooks[o]=a=Wt.test(o)?this.mouseHooks:zt.test(o)?this.keyHooks:{}),r=a.props?this.props.concat(a.props):this.props,t=new ut.Event(i),e=r.length;e--;)n=r[e],t[n]=i[n];return t.target||(t.target=Q),3===t.target.nodeType&&(t.target=t.target.parentNode),a.filter?a.filter(t,i):t},special:{load:{noBubble:!0},focus:{trigger:function(){if(this!==b()&&this.focus)return this.focus(),!1},delegateType:"focusin"},blur:{trigger:function(){if(this===b()&&this.blur)return this.blur(),!1},delegateType:"focusout"},click:{trigger:function(){if("checkbox"===this.type&&this.click&&ut.nodeName(this,"input"))return this.click(),!1},_default:function(t){return ut.nodeName(t.target,"a")}},beforeunload:{postDispatch:function(t){void 0!==t.result&&t.originalEvent&&(t.originalEvent.returnValue=t.result)}}}},ut.removeEvent=function(t,e,n){t.removeEventListener&&t.removeEventListener(e,n)},ut.Event=function(t,e){return this instanceof ut.Event?(t&&t.type?(this.originalEvent=t,this.type=t.type,this.isDefaultPrevented=t.defaultPrevented||void 0===t.defaultPrevented&&t.returnValue===!1?m:y):this.type=t,e&&ut.extend(this,e),this.timeStamp=t&&t.timeStamp||ut.now(),void(this[ut.expando]=!0)):new ut.Event(t,e)},ut.Event.prototype={constructor:ut.Event,isDefaultPrevented:y,isPropagationStopped:y,isImmediatePropagationStopped:y,isSimulated:!1,preventDefault:function(){var t=this.originalEvent;this.isDefaultPrevented=m,t&&!this.isSimulated&&t.preventDefault()},stopPropagation:function(){var t=this.originalEvent;this.isPropagationStopped=m,t&&!this.isSimulated&&t.stopPropagation()},stopImmediatePropagation:function(){var t=this.originalEvent;this.isImmediatePropagationStopped=m,t&&!this.isSimulated&&t.stopImmediatePropagation(),this.stopPropagation()}},ut.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(t,e){ut.event.special[t]={delegateType:e,bindType:e,handle:function(t){var n,r=this,o=t.relatedTarget,i=t.handleObj;return o&&(o===r||ut.contains(r,o))||(t.type=i.origType,n=i.handler.apply(this,arguments),t.type=e),n}}}),ut.fn.extend({on:function(t,e,n,r){return x(this,t,e,n,r)},one:function(t,e,n,r){return x(this,t,e,n,r,1)},off:function(t,e,n){var r,o;if(t&&t.preventDefault&&t.handleObj)return r=t.handleObj,ut(t.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof t){for(o in t)this.off(o,e,t[o]);return this}return e!==!1&&"function"!=typeof e||(n=e,e=void 0),n===!1&&(n=y),this.each(function(){ut.event.remove(this,t,n,e)})}});var Vt=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:-]+)[^>]*)\/>/gi,Kt=/<script|<style|<link/i,Yt=/checked\s*(?:[^=]|=\s*.checked.)/i,Gt=/^true\/(.*)/,Xt=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;ut.extend({htmlPrefilter:function(t){return t.replace(Vt,"<$1></$2>")},clone:function(t,e,n){var r,o,i,a,s=t.cloneNode(!0),l=ut.contains(t.ownerDocument,t);if(!(st.noCloneChecked||1!==t.nodeType&&11!==t.nodeType||ut.isXMLDoc(t)))for(a=h(s),i=h(t),r=0,o=i.length;r<o;r++)k(i[r],a[r]);if(e)if(n)for(i=i||h(t),a=a||h(s),r=0,o=i.length;r<o;r++)C(i[r],a[r]);else C(t,s);return a=h(s,"script"),a.length>0&&g(a,!l&&h(t,"script")),s},cleanData:function(t){for(var e,n,r,o=ut.event.special,i=0;void 0!==(n=t[i]);i++)if(St(n)){if(e=n[Mt.expando]){if(e.events)for(r in e.events)o[r]?ut.event.remove(n,r):ut.removeEvent(n,r,e.handle);n[Mt.expando]=void 0}n[Nt.expando]&&(n[Nt.expando]=void 0)}}}),ut.fn.extend({domManip:E,detach:function(t){return P(this,t,!0)},remove:function(t){return P(this,t)},text:function(t){return Pt(this,function(t){return void 0===t?ut.text(this):this.empty().each(function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=t)})},null,t,arguments.length)},append:function(){return E(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=_(this,t);e.appendChild(t)}})},prepend:function(){return E(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=_(this,t);e.insertBefore(t,e.firstChild)}})},before:function(){return E(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this)})},after:function(){return E(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this.nextSibling)})},empty:function(){for(var t,e=0;null!=(t=this[e]);e++)1===t.nodeType&&(ut.cleanData(h(t,!1)),t.textContent="");return this},clone:function(t,e){return t=null!=t&&t,e=null==e?t:e,this.map(function(){return ut.clone(this,t,e)})},html:function(t){return Pt(this,function(t){var e=this[0]||{},n=0,r=this.length;if(void 0===t&&1===e.nodeType)return e.innerHTML;if("string"==typeof t&&!Kt.test(t)&&!Ut[(jt.exec(t)||["",""])[1].toLowerCase()]){t=ut.htmlPrefilter(t);try{for(;n<r;n++)e=this[n]||{},1===e.nodeType&&(ut.cleanData(h(e,!1)),e.innerHTML=t);e=0}catch(t){}}e&&this.empty().append(t)},null,t,arguments.length)},replaceWith:function(){var t=[];return E(this,arguments,function(e){var n=this.parentNode;ut.inArray(this,t)<0&&(ut.cleanData(h(this)),n&&n.replaceChild(e,this))},t)}}),ut.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(t,e){ut.fn[t]=function(t){for(var n,r=[],o=ut(t),i=o.length-1,a=0;a<=i;a++)n=a===i?this:this.clone(!0),ut(o[a])[e](n),nt.apply(r,n.get());return this.pushStack(r)}});var $t,Zt={HTML:"block",BODY:"block"},Jt=/^margin/,Qt=new RegExp("^("+Dt+")(?!px)[a-z%]+$","i"),te=function(t){var e=t.ownerDocument.defaultView;return e&&e.opener||(e=n),e.getComputedStyle(t)},ee=function(t,e,n,r){var o,i,a={};for(i in e)a[i]=t.style[i],t.style[i]=e[i];o=n.apply(t,r||[]);for(i in e)t.style[i]=a[i];return o},ne=Q.documentElement;!function(){function t(){s.style.cssText="-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;position:relative;display:block;margin:auto;border:1px;padding:1px;top:1%;width:50%",s.innerHTML="",ne.appendChild(a);var t=n.getComputedStyle(s);e="1%"!==t.top,i="2px"===t.marginLeft,r="4px"===t.width,s.style.marginRight="50%",o="4px"===t.marginRight,ne.removeChild(a)}var e,r,o,i,a=Q.createElement("div"),s=Q.createElement("div");s.style&&(s.style.backgroundClip="content-box",s.cloneNode(!0).style.backgroundClip="",st.clearCloneStyle="content-box"===s.style.backgroundClip,a.style.cssText="border:0;width:8px;height:0;top:0;left:-9999px;padding:0;margin-top:1px;position:absolute",a.appendChild(s),ut.extend(st,{pixelPosition:function(){return t(),e},boxSizingReliable:function(){return null==r&&t(),r},pixelMarginRight:function(){return null==r&&t(),o},reliableMarginLeft:function(){return null==r&&t(),i},reliableMarginRight:function(){var t,e=s.appendChild(Q.createElement("div"));return e.style.cssText=s.style.cssText="-webkit-box-sizing:content-box;box-sizing:content-box;display:block;margin:0;border:0;padding:0",e.style.marginRight=e.style.width="0",s.style.width="1px",ne.appendChild(a),t=!parseFloat(n.getComputedStyle(e).marginRight),ne.removeChild(a),s.removeChild(e),t}}))}();var re=/^(none|table(?!-c[ea]).+)/,oe={position:"absolute",visibility:"hidden",display:"block"},ie={letterSpacing:"0",fontWeight:"400"},ae=["Webkit","O","Moz","ms"],se=Q.createElement("div").style;ut.extend({cssHooks:{opacity:{get:function(t,e){if(e){var n=N(t,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{float:"cssFloat"},style:function(t,e,n,r){if(t&&3!==t.nodeType&&8!==t.nodeType&&t.style){var o,i,a,s=ut.camelCase(e),l=t.style;return e=ut.cssProps[s]||(ut.cssProps[s]=O(s)||s),a=ut.cssHooks[e]||ut.cssHooks[s],void 0===n?a&&"get"in a&&void 0!==(o=a.get(t,!1,r))?o:l[e]:(i=typeof n,"string"===i&&(o=It.exec(n))&&o[1]&&(n=p(t,e,o),i="number"),null!=n&&n===n&&("number"===i&&(n+=o&&o[3]||(ut.cssNumber[s]?"":"px")),st.clearCloneStyle||""!==n||0!==e.indexOf("background")||(l[e]="inherit"),a&&"set"in a&&void 0===(n=a.set(t,n,r))||(l[e]=n)),void 0)}},css:function(t,e,n,r){var o,i,a,s=ut.camelCase(e);return e=ut.cssProps[s]||(ut.cssProps[s]=O(s)||s),a=ut.cssHooks[e]||ut.cssHooks[s],a&&"get"in a&&(o=a.get(t,!0,n)),void 0===o&&(o=N(t,e,r)),"normal"===o&&e in ie&&(o=ie[e]),""===n||n?(i=parseFloat(o),n===!0||isFinite(i)?i||0:o):o}}),ut.each(["height","width"],function(t,e){ut.cssHooks[e]={get:function(t,n,r){if(n)return re.test(ut.css(t,"display"))&&0===t.offsetWidth?ee(t,oe,function(){return R(t,e,r)}):R(t,e,r)},set:function(t,n,r){var o,i=r&&te(t),a=r&&I(t,e,r,"border-box"===ut.css(t,"boxSizing",!1,i),i);return a&&(o=It.exec(n))&&"px"!==(o[3]||"px")&&(t.style[e]=n,n=ut.css(t,e)),D(t,n,a)}}}),ut.cssHooks.marginLeft=A(st.reliableMarginLeft,function(t,e){if(e)return(parseFloat(N(t,"marginLeft"))||t.getBoundingClientRect().left-ee(t,{marginLeft:0},function(){return t.getBoundingClientRect().left}))+"px"}),ut.cssHooks.marginRight=A(st.reliableMarginRight,function(t,e){if(e)return ee(t,{display:"inline-block"},N,[t,"marginRight"])}),ut.each({margin:"",padding:"",border:"Width"},function(t,e){ut.cssHooks[t+e]={expand:function(n){for(var r=0,o={},i="string"==typeof n?n.split(" "):[n];r<4;r++)o[t+Rt[r]+e]=i[r]||i[r-2]||i[0];return o}},Jt.test(t)||(ut.cssHooks[t+e].set=D)}),ut.fn.extend({css:function(t,e){return Pt(this,function(t,e,n){var r,o,i={},a=0;if(ut.isArray(e)){for(r=te(t),o=e.length;a<o;a++)i[e[a]]=ut.css(t,e[a],!1,r);return i}return void 0!==n?ut.style(t,e,n):ut.css(t,e)},t,e,arguments.length>1)},show:function(){return L(this,!0)},hide:function(){return L(this)},toggle:function(t){return"boolean"==typeof t?t?this.show():this.hide():this.each(function(){Lt(this)?ut(this).show():ut(this).hide()})}}),ut.Tween=F,F.prototype={constructor:F,init:function(t,e,n,r,o,i){this.elem=t,this.prop=n,this.easing=o||ut.easing._default,this.options=e,this.start=this.now=this.cur(),this.end=r,this.unit=i||(ut.cssNumber[n]?"":"px")},cur:function(){var t=F.propHooks[this.prop];return t&&t.get?t.get(this):F.propHooks._default.get(this)},run:function(t){var e,n=F.propHooks[this.prop];return this.options.duration?this.pos=e=ut.easing[this.easing](t,this.options.duration*t,0,1,this.options.duration):this.pos=e=t,this.now=(this.end-this.start)*e+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):F.propHooks._default.set(this),this}},F.prototype.init.prototype=F.prototype,F.propHooks={_default:{get:function(t){var e;return 1!==t.elem.nodeType||null!=t.elem[t.prop]&&null==t.elem.style[t.prop]?t.elem[t.prop]:(e=ut.css(t.elem,t.prop,""),e&&"auto"!==e?e:0)},set:function(t){ut.fx.step[t.prop]?ut.fx.step[t.prop](t):1!==t.elem.nodeType||null==t.elem.style[ut.cssProps[t.prop]]&&!ut.cssHooks[t.prop]?t.elem[t.prop]=t.now:ut.style(t.elem,t.prop,t.now+t.unit)}}},F.propHooks.scrollTop=F.propHooks.scrollLeft={set:function(t){t.elem.nodeType&&t.elem.parentNode&&(t.elem[t.prop]=t.now)}},ut.easing={linear:function(t){return t},swing:function(t){return.5-Math.cos(t*Math.PI)/2},_default:"swing"},ut.fx=F.prototype.init,ut.fx.step={};var le,ue,ce=/^(?:toggle|show|hide)$/,fe=/queueHooks$/;ut.Animation=ut.extend(W,{tweeners:{"*":[function(t,e){var n=this.createTween(t,e);return p(n.elem,t,It.exec(e),n),n}]},tweener:function(t,e){ut.isFunction(t)?(e=t,t=["*"]):t=t.match(kt);for(var n,r=0,o=t.length;r<o;r++)n=t[r],W.tweeners[n]=W.tweeners[n]||[],W.tweeners[n].unshift(e)},prefilters:[H],prefilter:function(t,e){e?W.prefilters.unshift(t):W.prefilters.push(t)}}),ut.speed=function(t,e,n){var r=t&&"object"==typeof t?ut.extend({},t):{complete:n||!n&&e||ut.isFunction(t)&&t,duration:t,easing:n&&e||e&&!ut.isFunction(e)&&e};return r.duration=ut.fx.off?0:"number"==typeof r.duration?r.duration:r.duration in ut.fx.speeds?ut.fx.speeds[r.duration]:ut.fx.speeds._default,null!=r.queue&&r.queue!==!0||(r.queue="fx"),r.old=r.complete,r.complete=function(){ut.isFunction(r.old)&&r.old.call(this),r.queue&&ut.dequeue(this,r.queue)},r},ut.fn.extend({fadeTo:function(t,e,n,r){return this.filter(Lt).css("opacity",0).show().end().animate({opacity:e},t,n,r)},animate:function(t,e,n,r){var o=ut.isEmptyObject(t),i=ut.speed(e,n,r),a=function(){var e=W(this,ut.extend({},t),i);(o||Mt.get(this,"finish"))&&e.stop(!0)};return a.finish=a,o||i.queue===!1?this.each(a):this.queue(i.queue,a)},stop:function(t,e,n){var r=function(t){var e=t.stop;delete t.stop,e(n)};return"string"!=typeof t&&(n=e,e=t,t=void 0),e&&t!==!1&&this.queue(t||"fx",[]),this.each(function(){var e=!0,o=null!=t&&t+"queueHooks",i=ut.timers,a=Mt.get(this);if(o)a[o]&&a[o].stop&&r(a[o]);else for(o in a)a[o]&&a[o].stop&&fe.test(o)&&r(a[o]);for(o=i.length;o--;)i[o].elem!==this||null!=t&&i[o].queue!==t||(i[o].anim.stop(n),e=!1,i.splice(o,1));!e&&n||ut.dequeue(this,t)})},finish:function(t){return t!==!1&&(t=t||"fx"),this.each(function(){var e,n=Mt.get(this),r=n[t+"queue"],o=n[t+"queueHooks"],i=ut.timers,a=r?r.length:0;for(n.finish=!0,ut.queue(this,t,[]),o&&o.stop&&o.stop.call(this,!0),e=i.length;e--;)i[e].elem===this&&i[e].queue===t&&(i[e].anim.stop(!0),i.splice(e,1));for(e=0;e<a;e++)r[e]&&r[e].finish&&r[e].finish.call(this);delete n.finish})}}),ut.each(["toggle","show","hide"],function(t,e){var n=ut.fn[e];ut.fn[e]=function(t,r,o){return null==t||"boolean"==typeof t?n.apply(this,arguments):this.animate(B(e,!0),t,r,o)}}),ut.each({slideDown:B("show"),slideUp:B("hide"),slideToggle:B("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(t,e){ut.fn[t]=function(t,n,r){return this.animate(e,t,n,r)}}),ut.timers=[],ut.fx.tick=function(){var t,e=0,n=ut.timers;for(le=ut.now();e<n.length;e++)t=n[e],t()||n[e]!==t||n.splice(e--,1);n.length||ut.fx.stop(),le=void 0},ut.fx.timer=function(t){ut.timers.push(t),t()?ut.fx.start():ut.timers.pop()},ut.fx.interval=13,ut.fx.start=function(){ue||(ue=n.setInterval(ut.fx.tick,ut.fx.interval))},ut.fx.stop=function(){n.clearInterval(ue),ue=null},ut.fx.speeds={slow:600,fast:200,_default:400},ut.fn.delay=function(t,e){return t=ut.fx?ut.fx.speeds[t]||t:t,e=e||"fx",this.queue(e,function(e,r){var o=n.setTimeout(e,t);r.stop=function(){n.clearTimeout(o)}})},function(){var t=Q.createElement("input"),e=Q.createElement("select"),n=e.appendChild(Q.createElement("option"));t.type="checkbox",st.checkOn=""!==t.value,st.optSelected=n.selected,e.disabled=!0,st.optDisabled=!n.disabled,t=Q.createElement("input"),t.value="t",t.type="radio",st.radioValue="t"===t.value}();var de,pe=ut.expr.attrHandle;ut.fn.extend({attr:function(t,e){return Pt(this,ut.attr,t,e,arguments.length>1)},removeAttr:function(t){return this.each(function(){ut.removeAttr(this,t)})}}),ut.extend({attr:function(t,e,n){var r,o,i=t.nodeType;if(3!==i&&8!==i&&2!==i)return"undefined"==typeof t.getAttribute?ut.prop(t,e,n):(1===i&&ut.isXMLDoc(t)||(e=e.toLowerCase(),o=ut.attrHooks[e]||(ut.expr.match.bool.test(e)?de:void 0)),void 0!==n?null===n?void ut.removeAttr(t,e):o&&"set"in o&&void 0!==(r=o.set(t,n,e))?r:(t.setAttribute(e,n+""),n):o&&"get"in o&&null!==(r=o.get(t,e))?r:(r=ut.find.attr(t,e),null==r?void 0:r))},attrHooks:{type:{set:function(t,e){if(!st.radioValue&&"radio"===e&&ut.nodeName(t,"input")){var n=t.value;return t.setAttribute("type",e),n&&(t.value=n),e}}}},removeAttr:function(t,e){var n,r,o=0,i=e&&e.match(kt);if(i&&1===t.nodeType)for(;n=i[o++];)r=ut.propFix[n]||n,ut.expr.match.bool.test(n)&&(t[r]=!1),t.removeAttribute(n)}}),de={set:function(t,e,n){return e===!1?ut.removeAttr(t,n):t.setAttribute(n,n),n}},ut.each(ut.expr.match.bool.source.match(/\w+/g),function(t,e){var n=pe[e]||ut.find.attr;pe[e]=function(t,e,r){var o,i;return r||(i=pe[e],pe[e]=o,o=null!=n(t,e,r)?e.toLowerCase():null,pe[e]=i),o}});var he=/^(?:input|select|textarea|button)$/i,ge=/^(?:a|area)$/i;ut.fn.extend({prop:function(t,e){return Pt(this,ut.prop,t,e,arguments.length>1)},removeProp:function(t){return this.each(function(){delete this[ut.propFix[t]||t]})}}),ut.extend({prop:function(t,e,n){var r,o,i=t.nodeType;if(3!==i&&8!==i&&2!==i)return 1===i&&ut.isXMLDoc(t)||(e=ut.propFix[e]||e,o=ut.propHooks[e]),void 0!==n?o&&"set"in o&&void 0!==(r=o.set(t,n,e))?r:t[e]=n:o&&"get"in o&&null!==(r=o.get(t,e))?r:t[e]},propHooks:{tabIndex:{get:function(t){var e=ut.find.attr(t,"tabindex");return e?parseInt(e,10):he.test(t.nodeName)||ge.test(t.nodeName)&&t.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),st.optSelected||(ut.propHooks.selected={get:function(t){var e=t.parentNode;return e&&e.parentNode&&e.parentNode.selectedIndex,null},set:function(t){var e=t.parentNode;e&&(e.selectedIndex,e.parentNode&&e.parentNode.selectedIndex)}}),ut.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){ut.propFix[this.toLowerCase()]=this});var ve=/[\t\r\n\f]/g;ut.fn.extend({addClass:function(t){var e,n,r,o,i,a,s,l=0;if(ut.isFunction(t))return this.each(function(e){ut(this).addClass(t.call(this,e,q(this)))});if("string"==typeof t&&t)for(e=t.match(kt)||[];n=this[l++];)if(o=q(n),r=1===n.nodeType&&(" "+o+" ").replace(ve," ")){for(a=0;i=e[a++];)r.indexOf(" "+i+" ")<0&&(r+=i+" ");s=ut.trim(r),o!==s&&n.setAttribute("class",s)}return this},removeClass:function(t){var e,n,r,o,i,a,s,l=0;if(ut.isFunction(t))return this.each(function(e){ut(this).removeClass(t.call(this,e,q(this)))});if(!arguments.length)return this.attr("class","");if("string"==typeof t&&t)for(e=t.match(kt)||[];n=this[l++];)if(o=q(n),r=1===n.nodeType&&(" "+o+" ").replace(ve," ")){for(a=0;i=e[a++];)for(;r.indexOf(" "+i+" ")>-1;)r=r.replace(" "+i+" "," ");s=ut.trim(r),o!==s&&n.setAttribute("class",s)}return this},toggleClass:function(t,e){var n=typeof t;return"boolean"==typeof e&&"string"===n?e?this.addClass(t):this.removeClass(t):ut.isFunction(t)?this.each(function(n){ut(this).toggleClass(t.call(this,n,q(this),e),e)}):this.each(function(){var e,r,o,i;if("string"===n)for(r=0,o=ut(this),i=t.match(kt)||[];e=i[r++];)o.hasClass(e)?o.removeClass(e):o.addClass(e);else void 0!==t&&"boolean"!==n||(e=q(this),e&&Mt.set(this,"__className__",e),this.setAttribute&&this.setAttribute("class",e||t===!1?"":Mt.get(this,"__className__")||""))})},hasClass:function(t){var e,n,r=0;for(e=" "+t+" ";n=this[r++];)if(1===n.nodeType&&(" "+q(n)+" ").replace(ve," ").indexOf(e)>-1)return!0;return!1}});var me=/\r/g,ye=/[\x20\t\r\n\f]+/g;ut.fn.extend({val:function(t){var e,n,r,o=this[0];{if(arguments.length)return r=ut.isFunction(t),this.each(function(n){var o;1===this.nodeType&&(o=r?t.call(this,n,ut(this).val()):t,null==o?o="":"number"==typeof o?o+="":ut.isArray(o)&&(o=ut.map(o,function(t){return null==t?"":t+""})),e=ut.valHooks[this.type]||ut.valHooks[this.nodeName.toLowerCase()],e&&"set"in e&&void 0!==e.set(this,o,"value")||(this.value=o))});if(o)return e=ut.valHooks[o.type]||ut.valHooks[o.nodeName.toLowerCase()],e&&"get"in e&&void 0!==(n=e.get(o,"value"))?n:(n=o.value,"string"==typeof n?n.replace(me,""):null==n?"":n)}}}),ut.extend({valHooks:{option:{get:function(t){var e=ut.find.attr(t,"value");return null!=e?e:ut.trim(ut.text(t)).replace(ye," ")}},select:{get:function(t){for(var e,n,r=t.options,o=t.selectedIndex,i="select-one"===t.type||o<0,a=i?null:[],s=i?o+1:r.length,l=o<0?s:i?o:0;l<s;l++)if(n=r[l],(n.selected||l===o)&&(st.optDisabled?!n.disabled:null===n.getAttribute("disabled"))&&(!n.parentNode.disabled||!ut.nodeName(n.parentNode,"optgroup"))){if(e=ut(n).val(),i)return e;a.push(e)}return a},set:function(t,e){for(var n,r,o=t.options,i=ut.makeArray(e),a=o.length;a--;)r=o[a],(r.selected=ut.inArray(ut.valHooks.option.get(r),i)>-1)&&(n=!0);return n||(t.selectedIndex=-1),i}}}}),ut.each(["radio","checkbox"],function(){ut.valHooks[this]={set:function(t,e){if(ut.isArray(e))return t.checked=ut.inArray(ut(t).val(),e)>-1}},st.checkOn||(ut.valHooks[this].get=function(t){return null===t.getAttribute("value")?"on":t.value})});var be=/^(?:focusinfocus|focusoutblur)$/;ut.extend(ut.event,{trigger:function(t,e,r,o){var i,a,s,l,u,c,f,d=[r||Q],p=at.call(t,"type")?t.type:t,h=at.call(t,"namespace")?t.namespace.split("."):[];if(a=s=r=r||Q,3!==r.nodeType&&8!==r.nodeType&&!be.test(p+ut.event.triggered)&&(p.indexOf(".")>-1&&(h=p.split("."),p=h.shift(),h.sort()),u=p.indexOf(":")<0&&"on"+p,t=t[ut.expando]?t:new ut.Event(p,"object"==typeof t&&t),t.isTrigger=o?2:3,t.namespace=h.join("."),t.rnamespace=t.namespace?new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,t.result=void 0,t.target||(t.target=r),e=null==e?[t]:ut.makeArray(e,[t]),f=ut.event.special[p]||{},o||!f.trigger||f.trigger.apply(r,e)!==!1)){if(!o&&!f.noBubble&&!ut.isWindow(r)){for(l=f.delegateType||p,be.test(l+p)||(a=a.parentNode);a;a=a.parentNode)d.push(a),s=a;s===(r.ownerDocument||Q)&&d.push(s.defaultView||s.parentWindow||n)}for(i=0;(a=d[i++])&&!t.isPropagationStopped();)t.type=i>1?l:f.bindType||p,c=(Mt.get(a,"events")||{})[t.type]&&Mt.get(a,"handle"),c&&c.apply(a,e),c=u&&a[u],c&&c.apply&&St(a)&&(t.result=c.apply(a,e),t.result===!1&&t.preventDefault());return t.type=p,o||t.isDefaultPrevented()||f._default&&f._default.apply(d.pop(),e)!==!1||!St(r)||u&&ut.isFunction(r[p])&&!ut.isWindow(r)&&(s=r[u],s&&(r[u]=null),ut.event.triggered=p,r[p](),ut.event.triggered=void 0,s&&(r[u]=s)),t.result}},simulate:function(t,e,n){var r=ut.extend(new ut.Event,n,{type:t,isSimulated:!0});ut.event.trigger(r,null,e)}}),ut.fn.extend({trigger:function(t,e){return this.each(function(){ut.event.trigger(t,e,this)})},triggerHandler:function(t,e){var n=this[0];if(n)return ut.event.trigger(t,e,n,!0)}}),ut.each("blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error contextmenu".split(" "),function(t,e){ut.fn[e]=function(t,n){return arguments.length>0?this.on(e,null,t,n):this.trigger(e)}}),ut.fn.extend({hover:function(t,e){return this.mouseenter(t).mouseleave(e||t)}}),st.focusin="onfocusin"in n,st.focusin||ut.each({focus:"focusin",blur:"focusout"},function(t,e){var n=function(t){ut.event.simulate(e,t.target,ut.event.fix(t))};ut.event.special[e]={setup:function(){var r=this.ownerDocument||this,o=Mt.access(r,e);o||r.addEventListener(t,n,!0),Mt.access(r,e,(o||0)+1)},teardown:function(){var r=this.ownerDocument||this,o=Mt.access(r,e)-1;o?Mt.access(r,e,o):(r.removeEventListener(t,n,!0),Mt.remove(r,e))}}});var xe=n.location,_e=ut.now(),we=/\?/;ut.parseJSON=function(t){return JSON.parse(t+"")},ut.parseXML=function(t){var e;if(!t||"string"!=typeof t)return null;try{e=(new n.DOMParser).parseFromString(t,"text/xml")}catch(t){e=void 0}return e&&!e.getElementsByTagName("parsererror").length||ut.error("Invalid XML: "+t),e};var Te=/#.*$/,Ce=/([?&])_=[^&]*/,ke=/^(.*?):[ \t]*([^\r\n]*)$/gm,Ee=/^(?:about|app|app-storage|.+-extension|file|res|widget):$/,Pe=/^(?:GET|HEAD)$/,Se=/^\/\//,Me={},Ne={},Ae="*/".concat("*"),Oe=Q.createElement("a");Oe.href=xe.href,ut.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:xe.href,type:"GET",isLocal:Ee.test(xe.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":Ae,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":ut.parseJSON,"text xml":ut.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(t,e){return e?Y(Y(t,ut.ajaxSettings),e):Y(ut.ajaxSettings,t)},ajaxPrefilter:V(Me),ajaxTransport:V(Ne),ajax:function(t,e){function r(t,e,r,s){var u,f,y,b,_,T=e;2!==x&&(x=2,l&&n.clearTimeout(l),o=void 0,a=s||"",w.readyState=t>0?4:0,u=t>=200&&t<300||304===t,r&&(b=G(d,w,r)),b=X(d,b,w,u),u?(d.ifModified&&(_=w.getResponseHeader("Last-Modified"),_&&(ut.lastModified[i]=_),_=w.getResponseHeader("etag"),_&&(ut.etag[i]=_)),204===t||"HEAD"===d.type?T="nocontent":304===t?T="notmodified":(T=b.state,f=b.data,y=b.error,u=!y)):(y=T,!t&&T||(T="error",t<0&&(t=0))),w.status=t,w.statusText=(e||T)+"",u?g.resolveWith(p,[f,T,w]):g.rejectWith(p,[w,T,y]),w.statusCode(m),m=void 0,c&&h.trigger(u?"ajaxSuccess":"ajaxError",[w,d,u?f:y]),v.fireWith(p,[w,T]),c&&(h.trigger("ajaxComplete",[w,d]),--ut.active||ut.event.trigger("ajaxStop")))}"object"==typeof t&&(e=t,t=void 0),e=e||{};var o,i,a,s,l,u,c,f,d=ut.ajaxSetup({},e),p=d.context||d,h=d.context&&(p.nodeType||p.jquery)?ut(p):ut.event,g=ut.Deferred(),v=ut.Callbacks("once memory"),m=d.statusCode||{},y={},b={},x=0,_="canceled",w={readyState:0,getResponseHeader:function(t){var e;if(2===x){if(!s)for(s={};e=ke.exec(a);)s[e[1].toLowerCase()]=e[2];e=s[t.toLowerCase()]}return null==e?null:e},getAllResponseHeaders:function(){return 2===x?a:null},setRequestHeader:function(t,e){var n=t.toLowerCase();return x||(t=b[n]=b[n]||t,y[t]=e),this},overrideMimeType:function(t){return x||(d.mimeType=t),this},statusCode:function(t){var e;if(t)if(x<2)for(e in t)m[e]=[m[e],t[e]];else w.always(t[w.status]);return this},abort:function(t){var e=t||_;return o&&o.abort(e),r(0,e),this}};if(g.promise(w).complete=v.add,w.success=w.done,w.error=w.fail,d.url=((t||d.url||xe.href)+"").replace(Te,"").replace(Se,xe.protocol+"//"),d.type=e.method||e.type||d.method||d.type,d.dataTypes=ut.trim(d.dataType||"*").toLowerCase().match(kt)||[""],null==d.crossDomain){u=Q.createElement("a");try{u.href=d.url,u.href=u.href,d.crossDomain=Oe.protocol+"//"+Oe.host!=u.protocol+"//"+u.host}catch(t){d.crossDomain=!0}}if(d.data&&d.processData&&"string"!=typeof d.data&&(d.data=ut.param(d.data,d.traditional)),K(Me,d,e,w),2===x)return w;c=ut.event&&d.global,c&&0===ut.active++&&ut.event.trigger("ajaxStart"),d.type=d.type.toUpperCase(),d.hasContent=!Pe.test(d.type),i=d.url,d.hasContent||(d.data&&(i=d.url+=(we.test(i)?"&":"?")+d.data,delete d.data),d.cache===!1&&(d.url=Ce.test(i)?i.replace(Ce,"$1_="+_e++):i+(we.test(i)?"&":"?")+"_="+_e++)),d.ifModified&&(ut.lastModified[i]&&w.setRequestHeader("If-Modified-Since",ut.lastModified[i]),ut.etag[i]&&w.setRequestHeader("If-None-Match",ut.etag[i])),(d.data&&d.hasContent&&d.contentType!==!1||e.contentType)&&w.setRequestHeader("Content-Type",d.contentType),w.setRequestHeader("Accept",d.dataTypes[0]&&d.accepts[d.dataTypes[0]]?d.accepts[d.dataTypes[0]]+("*"!==d.dataTypes[0]?", "+Ae+"; q=0.01":""):d.accepts["*"]);for(f in d.headers)w.setRequestHeader(f,d.headers[f]);if(d.beforeSend&&(d.beforeSend.call(p,w,d)===!1||2===x))return w.abort();_="abort";for(f in{success:1,error:1,complete:1})w[f](d[f]);if(o=K(Ne,d,e,w)){if(w.readyState=1,c&&h.trigger("ajaxSend",[w,d]),2===x)return w;d.async&&d.timeout>0&&(l=n.setTimeout(function(){w.abort("timeout")},d.timeout));try{x=1,o.send(y,r)}catch(t){if(!(x<2))throw t;r(-1,t)}}else r(-1,"No Transport");return w},getJSON:function(t,e,n){return ut.get(t,e,n,"json")},getScript:function(t,e){return ut.get(t,void 0,e,"script")}}),ut.each(["get","post"],function(t,e){ut[e]=function(t,n,r,o){return ut.isFunction(n)&&(o=o||r,r=n,n=void 0),ut.ajax(ut.extend({url:t,type:e,dataType:o,data:n,success:r},ut.isPlainObject(t)&&t))}}),ut._evalUrl=function(t){return ut.ajax({url:t,type:"GET",dataType:"script",async:!1,global:!1,throws:!0})},ut.fn.extend({wrapAll:function(t){var e;return ut.isFunction(t)?this.each(function(e){ut(this).wrapAll(t.call(this,e))}):(this[0]&&(e=ut(t,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&e.insertBefore(this[0]),e.map(function(){for(var t=this;t.firstElementChild;)t=t.firstElementChild;return t}).append(this)),this)},wrapInner:function(t){return ut.isFunction(t)?this.each(function(e){ut(this).wrapInner(t.call(this,e))}):this.each(function(){var e=ut(this),n=e.contents();n.length?n.wrapAll(t):e.append(t)})},wrap:function(t){var e=ut.isFunction(t);return this.each(function(n){ut(this).wrapAll(e?t.call(this,n):t)})},unwrap:function(){return this.parent().each(function(){ut.nodeName(this,"body")||ut(this).replaceWith(this.childNodes)}).end()}}),ut.expr.filters.hidden=function(t){return!ut.expr.filters.visible(t)},ut.expr.filters.visible=function(t){return t.offsetWidth>0||t.offsetHeight>0||t.getClientRects().length>0};var De=/%20/g,Ie=/\[\]$/,Re=/\r?\n/g,Le=/^(?:submit|button|image|reset|file)$/i,Fe=/^(?:input|select|textarea|keygen)/i;ut.param=function(t,e){var n,r=[],o=function(t,e){e=ut.isFunction(e)?e():null==e?"":e,r[r.length]=encodeURIComponent(t)+"="+encodeURIComponent(e)};if(void 0===e&&(e=ut.ajaxSettings&&ut.ajaxSettings.traditional),ut.isArray(t)||t.jquery&&!ut.isPlainObject(t))ut.each(t,function(){o(this.name,this.value)});else for(n in t)$(n,t[n],e,o);return r.join("&").replace(De,"+")},ut.fn.extend({serialize:function(){return ut.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var t=ut.prop(this,"elements");return t?ut.makeArray(t):this}).filter(function(){var t=this.type;return this.name&&!ut(this).is(":disabled")&&Fe.test(this.nodeName)&&!Le.test(t)&&(this.checked||!Ft.test(t))}).map(function(t,e){var n=ut(this).val();return null==n?null:ut.isArray(n)?ut.map(n,function(t){return{name:e.name,value:t.replace(Re,"\r\n")}}):{name:e.name,value:n.replace(Re,"\r\n")}}).get()}}),ut.ajaxSettings.xhr=function(){try{return new n.XMLHttpRequest}catch(t){}};var je={0:200,1223:204},Be=ut.ajaxSettings.xhr();st.cors=!!Be&&"withCredentials"in Be,st.ajax=Be=!!Be,ut.ajaxTransport(function(t){var e,r;if(st.cors||Be&&!t.crossDomain)return{send:function(o,i){var a,s=t.xhr();if(s.open(t.type,t.url,t.async,t.username,t.password),t.xhrFields)for(a in t.xhrFields)s[a]=t.xhrFields[a];t.mimeType&&s.overrideMimeType&&s.overrideMimeType(t.mimeType),t.crossDomain||o["X-Requested-With"]||(o["X-Requested-With"]="XMLHttpRequest");
for(a in o)s.setRequestHeader(a,o[a]);e=function(t){return function(){e&&(e=r=s.onload=s.onerror=s.onabort=s.onreadystatechange=null,"abort"===t?s.abort():"error"===t?"number"!=typeof s.status?i(0,"error"):i(s.status,s.statusText):i(je[s.status]||s.status,s.statusText,"text"!==(s.responseType||"text")||"string"!=typeof s.responseText?{binary:s.response}:{text:s.responseText},s.getAllResponseHeaders()))}},s.onload=e(),r=s.onerror=e("error"),void 0!==s.onabort?s.onabort=r:s.onreadystatechange=function(){4===s.readyState&&n.setTimeout(function(){e&&r()})},e=e("abort");try{s.send(t.hasContent&&t.data||null)}catch(t){if(e)throw t}},abort:function(){e&&e()}}}),ut.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(t){return ut.globalEval(t),t}}}),ut.ajaxPrefilter("script",function(t){void 0===t.cache&&(t.cache=!1),t.crossDomain&&(t.type="GET")}),ut.ajaxTransport("script",function(t){if(t.crossDomain){var e,n;return{send:function(r,o){e=ut("<script>").prop({charset:t.scriptCharset,src:t.url}).on("load error",n=function(t){e.remove(),n=null,t&&o("error"===t.type?404:200,t.type)}),Q.head.appendChild(e[0])},abort:function(){n&&n()}}}});var Ue=[],He=/(=)\?(?=&|$)|\?\?/;ut.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var t=Ue.pop()||ut.expando+"_"+_e++;return this[t]=!0,t}}),ut.ajaxPrefilter("json jsonp",function(t,e,r){var o,i,a,s=t.jsonp!==!1&&(He.test(t.url)?"url":"string"==typeof t.data&&0===(t.contentType||"").indexOf("application/x-www-form-urlencoded")&&He.test(t.data)&&"data");if(s||"jsonp"===t.dataTypes[0])return o=t.jsonpCallback=ut.isFunction(t.jsonpCallback)?t.jsonpCallback():t.jsonpCallback,s?t[s]=t[s].replace(He,"$1"+o):t.jsonp!==!1&&(t.url+=(we.test(t.url)?"&":"?")+t.jsonp+"="+o),t.converters["script json"]=function(){return a||ut.error(o+" was not called"),a[0]},t.dataTypes[0]="json",i=n[o],n[o]=function(){a=arguments},r.always(function(){void 0===i?ut(n).removeProp(o):n[o]=i,t[o]&&(t.jsonpCallback=e.jsonpCallback,Ue.push(o)),a&&ut.isFunction(i)&&i(a[0]),a=i=void 0}),"script"}),ut.parseHTML=function(t,e,n){if(!t||"string"!=typeof t)return null;"boolean"==typeof e&&(n=e,e=!1),e=e||Q;var r=yt.exec(t),o=!n&&[];return r?[e.createElement(r[1])]:(r=v([t],e,o),o&&o.length&&ut(o).remove(),ut.merge([],r.childNodes))};var ze=ut.fn.load;ut.fn.load=function(t,e,n){if("string"!=typeof t&&ze)return ze.apply(this,arguments);var r,o,i,a=this,s=t.indexOf(" ");return s>-1&&(r=ut.trim(t.slice(s)),t=t.slice(0,s)),ut.isFunction(e)?(n=e,e=void 0):e&&"object"==typeof e&&(o="POST"),a.length>0&&ut.ajax({url:t,type:o||"GET",dataType:"html",data:e}).done(function(t){i=arguments,a.html(r?ut("<div>").append(ut.parseHTML(t)).find(r):t)}).always(n&&function(t,e){a.each(function(){n.apply(this,i||[t.responseText,e,t])})}),this},ut.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(t,e){ut.fn[e]=function(t){return this.on(e,t)}}),ut.expr.filters.animated=function(t){return ut.grep(ut.timers,function(e){return t===e.elem}).length},ut.offset={setOffset:function(t,e,n){var r,o,i,a,s,l,u,c=ut.css(t,"position"),f=ut(t),d={};"static"===c&&(t.style.position="relative"),s=f.offset(),i=ut.css(t,"top"),l=ut.css(t,"left"),u=("absolute"===c||"fixed"===c)&&(i+l).indexOf("auto")>-1,u?(r=f.position(),a=r.top,o=r.left):(a=parseFloat(i)||0,o=parseFloat(l)||0),ut.isFunction(e)&&(e=e.call(t,n,ut.extend({},s))),null!=e.top&&(d.top=e.top-s.top+a),null!=e.left&&(d.left=e.left-s.left+o),"using"in e?e.using.call(t,d):f.css(d)}},ut.fn.extend({offset:function(t){if(arguments.length)return void 0===t?this:this.each(function(e){ut.offset.setOffset(this,t,e)});var e,n,r=this[0],o={top:0,left:0},i=r&&r.ownerDocument;if(i)return e=i.documentElement,ut.contains(e,r)?(o=r.getBoundingClientRect(),n=Z(i),{top:o.top+n.pageYOffset-e.clientTop,left:o.left+n.pageXOffset-e.clientLeft}):o},position:function(){if(this[0]){var t,e,n=this[0],r={top:0,left:0};return"fixed"===ut.css(n,"position")?e=n.getBoundingClientRect():(t=this.offsetParent(),e=this.offset(),ut.nodeName(t[0],"html")||(r=t.offset()),r.top+=ut.css(t[0],"borderTopWidth",!0),r.left+=ut.css(t[0],"borderLeftWidth",!0)),{top:e.top-r.top-ut.css(n,"marginTop",!0),left:e.left-r.left-ut.css(n,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){for(var t=this.offsetParent;t&&"static"===ut.css(t,"position");)t=t.offsetParent;return t||ne})}}),ut.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(t,e){var n="pageYOffset"===e;ut.fn[t]=function(r){return Pt(this,function(t,r,o){var i=Z(t);return void 0===o?i?i[e]:t[r]:void(i?i.scrollTo(n?i.pageXOffset:o,n?o:i.pageYOffset):t[r]=o)},t,r,arguments.length)}}),ut.each(["top","left"],function(t,e){ut.cssHooks[e]=A(st.pixelPosition,function(t,n){if(n)return n=N(t,e),Qt.test(n)?ut(t).position()[e]+"px":n})}),ut.each({Height:"height",Width:"width"},function(t,e){ut.each({padding:"inner"+t,content:e,"":"outer"+t},function(n,r){ut.fn[r]=function(r,o){var i=arguments.length&&(n||"boolean"!=typeof r),a=n||(r===!0||o===!0?"margin":"border");return Pt(this,function(e,n,r){var o;return ut.isWindow(e)?e.document.documentElement["client"+t]:9===e.nodeType?(o=e.documentElement,Math.max(e.body["scroll"+t],o["scroll"+t],e.body["offset"+t],o["offset"+t],o["client"+t])):void 0===r?ut.css(e,n,a):ut.style(e,n,r,a)},e,i?r:void 0,i,null)}})}),ut.fn.extend({bind:function(t,e,n){return this.on(t,null,e,n)},unbind:function(t,e){return this.off(t,null,e)},delegate:function(t,e,n,r){return this.on(e,t,n,r)},undelegate:function(t,e,n){return 1===arguments.length?this.off(t,"**"):this.off(e,t||"**",n)},size:function(){return this.length}}),ut.fn.andSelf=ut.fn.addBack,r=[],o=function(){return ut}.apply(e,r),!(void 0!==o&&(t.exports=o));var We=n.jQuery,qe=n.$;return ut.noConflict=function(t){return n.$===ut&&(n.$=qe),t&&n.jQuery===ut&&(n.jQuery=We),ut},i||(n.jQuery=n.$=ut),ut})},function(t,e,n){"use strict";t.exports=n(4)},function(t,e,n){"use strict";var r=n(5),o=n(6),i=n(19),a=n(22),s=n(23),l=n(25),u=n(10),c=n(26),f=n(28),d=n(29),p=(n(12),u.createElement),h=u.createFactory,g=u.cloneElement,v=r,m={Children:{map:o.map,forEach:o.forEach,count:o.count,toArray:o.toArray,only:d},Component:i,PureComponent:a,createElement:p,cloneElement:g,isValidElement:u.isValidElement,PropTypes:c,createClass:s.createClass,createFactory:h,createMixin:function(t){return t},DOM:l,version:f,__spread:v};t.exports=m},function(t,e){"use strict";function n(t){if(null===t||void 0===t)throw new TypeError("Object.assign cannot be called with null or undefined");return Object(t)}function r(){try{if(!Object.assign)return!1;var t=new String("abc");if(t[5]="de","5"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},n=0;n<10;n++)e["_"+String.fromCharCode(n)]=n;var r=Object.getOwnPropertyNames(e).map(function(t){return e[t]});if("0123456789"!==r.join(""))return!1;var o={};return"abcdefghijklmnopqrst".split("").forEach(function(t){o[t]=t}),"abcdefghijklmnopqrst"===Object.keys(Object.assign({},o)).join("")}catch(t){return!1}}var o=Object.prototype.hasOwnProperty,i=Object.prototype.propertyIsEnumerable;t.exports=r()?Object.assign:function(t,e){for(var r,a,s=n(t),l=1;l<arguments.length;l++){r=Object(arguments[l]);for(var u in r)o.call(r,u)&&(s[u]=r[u]);if(Object.getOwnPropertySymbols){a=Object.getOwnPropertySymbols(r);for(var c=0;c<a.length;c++)i.call(r,a[c])&&(s[a[c]]=r[a[c]])}}return s}},function(t,e,n){"use strict";function r(t){return(""+t).replace(x,"$&/")}function o(t,e){this.func=t,this.context=e,this.count=0}function i(t,e,n){var r=t.func,o=t.context;r.call(o,e,t.count++)}function a(t,e,n){if(null==t)return t;var r=o.getPooled(e,n);m(t,i,r),o.release(r)}function s(t,e,n,r){this.result=t,this.keyPrefix=e,this.func=n,this.context=r,this.count=0}function l(t,e,n){var o=t.result,i=t.keyPrefix,a=t.func,s=t.context,l=a.call(s,e,t.count++);Array.isArray(l)?u(l,o,n,v.thatReturnsArgument):null!=l&&(g.isValidElement(l)&&(l=g.cloneAndReplaceKey(l,i+(!l.key||e&&e.key===l.key?"":r(l.key)+"/")+n)),o.push(l))}function u(t,e,n,o,i){var a="";null!=n&&(a=r(n)+"/");var u=s.getPooled(e,a,o,i);m(t,l,u),s.release(u)}function c(t,e,n){if(null==t)return t;var r=[];return u(t,r,null,e,n),r}function f(t,e,n){return null}function d(t,e){return m(t,f,null)}function p(t){var e=[];return u(t,e,null,v.thatReturnsArgument),e}var h=n(7),g=n(10),v=n(13),m=n(16),y=h.twoArgumentPooler,b=h.fourArgumentPooler,x=/\/+/g;o.prototype.destructor=function(){this.func=null,this.context=null,this.count=0},h.addPoolingTo(o,y),s.prototype.destructor=function(){this.result=null,this.keyPrefix=null,this.func=null,this.context=null,this.count=0},h.addPoolingTo(s,b);var _={forEach:a,map:c,mapIntoWithKeyPrefixInternal:u,count:d,toArray:p};t.exports=_},function(t,e,n){"use strict";var r=n(8),o=(n(9),function(t){var e=this;if(e.instancePool.length){var n=e.instancePool.pop();return e.call(n,t),n}return new e(t)}),i=function(t,e){var n=this;if(n.instancePool.length){var r=n.instancePool.pop();return n.call(r,t,e),r}return new n(t,e)},a=function(t,e,n){var r=this;if(r.instancePool.length){var o=r.instancePool.pop();return r.call(o,t,e,n),o}return new r(t,e,n)},s=function(t,e,n,r){var o=this;if(o.instancePool.length){var i=o.instancePool.pop();return o.call(i,t,e,n,r),i}return new o(t,e,n,r)},l=function(t){var e=this;t instanceof e?void 0:r("25"),t.destructor(),e.instancePool.length<e.poolSize&&e.instancePool.push(t)},u=10,c=o,f=function(t,e){var n=t;return n.instancePool=[],n.getPooled=e||c,n.poolSize||(n.poolSize=u),n.release=l,n},d={addPoolingTo:f,oneArgumentPooler:o,twoArgumentPooler:i,threeArgumentPooler:a,fourArgumentPooler:s};t.exports=d},function(t,e){"use strict";function n(t){for(var e=arguments.length-1,n="Minified React error #"+t+"; visit http://facebook.github.io/react/docs/error-decoder.html?invariant="+t,r=0;r<e;r++)n+="&args[]="+encodeURIComponent(arguments[r+1]);n+=" for the full message or use the non-minified dev environment for full errors and additional helpful warnings.";var o=new Error(n);throw o.name="Invariant Violation",o.framesToPop=1,o}t.exports=n},function(t,e,n){"use strict";function r(t,e,n,r,i,a,s,l){if(o(e),!t){var u;if(void 0===e)u=new Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var c=[n,r,i,a,s,l],f=0;u=new Error(e.replace(/%s/g,function(){return c[f++]})),u.name="Invariant Violation"}throw u.framesToPop=1,u}}var o=function(t){};t.exports=r},function(t,e,n){"use strict";function r(t){return void 0!==t.ref}function o(t){return void 0!==t.key}var i=n(5),a=n(11),s=(n(12),n(14),Object.prototype.hasOwnProperty),l=n(15),u={key:!0,ref:!0,__self:!0,__source:!0},c=function(t,e,n,r,o,i,a){var s={$$typeof:l,type:t,key:e,ref:n,props:a,_owner:i};return s};c.createElement=function(t,e,n){var i,l={},f=null,d=null,p=null,h=null;if(null!=e){r(e)&&(d=e.ref),o(e)&&(f=""+e.key),p=void 0===e.__self?null:e.__self,h=void 0===e.__source?null:e.__source;for(i in e)s.call(e,i)&&!u.hasOwnProperty(i)&&(l[i]=e[i])}var g=arguments.length-2;if(1===g)l.children=n;else if(g>1){for(var v=Array(g),m=0;m<g;m++)v[m]=arguments[m+2];l.children=v}if(t&&t.defaultProps){var y=t.defaultProps;for(i in y)void 0===l[i]&&(l[i]=y[i])}return c(t,f,d,p,h,a.current,l)},c.createFactory=function(t){var e=c.createElement.bind(null,t);return e.type=t,e},c.cloneAndReplaceKey=function(t,e){var n=c(t.type,e,t.ref,t._self,t._source,t._owner,t.props);return n},c.cloneElement=function(t,e,n){var l,f=i({},t.props),d=t.key,p=t.ref,h=t._self,g=t._source,v=t._owner;if(null!=e){r(e)&&(p=e.ref,v=a.current),o(e)&&(d=""+e.key);var m;t.type&&t.type.defaultProps&&(m=t.type.defaultProps);for(l in e)s.call(e,l)&&!u.hasOwnProperty(l)&&(void 0===e[l]&&void 0!==m?f[l]=m[l]:f[l]=e[l])}var y=arguments.length-2;if(1===y)f.children=n;else if(y>1){for(var b=Array(y),x=0;x<y;x++)b[x]=arguments[x+2];f.children=b}return c(t.type,d,p,h,g,v,f)},c.isValidElement=function(t){return"object"==typeof t&&null!==t&&t.$$typeof===l},t.exports=c},function(t,e){"use strict";var n={current:null};t.exports=n},function(t,e,n){"use strict";var r=n(13),o=r;t.exports=o},function(t,e){"use strict";function n(t){return function(){return t}}var r=function(){};r.thatReturns=n,r.thatReturnsFalse=n(!1),r.thatReturnsTrue=n(!0),r.thatReturnsNull=n(null),r.thatReturnsThis=function(){return this},r.thatReturnsArgument=function(t){return t},t.exports=r},function(t,e,n){"use strict";var r=!1;t.exports=r},function(t,e){"use strict";var n="function"==typeof Symbol&&Symbol.for&&Symbol.for("react.element")||60103;t.exports=n},function(t,e,n){"use strict";function r(t,e){return t&&"object"==typeof t&&null!=t.key?u.escape(t.key):e.toString(36)}function o(t,e,n,i){var d=typeof t;if("undefined"!==d&&"boolean"!==d||(t=null),null===t||"string"===d||"number"===d||"object"===d&&t.$$typeof===s)return n(i,t,""===e?c+r(t,0):e),1;var p,h,g=0,v=""===e?c:e+f;if(Array.isArray(t))for(var m=0;m<t.length;m++)p=t[m],h=v+r(p,m),g+=o(p,h,n,i);else{var y=l(t);if(y){var b,x=y.call(t);if(y!==t.entries)for(var _=0;!(b=x.next()).done;)p=b.value,h=v+r(p,_++),g+=o(p,h,n,i);else for(;!(b=x.next()).done;){var w=b.value;w&&(p=w[1],h=v+u.escape(w[0])+f+r(p,0),g+=o(p,h,n,i))}}else if("object"===d){var T="",C=String(t);a("31","[object Object]"===C?"object with keys {"+Object.keys(t).join(", ")+"}":C,T)}}return g}function i(t,e,n){return null==t?0:o(t,"",e,n)}var a=n(8),s=(n(11),n(15)),l=n(17),u=(n(9),n(18)),c=(n(12),"."),f=":";t.exports=i},function(t,e){"use strict";function n(t){var e=t&&(r&&t[r]||t[o]);if("function"==typeof e)return e}var r="function"==typeof Symbol&&Symbol.iterator,o="@@iterator";t.exports=n},function(t,e){"use strict";function n(t){var e=/[=:]/g,n={"=":"=0",":":"=2"},r=(""+t).replace(e,function(t){return n[t]});return"$"+r}function r(t){var e=/(=0|=2)/g,n={"=0":"=","=2":":"},r="."===t[0]&&"$"===t[1]?t.substring(2):t.substring(1);return(""+r).replace(e,function(t){return n[t]})}var o={escape:n,unescape:r};t.exports=o},function(t,e,n){"use strict";function r(t,e,n){this.props=t,this.context=e,this.refs=a,this.updater=n||i}var o=n(8),i=n(20),a=(n(14),n(21));n(9),n(12);r.prototype.isReactComponent={},r.prototype.setState=function(t,e){"object"!=typeof t&&"function"!=typeof t&&null!=t?o("85"):void 0,this.updater.enqueueSetState(this,t),e&&this.updater.enqueueCallback(this,e,"setState")},r.prototype.forceUpdate=function(t){this.updater.enqueueForceUpdate(this),t&&this.updater.enqueueCallback(this,t,"forceUpdate")};t.exports=r},function(t,e,n){"use strict";function r(t,e){}var o=(n(12),{isMounted:function(t){return!1},enqueueCallback:function(t,e){},enqueueForceUpdate:function(t){r(t,"forceUpdate")},enqueueReplaceState:function(t,e){r(t,"replaceState")},enqueueSetState:function(t,e){r(t,"setState")}});t.exports=o},function(t,e,n){"use strict";var r={};t.exports=r},function(t,e,n){"use strict";function r(t,e,n){this.props=t,this.context=e,this.refs=l,this.updater=n||s}function o(){}var i=n(5),a=n(19),s=n(20),l=n(21);o.prototype=a.prototype,r.prototype=new o,r.prototype.constructor=r,i(r.prototype,a.prototype),r.prototype.isPureReactComponent=!0,t.exports=r},function(t,e,n){"use strict";function r(t){return t}function o(t,e){var n=x.hasOwnProperty(e)?x[e]:null;w.hasOwnProperty(e)&&("OVERRIDE_BASE"!==n?d("73",e):void 0),t&&("DEFINE_MANY"!==n&&"DEFINE_MANY_MERGED"!==n?d("74",e):void 0)}function i(t,e){if(e){"function"==typeof e?d("75"):void 0,g.isValidElement(e)?d("76"):void 0;var n=t.prototype,r=n.__reactAutoBindPairs;e.hasOwnProperty(y)&&_.mixins(t,e.mixins);for(var i in e)if(e.hasOwnProperty(i)&&i!==y){var a=e[i],s=n.hasOwnProperty(i);if(o(s,i),_.hasOwnProperty(i))_[i](t,a);else{var c=x.hasOwnProperty(i),f="function"==typeof a,p=f&&!c&&!s&&e.autobind!==!1;if(p)r.push(i,a),n[i]=a;else if(s){var h=x[i];!c||"DEFINE_MANY_MERGED"!==h&&"DEFINE_MANY"!==h?d("77",h,i):void 0,"DEFINE_MANY_MERGED"===h?n[i]=l(n[i],a):"DEFINE_MANY"===h&&(n[i]=u(n[i],a))}else n[i]=a}}}else;}function a(t,e){if(e)for(var n in e){var r=e[n];if(e.hasOwnProperty(n)){var o=n in _;o?d("78",n):void 0;var i=n in t;i?d("79",n):void 0,t[n]=r}}}function s(t,e){t&&e&&"object"==typeof t&&"object"==typeof e?void 0:d("80");for(var n in e)e.hasOwnProperty(n)&&(void 0!==t[n]?d("81",n):void 0,t[n]=e[n]);return t}function l(t,e){return function(){var n=t.apply(this,arguments),r=e.apply(this,arguments);if(null==n)return r;if(null==r)return n;var o={};return s(o,n),s(o,r),o}}function u(t,e){return function(){t.apply(this,arguments),e.apply(this,arguments)}}function c(t,e){var n=e.bind(t);return n}function f(t){for(var e=t.__reactAutoBindPairs,n=0;n<e.length;n+=2){var r=e[n],o=e[n+1];t[r]=c(t,o)}}var d=n(8),p=n(5),h=n(19),g=n(10),v=(n(24),n(20)),m=n(21),y=(n(9),n(12),"mixins"),b=[],x={mixins:"DEFINE_MANY",statics:"DEFINE_MANY",propTypes:"DEFINE_MANY",contextTypes:"DEFINE_MANY",childContextTypes:"DEFINE_MANY",getDefaultProps:"DEFINE_MANY_MERGED",getInitialState:"DEFINE_MANY_MERGED",getChildContext:"DEFINE_MANY_MERGED",render:"DEFINE_ONCE",componentWillMount:"DEFINE_MANY",componentDidMount:"DEFINE_MANY",componentWillReceiveProps:"DEFINE_MANY",shouldComponentUpdate:"DEFINE_ONCE",componentWillUpdate:"DEFINE_MANY",componentDidUpdate:"DEFINE_MANY",componentWillUnmount:"DEFINE_MANY",updateComponent:"OVERRIDE_BASE"},_={displayName:function(t,e){t.displayName=e},mixins:function(t,e){if(e)for(var n=0;n<e.length;n++)i(t,e[n])},childContextTypes:function(t,e){t.childContextTypes=p({},t.childContextTypes,e)},contextTypes:function(t,e){t.contextTypes=p({},t.contextTypes,e)},getDefaultProps:function(t,e){t.getDefaultProps?t.getDefaultProps=l(t.getDefaultProps,e):t.getDefaultProps=e},propTypes:function(t,e){t.propTypes=p({},t.propTypes,e)},statics:function(t,e){a(t,e)},autobind:function(){}},w={replaceState:function(t,e){this.updater.enqueueReplaceState(this,t),e&&this.updater.enqueueCallback(this,e,"replaceState")},isMounted:function(){return this.updater.isMounted(this)}},T=function(){};p(T.prototype,h.prototype,w);var C={createClass:function(t){var e=r(function(t,n,r){this.__reactAutoBindPairs.length&&f(this),this.props=t,this.context=n,this.refs=m,this.updater=r||v,this.state=null;var o=this.getInitialState?this.getInitialState():null;"object"!=typeof o||Array.isArray(o)?d("82",e.displayName||"ReactCompositeComponent"):void 0,this.state=o});e.prototype=new T,e.prototype.constructor=e,e.prototype.__reactAutoBindPairs=[],b.forEach(i.bind(null,e)),i(e,t),e.getDefaultProps&&(e.defaultProps=e.getDefaultProps()),e.prototype.render?void 0:d("83");for(var n in x)e.prototype[n]||(e.prototype[n]=null);return e},injection:{injectMixin:function(t){b.push(t)}}};t.exports=C},function(t,e,n){"use strict";var r={};t.exports=r},function(t,e,n){"use strict";var r=n(10),o=r.createFactory,i={a:o("a"),abbr:o("abbr"),address:o("address"),area:o("area"),article:o("article"),aside:o("aside"),audio:o("audio"),b:o("b"),base:o("base"),bdi:o("bdi"),bdo:o("bdo"),big:o("big"),blockquote:o("blockquote"),body:o("body"),br:o("br"),button:o("button"),canvas:o("canvas"),caption:o("caption"),cite:o("cite"),code:o("code"),col:o("col"),colgroup:o("colgroup"),data:o("data"),datalist:o("datalist"),dd:o("dd"),del:o("del"),details:o("details"),dfn:o("dfn"),dialog:o("dialog"),div:o("div"),dl:o("dl"),dt:o("dt"),em:o("em"),embed:o("embed"),fieldset:o("fieldset"),figcaption:o("figcaption"),figure:o("figure"),footer:o("footer"),form:o("form"),h1:o("h1"),h2:o("h2"),h3:o("h3"),h4:o("h4"),h5:o("h5"),h6:o("h6"),head:o("head"),header:o("header"),hgroup:o("hgroup"),hr:o("hr"),html:o("html"),i:o("i"),iframe:o("iframe"),img:o("img"),input:o("input"),ins:o("ins"),kbd:o("kbd"),keygen:o("keygen"),label:o("label"),legend:o("legend"),li:o("li"),link:o("link"),main:o("main"),map:o("map"),mark:o("mark"),menu:o("menu"),menuitem:o("menuitem"),meta:o("meta"),meter:o("meter"),nav:o("nav"),noscript:o("noscript"),object:o("object"),ol:o("ol"),optgroup:o("optgroup"),option:o("option"),output:o("output"),p:o("p"),param:o("param"),picture:o("picture"),pre:o("pre"),progress:o("progress"),q:o("q"),rp:o("rp"),rt:o("rt"),ruby:o("ruby"),s:o("s"),samp:o("samp"),script:o("script"),section:o("section"),select:o("select"),small:o("small"),source:o("source"),span:o("span"),strong:o("strong"),style:o("style"),sub:o("sub"),summary:o("summary"),sup:o("sup"),table:o("table"),tbody:o("tbody"),td:o("td"),textarea:o("textarea"),tfoot:o("tfoot"),th:o("th"),thead:o("thead"),time:o("time"),title:o("title"),tr:o("tr"),track:o("track"),u:o("u"),ul:o("ul"),var:o("var"),video:o("video"),wbr:o("wbr"),circle:o("circle"),clipPath:o("clipPath"),defs:o("defs"),ellipse:o("ellipse"),g:o("g"),image:o("image"),line:o("line"),linearGradient:o("linearGradient"),mask:o("mask"),path:o("path"),pattern:o("pattern"),polygon:o("polygon"),polyline:o("polyline"),radialGradient:o("radialGradient"),rect:o("rect"),stop:o("stop"),svg:o("svg"),text:o("text"),tspan:o("tspan")};t.exports=i},function(t,e,n){"use strict";function r(t,e){return t===e?0!==t||1/t===1/e:t!==t&&e!==e}function o(t){this.message=t,this.stack=""}function i(t){function e(e,n,r,i,a,s,l){i=i||E,s=s||r;if(null==n[r]){var u=w[a];return e?new o(null===n[r]?"The "+u+" `"+s+"` is marked as required "+("in `"+i+"`, but its value is `null`."):"The "+u+" `"+s+"` is marked as required in "+("`"+i+"`, but its value is `undefined`.")):null}return t(n,r,i,a,s)}var n=e.bind(null,!1);return n.isRequired=e.bind(null,!0),n}function a(t){function e(e,n,r,i,a,s){var l=e[n],u=y(l);if(u!==t){var c=w[i],f=b(l);return new o("Invalid "+c+" `"+a+"` of type "+("`"+f+"` supplied to `"+r+"`, expected ")+("`"+t+"`."))}return null}return i(e)}function s(){return i(C.thatReturns(null))}function l(t){function e(e,n,r,i,a){if("function"!=typeof t)return new o("Property `"+a+"` of component `"+r+"` has invalid PropType notation inside arrayOf.");var s=e[n];if(!Array.isArray(s)){var l=w[i],u=y(s);return new o("Invalid "+l+" `"+a+"` of type "+("`"+u+"` supplied to `"+r+"`, expected an array."))}for(var c=0;c<s.length;c++){var f=t(s,c,r,i,a+"["+c+"]",T);if(f instanceof Error)return f}return null}return i(e)}function u(){function t(t,e,n,r,i){var a=t[e];if(!_.isValidElement(a)){var s=w[r],l=y(a);return new o("Invalid "+s+" `"+i+"` of type "+("`"+l+"` supplied to `"+n+"`, expected a single ReactElement."))}return null}return i(t)}function c(t){function e(e,n,r,i,a){if(!(e[n]instanceof t)){var s=w[i],l=t.name||E,u=x(e[n]);return new o("Invalid "+s+" `"+a+"` of type "+("`"+u+"` supplied to `"+r+"`, expected ")+("instance of `"+l+"`."))}return null}return i(e)}function f(t){function e(e,n,i,a,s){for(var l=e[n],u=0;u<t.length;u++)if(r(l,t[u]))return null;var c=w[a],f=JSON.stringify(t);return new o("Invalid "+c+" `"+s+"` of value `"+l+"` "+("supplied to `"+i+"`, expected one of "+f+"."))}return Array.isArray(t)?i(e):C.thatReturnsNull}function d(t){function e(e,n,r,i,a){if("function"!=typeof t)return new o("Property `"+a+"` of component `"+r+"` has invalid PropType notation inside objectOf.");var s=e[n],l=y(s);if("object"!==l){var u=w[i];return new o("Invalid "+u+" `"+a+"` of type "+("`"+l+"` supplied to `"+r+"`, expected an object."))}for(var c in s)if(s.hasOwnProperty(c)){var f=t(s,c,r,i,a+"."+c,T);if(f instanceof Error)return f}return null}return i(e)}function p(t){function e(e,n,r,i,a){for(var s=0;s<t.length;s++){var l=t[s];if(null==l(e,n,r,i,a,T))return null}var u=w[i];return new o("Invalid "+u+" `"+a+"` supplied to "+("`"+r+"`."))}return Array.isArray(t)?i(e):C.thatReturnsNull}function h(){function t(t,e,n,r,i){if(!v(t[e])){var a=w[r];return new o("Invalid "+a+" `"+i+"` supplied to "+("`"+n+"`, expected a ReactNode."))}return null}return i(t)}function g(t){function e(e,n,r,i,a){var s=e[n],l=y(s);if("object"!==l){var u=w[i];return new o("Invalid "+u+" `"+a+"` of type `"+l+"` "+("supplied to `"+r+"`, expected `object`."))}for(var c in t){var f=t[c];if(f){var d=f(s,c,r,i,a+"."+c,T);if(d)return d}}return null}return i(e)}function v(t){switch(typeof t){case"number":case"string":case"undefined":return!0;case"boolean":return!t;case"object":if(Array.isArray(t))return t.every(v);if(null===t||_.isValidElement(t))return!0;var e=k(t);if(!e)return!1;var n,r=e.call(t);if(e!==t.entries){for(;!(n=r.next()).done;)if(!v(n.value))return!1}else for(;!(n=r.next()).done;){var o=n.value;if(o&&!v(o[1]))return!1}return!0;default:return!1}}function m(t,e){return"symbol"===t||("Symbol"===e["@@toStringTag"]||"function"==typeof Symbol&&e instanceof Symbol)}function y(t){var e=typeof t;return Array.isArray(t)?"array":t instanceof RegExp?"object":m(e,t)?"symbol":e}function b(t){var e=y(t);if("object"===e){if(t instanceof Date)return"date";if(t instanceof RegExp)return"regexp"}return e}function x(t){return t.constructor&&t.constructor.name?t.constructor.name:E}var _=n(10),w=n(24),T=n(27),C=n(13),k=n(17),E=(n(12),"<<anonymous>>"),P={array:a("array"),bool:a("boolean"),func:a("function"),number:a("number"),object:a("object"),string:a("string"),symbol:a("symbol"),any:s(),arrayOf:l,element:u(),instanceOf:c,node:h(),objectOf:d,oneOf:f,oneOfType:p,shape:g};o.prototype=Error.prototype,t.exports=P},function(t,e){"use strict";var n="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED";t.exports=n},function(t,e){"use strict";t.exports="15.4.2"},function(t,e,n){"use strict";function r(t){return i.isValidElement(t)?void 0:o("143"),t}var o=n(8),i=n(10);n(9);t.exports=r},function(t,e,n){"use strict";t.exports=n(31)},function(t,e,n){"use strict";var r=n(32),o=n(36),i=n(159),a=n(57),s=n(54),l=n(164),u=n(165),c=n(166),f=n(167);n(12);o.inject();var d={findDOMNode:u,render:i.render,unmountComponentAtNode:i.unmountComponentAtNode,version:l,unstable_batchedUpdates:s.batchedUpdates,unstable_renderSubtreeIntoContainer:f};"undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.inject&&__REACT_DEVTOOLS_GLOBAL_HOOK__.inject({ComponentTree:{getClosestInstanceFromNode:r.getClosestInstanceFromNode,getNodeFromInstance:function(t){return t._renderedComponent&&(t=c(t)),t?r.getNodeFromInstance(t):null}},Mount:i,Reconciler:a});t.exports=d},function(t,e,n){"use strict";function r(t,e){return 1===t.nodeType&&t.getAttribute(h)===String(e)||8===t.nodeType&&t.nodeValue===" react-text: "+e+" "||8===t.nodeType&&t.nodeValue===" react-empty: "+e+" "}function o(t){for(var e;e=t._renderedComponent;)t=e;return t}function i(t,e){var n=o(t);n._hostNode=e,e[v]=n}function a(t){var e=t._hostNode;e&&(delete e[v],t._hostNode=null)}function s(t,e){if(!(t._flags&g.hasCachedChildNodes)){var n=t._renderedChildren,a=e.firstChild;t:for(var s in n)if(n.hasOwnProperty(s)){var l=n[s],u=o(l)._domID;if(0!==u){for(;null!==a;a=a.nextSibling)if(r(a,u)){i(l,a);continue t}f("32",u)}}t._flags|=g.hasCachedChildNodes}}function l(t){if(t[v])return t[v];for(var e=[];!t[v];){if(e.push(t),!t.parentNode)return null;t=t.parentNode}for(var n,r;t&&(r=t[v]);t=e.pop())n=r,e.length&&s(r,t);return n}function u(t){var e=l(t);return null!=e&&e._hostNode===t?e:null}function c(t){if(void 0===t._hostNode?f("33"):void 0,t._hostNode)return t._hostNode;for(var e=[];!t._hostNode;)e.push(t),t._hostParent?void 0:f("34"),t=t._hostParent;for(;e.length;t=e.pop())s(t,t._hostNode);return t._hostNode}var f=n(33),d=n(34),p=n(35),h=(n(9),d.ID_ATTRIBUTE_NAME),g=p,v="__reactInternalInstance$"+Math.random().toString(36).slice(2),m={getClosestInstanceFromNode:l,getInstanceFromNode:u,getNodeFromInstance:c,precacheChildNodes:s,precacheNode:i,uncacheNode:a};t.exports=m},function(t,e){"use strict";function n(t){for(var e=arguments.length-1,n="Minified React error #"+t+"; visit http://facebook.github.io/react/docs/error-decoder.html?invariant="+t,r=0;r<e;r++)n+="&args[]="+encodeURIComponent(arguments[r+1]);n+=" for the full message or use the non-minified dev environment for full errors and additional helpful warnings.";var o=new Error(n);throw o.name="Invariant Violation",o.framesToPop=1,o}t.exports=n},function(t,e,n){"use strict";function r(t,e){return(t&e)===e}var o=n(33),i=(n(9),{MUST_USE_PROPERTY:1,HAS_BOOLEAN_VALUE:4,HAS_NUMERIC_VALUE:8,HAS_POSITIVE_NUMERIC_VALUE:24,HAS_OVERLOADED_BOOLEAN_VALUE:32,injectDOMPropertyConfig:function(t){var e=i,n=t.Properties||{},a=t.DOMAttributeNamespaces||{},l=t.DOMAttributeNames||{},u=t.DOMPropertyNames||{},c=t.DOMMutationMethods||{};t.isCustomAttribute&&s._isCustomAttributeFunctions.push(t.isCustomAttribute);for(var f in n){s.properties.hasOwnProperty(f)?o("48",f):void 0;var d=f.toLowerCase(),p=n[f],h={attributeName:d,attributeNamespace:null,propertyName:f,mutationMethod:null,mustUseProperty:r(p,e.MUST_USE_PROPERTY),hasBooleanValue:r(p,e.HAS_BOOLEAN_VALUE),hasNumericValue:r(p,e.HAS_NUMERIC_VALUE),hasPositiveNumericValue:r(p,e.HAS_POSITIVE_NUMERIC_VALUE),hasOverloadedBooleanValue:r(p,e.HAS_OVERLOADED_BOOLEAN_VALUE)};if(h.hasBooleanValue+h.hasNumericValue+h.hasOverloadedBooleanValue<=1?void 0:o("50",f),l.hasOwnProperty(f)){var g=l[f];h.attributeName=g}a.hasOwnProperty(f)&&(h.attributeNamespace=a[f]),u.hasOwnProperty(f)&&(h.propertyName=u[f]),c.hasOwnProperty(f)&&(h.mutationMethod=c[f]),s.properties[f]=h}}}),a=":A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD",s={ID_ATTRIBUTE_NAME:"data-reactid",ROOT_ATTRIBUTE_NAME:"data-reactroot",ATTRIBUTE_NAME_START_CHAR:a,ATTRIBUTE_NAME_CHAR:a+"\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040",properties:{},getPossibleStandardName:null,_isCustomAttributeFunctions:[],isCustomAttribute:function(t){for(var e=0;e<s._isCustomAttributeFunctions.length;e++){var n=s._isCustomAttributeFunctions[e];if(n(t))return!0}return!1},injection:i};t.exports=s},function(t,e){"use strict";var n={hasCachedChildNodes:1};t.exports=n},function(t,e,n){"use strict";function r(){T||(T=!0,y.EventEmitter.injectReactEventListener(m),y.EventPluginHub.injectEventPluginOrder(s),y.EventPluginUtils.injectComponentTree(d),y.EventPluginUtils.injectTreeTraversal(h),y.EventPluginHub.injectEventPluginsByName({SimpleEventPlugin:w,EnterLeaveEventPlugin:l,ChangeEventPlugin:a,SelectEventPlugin:_,BeforeInputEventPlugin:i}),y.HostComponent.injectGenericComponentClass(f),y.HostComponent.injectTextComponentClass(g),y.DOMProperty.injectDOMPropertyConfig(o),y.DOMProperty.injectDOMPropertyConfig(u),y.DOMProperty.injectDOMPropertyConfig(x),y.EmptyComponent.injectEmptyComponentFactory(function(t){return new p(t)}),y.Updates.injectReconcileTransaction(b),y.Updates.injectBatchingStrategy(v),y.Component.injectEnvironment(c))}var o=n(37),i=n(38),a=n(53),s=n(65),l=n(66),u=n(71),c=n(72),f=n(85),d=n(32),p=n(130),h=n(131),g=n(132),v=n(133),m=n(134),y=n(137),b=n(138),x=n(146),_=n(147),w=n(148),T=!1;t.exports={inject:r}},function(t,e){"use strict";var n={Properties:{"aria-current":0,"aria-details":0,"aria-disabled":0,"aria-hidden":0,"aria-invalid":0,"aria-keyshortcuts":0,"aria-label":0,"aria-roledescription":0,"aria-autocomplete":0,"aria-checked":0,"aria-expanded":0,"aria-haspopup":0,"aria-level":0,"aria-modal":0,"aria-multiline":0,"aria-multiselectable":0,"aria-orientation":0,"aria-placeholder":0,"aria-pressed":0,"aria-readonly":0,"aria-required":0,"aria-selected":0,"aria-sort":0,"aria-valuemax":0,"aria-valuemin":0,"aria-valuenow":0,"aria-valuetext":0,"aria-atomic":0,"aria-busy":0,"aria-live":0,"aria-relevant":0,"aria-dropeffect":0,"aria-grabbed":0,"aria-activedescendant":0,"aria-colcount":0,"aria-colindex":0,"aria-colspan":0,"aria-controls":0,"aria-describedby":0,"aria-errormessage":0,"aria-flowto":0,"aria-labelledby":0,"aria-owns":0,"aria-posinset":0,"aria-rowcount":0,"aria-rowindex":0,"aria-rowspan":0,"aria-setsize":0},DOMAttributeNames:{},DOMPropertyNames:{}};t.exports=n},function(t,e,n){"use strict";function r(){var t=window.opera;return"object"==typeof t&&"function"==typeof t.version&&parseInt(t.version(),10)<=12}function o(t){return(t.ctrlKey||t.altKey||t.metaKey)&&!(t.ctrlKey&&t.altKey);
}function i(t){switch(t){case"topCompositionStart":return E.compositionStart;case"topCompositionEnd":return E.compositionEnd;case"topCompositionUpdate":return E.compositionUpdate}}function a(t,e){return"topKeyDown"===t&&e.keyCode===b}function s(t,e){switch(t){case"topKeyUp":return y.indexOf(e.keyCode)!==-1;case"topKeyDown":return e.keyCode!==b;case"topKeyPress":case"topMouseDown":case"topBlur":return!0;default:return!1}}function l(t){var e=t.detail;return"object"==typeof e&&"data"in e?e.data:null}function u(t,e,n,r){var o,u;if(x?o=i(t):S?s(t,n)&&(o=E.compositionEnd):a(t,n)&&(o=E.compositionStart),!o)return null;T&&(S||o!==E.compositionStart?o===E.compositionEnd&&S&&(u=S.getData()):S=g.getPooled(r));var c=v.getPooled(o,e,n,r);if(u)c.data=u;else{var f=l(n);null!==f&&(c.data=f)}return p.accumulateTwoPhaseDispatches(c),c}function c(t,e){switch(t){case"topCompositionEnd":return l(e);case"topKeyPress":var n=e.which;return n!==C?null:(P=!0,k);case"topTextInput":var r=e.data;return r===k&&P?null:r;default:return null}}function f(t,e){if(S){if("topCompositionEnd"===t||!x&&s(t,e)){var n=S.getData();return g.release(S),S=null,n}return null}switch(t){case"topPaste":return null;case"topKeyPress":return e.which&&!o(e)?String.fromCharCode(e.which):null;case"topCompositionEnd":return T?null:e.data;default:return null}}function d(t,e,n,r){var o;if(o=w?c(t,n):f(t,n),!o)return null;var i=m.getPooled(E.beforeInput,e,n,r);return i.data=o,p.accumulateTwoPhaseDispatches(i),i}var p=n(39),h=n(46),g=n(47),v=n(50),m=n(52),y=[9,13,27,32],b=229,x=h.canUseDOM&&"CompositionEvent"in window,_=null;h.canUseDOM&&"documentMode"in document&&(_=document.documentMode);var w=h.canUseDOM&&"TextEvent"in window&&!_&&!r(),T=h.canUseDOM&&(!x||_&&_>8&&_<=11),C=32,k=String.fromCharCode(C),E={beforeInput:{phasedRegistrationNames:{bubbled:"onBeforeInput",captured:"onBeforeInputCapture"},dependencies:["topCompositionEnd","topKeyPress","topTextInput","topPaste"]},compositionEnd:{phasedRegistrationNames:{bubbled:"onCompositionEnd",captured:"onCompositionEndCapture"},dependencies:["topBlur","topCompositionEnd","topKeyDown","topKeyPress","topKeyUp","topMouseDown"]},compositionStart:{phasedRegistrationNames:{bubbled:"onCompositionStart",captured:"onCompositionStartCapture"},dependencies:["topBlur","topCompositionStart","topKeyDown","topKeyPress","topKeyUp","topMouseDown"]},compositionUpdate:{phasedRegistrationNames:{bubbled:"onCompositionUpdate",captured:"onCompositionUpdateCapture"},dependencies:["topBlur","topCompositionUpdate","topKeyDown","topKeyPress","topKeyUp","topMouseDown"]}},P=!1,S=null,M={eventTypes:E,extractEvents:function(t,e,n,r){return[u(t,e,n,r),d(t,e,n,r)]}};t.exports=M},function(t,e,n){"use strict";function r(t,e,n){var r=e.dispatchConfig.phasedRegistrationNames[n];return m(t,r)}function o(t,e,n){var o=r(t,n,e);o&&(n._dispatchListeners=g(n._dispatchListeners,o),n._dispatchInstances=g(n._dispatchInstances,t))}function i(t){t&&t.dispatchConfig.phasedRegistrationNames&&h.traverseTwoPhase(t._targetInst,o,t)}function a(t){if(t&&t.dispatchConfig.phasedRegistrationNames){var e=t._targetInst,n=e?h.getParentInstance(e):null;h.traverseTwoPhase(n,o,t)}}function s(t,e,n){if(n&&n.dispatchConfig.registrationName){var r=n.dispatchConfig.registrationName,o=m(t,r);o&&(n._dispatchListeners=g(n._dispatchListeners,o),n._dispatchInstances=g(n._dispatchInstances,t))}}function l(t){t&&t.dispatchConfig.registrationName&&s(t._targetInst,null,t)}function u(t){v(t,i)}function c(t){v(t,a)}function f(t,e,n,r){h.traverseEnterLeave(n,r,s,t,e)}function d(t){v(t,l)}var p=n(40),h=n(42),g=n(44),v=n(45),m=(n(12),p.getListener),y={accumulateTwoPhaseDispatches:u,accumulateTwoPhaseDispatchesSkipTarget:c,accumulateDirectDispatches:d,accumulateEnterLeaveDispatches:f};t.exports=y},function(t,e,n){"use strict";function r(t){return"button"===t||"input"===t||"select"===t||"textarea"===t}function o(t,e,n){switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":return!(!n.disabled||!r(e));default:return!1}}var i=n(33),a=n(41),s=n(42),l=n(43),u=n(44),c=n(45),f=(n(9),{}),d=null,p=function(t,e){t&&(s.executeDispatchesInOrder(t,e),t.isPersistent()||t.constructor.release(t))},h=function(t){return p(t,!0)},g=function(t){return p(t,!1)},v=function(t){return"."+t._rootNodeID},m={injection:{injectEventPluginOrder:a.injectEventPluginOrder,injectEventPluginsByName:a.injectEventPluginsByName},putListener:function(t,e,n){"function"!=typeof n?i("94",e,typeof n):void 0;var r=v(t),o=f[e]||(f[e]={});o[r]=n;var s=a.registrationNameModules[e];s&&s.didPutListener&&s.didPutListener(t,e,n)},getListener:function(t,e){var n=f[e];if(o(e,t._currentElement.type,t._currentElement.props))return null;var r=v(t);return n&&n[r]},deleteListener:function(t,e){var n=a.registrationNameModules[e];n&&n.willDeleteListener&&n.willDeleteListener(t,e);var r=f[e];if(r){var o=v(t);delete r[o]}},deleteAllListeners:function(t){var e=v(t);for(var n in f)if(f.hasOwnProperty(n)&&f[n][e]){var r=a.registrationNameModules[n];r&&r.willDeleteListener&&r.willDeleteListener(t,n),delete f[n][e]}},extractEvents:function(t,e,n,r){for(var o,i=a.plugins,s=0;s<i.length;s++){var l=i[s];if(l){var c=l.extractEvents(t,e,n,r);c&&(o=u(o,c))}}return o},enqueueEvents:function(t){t&&(d=u(d,t))},processEventQueue:function(t){var e=d;d=null,t?c(e,h):c(e,g),d?i("95"):void 0,l.rethrowCaughtError()},__purge:function(){f={}},__getListenerBank:function(){return f}};t.exports=m},function(t,e,n){"use strict";function r(){if(s)for(var t in l){var e=l[t],n=s.indexOf(t);if(n>-1?void 0:a("96",t),!u.plugins[n]){e.extractEvents?void 0:a("97",t),u.plugins[n]=e;var r=e.eventTypes;for(var i in r)o(r[i],e,i)?void 0:a("98",i,t)}}}function o(t,e,n){u.eventNameDispatchConfigs.hasOwnProperty(n)?a("99",n):void 0,u.eventNameDispatchConfigs[n]=t;var r=t.phasedRegistrationNames;if(r){for(var o in r)if(r.hasOwnProperty(o)){var s=r[o];i(s,e,n)}return!0}return!!t.registrationName&&(i(t.registrationName,e,n),!0)}function i(t,e,n){u.registrationNameModules[t]?a("100",t):void 0,u.registrationNameModules[t]=e,u.registrationNameDependencies[t]=e.eventTypes[n].dependencies}var a=n(33),s=(n(9),null),l={},u={plugins:[],eventNameDispatchConfigs:{},registrationNameModules:{},registrationNameDependencies:{},possibleRegistrationNames:null,injectEventPluginOrder:function(t){s?a("101"):void 0,s=Array.prototype.slice.call(t),r()},injectEventPluginsByName:function(t){var e=!1;for(var n in t)if(t.hasOwnProperty(n)){var o=t[n];l.hasOwnProperty(n)&&l[n]===o||(l[n]?a("102",n):void 0,l[n]=o,e=!0)}e&&r()},getPluginModuleForEvent:function(t){var e=t.dispatchConfig;if(e.registrationName)return u.registrationNameModules[e.registrationName]||null;if(void 0!==e.phasedRegistrationNames){var n=e.phasedRegistrationNames;for(var r in n)if(n.hasOwnProperty(r)){var o=u.registrationNameModules[n[r]];if(o)return o}}return null},_resetEventPlugins:function(){s=null;for(var t in l)l.hasOwnProperty(t)&&delete l[t];u.plugins.length=0;var e=u.eventNameDispatchConfigs;for(var n in e)e.hasOwnProperty(n)&&delete e[n];var r=u.registrationNameModules;for(var o in r)r.hasOwnProperty(o)&&delete r[o]}};t.exports=u},function(t,e,n){"use strict";function r(t){return"topMouseUp"===t||"topTouchEnd"===t||"topTouchCancel"===t}function o(t){return"topMouseMove"===t||"topTouchMove"===t}function i(t){return"topMouseDown"===t||"topTouchStart"===t}function a(t,e,n,r){var o=t.type||"unknown-event";t.currentTarget=m.getNodeFromInstance(r),e?g.invokeGuardedCallbackWithCatch(o,n,t):g.invokeGuardedCallback(o,n,t),t.currentTarget=null}function s(t,e){var n=t._dispatchListeners,r=t._dispatchInstances;if(Array.isArray(n))for(var o=0;o<n.length&&!t.isPropagationStopped();o++)a(t,e,n[o],r[o]);else n&&a(t,e,n,r);t._dispatchListeners=null,t._dispatchInstances=null}function l(t){var e=t._dispatchListeners,n=t._dispatchInstances;if(Array.isArray(e)){for(var r=0;r<e.length&&!t.isPropagationStopped();r++)if(e[r](t,n[r]))return n[r]}else if(e&&e(t,n))return n;return null}function u(t){var e=l(t);return t._dispatchInstances=null,t._dispatchListeners=null,e}function c(t){var e=t._dispatchListeners,n=t._dispatchInstances;Array.isArray(e)?h("103"):void 0,t.currentTarget=e?m.getNodeFromInstance(n):null;var r=e?e(t):null;return t.currentTarget=null,t._dispatchListeners=null,t._dispatchInstances=null,r}function f(t){return!!t._dispatchListeners}var d,p,h=n(33),g=n(43),v=(n(9),n(12),{injectComponentTree:function(t){d=t},injectTreeTraversal:function(t){p=t}}),m={isEndish:r,isMoveish:o,isStartish:i,executeDirectDispatch:c,executeDispatchesInOrder:s,executeDispatchesInOrderStopAtTrue:u,hasDispatches:f,getInstanceFromNode:function(t){return d.getInstanceFromNode(t)},getNodeFromInstance:function(t){return d.getNodeFromInstance(t)},isAncestor:function(t,e){return p.isAncestor(t,e)},getLowestCommonAncestor:function(t,e){return p.getLowestCommonAncestor(t,e)},getParentInstance:function(t){return p.getParentInstance(t)},traverseTwoPhase:function(t,e,n){return p.traverseTwoPhase(t,e,n)},traverseEnterLeave:function(t,e,n,r,o){return p.traverseEnterLeave(t,e,n,r,o)},injection:v};t.exports=m},function(t,e,n){"use strict";function r(t,e,n){try{e(n)}catch(t){null===o&&(o=t)}}var o=null,i={invokeGuardedCallback:r,invokeGuardedCallbackWithCatch:r,rethrowCaughtError:function(){if(o){var t=o;throw o=null,t}}};t.exports=i},function(t,e,n){"use strict";function r(t,e){return null==e?o("30"):void 0,null==t?e:Array.isArray(t)?Array.isArray(e)?(t.push.apply(t,e),t):(t.push(e),t):Array.isArray(e)?[t].concat(e):[t,e]}var o=n(33);n(9);t.exports=r},function(t,e){"use strict";function n(t,e,n){Array.isArray(t)?t.forEach(e,n):t&&e.call(n,t)}t.exports=n},function(t,e){"use strict";var n=!("undefined"==typeof window||!window.document||!window.document.createElement),r={canUseDOM:n,canUseWorkers:"undefined"!=typeof Worker,canUseEventListeners:n&&!(!window.addEventListener&&!window.attachEvent),canUseViewport:n&&!!window.screen,isInWorker:!n};t.exports=r},function(t,e,n){"use strict";function r(t){this._root=t,this._startText=this.getText(),this._fallbackText=null}var o=n(5),i=n(48),a=n(49);o(r.prototype,{destructor:function(){this._root=null,this._startText=null,this._fallbackText=null},getText:function(){return"value"in this._root?this._root.value:this._root[a()]},getData:function(){if(this._fallbackText)return this._fallbackText;var t,e,n=this._startText,r=n.length,o=this.getText(),i=o.length;for(t=0;t<r&&n[t]===o[t];t++);var a=r-t;for(e=1;e<=a&&n[r-e]===o[i-e];e++);var s=e>1?1-e:void 0;return this._fallbackText=o.slice(t,s),this._fallbackText}}),i.addPoolingTo(r),t.exports=r},function(t,e,n){"use strict";var r=n(33),o=(n(9),function(t){var e=this;if(e.instancePool.length){var n=e.instancePool.pop();return e.call(n,t),n}return new e(t)}),i=function(t,e){var n=this;if(n.instancePool.length){var r=n.instancePool.pop();return n.call(r,t,e),r}return new n(t,e)},a=function(t,e,n){var r=this;if(r.instancePool.length){var o=r.instancePool.pop();return r.call(o,t,e,n),o}return new r(t,e,n)},s=function(t,e,n,r){var o=this;if(o.instancePool.length){var i=o.instancePool.pop();return o.call(i,t,e,n,r),i}return new o(t,e,n,r)},l=function(t){var e=this;t instanceof e?void 0:r("25"),t.destructor(),e.instancePool.length<e.poolSize&&e.instancePool.push(t)},u=10,c=o,f=function(t,e){var n=t;return n.instancePool=[],n.getPooled=e||c,n.poolSize||(n.poolSize=u),n.release=l,n},d={addPoolingTo:f,oneArgumentPooler:o,twoArgumentPooler:i,threeArgumentPooler:a,fourArgumentPooler:s};t.exports=d},function(t,e,n){"use strict";function r(){return!i&&o.canUseDOM&&(i="textContent"in document.documentElement?"textContent":"innerText"),i}var o=n(46),i=null;t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(51),i={data:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){this.dispatchConfig=t,this._targetInst=e,this.nativeEvent=n;var o=this.constructor.Interface;for(var i in o)if(o.hasOwnProperty(i)){var s=o[i];s?this[i]=s(n):"target"===i?this.target=r:this[i]=n[i]}var l=null!=n.defaultPrevented?n.defaultPrevented:n.returnValue===!1;return l?this.isDefaultPrevented=a.thatReturnsTrue:this.isDefaultPrevented=a.thatReturnsFalse,this.isPropagationStopped=a.thatReturnsFalse,this}var o=n(5),i=n(48),a=n(13),s=(n(12),"function"==typeof Proxy,["dispatchConfig","_targetInst","nativeEvent","isDefaultPrevented","isPropagationStopped","_dispatchListeners","_dispatchInstances"]),l={type:null,target:null,currentTarget:a.thatReturnsNull,eventPhase:null,bubbles:null,cancelable:null,timeStamp:function(t){return t.timeStamp||Date.now()},defaultPrevented:null,isTrusted:null};o(r.prototype,{preventDefault:function(){this.defaultPrevented=!0;var t=this.nativeEvent;t&&(t.preventDefault?t.preventDefault():"unknown"!=typeof t.returnValue&&(t.returnValue=!1),this.isDefaultPrevented=a.thatReturnsTrue)},stopPropagation:function(){var t=this.nativeEvent;t&&(t.stopPropagation?t.stopPropagation():"unknown"!=typeof t.cancelBubble&&(t.cancelBubble=!0),this.isPropagationStopped=a.thatReturnsTrue)},persist:function(){this.isPersistent=a.thatReturnsTrue},isPersistent:a.thatReturnsFalse,destructor:function(){var t=this.constructor.Interface;for(var e in t)this[e]=null;for(var n=0;n<s.length;n++)this[s[n]]=null}}),r.Interface=l,r.augmentClass=function(t,e){var n=this,r=function(){};r.prototype=n.prototype;var a=new r;o(a,t.prototype),t.prototype=a,t.prototype.constructor=t,t.Interface=o({},n.Interface,e),t.augmentClass=n.augmentClass,i.addPoolingTo(t,i.fourArgumentPooler)},i.addPoolingTo(r,i.fourArgumentPooler),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(51),i={data:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t){var e=t.nodeName&&t.nodeName.toLowerCase();return"select"===e||"input"===e&&"file"===t.type}function o(t){var e=T.getPooled(P.change,M,t,C(t));b.accumulateTwoPhaseDispatches(e),w.batchedUpdates(i,e)}function i(t){y.enqueueEvents(t),y.processEventQueue(!1)}function a(t,e){S=t,M=e,S.attachEvent("onchange",o)}function s(){S&&(S.detachEvent("onchange",o),S=null,M=null)}function l(t,e){if("topChange"===t)return e}function u(t,e,n){"topFocus"===t?(s(),a(e,n)):"topBlur"===t&&s()}function c(t,e){S=t,M=e,N=t.value,A=Object.getOwnPropertyDescriptor(t.constructor.prototype,"value"),Object.defineProperty(S,"value",I),S.attachEvent?S.attachEvent("onpropertychange",d):S.addEventListener("propertychange",d,!1)}function f(){S&&(delete S.value,S.detachEvent?S.detachEvent("onpropertychange",d):S.removeEventListener("propertychange",d,!1),S=null,M=null,N=null,A=null)}function d(t){if("value"===t.propertyName){var e=t.srcElement.value;e!==N&&(N=e,o(t))}}function p(t,e){if("topInput"===t)return e}function h(t,e,n){"topFocus"===t?(f(),c(e,n)):"topBlur"===t&&f()}function g(t,e){if(("topSelectionChange"===t||"topKeyUp"===t||"topKeyDown"===t)&&S&&S.value!==N)return N=S.value,M}function v(t){return t.nodeName&&"input"===t.nodeName.toLowerCase()&&("checkbox"===t.type||"radio"===t.type)}function m(t,e){if("topClick"===t)return e}var y=n(40),b=n(39),x=n(46),_=n(32),w=n(54),T=n(51),C=n(62),k=n(63),E=n(64),P={change:{phasedRegistrationNames:{bubbled:"onChange",captured:"onChangeCapture"},dependencies:["topBlur","topChange","topClick","topFocus","topInput","topKeyDown","topKeyUp","topSelectionChange"]}},S=null,M=null,N=null,A=null,O=!1;x.canUseDOM&&(O=k("change")&&(!document.documentMode||document.documentMode>8));var D=!1;x.canUseDOM&&(D=k("input")&&(!document.documentMode||document.documentMode>11));var I={get:function(){return A.get.call(this)},set:function(t){N=""+t,A.set.call(this,t)}},R={eventTypes:P,extractEvents:function(t,e,n,o){var i,a,s=e?_.getNodeFromInstance(e):window;if(r(s)?O?i=l:a=u:E(s)?D?i=p:(i=g,a=h):v(s)&&(i=m),i){var c=i(t,e);if(c){var f=T.getPooled(P.change,c,n,o);return f.type="change",b.accumulateTwoPhaseDispatches(f),f}}a&&a(t,s,e)}};t.exports=R},function(t,e,n){"use strict";function r(){P.ReactReconcileTransaction&&_?void 0:c("123")}function o(){this.reinitializeTransaction(),this.dirtyComponentsLength=null,this.callbackQueue=d.getPooled(),this.reconcileTransaction=P.ReactReconcileTransaction.getPooled(!0)}function i(t,e,n,o,i,a){return r(),_.batchedUpdates(t,e,n,o,i,a)}function a(t,e){return t._mountOrder-e._mountOrder}function s(t){var e=t.dirtyComponentsLength;e!==m.length?c("124",e,m.length):void 0,m.sort(a),y++;for(var n=0;n<e;n++){var r=m[n],o=r._pendingCallbacks;r._pendingCallbacks=null;var i;if(h.logTopLevelRenders){var s=r;r._currentElement.type.isReactTopLevelWrapper&&(s=r._renderedComponent),i="React update: "+s.getName(),console.time(i)}if(g.performUpdateIfNecessary(r,t.reconcileTransaction,y),i&&console.timeEnd(i),o)for(var l=0;l<o.length;l++)t.callbackQueue.enqueue(o[l],r.getPublicInstance())}}function l(t){return r(),_.isBatchingUpdates?(m.push(t),void(null==t._updateBatchNumber&&(t._updateBatchNumber=y+1))):void _.batchedUpdates(l,t)}function u(t,e){_.isBatchingUpdates?void 0:c("125"),b.enqueue(t,e),x=!0}var c=n(33),f=n(5),d=n(55),p=n(48),h=n(56),g=n(57),v=n(61),m=(n(9),[]),y=0,b=d.getPooled(),x=!1,_=null,w={initialize:function(){this.dirtyComponentsLength=m.length},close:function(){this.dirtyComponentsLength!==m.length?(m.splice(0,this.dirtyComponentsLength),k()):m.length=0}},T={initialize:function(){this.callbackQueue.reset()},close:function(){this.callbackQueue.notifyAll()}},C=[w,T];f(o.prototype,v,{getTransactionWrappers:function(){return C},destructor:function(){this.dirtyComponentsLength=null,d.release(this.callbackQueue),this.callbackQueue=null,P.ReactReconcileTransaction.release(this.reconcileTransaction),this.reconcileTransaction=null},perform:function(t,e,n){return v.perform.call(this,this.reconcileTransaction.perform,this.reconcileTransaction,t,e,n)}}),p.addPoolingTo(o);var k=function(){for(;m.length||x;){if(m.length){var t=o.getPooled();t.perform(s,null,t),o.release(t)}if(x){x=!1;var e=b;b=d.getPooled(),e.notifyAll(),d.release(e)}}},E={injectReconcileTransaction:function(t){t?void 0:c("126"),P.ReactReconcileTransaction=t},injectBatchingStrategy:function(t){t?void 0:c("127"),"function"!=typeof t.batchedUpdates?c("128"):void 0,"boolean"!=typeof t.isBatchingUpdates?c("129"):void 0,_=t}},P={ReactReconcileTransaction:null,batchedUpdates:i,enqueueUpdate:l,flushBatchedUpdates:k,injection:E,asap:u};t.exports=P},function(t,e,n){"use strict";function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}var o=n(33),i=n(48),a=(n(9),function(){function t(e){r(this,t),this._callbacks=null,this._contexts=null,this._arg=e}return t.prototype.enqueue=function(t,e){this._callbacks=this._callbacks||[],this._callbacks.push(t),this._contexts=this._contexts||[],this._contexts.push(e)},t.prototype.notifyAll=function(){var t=this._callbacks,e=this._contexts,n=this._arg;if(t&&e){t.length!==e.length?o("24"):void 0,this._callbacks=null,this._contexts=null;for(var r=0;r<t.length;r++)t[r].call(e[r],n);t.length=0,e.length=0}},t.prototype.checkpoint=function(){return this._callbacks?this._callbacks.length:0},t.prototype.rollback=function(t){this._callbacks&&this._contexts&&(this._callbacks.length=t,this._contexts.length=t)},t.prototype.reset=function(){this._callbacks=null,this._contexts=null},t.prototype.destructor=function(){this.reset()},t}());t.exports=i.addPoolingTo(a)},function(t,e){"use strict";var n={logTopLevelRenders:!1};t.exports=n},function(t,e,n){"use strict";function r(){o.attachRefs(this,this._currentElement)}var o=n(58),i=(n(60),n(12),{mountComponent:function(t,e,n,o,i,a){var s=t.mountComponent(e,n,o,i,a);return t._currentElement&&null!=t._currentElement.ref&&e.getReactMountReady().enqueue(r,t),s},getHostNode:function(t){return t.getHostNode()},unmountComponent:function(t,e){o.detachRefs(t,t._currentElement),t.unmountComponent(e)},receiveComponent:function(t,e,n,i){var a=t._currentElement;if(e!==a||i!==t._context){var s=o.shouldUpdateRefs(a,e);s&&o.detachRefs(t,a),t.receiveComponent(e,n,i),s&&t._currentElement&&null!=t._currentElement.ref&&n.getReactMountReady().enqueue(r,t)}},performUpdateIfNecessary:function(t,e,n){t._updateBatchNumber===n&&t.performUpdateIfNecessary(e)}});t.exports=i},function(t,e,n){"use strict";function r(t,e,n){"function"==typeof t?t(e.getPublicInstance()):i.addComponentAsRefTo(e,t,n)}function o(t,e,n){"function"==typeof t?t(null):i.removeComponentAsRefFrom(e,t,n)}var i=n(59),a={};a.attachRefs=function(t,e){if(null!==e&&"object"==typeof e){var n=e.ref;null!=n&&r(n,t,e._owner)}},a.shouldUpdateRefs=function(t,e){var n=null,r=null;null!==t&&"object"==typeof t&&(n=t.ref,r=t._owner);var o=null,i=null;return null!==e&&"object"==typeof e&&(o=e.ref,i=e._owner),n!==o||"string"==typeof o&&i!==r},a.detachRefs=function(t,e){if(null!==e&&"object"==typeof e){var n=e.ref;null!=n&&o(n,t,e._owner)}},t.exports=a},function(t,e,n){"use strict";function r(t){return!(!t||"function"!=typeof t.attachRef||"function"!=typeof t.detachRef)}var o=n(33),i=(n(9),{addComponentAsRefTo:function(t,e,n){r(n)?void 0:o("119"),n.attachRef(e,t)},removeComponentAsRefFrom:function(t,e,n){r(n)?void 0:o("120");var i=n.getPublicInstance();i&&i.refs[e]===t.getPublicInstance()&&n.detachRef(e)}});t.exports=i},function(t,e,n){"use strict";var r=null;t.exports={debugTool:r}},function(t,e,n){"use strict";var r=n(33),o=(n(9),{}),i={reinitializeTransaction:function(){this.transactionWrappers=this.getTransactionWrappers(),this.wrapperInitData?this.wrapperInitData.length=0:this.wrapperInitData=[],this._isInTransaction=!1},_isInTransaction:!1,getTransactionWrappers:null,isInTransaction:function(){return!!this._isInTransaction},perform:function(t,e,n,o,i,a,s,l){this.isInTransaction()?r("27"):void 0;var u,c;try{this._isInTransaction=!0,u=!0,this.initializeAll(0),c=t.call(e,n,o,i,a,s,l),u=!1}finally{try{if(u)try{this.closeAll(0)}catch(t){}else this.closeAll(0)}finally{this._isInTransaction=!1}}return c},initializeAll:function(t){for(var e=this.transactionWrappers,n=t;n<e.length;n++){var r=e[n];try{this.wrapperInitData[n]=o,this.wrapperInitData[n]=r.initialize?r.initialize.call(this):null}finally{if(this.wrapperInitData[n]===o)try{this.initializeAll(n+1)}catch(t){}}}},closeAll:function(t){this.isInTransaction()?void 0:r("28");for(var e=this.transactionWrappers,n=t;n<e.length;n++){var i,a=e[n],s=this.wrapperInitData[n];try{i=!0,s!==o&&a.close&&a.close.call(this,s),i=!1}finally{if(i)try{this.closeAll(n+1)}catch(t){}}}this.wrapperInitData.length=0}};t.exports=i},function(t,e){"use strict";function n(t){var e=t.target||t.srcElement||window;return e.correspondingUseElement&&(e=e.correspondingUseElement),3===e.nodeType?e.parentNode:e}t.exports=n},function(t,e,n){"use strict";/**
	 * Checks if an event is supported in the current execution environment.
	 *
	 * NOTE: This will not work correctly for non-generic events such as `change`,
	 * `reset`, `load`, `error`, and `select`.
	 *
	 * Borrows from Modernizr.
	 *
	 * @param {string} eventNameSuffix Event name, e.g. "click".
	 * @param {?boolean} capture Check if the capture phase is supported.
	 * @return {boolean} True if the event is supported.
	 * @internal
	 * @license Modernizr 3.0.0pre (Custom Build) | MIT
	 */
function r(t,e){if(!i.canUseDOM||e&&!("addEventListener"in document))return!1;var n="on"+t,r=n in document;if(!r){var a=document.createElement("div");a.setAttribute(n,"return;"),r="function"==typeof a[n]}return!r&&o&&"wheel"===t&&(r=document.implementation.hasFeature("Events.wheel","3.0")),r}var o,i=n(46);i.canUseDOM&&(o=document.implementation&&document.implementation.hasFeature&&document.implementation.hasFeature("","")!==!0),t.exports=r},function(t,e){"use strict";function n(t){var e=t&&t.nodeName&&t.nodeName.toLowerCase();return"input"===e?!!r[t.type]:"textarea"===e}var r={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};t.exports=n},function(t,e){"use strict";var n=["ResponderEventPlugin","SimpleEventPlugin","TapEventPlugin","EnterLeaveEventPlugin","ChangeEventPlugin","SelectEventPlugin","BeforeInputEventPlugin"];t.exports=n},function(t,e,n){"use strict";var r=n(39),o=n(32),i=n(67),a={mouseEnter:{registrationName:"onMouseEnter",dependencies:["topMouseOut","topMouseOver"]},mouseLeave:{registrationName:"onMouseLeave",dependencies:["topMouseOut","topMouseOver"]}},s={eventTypes:a,extractEvents:function(t,e,n,s){if("topMouseOver"===t&&(n.relatedTarget||n.fromElement))return null;if("topMouseOut"!==t&&"topMouseOver"!==t)return null;var l;if(s.window===s)l=s;else{var u=s.ownerDocument;l=u?u.defaultView||u.parentWindow:window}var c,f;if("topMouseOut"===t){c=e;var d=n.relatedTarget||n.toElement;f=d?o.getClosestInstanceFromNode(d):null}else c=null,f=e;if(c===f)return null;var p=null==c?l:o.getNodeFromInstance(c),h=null==f?l:o.getNodeFromInstance(f),g=i.getPooled(a.mouseLeave,c,n,s);g.type="mouseleave",g.target=p,g.relatedTarget=h;var v=i.getPooled(a.mouseEnter,f,n,s);return v.type="mouseenter",v.target=h,v.relatedTarget=p,r.accumulateEnterLeaveDispatches(g,v,c,f),[g,v]}};t.exports=s},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(68),i=n(69),a=n(70),s={screenX:null,screenY:null,clientX:null,clientY:null,ctrlKey:null,shiftKey:null,altKey:null,metaKey:null,getModifierState:a,button:function(t){var e=t.button;return"which"in t?e:2===e?2:4===e?1:0},buttons:null,relatedTarget:function(t){return t.relatedTarget||(t.fromElement===t.srcElement?t.toElement:t.fromElement)},pageX:function(t){return"pageX"in t?t.pageX:t.clientX+i.currentScrollLeft},pageY:function(t){return"pageY"in t?t.pageY:t.clientY+i.currentScrollTop}};o.augmentClass(r,s),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(51),i=n(62),a={view:function(t){if(t.view)return t.view;var e=i(t);if(e.window===e)return e;var n=e.ownerDocument;return n?n.defaultView||n.parentWindow:window},detail:function(t){return t.detail||0}};o.augmentClass(r,a),t.exports=r},function(t,e){"use strict";var n={currentScrollLeft:0,currentScrollTop:0,refreshScrollValues:function(t){n.currentScrollLeft=t.x,n.currentScrollTop=t.y}};t.exports=n},function(t,e){"use strict";function n(t){var e=this,n=e.nativeEvent;if(n.getModifierState)return n.getModifierState(t);var r=o[t];return!!r&&!!n[r]}function r(t){return n}var o={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};t.exports=r},function(t,e,n){"use strict";var r=n(34),o=r.injection.MUST_USE_PROPERTY,i=r.injection.HAS_BOOLEAN_VALUE,a=r.injection.HAS_NUMERIC_VALUE,s=r.injection.HAS_POSITIVE_NUMERIC_VALUE,l=r.injection.HAS_OVERLOADED_BOOLEAN_VALUE,u={isCustomAttribute:RegExp.prototype.test.bind(new RegExp("^(data|aria)-["+r.ATTRIBUTE_NAME_CHAR+"]*$")),Properties:{accept:0,acceptCharset:0,accessKey:0,action:0,allowFullScreen:i,allowTransparency:0,alt:0,as:0,async:i,autoComplete:0,autoPlay:i,capture:i,cellPadding:0,cellSpacing:0,charSet:0,challenge:0,checked:o|i,cite:0,classID:0,className:0,cols:s,colSpan:0,content:0,contentEditable:0,contextMenu:0,controls:i,coords:0,crossOrigin:0,data:0,dateTime:0,default:i,defer:i,dir:0,disabled:i,download:l,draggable:0,encType:0,form:0,formAction:0,formEncType:0,formMethod:0,formNoValidate:i,formTarget:0,frameBorder:0,headers:0,height:0,hidden:i,high:0,href:0,hrefLang:0,htmlFor:0,httpEquiv:0,icon:0,id:0,inputMode:0,integrity:0,is:0,keyParams:0,keyType:0,kind:0,label:0,lang:0,list:0,loop:i,low:0,manifest:0,marginHeight:0,marginWidth:0,max:0,maxLength:0,media:0,mediaGroup:0,method:0,min:0,minLength:0,multiple:o|i,muted:o|i,name:0,nonce:0,noValidate:i,open:i,optimum:0,pattern:0,placeholder:0,playsInline:i,poster:0,preload:0,profile:0,radioGroup:0,readOnly:i,referrerPolicy:0,rel:0,required:i,reversed:i,role:0,rows:s,rowSpan:a,sandbox:0,scope:0,scoped:i,scrolling:0,seamless:i,selected:o|i,shape:0,size:s,sizes:0,span:s,spellCheck:0,src:0,srcDoc:0,srcLang:0,srcSet:0,start:a,step:0,style:0,summary:0,tabIndex:0,target:0,title:0,type:0,useMap:0,value:0,width:0,wmode:0,wrap:0,about:0,datatype:0,inlist:0,prefix:0,property:0,resource:0,typeof:0,vocab:0,autoCapitalize:0,autoCorrect:0,autoSave:0,color:0,itemProp:0,itemScope:i,itemType:0,itemID:0,itemRef:0,results:0,security:0,unselectable:0},DOMAttributeNames:{acceptCharset:"accept-charset",className:"class",htmlFor:"for",httpEquiv:"http-equiv"},DOMPropertyNames:{}};t.exports=u},function(t,e,n){"use strict";var r=n(73),o=n(84),i={processChildrenUpdates:o.dangerouslyProcessChildrenUpdates,replaceNodeWithMarkup:r.dangerouslyReplaceNodeWithMarkup};t.exports=i},function(t,e,n){"use strict";function r(t,e){return Array.isArray(e)&&(e=e[1]),e?e.nextSibling:t.firstChild}function o(t,e,n){c.insertTreeBefore(t,e,n)}function i(t,e,n){Array.isArray(e)?s(t,e[0],e[1],n):g(t,e,n)}function a(t,e){if(Array.isArray(e)){var n=e[1];e=e[0],l(t,e,n),t.removeChild(n)}t.removeChild(e)}function s(t,e,n,r){for(var o=e;;){var i=o.nextSibling;if(g(t,o,r),o===n)break;o=i}}function l(t,e,n){for(;;){var r=e.nextSibling;if(r===n)break;t.removeChild(r)}}function u(t,e,n){var r=t.parentNode,o=t.nextSibling;o===e?n&&g(r,document.createTextNode(n),o):n?(h(o,n),l(r,o,e)):l(r,t,e)}var c=n(74),f=n(80),d=(n(32),n(60),n(77)),p=n(76),h=n(78),g=d(function(t,e,n){t.insertBefore(e,n)}),v=f.dangerouslyReplaceNodeWithMarkup,m={dangerouslyReplaceNodeWithMarkup:v,replaceDelimitedText:u,processUpdates:function(t,e){for(var n=0;n<e.length;n++){var s=e[n];switch(s.type){case"INSERT_MARKUP":o(t,s.content,r(t,s.afterNode));break;case"MOVE_EXISTING":i(t,s.fromNode,r(t,s.afterNode));break;case"SET_MARKUP":p(t,s.content);break;case"TEXT_CONTENT":h(t,s.content);break;case"REMOVE_NODE":a(t,s.fromNode)}}}};t.exports=m},function(t,e,n){"use strict";function r(t){if(v){var e=t.node,n=t.children;if(n.length)for(var r=0;r<n.length;r++)m(e,n[r],null);else null!=t.html?f(e,t.html):null!=t.text&&p(e,t.text)}}function o(t,e){t.parentNode.replaceChild(e.node,t),r(e)}function i(t,e){v?t.children.push(e):t.node.appendChild(e.node)}function a(t,e){v?t.html=e:f(t.node,e)}function s(t,e){v?t.text=e:p(t.node,e)}function l(){return this.node.nodeName}function u(t){return{node:t,children:[],html:null,text:null,toString:l}}var c=n(75),f=n(76),d=n(77),p=n(78),h=1,g=11,v="undefined"!=typeof document&&"number"==typeof document.documentMode||"undefined"!=typeof navigator&&"string"==typeof navigator.userAgent&&/\bEdge\/\d/.test(navigator.userAgent),m=d(function(t,e,n){e.node.nodeType===g||e.node.nodeType===h&&"object"===e.node.nodeName.toLowerCase()&&(null==e.node.namespaceURI||e.node.namespaceURI===c.html)?(r(e),t.insertBefore(e.node,n)):(t.insertBefore(e.node,n),r(e))});u.insertTreeBefore=m,u.replaceChildWithTree=o,u.queueChild=i,u.queueHTML=a,u.queueText=s,t.exports=u},function(t,e){"use strict";var n={html:"http://www.w3.org/1999/xhtml",mathml:"http://www.w3.org/1998/Math/MathML",svg:"http://www.w3.org/2000/svg"};t.exports=n},function(t,e,n){"use strict";var r,o=n(46),i=n(75),a=/^[ \r\n\t\f]/,s=/<(!--|link|noscript|meta|script|style)[ \r\n\t\f\/>]/,l=n(77),u=l(function(t,e){if(t.namespaceURI!==i.svg||"innerHTML"in t)t.innerHTML=e;else{r=r||document.createElement("div"),r.innerHTML="<svg>"+e+"</svg>";for(var n=r.firstChild;n.firstChild;)t.appendChild(n.firstChild)}});if(o.canUseDOM){var c=document.createElement("div");c.innerHTML=" ",""===c.innerHTML&&(u=function(t,e){if(t.parentNode&&t.parentNode.replaceChild(t,t),a.test(e)||"<"===e[0]&&s.test(e)){t.innerHTML=String.fromCharCode(65279)+e;var n=t.firstChild;1===n.data.length?t.removeChild(n):n.deleteData(0,1)}else t.innerHTML=e}),c=null}t.exports=u},function(t,e){"use strict";var n=function(t){return"undefined"!=typeof MSApp&&MSApp.execUnsafeLocalFunction?function(e,n,r,o){MSApp.execUnsafeLocalFunction(function(){return t(e,n,r,o)})}:t};t.exports=n},function(t,e,n){"use strict";var r=n(46),o=n(79),i=n(76),a=function(t,e){if(e){var n=t.firstChild;if(n&&n===t.lastChild&&3===n.nodeType)return void(n.nodeValue=e)}t.textContent=e};r.canUseDOM&&("textContent"in document.documentElement||(a=function(t,e){return 3===t.nodeType?void(t.nodeValue=e):void i(t,o(e))})),t.exports=a},function(t,e){"use strict";function n(t){var e=""+t,n=o.exec(e);if(!n)return e;var r,i="",a=0,s=0;for(a=n.index;a<e.length;a++){switch(e.charCodeAt(a)){case 34:r="&quot;";break;case 38:r="&amp;";break;case 39:r="&#x27;";break;case 60:r="&lt;";break;case 62:r="&gt;";break;default:continue}s!==a&&(i+=e.substring(s,a)),s=a+1,i+=r}return s!==a?i+e.substring(s,a):i}function r(t){return"boolean"==typeof t||"number"==typeof t?""+t:n(t)}var o=/["'&<>]/;t.exports=r},function(t,e,n){"use strict";var r=n(33),o=n(74),i=n(46),a=n(81),s=n(13),l=(n(9),{dangerouslyReplaceNodeWithMarkup:function(t,e){if(i.canUseDOM?void 0:r("56"),e?void 0:r("57"),"HTML"===t.nodeName?r("58"):void 0,"string"==typeof e){var n=a(e,s)[0];t.parentNode.replaceChild(n,t)}else o.replaceChildWithTree(t,e)}});t.exports=l},function(t,e,n){"use strict";function r(t){var e=t.match(c);return e&&e[1].toLowerCase()}function o(t,e){var n=u;u?void 0:l(!1);var o=r(t),i=o&&s(o);if(i){n.innerHTML=i[1]+t+i[2];for(var c=i[0];c--;)n=n.lastChild}else n.innerHTML=t;var f=n.getElementsByTagName("script");f.length&&(e?void 0:l(!1),a(f).forEach(e));for(var d=Array.from(n.childNodes);n.lastChild;)n.removeChild(n.lastChild);return d}var i=n(46),a=n(82),s=n(83),l=n(9),u=i.canUseDOM?document.createElement("div"):null,c=/^\s*<(\w+)/;t.exports=o},function(t,e,n){"use strict";function r(t){var e=t.length;if(Array.isArray(t)||"object"!=typeof t&&"function"!=typeof t?a(!1):void 0,"number"!=typeof e?a(!1):void 0,0===e||e-1 in t?void 0:a(!1),"function"==typeof t.callee?a(!1):void 0,t.hasOwnProperty)try{return Array.prototype.slice.call(t)}catch(t){}for(var n=Array(e),r=0;r<e;r++)n[r]=t[r];return n}function o(t){return!!t&&("object"==typeof t||"function"==typeof t)&&"length"in t&&!("setInterval"in t)&&"number"!=typeof t.nodeType&&(Array.isArray(t)||"callee"in t||"item"in t)}function i(t){return o(t)?Array.isArray(t)?t.slice():r(t):[t]}var a=n(9);t.exports=i},function(t,e,n){"use strict";function r(t){return a?void 0:i(!1),d.hasOwnProperty(t)||(t="*"),s.hasOwnProperty(t)||("*"===t?a.innerHTML="<link />":a.innerHTML="<"+t+"></"+t+">",s[t]=!a.firstChild),s[t]?d[t]:null}var o=n(46),i=n(9),a=o.canUseDOM?document.createElement("div"):null,s={},l=[1,'<select multiple="true">',"</select>"],u=[1,"<table>","</table>"],c=[3,"<table><tbody><tr>","</tr></tbody></table>"],f=[1,'<svg xmlns="http://www.w3.org/2000/svg">',"</svg>"],d={"*":[1,"?<div>","</div>"],area:[1,"<map>","</map>"],col:[2,"<table><tbody></tbody><colgroup>","</colgroup></table>"],legend:[1,"<fieldset>","</fieldset>"],param:[1,"<object>","</object>"],tr:[2,"<table><tbody>","</tbody></table>"],optgroup:l,option:l,caption:u,colgroup:u,tbody:u,tfoot:u,thead:u,td:c,th:c},p=["circle","clipPath","defs","ellipse","g","image","line","linearGradient","mask","path","pattern","polygon","polyline","radialGradient","rect","stop","text","tspan"];p.forEach(function(t){d[t]=f,s[t]=!0}),t.exports=r},function(t,e,n){"use strict";var r=n(73),o=n(32),i={dangerouslyProcessChildrenUpdates:function(t,e){var n=o.getNodeFromInstance(t);r.processUpdates(n,e)}};t.exports=i},function(t,e,n){"use strict";function r(t){if(t){var e=t._currentElement._owner||null;if(e){var n=e.getName();if(n)return" This DOM node was rendered by `"+n+"`."}}return""}function o(t,e){e&&(G[t._tag]&&(null!=e.children||null!=e.dangerouslySetInnerHTML?g("137",t._tag,t._currentElement._owner?" Check the render method of "+t._currentElement._owner.getName()+".":""):void 0),null!=e.dangerouslySetInnerHTML&&(null!=e.children?g("60"):void 0,"object"==typeof e.dangerouslySetInnerHTML&&z in e.dangerouslySetInnerHTML?void 0:g("61")),null!=e.style&&"object"!=typeof e.style?g("62",r(t)):void 0)}function i(t,e,n,r){if(!(r instanceof D)){var o=t._hostContainerInfo,i=o._node&&o._node.nodeType===q,s=i?o._node:o._ownerDocument;j(e,s),r.getReactMountReady().enqueue(a,{inst:t,registrationName:e,listener:n})}}function a(){var t=this;T.putListener(t.inst,t.registrationName,t.listener)}function s(){var t=this;S.postMountWrapper(t)}function l(){var t=this;A.postMountWrapper(t)}function u(){var t=this;M.postMountWrapper(t)}function c(){var t=this;t._rootNodeID?void 0:g("63");var e=F(t);switch(e?void 0:g("64"),t._tag){case"iframe":case"object":t._wrapperState.listeners=[k.trapBubbledEvent("topLoad","load",e)];break;case"video":case"audio":t._wrapperState.listeners=[];for(var n in V)V.hasOwnProperty(n)&&t._wrapperState.listeners.push(k.trapBubbledEvent(n,V[n],e));break;case"source":t._wrapperState.listeners=[k.trapBubbledEvent("topError","error",e)];break;case"img":t._wrapperState.listeners=[k.trapBubbledEvent("topError","error",e),k.trapBubbledEvent("topLoad","load",e)];break;case"form":t._wrapperState.listeners=[k.trapBubbledEvent("topReset","reset",e),k.trapBubbledEvent("topSubmit","submit",e)];break;case"input":case"select":case"textarea":t._wrapperState.listeners=[k.trapBubbledEvent("topInvalid","invalid",e)]}}function f(){N.postUpdateWrapper(this)}function d(t){Z.call($,t)||(X.test(t)?void 0:g("65",t),$[t]=!0)}function p(t,e){return t.indexOf("-")>=0||null!=e.is}function h(t){var e=t.type;d(e),this._currentElement=t,this._tag=e.toLowerCase(),this._namespaceURI=null,this._renderedChildren=null,this._previousStyle=null,this._previousStyleCopy=null,this._hostNode=null,this._hostParent=null,this._rootNodeID=0,this._domID=0,this._hostContainerInfo=null,this._wrapperState=null,this._topLevelWrapper=null,this._flags=0}var g=n(33),v=n(5),m=n(86),y=n(88),b=n(74),x=n(75),_=n(34),w=n(96),T=n(40),C=n(41),k=n(98),E=n(35),P=n(32),S=n(101),M=n(104),N=n(105),A=n(106),O=(n(60),n(107)),D=n(126),I=(n(13),n(79)),R=(n(9),n(63),n(115),n(129),n(12),E),L=T.deleteListener,F=P.getNodeFromInstance,j=k.listenTo,B=C.registrationNameModules,U={string:!0,number:!0},H="style",z="__html",W={children:null,dangerouslySetInnerHTML:null,suppressContentEditableWarning:null},q=11,V={topAbort:"abort",topCanPlay:"canplay",topCanPlayThrough:"canplaythrough",topDurationChange:"durationchange",topEmptied:"emptied",topEncrypted:"encrypted",topEnded:"ended",topError:"error",topLoadedData:"loadeddata",topLoadedMetadata:"loadedmetadata",topLoadStart:"loadstart",topPause:"pause",topPlay:"play",topPlaying:"playing",topProgress:"progress",topRateChange:"ratechange",topSeeked:"seeked",topSeeking:"seeking",topStalled:"stalled",topSuspend:"suspend",topTimeUpdate:"timeupdate",topVolumeChange:"volumechange",topWaiting:"waiting"},K={area:!0,base:!0,br:!0,col:!0,embed:!0,hr:!0,img:!0,input:!0,keygen:!0,link:!0,meta:!0,param:!0,source:!0,track:!0,wbr:!0},Y={listing:!0,pre:!0,textarea:!0},G=v({menuitem:!0},K),X=/^[a-zA-Z][a-zA-Z:_\.\-\d]*$/,$={},Z={}.hasOwnProperty,J=1;h.displayName="ReactDOMComponent",h.Mixin={mountComponent:function(t,e,n,r){this._rootNodeID=J++,this._domID=n._idCounter++,this._hostParent=e,this._hostContainerInfo=n;var i=this._currentElement.props;switch(this._tag){case"audio":case"form":case"iframe":case"img":case"link":case"object":case"source":case"video":this._wrapperState={listeners:null},t.getReactMountReady().enqueue(c,this);break;case"input":S.mountWrapper(this,i,e),i=S.getHostProps(this,i),t.getReactMountReady().enqueue(c,this);break;case"option":M.mountWrapper(this,i,e),i=M.getHostProps(this,i);break;case"select":N.mountWrapper(this,i,e),i=N.getHostProps(this,i),t.getReactMountReady().enqueue(c,this);break;case"textarea":A.mountWrapper(this,i,e),i=A.getHostProps(this,i),t.getReactMountReady().enqueue(c,this)}o(this,i);var a,f;null!=e?(a=e._namespaceURI,f=e._tag):n._tag&&(a=n._namespaceURI,f=n._tag),(null==a||a===x.svg&&"foreignobject"===f)&&(a=x.html),a===x.html&&("svg"===this._tag?a=x.svg:"math"===this._tag&&(a=x.mathml)),this._namespaceURI=a;var d;if(t.useCreateElement){var p,h=n._ownerDocument;if(a===x.html)if("script"===this._tag){var g=h.createElement("div"),v=this._currentElement.type;g.innerHTML="<"+v+"></"+v+">",p=g.removeChild(g.firstChild)}else p=i.is?h.createElement(this._currentElement.type,i.is):h.createElement(this._currentElement.type);else p=h.createElementNS(a,this._currentElement.type);P.precacheNode(this,p),this._flags|=R.hasCachedChildNodes,this._hostParent||w.setAttributeForRoot(p),this._updateDOMProperties(null,i,t);var y=b(p);this._createInitialChildren(t,i,r,y),d=y}else{var _=this._createOpenTagMarkupAndPutListeners(t,i),T=this._createContentMarkup(t,i,r);d=!T&&K[this._tag]?_+"/>":_+">"+T+"</"+this._currentElement.type+">"}switch(this._tag){case"input":t.getReactMountReady().enqueue(s,this),i.autoFocus&&t.getReactMountReady().enqueue(m.focusDOMComponent,this);break;case"textarea":t.getReactMountReady().enqueue(l,this),i.autoFocus&&t.getReactMountReady().enqueue(m.focusDOMComponent,this);break;case"select":i.autoFocus&&t.getReactMountReady().enqueue(m.focusDOMComponent,this);break;case"button":i.autoFocus&&t.getReactMountReady().enqueue(m.focusDOMComponent,this);break;case"option":t.getReactMountReady().enqueue(u,this)}return d},_createOpenTagMarkupAndPutListeners:function(t,e){var n="<"+this._currentElement.type;for(var r in e)if(e.hasOwnProperty(r)){var o=e[r];if(null!=o)if(B.hasOwnProperty(r))o&&i(this,r,o,t);else{r===H&&(o&&(o=this._previousStyleCopy=v({},e.style)),o=y.createMarkupForStyles(o,this));var a=null;null!=this._tag&&p(this._tag,e)?W.hasOwnProperty(r)||(a=w.createMarkupForCustomAttribute(r,o)):a=w.createMarkupForProperty(r,o),a&&(n+=" "+a)}}return t.renderToStaticMarkup?n:(this._hostParent||(n+=" "+w.createMarkupForRoot()),n+=" "+w.createMarkupForID(this._domID))},_createContentMarkup:function(t,e,n){var r="",o=e.dangerouslySetInnerHTML;if(null!=o)null!=o.__html&&(r=o.__html);else{var i=U[typeof e.children]?e.children:null,a=null!=i?null:e.children;if(null!=i)r=I(i);else if(null!=a){var s=this.mountChildren(a,t,n);r=s.join("")}}return Y[this._tag]&&"\n"===r.charAt(0)?"\n"+r:r},_createInitialChildren:function(t,e,n,r){var o=e.dangerouslySetInnerHTML;if(null!=o)null!=o.__html&&b.queueHTML(r,o.__html);else{var i=U[typeof e.children]?e.children:null,a=null!=i?null:e.children;if(null!=i)""!==i&&b.queueText(r,i);else if(null!=a)for(var s=this.mountChildren(a,t,n),l=0;l<s.length;l++)b.queueChild(r,s[l])}},receiveComponent:function(t,e,n){var r=this._currentElement;this._currentElement=t,this.updateComponent(e,r,t,n)},updateComponent:function(t,e,n,r){var i=e.props,a=this._currentElement.props;switch(this._tag){case"input":i=S.getHostProps(this,i),a=S.getHostProps(this,a);break;case"option":i=M.getHostProps(this,i),a=M.getHostProps(this,a);break;case"select":i=N.getHostProps(this,i),a=N.getHostProps(this,a);break;case"textarea":i=A.getHostProps(this,i),a=A.getHostProps(this,a)}switch(o(this,a),this._updateDOMProperties(i,a,t),this._updateDOMChildren(i,a,t,r),this._tag){case"input":S.updateWrapper(this);break;case"textarea":A.updateWrapper(this);break;case"select":t.getReactMountReady().enqueue(f,this)}},_updateDOMProperties:function(t,e,n){var r,o,a;for(r in t)if(!e.hasOwnProperty(r)&&t.hasOwnProperty(r)&&null!=t[r])if(r===H){var s=this._previousStyleCopy;for(o in s)s.hasOwnProperty(o)&&(a=a||{},a[o]="");this._previousStyleCopy=null}else B.hasOwnProperty(r)?t[r]&&L(this,r):p(this._tag,t)?W.hasOwnProperty(r)||w.deleteValueForAttribute(F(this),r):(_.properties[r]||_.isCustomAttribute(r))&&w.deleteValueForProperty(F(this),r);for(r in e){var l=e[r],u=r===H?this._previousStyleCopy:null!=t?t[r]:void 0;if(e.hasOwnProperty(r)&&l!==u&&(null!=l||null!=u))if(r===H)if(l?l=this._previousStyleCopy=v({},l):this._previousStyleCopy=null,u){for(o in u)!u.hasOwnProperty(o)||l&&l.hasOwnProperty(o)||(a=a||{},a[o]="");for(o in l)l.hasOwnProperty(o)&&u[o]!==l[o]&&(a=a||{},a[o]=l[o])}else a=l;else if(B.hasOwnProperty(r))l?i(this,r,l,n):u&&L(this,r);else if(p(this._tag,e))W.hasOwnProperty(r)||w.setValueForAttribute(F(this),r,l);else if(_.properties[r]||_.isCustomAttribute(r)){var c=F(this);null!=l?w.setValueForProperty(c,r,l):w.deleteValueForProperty(c,r)}}a&&y.setValueForStyles(F(this),a,this)},_updateDOMChildren:function(t,e,n,r){var o=U[typeof t.children]?t.children:null,i=U[typeof e.children]?e.children:null,a=t.dangerouslySetInnerHTML&&t.dangerouslySetInnerHTML.__html,s=e.dangerouslySetInnerHTML&&e.dangerouslySetInnerHTML.__html,l=null!=o?null:t.children,u=null!=i?null:e.children,c=null!=o||null!=a,f=null!=i||null!=s;null!=l&&null==u?this.updateChildren(null,n,r):c&&!f&&this.updateTextContent(""),null!=i?o!==i&&this.updateTextContent(""+i):null!=s?a!==s&&this.updateMarkup(""+s):null!=u&&this.updateChildren(u,n,r)},getHostNode:function(){return F(this)},unmountComponent:function(t){switch(this._tag){case"audio":case"form":case"iframe":case"img":case"link":case"object":case"source":case"video":var e=this._wrapperState.listeners;if(e)for(var n=0;n<e.length;n++)e[n].remove();break;case"html":case"head":case"body":g("66",this._tag)}this.unmountChildren(t),P.uncacheNode(this),T.deleteAllListeners(this),this._rootNodeID=0,this._domID=0,this._wrapperState=null},getPublicInstance:function(){return F(this)}},v(h.prototype,h.Mixin,O.Mixin),t.exports=h},function(t,e,n){"use strict";var r=n(32),o=n(87),i={focusDOMComponent:function(){o(r.getNodeFromInstance(this))}};t.exports=i},function(t,e){"use strict";function n(t){try{t.focus()}catch(t){}}t.exports=n},function(t,e,n){"use strict";var r=n(89),o=n(46),i=(n(60),n(90),n(92)),a=n(93),s=n(95),l=(n(12),s(function(t){return a(t)})),u=!1,c="cssFloat";if(o.canUseDOM){var f=document.createElement("div").style;try{f.font=""}catch(t){u=!0}void 0===document.documentElement.style.cssFloat&&(c="styleFloat")}var d={createMarkupForStyles:function(t,e){var n="";for(var r in t)if(t.hasOwnProperty(r)){var o=t[r];null!=o&&(n+=l(r)+":",n+=i(r,o,e)+";")}return n||null},setValueForStyles:function(t,e,n){var o=t.style;for(var a in e)if(e.hasOwnProperty(a)){var s=i(a,e[a],n);if("float"!==a&&"cssFloat"!==a||(a=c),s)o[a]=s;else{var l=u&&r.shorthandPropertyExpansions[a];if(l)for(var f in l)o[f]="";else o[a]=""}}}};t.exports=d},function(t,e){"use strict";function n(t,e){return t+e.charAt(0).toUpperCase()+e.substring(1)}var r={animationIterationCount:!0,borderImageOutset:!0,borderImageSlice:!0,borderImageWidth:!0,boxFlex:!0,boxFlexGroup:!0,boxOrdinalGroup:!0,columnCount:!0,flex:!0,flexGrow:!0,flexPositive:!0,flexShrink:!0,flexNegative:!0,flexOrder:!0,gridRow:!0,gridColumn:!0,fontWeight:!0,lineClamp:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,tabSize:!0,widows:!0,zIndex:!0,zoom:!0,fillOpacity:!0,floodOpacity:!0,stopOpacity:!0,strokeDasharray:!0,strokeDashoffset:!0,strokeMiterlimit:!0,strokeOpacity:!0,strokeWidth:!0},o=["Webkit","ms","Moz","O"];Object.keys(r).forEach(function(t){o.forEach(function(e){r[n(e,t)]=r[t]})});var i={background:{backgroundAttachment:!0,backgroundColor:!0,backgroundImage:!0,backgroundPositionX:!0,backgroundPositionY:!0,backgroundRepeat:!0},backgroundPosition:{backgroundPositionX:!0,backgroundPositionY:!0},border:{borderWidth:!0,borderStyle:!0,borderColor:!0},borderBottom:{borderBottomWidth:!0,borderBottomStyle:!0,borderBottomColor:!0},borderLeft:{borderLeftWidth:!0,borderLeftStyle:!0,borderLeftColor:!0},borderRight:{borderRightWidth:!0,borderRightStyle:!0,borderRightColor:!0},borderTop:{borderTopWidth:!0,borderTopStyle:!0,borderTopColor:!0},font:{fontStyle:!0,fontVariant:!0,fontWeight:!0,fontSize:!0,lineHeight:!0,fontFamily:!0},outline:{outlineWidth:!0,outlineStyle:!0,outlineColor:!0}},a={isUnitlessNumber:r,shorthandPropertyExpansions:i};t.exports=a},function(t,e,n){"use strict";function r(t){return o(t.replace(i,"ms-"))}var o=n(91),i=/^-ms-/;t.exports=r},function(t,e){"use strict";function n(t){return t.replace(r,function(t,e){return e.toUpperCase()})}var r=/-(.)/g;t.exports=n},function(t,e,n){"use strict";function r(t,e,n){var r=null==e||"boolean"==typeof e||""===e;if(r)return"";var o=isNaN(e);if(o||0===e||i.hasOwnProperty(t)&&i[t])return""+e;if("string"==typeof e){e=e.trim()}return e+"px"}var o=n(89),i=(n(12),o.isUnitlessNumber);t.exports=r},function(t,e,n){"use strict";function r(t){return o(t).replace(i,"-ms-")}var o=n(94),i=/^ms-/;t.exports=r},function(t,e){"use strict";function n(t){return t.replace(r,"-$1").toLowerCase()}var r=/([A-Z])/g;t.exports=n},function(t,e){"use strict";function n(t){var e={};return function(n){return e.hasOwnProperty(n)||(e[n]=t.call(this,n)),e[n]}}t.exports=n},function(t,e,n){"use strict";function r(t){return!!u.hasOwnProperty(t)||!l.hasOwnProperty(t)&&(s.test(t)?(u[t]=!0,!0):(l[t]=!0,!1))}function o(t,e){return null==e||t.hasBooleanValue&&!e||t.hasNumericValue&&isNaN(e)||t.hasPositiveNumericValue&&e<1||t.hasOverloadedBooleanValue&&e===!1}var i=n(34),a=(n(32),n(60),n(97)),s=(n(12),new RegExp("^["+i.ATTRIBUTE_NAME_START_CHAR+"]["+i.ATTRIBUTE_NAME_CHAR+"]*$")),l={},u={},c={createMarkupForID:function(t){return i.ID_ATTRIBUTE_NAME+"="+a(t)},setAttributeForID:function(t,e){t.setAttribute(i.ID_ATTRIBUTE_NAME,e)},createMarkupForRoot:function(){return i.ROOT_ATTRIBUTE_NAME+'=""'},setAttributeForRoot:function(t){t.setAttribute(i.ROOT_ATTRIBUTE_NAME,"")},createMarkupForProperty:function(t,e){var n=i.properties.hasOwnProperty(t)?i.properties[t]:null;if(n){if(o(n,e))return"";var r=n.attributeName;return n.hasBooleanValue||n.hasOverloadedBooleanValue&&e===!0?r+'=""':r+"="+a(e)}return i.isCustomAttribute(t)?null==e?"":t+"="+a(e):null},createMarkupForCustomAttribute:function(t,e){return r(t)&&null!=e?t+"="+a(e):""},setValueForProperty:function(t,e,n){var r=i.properties.hasOwnProperty(e)?i.properties[e]:null;if(r){var a=r.mutationMethod;if(a)a(t,n);else{if(o(r,n))return void this.deleteValueForProperty(t,e);if(r.mustUseProperty)t[r.propertyName]=n;else{var s=r.attributeName,l=r.attributeNamespace;l?t.setAttributeNS(l,s,""+n):r.hasBooleanValue||r.hasOverloadedBooleanValue&&n===!0?t.setAttribute(s,""):t.setAttribute(s,""+n)}}}else if(i.isCustomAttribute(e))return void c.setValueForAttribute(t,e,n)},setValueForAttribute:function(t,e,n){if(r(e)){null==n?t.removeAttribute(e):t.setAttribute(e,""+n)}},deleteValueForAttribute:function(t,e){t.removeAttribute(e)},deleteValueForProperty:function(t,e){var n=i.properties.hasOwnProperty(e)?i.properties[e]:null;if(n){var r=n.mutationMethod;if(r)r(t,void 0);else if(n.mustUseProperty){var o=n.propertyName;n.hasBooleanValue?t[o]=!1:t[o]=""}else t.removeAttribute(n.attributeName)}else i.isCustomAttribute(e)&&t.removeAttribute(e)}};t.exports=c},function(t,e,n){"use strict";function r(t){return'"'+o(t)+'"'}var o=n(79);t.exports=r},function(t,e,n){"use strict";function r(t){return Object.prototype.hasOwnProperty.call(t,g)||(t[g]=p++,f[t[g]]={}),f[t[g]]}var o,i=n(5),a=n(41),s=n(99),l=n(69),u=n(100),c=n(63),f={},d=!1,p=0,h={topAbort:"abort",topAnimationEnd:u("animationend")||"animationend",topAnimationIteration:u("animationiteration")||"animationiteration",topAnimationStart:u("animationstart")||"animationstart",topBlur:"blur",topCanPlay:"canplay",topCanPlayThrough:"canplaythrough",topChange:"change",topClick:"click",topCompositionEnd:"compositionend",topCompositionStart:"compositionstart",topCompositionUpdate:"compositionupdate",topContextMenu:"contextmenu",topCopy:"copy",topCut:"cut",topDoubleClick:"dblclick",topDrag:"drag",topDragEnd:"dragend",topDragEnter:"dragenter",topDragExit:"dragexit",topDragLeave:"dragleave",topDragOver:"dragover",topDragStart:"dragstart",topDrop:"drop",topDurationChange:"durationchange",topEmptied:"emptied",topEncrypted:"encrypted",topEnded:"ended",topError:"error",topFocus:"focus",topInput:"input",topKeyDown:"keydown",topKeyPress:"keypress",topKeyUp:"keyup",topLoadedData:"loadeddata",topLoadedMetadata:"loadedmetadata",topLoadStart:"loadstart",topMouseDown:"mousedown",topMouseMove:"mousemove",topMouseOut:"mouseout",topMouseOver:"mouseover",topMouseUp:"mouseup",topPaste:"paste",topPause:"pause",topPlay:"play",topPlaying:"playing",topProgress:"progress",topRateChange:"ratechange",topScroll:"scroll",topSeeked:"seeked",topSeeking:"seeking",topSelectionChange:"selectionchange",topStalled:"stalled",topSuspend:"suspend",topTextInput:"textInput",topTimeUpdate:"timeupdate",topTouchCancel:"touchcancel",topTouchEnd:"touchend",topTouchMove:"touchmove",topTouchStart:"touchstart",topTransitionEnd:u("transitionend")||"transitionend",topVolumeChange:"volumechange",topWaiting:"waiting",topWheel:"wheel"},g="_reactListenersID"+String(Math.random()).slice(2),v=i({},s,{ReactEventListener:null,injection:{injectReactEventListener:function(t){t.setHandleTopLevel(v.handleTopLevel),v.ReactEventListener=t}},setEnabled:function(t){v.ReactEventListener&&v.ReactEventListener.setEnabled(t)},isEnabled:function(){return!(!v.ReactEventListener||!v.ReactEventListener.isEnabled())},listenTo:function(t,e){for(var n=e,o=r(n),i=a.registrationNameDependencies[t],s=0;s<i.length;s++){var l=i[s];o.hasOwnProperty(l)&&o[l]||("topWheel"===l?c("wheel")?v.ReactEventListener.trapBubbledEvent("topWheel","wheel",n):c("mousewheel")?v.ReactEventListener.trapBubbledEvent("topWheel","mousewheel",n):v.ReactEventListener.trapBubbledEvent("topWheel","DOMMouseScroll",n):"topScroll"===l?c("scroll",!0)?v.ReactEventListener.trapCapturedEvent("topScroll","scroll",n):v.ReactEventListener.trapBubbledEvent("topScroll","scroll",v.ReactEventListener.WINDOW_HANDLE):"topFocus"===l||"topBlur"===l?(c("focus",!0)?(v.ReactEventListener.trapCapturedEvent("topFocus","focus",n),v.ReactEventListener.trapCapturedEvent("topBlur","blur",n)):c("focusin")&&(v.ReactEventListener.trapBubbledEvent("topFocus","focusin",n),v.ReactEventListener.trapBubbledEvent("topBlur","focusout",n)),o.topBlur=!0,o.topFocus=!0):h.hasOwnProperty(l)&&v.ReactEventListener.trapBubbledEvent(l,h[l],n),o[l]=!0)}},trapBubbledEvent:function(t,e,n){return v.ReactEventListener.trapBubbledEvent(t,e,n)},trapCapturedEvent:function(t,e,n){return v.ReactEventListener.trapCapturedEvent(t,e,n)},supportsEventPageXY:function(){if(!document.createEvent)return!1;var t=document.createEvent("MouseEvent");return null!=t&&"pageX"in t},ensureScrollValueMonitoring:function(){if(void 0===o&&(o=v.supportsEventPageXY()),!o&&!d){var t=l.refreshScrollValues;v.ReactEventListener.monitorScrollValue(t),d=!0}}});t.exports=v},function(t,e,n){"use strict";function r(t){o.enqueueEvents(t),o.processEventQueue(!1)}var o=n(40),i={handleTopLevel:function(t,e,n,i){var a=o.extractEvents(t,e,n,i);r(a)}};t.exports=i},function(t,e,n){"use strict";function r(t,e){var n={};return n[t.toLowerCase()]=e.toLowerCase(),n["Webkit"+t]="webkit"+e,n["Moz"+t]="moz"+e,n["ms"+t]="MS"+e,n["O"+t]="o"+e.toLowerCase(),n}function o(t){if(s[t])return s[t];if(!a[t])return t;var e=a[t];for(var n in e)if(e.hasOwnProperty(n)&&n in l)return s[t]=e[n];return""}var i=n(46),a={animationend:r("Animation","AnimationEnd"),animationiteration:r("Animation","AnimationIteration"),animationstart:r("Animation","AnimationStart"),transitionend:r("Transition","TransitionEnd")},s={},l={};i.canUseDOM&&(l=document.createElement("div").style,"AnimationEvent"in window||(delete a.animationend.animation,delete a.animationiteration.animation,delete a.animationstart.animation),"TransitionEvent"in window||delete a.transitionend.transition),t.exports=o},function(t,e,n){"use strict";function r(){this._rootNodeID&&f.updateWrapper(this);
}function o(t){var e=this._currentElement.props,n=l.executeOnChange(e,t);c.asap(r,this);var o=e.name;if("radio"===e.type&&null!=o){for(var a=u.getNodeFromInstance(this),s=a;s.parentNode;)s=s.parentNode;for(var f=s.querySelectorAll("input[name="+JSON.stringify(""+o)+'][type="radio"]'),d=0;d<f.length;d++){var p=f[d];if(p!==a&&p.form===a.form){var h=u.getInstanceFromNode(p);h?void 0:i("90"),c.asap(r,h)}}}return n}var i=n(33),a=n(5),s=n(96),l=n(102),u=n(32),c=n(54),f=(n(9),n(12),{getHostProps:function(t,e){var n=l.getValue(e),r=l.getChecked(e),o=a({type:void 0,step:void 0,min:void 0,max:void 0},e,{defaultChecked:void 0,defaultValue:void 0,value:null!=n?n:t._wrapperState.initialValue,checked:null!=r?r:t._wrapperState.initialChecked,onChange:t._wrapperState.onChange});return o},mountWrapper:function(t,e){var n=e.defaultValue;t._wrapperState={initialChecked:null!=e.checked?e.checked:e.defaultChecked,initialValue:null!=e.value?e.value:n,listeners:null,onChange:o.bind(t)}},updateWrapper:function(t){var e=t._currentElement.props,n=e.checked;null!=n&&s.setValueForProperty(u.getNodeFromInstance(t),"checked",n||!1);var r=u.getNodeFromInstance(t),o=l.getValue(e);if(null!=o){var i=""+o;i!==r.value&&(r.value=i)}else null==e.value&&null!=e.defaultValue&&r.defaultValue!==""+e.defaultValue&&(r.defaultValue=""+e.defaultValue),null==e.checked&&null!=e.defaultChecked&&(r.defaultChecked=!!e.defaultChecked)},postMountWrapper:function(t){var e=t._currentElement.props,n=u.getNodeFromInstance(t);switch(e.type){case"submit":case"reset":break;case"color":case"date":case"datetime":case"datetime-local":case"month":case"time":case"week":n.value="",n.value=n.defaultValue;break;default:n.value=n.value}var r=n.name;""!==r&&(n.name=""),n.defaultChecked=!n.defaultChecked,n.defaultChecked=!n.defaultChecked,""!==r&&(n.name=r)}});t.exports=f},function(t,e,n){"use strict";function r(t){null!=t.checkedLink&&null!=t.valueLink?s("87"):void 0}function o(t){r(t),null!=t.value||null!=t.onChange?s("88"):void 0}function i(t){r(t),null!=t.checked||null!=t.onChange?s("89"):void 0}function a(t){if(t){var e=t.getName();if(e)return" Check the render method of `"+e+"`."}return""}var s=n(33),l=n(4),u=n(103),c=(n(9),n(12),{button:!0,checkbox:!0,image:!0,hidden:!0,radio:!0,reset:!0,submit:!0}),f={value:function(t,e,n){return!t[e]||c[t.type]||t.onChange||t.readOnly||t.disabled?null:new Error("You provided a `value` prop to a form field without an `onChange` handler. This will render a read-only field. If the field should be mutable use `defaultValue`. Otherwise, set either `onChange` or `readOnly`.")},checked:function(t,e,n){return!t[e]||t.onChange||t.readOnly||t.disabled?null:new Error("You provided a `checked` prop to a form field without an `onChange` handler. This will render a read-only field. If the field should be mutable use `defaultChecked`. Otherwise, set either `onChange` or `readOnly`.")},onChange:l.PropTypes.func},d={},p={checkPropTypes:function(t,e,n){for(var r in f){if(f.hasOwnProperty(r))var o=f[r](e,r,t,"prop",null,u);if(o instanceof Error&&!(o.message in d)){d[o.message]=!0;a(n)}}},getValue:function(t){return t.valueLink?(o(t),t.valueLink.value):t.value},getChecked:function(t){return t.checkedLink?(i(t),t.checkedLink.value):t.checked},executeOnChange:function(t,e){return t.valueLink?(o(t),t.valueLink.requestChange(e.target.value)):t.checkedLink?(i(t),t.checkedLink.requestChange(e.target.checked)):t.onChange?t.onChange.call(void 0,e):void 0}};t.exports=p},function(t,e){"use strict";var n="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED";t.exports=n},function(t,e,n){"use strict";function r(t){var e="";return i.Children.forEach(t,function(t){null!=t&&("string"==typeof t||"number"==typeof t?e+=t:l||(l=!0))}),e}var o=n(5),i=n(4),a=n(32),s=n(105),l=(n(12),!1),u={mountWrapper:function(t,e,n){var o=null;if(null!=n){var i=n;"optgroup"===i._tag&&(i=i._hostParent),null!=i&&"select"===i._tag&&(o=s.getSelectValueContext(i))}var a=null;if(null!=o){var l;if(l=null!=e.value?e.value+"":r(e.children),a=!1,Array.isArray(o)){for(var u=0;u<o.length;u++)if(""+o[u]===l){a=!0;break}}else a=""+o===l}t._wrapperState={selected:a}},postMountWrapper:function(t){var e=t._currentElement.props;if(null!=e.value){var n=a.getNodeFromInstance(t);n.setAttribute("value",e.value)}},getHostProps:function(t,e){var n=o({selected:void 0,children:void 0},e);null!=t._wrapperState.selected&&(n.selected=t._wrapperState.selected);var i=r(e.children);return i&&(n.children=i),n}};t.exports=u},function(t,e,n){"use strict";function r(){if(this._rootNodeID&&this._wrapperState.pendingUpdate){this._wrapperState.pendingUpdate=!1;var t=this._currentElement.props,e=s.getValue(t);null!=e&&o(this,Boolean(t.multiple),e)}}function o(t,e,n){var r,o,i=l.getNodeFromInstance(t).options;if(e){for(r={},o=0;o<n.length;o++)r[""+n[o]]=!0;for(o=0;o<i.length;o++){var a=r.hasOwnProperty(i[o].value);i[o].selected!==a&&(i[o].selected=a)}}else{for(r=""+n,o=0;o<i.length;o++)if(i[o].value===r)return void(i[o].selected=!0);i.length&&(i[0].selected=!0)}}function i(t){var e=this._currentElement.props,n=s.executeOnChange(e,t);return this._rootNodeID&&(this._wrapperState.pendingUpdate=!0),u.asap(r,this),n}var a=n(5),s=n(102),l=n(32),u=n(54),c=(n(12),!1),f={getHostProps:function(t,e){return a({},e,{onChange:t._wrapperState.onChange,value:void 0})},mountWrapper:function(t,e){var n=s.getValue(e);t._wrapperState={pendingUpdate:!1,initialValue:null!=n?n:e.defaultValue,listeners:null,onChange:i.bind(t),wasMultiple:Boolean(e.multiple)},void 0===e.value||void 0===e.defaultValue||c||(c=!0)},getSelectValueContext:function(t){return t._wrapperState.initialValue},postUpdateWrapper:function(t){var e=t._currentElement.props;t._wrapperState.initialValue=void 0;var n=t._wrapperState.wasMultiple;t._wrapperState.wasMultiple=Boolean(e.multiple);var r=s.getValue(e);null!=r?(t._wrapperState.pendingUpdate=!1,o(t,Boolean(e.multiple),r)):n!==Boolean(e.multiple)&&(null!=e.defaultValue?o(t,Boolean(e.multiple),e.defaultValue):o(t,Boolean(e.multiple),e.multiple?[]:""))}};t.exports=f},function(t,e,n){"use strict";function r(){this._rootNodeID&&c.updateWrapper(this)}function o(t){var e=this._currentElement.props,n=s.executeOnChange(e,t);return u.asap(r,this),n}var i=n(33),a=n(5),s=n(102),l=n(32),u=n(54),c=(n(9),n(12),{getHostProps:function(t,e){null!=e.dangerouslySetInnerHTML?i("91"):void 0;var n=a({},e,{value:void 0,defaultValue:void 0,children:""+t._wrapperState.initialValue,onChange:t._wrapperState.onChange});return n},mountWrapper:function(t,e){var n=s.getValue(e),r=n;if(null==n){var a=e.defaultValue,l=e.children;null!=l&&(null!=a?i("92"):void 0,Array.isArray(l)&&(l.length<=1?void 0:i("93"),l=l[0]),a=""+l),null==a&&(a=""),r=a}t._wrapperState={initialValue:""+r,listeners:null,onChange:o.bind(t)}},updateWrapper:function(t){var e=t._currentElement.props,n=l.getNodeFromInstance(t),r=s.getValue(e);if(null!=r){var o=""+r;o!==n.value&&(n.value=o),null==e.defaultValue&&(n.defaultValue=o)}null!=e.defaultValue&&(n.defaultValue=e.defaultValue)},postMountWrapper:function(t){var e=l.getNodeFromInstance(t),n=e.textContent;n===t._wrapperState.initialValue&&(e.value=n)}});t.exports=c},function(t,e,n){"use strict";function r(t,e,n){return{type:"INSERT_MARKUP",content:t,fromIndex:null,fromNode:null,toIndex:n,afterNode:e}}function o(t,e,n){return{type:"MOVE_EXISTING",content:null,fromIndex:t._mountIndex,fromNode:d.getHostNode(t),toIndex:n,afterNode:e}}function i(t,e){return{type:"REMOVE_NODE",content:null,fromIndex:t._mountIndex,fromNode:e,toIndex:null,afterNode:null}}function a(t){return{type:"SET_MARKUP",content:t,fromIndex:null,fromNode:null,toIndex:null,afterNode:null}}function s(t){return{type:"TEXT_CONTENT",content:t,fromIndex:null,fromNode:null,toIndex:null,afterNode:null}}function l(t,e){return e&&(t=t||[],t.push(e)),t}function u(t,e){f.processChildrenUpdates(t,e)}var c=n(33),f=n(108),d=(n(109),n(60),n(11),n(57)),p=n(110),h=(n(13),n(125)),g=(n(9),{Mixin:{_reconcilerInstantiateChildren:function(t,e,n){return p.instantiateChildren(t,e,n)},_reconcilerUpdateChildren:function(t,e,n,r,o,i){var a,s=0;return a=h(e,s),p.updateChildren(t,a,n,r,o,this,this._hostContainerInfo,i,s),a},mountChildren:function(t,e,n){var r=this._reconcilerInstantiateChildren(t,e,n);this._renderedChildren=r;var o=[],i=0;for(var a in r)if(r.hasOwnProperty(a)){var s=r[a],l=0,u=d.mountComponent(s,e,this,this._hostContainerInfo,n,l);s._mountIndex=i++,o.push(u)}return o},updateTextContent:function(t){var e=this._renderedChildren;p.unmountChildren(e,!1);for(var n in e)e.hasOwnProperty(n)&&c("118");var r=[s(t)];u(this,r)},updateMarkup:function(t){var e=this._renderedChildren;p.unmountChildren(e,!1);for(var n in e)e.hasOwnProperty(n)&&c("118");var r=[a(t)];u(this,r)},updateChildren:function(t,e,n){this._updateChildren(t,e,n)},_updateChildren:function(t,e,n){var r=this._renderedChildren,o={},i=[],a=this._reconcilerUpdateChildren(r,t,i,o,e,n);if(a||r){var s,c=null,f=0,p=0,h=0,g=null;for(s in a)if(a.hasOwnProperty(s)){var v=r&&r[s],m=a[s];v===m?(c=l(c,this.moveChild(v,g,f,p)),p=Math.max(v._mountIndex,p),v._mountIndex=f):(v&&(p=Math.max(v._mountIndex,p)),c=l(c,this._mountChildAtIndex(m,i[h],g,f,e,n)),h++),f++,g=d.getHostNode(m)}for(s in o)o.hasOwnProperty(s)&&(c=l(c,this._unmountChild(r[s],o[s])));c&&u(this,c),this._renderedChildren=a}},unmountChildren:function(t){var e=this._renderedChildren;p.unmountChildren(e,t),this._renderedChildren=null},moveChild:function(t,e,n,r){if(t._mountIndex<r)return o(t,e,n)},createChild:function(t,e,n){return r(n,e,t._mountIndex)},removeChild:function(t,e){return i(t,e)},_mountChildAtIndex:function(t,e,n,r,o,i){return t._mountIndex=r,this.createChild(t,n,e)},_unmountChild:function(t,e){var n=this.removeChild(t,e);return t._mountIndex=null,n}}});t.exports=g},function(t,e,n){"use strict";var r=n(33),o=(n(9),!1),i={replaceNodeWithMarkup:null,processChildrenUpdates:null,injection:{injectEnvironment:function(t){o?r("104"):void 0,i.replaceNodeWithMarkup=t.replaceNodeWithMarkup,i.processChildrenUpdates=t.processChildrenUpdates,o=!0}}};t.exports=i},function(t,e){"use strict";var n={remove:function(t){t._reactInternalInstance=void 0},get:function(t){return t._reactInternalInstance},has:function(t){return void 0!==t._reactInternalInstance},set:function(t,e){t._reactInternalInstance=e}};t.exports=n},function(t,e,n){(function(e){"use strict";function r(t,e,n,r){var o=void 0===t[n];null!=e&&o&&(t[n]=i(e,!0))}var o=n(57),i=n(112),a=(n(120),n(116)),s=n(121),l=(n(12),{instantiateChildren:function(t,e,n,o){if(null==t)return null;var i={};return s(t,r,i),i},updateChildren:function(t,e,n,r,s,l,u,c,f){if(e||t){var d,p;for(d in e)if(e.hasOwnProperty(d)){p=t&&t[d];var h=p&&p._currentElement,g=e[d];if(null!=p&&a(h,g))o.receiveComponent(p,g,s,c),e[d]=p;else{p&&(r[d]=o.getHostNode(p),o.unmountComponent(p,!1));var v=i(g,!0);e[d]=v;var m=o.mountComponent(v,s,l,u,c,f);n.push(m)}}for(d in t)!t.hasOwnProperty(d)||e&&e.hasOwnProperty(d)||(p=t[d],r[d]=o.getHostNode(p),o.unmountComponent(p,!1))}},unmountChildren:function(t,e){for(var n in t)if(t.hasOwnProperty(n)){var r=t[n];o.unmountComponent(r,e)}}});t.exports=l}).call(e,n(111))},function(t,e){function n(){throw new Error("setTimeout has not been defined")}function r(){throw new Error("clearTimeout has not been defined")}function o(t){if(c===setTimeout)return setTimeout(t,0);if((c===n||!c)&&setTimeout)return c=setTimeout,setTimeout(t,0);try{return c(t,0)}catch(e){try{return c.call(null,t,0)}catch(e){return c.call(this,t,0)}}}function i(t){if(f===clearTimeout)return clearTimeout(t);if((f===r||!f)&&clearTimeout)return f=clearTimeout,clearTimeout(t);try{return f(t)}catch(e){try{return f.call(null,t)}catch(e){return f.call(this,t)}}}function a(){g&&p&&(g=!1,p.length?h=p.concat(h):v=-1,h.length&&s())}function s(){if(!g){var t=o(a);g=!0;for(var e=h.length;e;){for(p=h,h=[];++v<e;)p&&p[v].run();v=-1,e=h.length}p=null,g=!1,i(t)}}function l(t,e){this.fun=t,this.array=e}function u(){}var c,f,d=t.exports={};!function(){try{c="function"==typeof setTimeout?setTimeout:n}catch(t){c=n}try{f="function"==typeof clearTimeout?clearTimeout:r}catch(t){f=r}}();var p,h=[],g=!1,v=-1;d.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var n=1;n<arguments.length;n++)e[n-1]=arguments[n];h.push(new l(t,e)),1!==h.length||g||o(s)},l.prototype.run=function(){this.fun.apply(null,this.array)},d.title="browser",d.browser=!0,d.env={},d.argv=[],d.version="",d.versions={},d.on=u,d.addListener=u,d.once=u,d.off=u,d.removeListener=u,d.removeAllListeners=u,d.emit=u,d.binding=function(t){throw new Error("process.binding is not supported")},d.cwd=function(){return"/"},d.chdir=function(t){throw new Error("process.chdir is not supported")},d.umask=function(){return 0}},function(t,e,n){"use strict";function r(t){if(t){var e=t.getName();if(e)return" Check the render method of `"+e+"`."}return""}function o(t){return"function"==typeof t&&"undefined"!=typeof t.prototype&&"function"==typeof t.prototype.mountComponent&&"function"==typeof t.prototype.receiveComponent}function i(t,e){var n;if(null===t||t===!1)n=u.create(i);else if("object"==typeof t){var s=t,l=s.type;if("function"!=typeof l&&"string"!=typeof l){var d="";d+=r(s._owner),a("130",null==l?l:typeof l,d)}"string"==typeof s.type?n=c.createInternalComponent(s):o(s.type)?(n=new s.type(s),n.getHostNode||(n.getHostNode=n.getNativeNode)):n=new f(s)}else"string"==typeof t||"number"==typeof t?n=c.createInstanceForText(t):a("131",typeof t);return n._mountIndex=0,n._mountImage=null,n}var a=n(33),s=n(5),l=n(113),u=n(117),c=n(118),f=(n(119),n(9),n(12),function(t){this.construct(t)});s(f.prototype,l,{_instantiateReactComponent:i}),t.exports=i},function(t,e,n){"use strict";function r(t){}function o(t,e){}function i(t){return!(!t.prototype||!t.prototype.isReactComponent)}function a(t){return!(!t.prototype||!t.prototype.isPureReactComponent)}var s=n(33),l=n(5),u=n(4),c=n(108),f=n(11),d=n(43),p=n(109),h=(n(60),n(114)),g=n(57),v=n(21),m=(n(9),n(115)),y=n(116),b=(n(12),{ImpureClass:0,PureClass:1,StatelessFunctional:2});r.prototype.render=function(){var t=p.get(this)._currentElement.type,e=t(this.props,this.context,this.updater);return o(t,e),e};var x=1,_={construct:function(t){this._currentElement=t,this._rootNodeID=0,this._compositeType=null,this._instance=null,this._hostParent=null,this._hostContainerInfo=null,this._updateBatchNumber=null,this._pendingElement=null,this._pendingStateQueue=null,this._pendingReplaceState=!1,this._pendingForceUpdate=!1,this._renderedNodeType=null,this._renderedComponent=null,this._context=null,this._mountOrder=0,this._topLevelWrapper=null,this._pendingCallbacks=null,this._calledComponentWillUnmount=!1},mountComponent:function(t,e,n,l){this._context=l,this._mountOrder=x++,this._hostParent=e,this._hostContainerInfo=n;var c,f=this._currentElement.props,d=this._processContext(l),h=this._currentElement.type,g=t.getUpdateQueue(),m=i(h),y=this._constructComponent(m,f,d,g);m||null!=y&&null!=y.render?a(h)?this._compositeType=b.PureClass:this._compositeType=b.ImpureClass:(c=y,o(h,c),null===y||y===!1||u.isValidElement(y)?void 0:s("105",h.displayName||h.name||"Component"),y=new r(h),this._compositeType=b.StatelessFunctional);y.props=f,y.context=d,y.refs=v,y.updater=g,this._instance=y,p.set(y,this);var _=y.state;void 0===_&&(y.state=_=null),"object"!=typeof _||Array.isArray(_)?s("106",this.getName()||"ReactCompositeComponent"):void 0,this._pendingStateQueue=null,this._pendingReplaceState=!1,this._pendingForceUpdate=!1;var w;return w=y.unstable_handleError?this.performInitialMountWithErrorHandling(c,e,n,t,l):this.performInitialMount(c,e,n,t,l),y.componentDidMount&&t.getReactMountReady().enqueue(y.componentDidMount,y),w},_constructComponent:function(t,e,n,r){return this._constructComponentWithoutOwner(t,e,n,r)},_constructComponentWithoutOwner:function(t,e,n,r){var o=this._currentElement.type;return t?new o(e,n,r):o(e,n,r)},performInitialMountWithErrorHandling:function(t,e,n,r,o){var i,a=r.checkpoint();try{i=this.performInitialMount(t,e,n,r,o)}catch(s){r.rollback(a),this._instance.unstable_handleError(s),this._pendingStateQueue&&(this._instance.state=this._processPendingState(this._instance.props,this._instance.context)),a=r.checkpoint(),this._renderedComponent.unmountComponent(!0),r.rollback(a),i=this.performInitialMount(t,e,n,r,o)}return i},performInitialMount:function(t,e,n,r,o){var i=this._instance,a=0;i.componentWillMount&&(i.componentWillMount(),this._pendingStateQueue&&(i.state=this._processPendingState(i.props,i.context))),void 0===t&&(t=this._renderValidatedComponent());var s=h.getType(t);this._renderedNodeType=s;var l=this._instantiateReactComponent(t,s!==h.EMPTY);this._renderedComponent=l;var u=g.mountComponent(l,r,e,n,this._processChildContext(o),a);return u},getHostNode:function(){return g.getHostNode(this._renderedComponent)},unmountComponent:function(t){if(this._renderedComponent){var e=this._instance;if(e.componentWillUnmount&&!e._calledComponentWillUnmount)if(e._calledComponentWillUnmount=!0,t){var n=this.getName()+".componentWillUnmount()";d.invokeGuardedCallback(n,e.componentWillUnmount.bind(e))}else e.componentWillUnmount();this._renderedComponent&&(g.unmountComponent(this._renderedComponent,t),this._renderedNodeType=null,this._renderedComponent=null,this._instance=null),this._pendingStateQueue=null,this._pendingReplaceState=!1,this._pendingForceUpdate=!1,this._pendingCallbacks=null,this._pendingElement=null,this._context=null,this._rootNodeID=0,this._topLevelWrapper=null,p.remove(e)}},_maskContext:function(t){var e=this._currentElement.type,n=e.contextTypes;if(!n)return v;var r={};for(var o in n)r[o]=t[o];return r},_processContext:function(t){var e=this._maskContext(t);return e},_processChildContext:function(t){var e,n=this._currentElement.type,r=this._instance;if(r.getChildContext&&(e=r.getChildContext()),e){"object"!=typeof n.childContextTypes?s("107",this.getName()||"ReactCompositeComponent"):void 0;for(var o in e)o in n.childContextTypes?void 0:s("108",this.getName()||"ReactCompositeComponent",o);return l({},t,e)}return t},_checkContextTypes:function(t,e,n){},receiveComponent:function(t,e,n){var r=this._currentElement,o=this._context;this._pendingElement=null,this.updateComponent(e,r,t,o,n)},performUpdateIfNecessary:function(t){null!=this._pendingElement?g.receiveComponent(this,this._pendingElement,t,this._context):null!==this._pendingStateQueue||this._pendingForceUpdate?this.updateComponent(t,this._currentElement,this._currentElement,this._context,this._context):this._updateBatchNumber=null},updateComponent:function(t,e,n,r,o){var i=this._instance;null==i?s("136",this.getName()||"ReactCompositeComponent"):void 0;var a,l=!1;this._context===o?a=i.context:(a=this._processContext(o),l=!0);var u=e.props,c=n.props;e!==n&&(l=!0),l&&i.componentWillReceiveProps&&i.componentWillReceiveProps(c,a);var f=this._processPendingState(c,a),d=!0;this._pendingForceUpdate||(i.shouldComponentUpdate?d=i.shouldComponentUpdate(c,f,a):this._compositeType===b.PureClass&&(d=!m(u,c)||!m(i.state,f))),this._updateBatchNumber=null,d?(this._pendingForceUpdate=!1,this._performComponentUpdate(n,c,f,a,t,o)):(this._currentElement=n,this._context=o,i.props=c,i.state=f,i.context=a)},_processPendingState:function(t,e){var n=this._instance,r=this._pendingStateQueue,o=this._pendingReplaceState;if(this._pendingReplaceState=!1,this._pendingStateQueue=null,!r)return n.state;if(o&&1===r.length)return r[0];for(var i=l({},o?r[0]:n.state),a=o?1:0;a<r.length;a++){var s=r[a];l(i,"function"==typeof s?s.call(n,i,t,e):s)}return i},_performComponentUpdate:function(t,e,n,r,o,i){var a,s,l,u=this._instance,c=Boolean(u.componentDidUpdate);c&&(a=u.props,s=u.state,l=u.context),u.componentWillUpdate&&u.componentWillUpdate(e,n,r),this._currentElement=t,this._context=i,u.props=e,u.state=n,u.context=r,this._updateRenderedComponent(o,i),c&&o.getReactMountReady().enqueue(u.componentDidUpdate.bind(u,a,s,l),u)},_updateRenderedComponent:function(t,e){var n=this._renderedComponent,r=n._currentElement,o=this._renderValidatedComponent(),i=0;if(y(r,o))g.receiveComponent(n,o,t,this._processChildContext(e));else{var a=g.getHostNode(n);g.unmountComponent(n,!1);var s=h.getType(o);this._renderedNodeType=s;var l=this._instantiateReactComponent(o,s!==h.EMPTY);this._renderedComponent=l;var u=g.mountComponent(l,t,this._hostParent,this._hostContainerInfo,this._processChildContext(e),i);this._replaceNodeWithMarkup(a,u,n)}},_replaceNodeWithMarkup:function(t,e,n){c.replaceNodeWithMarkup(t,e,n)},_renderValidatedComponentWithoutOwnerOrContext:function(){var t,e=this._instance;return t=e.render()},_renderValidatedComponent:function(){var t;if(this._compositeType!==b.StatelessFunctional){f.current=this;try{t=this._renderValidatedComponentWithoutOwnerOrContext()}finally{f.current=null}}else t=this._renderValidatedComponentWithoutOwnerOrContext();return null===t||t===!1||u.isValidElement(t)?void 0:s("109",this.getName()||"ReactCompositeComponent"),t},attachRef:function(t,e){var n=this.getPublicInstance();null==n?s("110"):void 0;var r=e.getPublicInstance(),o=n.refs===v?n.refs={}:n.refs;o[t]=r},detachRef:function(t){var e=this.getPublicInstance().refs;delete e[t]},getName:function(){var t=this._currentElement.type,e=this._instance&&this._instance.constructor;return t.displayName||e&&e.displayName||t.name||e&&e.name||null},getPublicInstance:function(){var t=this._instance;return this._compositeType===b.StatelessFunctional?null:t},_instantiateReactComponent:null};t.exports=_},function(t,e,n){"use strict";var r=n(33),o=n(4),i=(n(9),{HOST:0,COMPOSITE:1,EMPTY:2,getType:function(t){return null===t||t===!1?i.EMPTY:o.isValidElement(t)?"function"==typeof t.type?i.COMPOSITE:i.HOST:void r("26",t)}});t.exports=i},function(t,e){"use strict";function n(t,e){return t===e?0!==t||0!==e||1/t===1/e:t!==t&&e!==e}function r(t,e){if(n(t,e))return!0;if("object"!=typeof t||null===t||"object"!=typeof e||null===e)return!1;var r=Object.keys(t),i=Object.keys(e);if(r.length!==i.length)return!1;for(var a=0;a<r.length;a++)if(!o.call(e,r[a])||!n(t[r[a]],e[r[a]]))return!1;return!0}var o=Object.prototype.hasOwnProperty;t.exports=r},function(t,e){"use strict";function n(t,e){var n=null===t||t===!1,r=null===e||e===!1;if(n||r)return n===r;var o=typeof t,i=typeof e;return"string"===o||"number"===o?"string"===i||"number"===i:"object"===i&&t.type===e.type&&t.key===e.key}t.exports=n},function(t,e){"use strict";var n,r={injectEmptyComponentFactory:function(t){n=t}},o={create:function(t){return n(t)}};o.injection=r,t.exports=o},function(t,e,n){"use strict";function r(t){return s?void 0:a("111",t.type),new s(t)}function o(t){return new l(t)}function i(t){return t instanceof l}var a=n(33),s=(n(9),null),l=null,u={injectGenericComponentClass:function(t){s=t},injectTextComponentClass:function(t){l=t}},c={createInternalComponent:r,createInstanceForText:o,isTextComponent:i,injection:u};t.exports=c},function(t,e){"use strict";function n(){return r++}var r=1;t.exports=n},function(t,e){"use strict";function n(t){var e=/[=:]/g,n={"=":"=0",":":"=2"},r=(""+t).replace(e,function(t){return n[t]});return"$"+r}function r(t){var e=/(=0|=2)/g,n={"=0":"=","=2":":"},r="."===t[0]&&"$"===t[1]?t.substring(2):t.substring(1);return(""+r).replace(e,function(t){return n[t]})}var o={escape:n,unescape:r};t.exports=o},function(t,e,n){"use strict";function r(t,e){return t&&"object"==typeof t&&null!=t.key?u.escape(t.key):e.toString(36)}function o(t,e,n,i){var d=typeof t;if("undefined"!==d&&"boolean"!==d||(t=null),null===t||"string"===d||"number"===d||"object"===d&&t.$$typeof===s)return n(i,t,""===e?c+r(t,0):e),1;var p,h,g=0,v=""===e?c:e+f;if(Array.isArray(t))for(var m=0;m<t.length;m++)p=t[m],h=v+r(p,m),g+=o(p,h,n,i);else{var y=l(t);if(y){var b,x=y.call(t);if(y!==t.entries)for(var _=0;!(b=x.next()).done;)p=b.value,h=v+r(p,_++),g+=o(p,h,n,i);else for(;!(b=x.next()).done;){var w=b.value;w&&(p=w[1],h=v+u.escape(w[0])+f+r(p,0),g+=o(p,h,n,i))}}else if("object"===d){var T="",C=String(t);a("31","[object Object]"===C?"object with keys {"+Object.keys(t).join(", ")+"}":C,T)}}return g}function i(t,e,n){return null==t?0:o(t,"",e,n)}var a=n(33),s=(n(11),n(122)),l=n(123),u=(n(9),n(120)),c=(n(12),"."),f=":";t.exports=i},function(t,e){"use strict";var n="function"==typeof Symbol&&Symbol.for&&Symbol.for("react.element")||60103;t.exports=n},function(t,e){"use strict";function n(t){var e=t&&(r&&t[r]||t[o]);if("function"==typeof e)return e}var r="function"==typeof Symbol&&Symbol.iterator,o="@@iterator";t.exports=n},function(t,e,n){"use strict";function r(t){var e=Function.prototype.toString,n=Object.prototype.hasOwnProperty,r=RegExp("^"+e.call(n).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$");try{var o=e.call(t);return r.test(o)}catch(t){return!1}}function o(t){var e=u(t);if(e){var n=e.childIDs;c(t),n.forEach(o)}}function i(t,e,n){return"\n    in "+(t||"Unknown")+(e?" (at "+e.fileName.replace(/^.*[\\\/]/,"")+":"+e.lineNumber+")":n?" (created by "+n+")":"")}function a(t){return null==t?"#empty":"string"==typeof t||"number"==typeof t?"#text":"string"==typeof t.type?t.type:t.type.displayName||t.type.name||"Unknown"}function s(t){var e,n=k.getDisplayName(t),r=k.getElement(t),o=k.getOwnerID(t);return o&&(e=k.getDisplayName(o)),i(n,r&&r._source,e)}var l,u,c,f,d,p,h,g=n(8),v=n(11),m=(n(9),n(12),"function"==typeof Array.from&&"function"==typeof Map&&r(Map)&&null!=Map.prototype&&"function"==typeof Map.prototype.keys&&r(Map.prototype.keys)&&"function"==typeof Set&&r(Set)&&null!=Set.prototype&&"function"==typeof Set.prototype.keys&&r(Set.prototype.keys));if(m){var y=new Map,b=new Set;l=function(t,e){y.set(t,e)},u=function(t){return y.get(t)},c=function(t){y.delete(t)},f=function(){return Array.from(y.keys())},d=function(t){b.add(t)},p=function(t){b.delete(t)},h=function(){return Array.from(b.keys())}}else{var x={},_={},w=function(t){return"."+t},T=function(t){return parseInt(t.substr(1),10)};l=function(t,e){var n=w(t);x[n]=e},u=function(t){var e=w(t);return x[e]},c=function(t){var e=w(t);delete x[e]},f=function(){return Object.keys(x).map(T)},d=function(t){var e=w(t);_[e]=!0},p=function(t){var e=w(t);delete _[e]},h=function(){return Object.keys(_).map(T)}}var C=[],k={onSetChildren:function(t,e){var n=u(t);n?void 0:g("144"),n.childIDs=e;for(var r=0;r<e.length;r++){var o=e[r],i=u(o);i?void 0:g("140"),null==i.childIDs&&"object"==typeof i.element&&null!=i.element?g("141"):void 0,i.isMounted?void 0:g("71"),null==i.parentID&&(i.parentID=t),i.parentID!==t?g("142",o,i.parentID,t):void 0}},onBeforeMountComponent:function(t,e,n){var r={element:e,parentID:n,text:null,childIDs:[],isMounted:!1,updateCount:0};l(t,r)},onBeforeUpdateComponent:function(t,e){var n=u(t);n&&n.isMounted&&(n.element=e)},onMountComponent:function(t){var e=u(t);e?void 0:g("144"),e.isMounted=!0;var n=0===e.parentID;n&&d(t)},onUpdateComponent:function(t){var e=u(t);e&&e.isMounted&&e.updateCount++},onUnmountComponent:function(t){var e=u(t);if(e){e.isMounted=!1;var n=0===e.parentID;n&&p(t)}C.push(t)},purgeUnmountedComponents:function(){if(!k._preventPurging){for(var t=0;t<C.length;t++){var e=C[t];o(e)}C.length=0}},isMounted:function(t){var e=u(t);return!!e&&e.isMounted},getCurrentStackAddendum:function(t){var e="";if(t){var n=a(t),r=t._owner;e+=i(n,t._source,r&&r.getName())}var o=v.current,s=o&&o._debugID;return e+=k.getStackAddendumByID(s)},getStackAddendumByID:function(t){for(var e="";t;)e+=s(t),t=k.getParentID(t);return e},getChildIDs:function(t){var e=u(t);return e?e.childIDs:[]},getDisplayName:function(t){var e=k.getElement(t);return e?a(e):null},getElement:function(t){var e=u(t);return e?e.element:null},getOwnerID:function(t){var e=k.getElement(t);return e&&e._owner?e._owner._debugID:null},getParentID:function(t){var e=u(t);return e?e.parentID:null},getSource:function(t){var e=u(t),n=e?e.element:null,r=null!=n?n._source:null;return r},getText:function(t){var e=k.getElement(t);return"string"==typeof e?e:"number"==typeof e?""+e:null},getUpdateCount:function(t){var e=u(t);return e?e.updateCount:0},getRootIDs:h,getRegisteredIDs:f};t.exports=k},function(t,e,n){(function(e){"use strict";function r(t,e,n,r){if(t&&"object"==typeof t){var o=t,i=void 0===o[n];i&&null!=e&&(o[n]=e)}}function o(t,e){if(null==t)return t;var n={};return i(t,r,n),n}var i=(n(120),n(121));n(12);t.exports=o}).call(e,n(111))},function(t,e,n){"use strict";function r(t){this.reinitializeTransaction(),this.renderToStaticMarkup=t,this.useCreateElement=!1,this.updateQueue=new s(this)}var o=n(5),i=n(48),a=n(61),s=(n(60),n(127)),l=[],u={enqueue:function(){}},c={getTransactionWrappers:function(){return l},getReactMountReady:function(){return u},getUpdateQueue:function(){return this.updateQueue},destructor:function(){},checkpoint:function(){},rollback:function(){}};o(r.prototype,a,c),i.addPoolingTo(r),t.exports=r},function(t,e,n){"use strict";function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function o(t,e){}var i=n(128),a=(n(12),function(){function t(e){r(this,t),this.transaction=e}return t.prototype.isMounted=function(t){return!1},t.prototype.enqueueCallback=function(t,e,n){this.transaction.isInTransaction()&&i.enqueueCallback(t,e,n)},t.prototype.enqueueForceUpdate=function(t){this.transaction.isInTransaction()?i.enqueueForceUpdate(t):o(t,"forceUpdate")},t.prototype.enqueueReplaceState=function(t,e){this.transaction.isInTransaction()?i.enqueueReplaceState(t,e):o(t,"replaceState")},t.prototype.enqueueSetState=function(t,e){this.transaction.isInTransaction()?i.enqueueSetState(t,e):o(t,"setState")},t}());t.exports=a},function(t,e,n){"use strict";function r(t){l.enqueueUpdate(t)}function o(t){var e=typeof t;if("object"!==e)return e;var n=t.constructor&&t.constructor.name||e,r=Object.keys(t);return r.length>0&&r.length<20?n+" (keys: "+r.join(", ")+")":n}function i(t,e){var n=s.get(t);if(!n){return null}return n}var a=n(33),s=(n(11),n(109)),l=(n(60),n(54)),u=(n(9),n(12),{isMounted:function(t){var e=s.get(t);return!!e&&!!e._renderedComponent},enqueueCallback:function(t,e,n){u.validateCallback(e,n);var o=i(t);return o?(o._pendingCallbacks?o._pendingCallbacks.push(e):o._pendingCallbacks=[e],void r(o)):null},enqueueCallbackInternal:function(t,e){t._pendingCallbacks?t._pendingCallbacks.push(e):t._pendingCallbacks=[e],r(t)},enqueueForceUpdate:function(t){var e=i(t,"forceUpdate");e&&(e._pendingForceUpdate=!0,r(e))},enqueueReplaceState:function(t,e){var n=i(t,"replaceState");n&&(n._pendingStateQueue=[e],n._pendingReplaceState=!0,r(n))},enqueueSetState:function(t,e){var n=i(t,"setState");if(n){var o=n._pendingStateQueue||(n._pendingStateQueue=[]);o.push(e),r(n)}},enqueueElementInternal:function(t,e,n){t._pendingElement=e,t._context=n,r(t)},validateCallback:function(t,e){t&&"function"!=typeof t?a("122",e,o(t)):void 0}});t.exports=u},function(t,e,n){"use strict";var r=(n(5),n(13)),o=(n(12),r);t.exports=o},function(t,e,n){"use strict";var r=n(5),o=n(74),i=n(32),a=function(t){this._currentElement=null,this._hostNode=null,this._hostParent=null,this._hostContainerInfo=null,this._domID=0};r(a.prototype,{mountComponent:function(t,e,n,r){var a=n._idCounter++;this._domID=a,this._hostParent=e,this._hostContainerInfo=n;var s=" react-empty: "+this._domID+" ";if(t.useCreateElement){var l=n._ownerDocument,u=l.createComment(s);return i.precacheNode(this,u),o(u)}return t.renderToStaticMarkup?"":"<!--"+s+"-->"},receiveComponent:function(){},getHostNode:function(){return i.getNodeFromInstance(this)},unmountComponent:function(){i.uncacheNode(this)}}),t.exports=a},function(t,e,n){"use strict";function r(t,e){"_hostNode"in t?void 0:l("33"),"_hostNode"in e?void 0:l("33");for(var n=0,r=t;r;r=r._hostParent)n++;for(var o=0,i=e;i;i=i._hostParent)o++;for(;n-o>0;)t=t._hostParent,n--;for(;o-n>0;)e=e._hostParent,o--;for(var a=n;a--;){if(t===e)return t;t=t._hostParent,e=e._hostParent}return null}function o(t,e){"_hostNode"in t?void 0:l("35"),"_hostNode"in e?void 0:l("35");for(;e;){if(e===t)return!0;
e=e._hostParent}return!1}function i(t){return"_hostNode"in t?void 0:l("36"),t._hostParent}function a(t,e,n){for(var r=[];t;)r.push(t),t=t._hostParent;var o;for(o=r.length;o-- >0;)e(r[o],"captured",n);for(o=0;o<r.length;o++)e(r[o],"bubbled",n)}function s(t,e,n,o,i){for(var a=t&&e?r(t,e):null,s=[];t&&t!==a;)s.push(t),t=t._hostParent;for(var l=[];e&&e!==a;)l.push(e),e=e._hostParent;var u;for(u=0;u<s.length;u++)n(s[u],"bubbled",o);for(u=l.length;u-- >0;)n(l[u],"captured",i)}var l=n(33);n(9);t.exports={isAncestor:o,getLowestCommonAncestor:r,getParentInstance:i,traverseTwoPhase:a,traverseEnterLeave:s}},function(t,e,n){"use strict";var r=n(33),o=n(5),i=n(73),a=n(74),s=n(32),l=n(79),u=(n(9),n(129),function(t){this._currentElement=t,this._stringText=""+t,this._hostNode=null,this._hostParent=null,this._domID=0,this._mountIndex=0,this._closingComment=null,this._commentNodes=null});o(u.prototype,{mountComponent:function(t,e,n,r){var o=n._idCounter++,i=" react-text: "+o+" ",u=" /react-text ";if(this._domID=o,this._hostParent=e,t.useCreateElement){var c=n._ownerDocument,f=c.createComment(i),d=c.createComment(u),p=a(c.createDocumentFragment());return a.queueChild(p,a(f)),this._stringText&&a.queueChild(p,a(c.createTextNode(this._stringText))),a.queueChild(p,a(d)),s.precacheNode(this,f),this._closingComment=d,p}var h=l(this._stringText);return t.renderToStaticMarkup?h:"<!--"+i+"-->"+h+"<!--"+u+"-->"},receiveComponent:function(t,e){if(t!==this._currentElement){this._currentElement=t;var n=""+t;if(n!==this._stringText){this._stringText=n;var r=this.getHostNode();i.replaceDelimitedText(r[0],r[1],n)}}},getHostNode:function(){var t=this._commentNodes;if(t)return t;if(!this._closingComment)for(var e=s.getNodeFromInstance(this),n=e.nextSibling;;){if(null==n?r("67",this._domID):void 0,8===n.nodeType&&" /react-text "===n.nodeValue){this._closingComment=n;break}n=n.nextSibling}return t=[this._hostNode,this._closingComment],this._commentNodes=t,t},unmountComponent:function(){this._closingComment=null,this._commentNodes=null,s.uncacheNode(this)}}),t.exports=u},function(t,e,n){"use strict";function r(){this.reinitializeTransaction()}var o=n(5),i=n(54),a=n(61),s=n(13),l={initialize:s,close:function(){d.isBatchingUpdates=!1}},u={initialize:s,close:i.flushBatchedUpdates.bind(i)},c=[u,l];o(r.prototype,a,{getTransactionWrappers:function(){return c}});var f=new r,d={isBatchingUpdates:!1,batchedUpdates:function(t,e,n,r,o,i){var a=d.isBatchingUpdates;return d.isBatchingUpdates=!0,a?t(e,n,r,o,i):f.perform(t,null,e,n,r,o,i)}};t.exports=d},function(t,e,n){"use strict";function r(t){for(;t._hostParent;)t=t._hostParent;var e=f.getNodeFromInstance(t),n=e.parentNode;return f.getClosestInstanceFromNode(n)}function o(t,e){this.topLevelType=t,this.nativeEvent=e,this.ancestors=[]}function i(t){var e=p(t.nativeEvent),n=f.getClosestInstanceFromNode(e),o=n;do t.ancestors.push(o),o=o&&r(o);while(o);for(var i=0;i<t.ancestors.length;i++)n=t.ancestors[i],g._handleTopLevel(t.topLevelType,n,t.nativeEvent,p(t.nativeEvent))}function a(t){var e=h(window);t(e)}var s=n(5),l=n(135),u=n(46),c=n(48),f=n(32),d=n(54),p=n(62),h=n(136);s(o.prototype,{destructor:function(){this.topLevelType=null,this.nativeEvent=null,this.ancestors.length=0}}),c.addPoolingTo(o,c.twoArgumentPooler);var g={_enabled:!0,_handleTopLevel:null,WINDOW_HANDLE:u.canUseDOM?window:null,setHandleTopLevel:function(t){g._handleTopLevel=t},setEnabled:function(t){g._enabled=!!t},isEnabled:function(){return g._enabled},trapBubbledEvent:function(t,e,n){return n?l.listen(n,e,g.dispatchEvent.bind(null,t)):null},trapCapturedEvent:function(t,e,n){return n?l.capture(n,e,g.dispatchEvent.bind(null,t)):null},monitorScrollValue:function(t){var e=a.bind(null,t);l.listen(window,"scroll",e)},dispatchEvent:function(t,e){if(g._enabled){var n=o.getPooled(t,e);try{d.batchedUpdates(i,n)}finally{o.release(n)}}}};t.exports=g},function(t,e,n){"use strict";var r=n(13),o={listen:function(t,e,n){return t.addEventListener?(t.addEventListener(e,n,!1),{remove:function(){t.removeEventListener(e,n,!1)}}):t.attachEvent?(t.attachEvent("on"+e,n),{remove:function(){t.detachEvent("on"+e,n)}}):void 0},capture:function(t,e,n){return t.addEventListener?(t.addEventListener(e,n,!0),{remove:function(){t.removeEventListener(e,n,!0)}}):{remove:r}},registerDefault:function(){}};t.exports=o},function(t,e){"use strict";function n(t){return t===window?{x:window.pageXOffset||document.documentElement.scrollLeft,y:window.pageYOffset||document.documentElement.scrollTop}:{x:t.scrollLeft,y:t.scrollTop}}t.exports=n},function(t,e,n){"use strict";var r=n(34),o=n(40),i=n(42),a=n(108),s=n(117),l=n(98),u=n(118),c=n(54),f={Component:a.injection,DOMProperty:r.injection,EmptyComponent:s.injection,EventPluginHub:o.injection,EventPluginUtils:i.injection,EventEmitter:l.injection,HostComponent:u.injection,Updates:c.injection};t.exports=f},function(t,e,n){"use strict";function r(t){this.reinitializeTransaction(),this.renderToStaticMarkup=!1,this.reactMountReady=i.getPooled(null),this.useCreateElement=t}var o=n(5),i=n(55),a=n(48),s=n(98),l=n(139),u=(n(60),n(61)),c=n(128),f={initialize:l.getSelectionInformation,close:l.restoreSelection},d={initialize:function(){var t=s.isEnabled();return s.setEnabled(!1),t},close:function(t){s.setEnabled(t)}},p={initialize:function(){this.reactMountReady.reset()},close:function(){this.reactMountReady.notifyAll()}},h=[f,d,p],g={getTransactionWrappers:function(){return h},getReactMountReady:function(){return this.reactMountReady},getUpdateQueue:function(){return c},checkpoint:function(){return this.reactMountReady.checkpoint()},rollback:function(t){this.reactMountReady.rollback(t)},destructor:function(){i.release(this.reactMountReady),this.reactMountReady=null}};o(r.prototype,u,g),a.addPoolingTo(r),t.exports=r},function(t,e,n){"use strict";function r(t){return i(document.documentElement,t)}var o=n(140),i=n(142),a=n(87),s=n(145),l={hasSelectionCapabilities:function(t){var e=t&&t.nodeName&&t.nodeName.toLowerCase();return e&&("input"===e&&"text"===t.type||"textarea"===e||"true"===t.contentEditable)},getSelectionInformation:function(){var t=s();return{focusedElem:t,selectionRange:l.hasSelectionCapabilities(t)?l.getSelection(t):null}},restoreSelection:function(t){var e=s(),n=t.focusedElem,o=t.selectionRange;e!==n&&r(n)&&(l.hasSelectionCapabilities(n)&&l.setSelection(n,o),a(n))},getSelection:function(t){var e;if("selectionStart"in t)e={start:t.selectionStart,end:t.selectionEnd};else if(document.selection&&t.nodeName&&"input"===t.nodeName.toLowerCase()){var n=document.selection.createRange();n.parentElement()===t&&(e={start:-n.moveStart("character",-t.value.length),end:-n.moveEnd("character",-t.value.length)})}else e=o.getOffsets(t);return e||{start:0,end:0}},setSelection:function(t,e){var n=e.start,r=e.end;if(void 0===r&&(r=n),"selectionStart"in t)t.selectionStart=n,t.selectionEnd=Math.min(r,t.value.length);else if(document.selection&&t.nodeName&&"input"===t.nodeName.toLowerCase()){var i=t.createTextRange();i.collapse(!0),i.moveStart("character",n),i.moveEnd("character",r-n),i.select()}else o.setOffsets(t,e)}};t.exports=l},function(t,e,n){"use strict";function r(t,e,n,r){return t===n&&e===r}function o(t){var e=document.selection,n=e.createRange(),r=n.text.length,o=n.duplicate();o.moveToElementText(t),o.setEndPoint("EndToStart",n);var i=o.text.length,a=i+r;return{start:i,end:a}}function i(t){var e=window.getSelection&&window.getSelection();if(!e||0===e.rangeCount)return null;var n=e.anchorNode,o=e.anchorOffset,i=e.focusNode,a=e.focusOffset,s=e.getRangeAt(0);try{s.startContainer.nodeType,s.endContainer.nodeType}catch(t){return null}var l=r(e.anchorNode,e.anchorOffset,e.focusNode,e.focusOffset),u=l?0:s.toString().length,c=s.cloneRange();c.selectNodeContents(t),c.setEnd(s.startContainer,s.startOffset);var f=r(c.startContainer,c.startOffset,c.endContainer,c.endOffset),d=f?0:c.toString().length,p=d+u,h=document.createRange();h.setStart(n,o),h.setEnd(i,a);var g=h.collapsed;return{start:g?p:d,end:g?d:p}}function a(t,e){var n,r,o=document.selection.createRange().duplicate();void 0===e.end?(n=e.start,r=n):e.start>e.end?(n=e.end,r=e.start):(n=e.start,r=e.end),o.moveToElementText(t),o.moveStart("character",n),o.setEndPoint("EndToStart",o),o.moveEnd("character",r-n),o.select()}function s(t,e){if(window.getSelection){var n=window.getSelection(),r=t[c()].length,o=Math.min(e.start,r),i=void 0===e.end?o:Math.min(e.end,r);if(!n.extend&&o>i){var a=i;i=o,o=a}var s=u(t,o),l=u(t,i);if(s&&l){var f=document.createRange();f.setStart(s.node,s.offset),n.removeAllRanges(),o>i?(n.addRange(f),n.extend(l.node,l.offset)):(f.setEnd(l.node,l.offset),n.addRange(f))}}}var l=n(46),u=n(141),c=n(49),f=l.canUseDOM&&"selection"in document&&!("getSelection"in window),d={getOffsets:f?o:i,setOffsets:f?a:s};t.exports=d},function(t,e){"use strict";function n(t){for(;t&&t.firstChild;)t=t.firstChild;return t}function r(t){for(;t;){if(t.nextSibling)return t.nextSibling;t=t.parentNode}}function o(t,e){for(var o=n(t),i=0,a=0;o;){if(3===o.nodeType){if(a=i+o.textContent.length,i<=e&&a>=e)return{node:o,offset:e-i};i=a}o=n(r(o))}}t.exports=o},function(t,e,n){"use strict";function r(t,e){return!(!t||!e)&&(t===e||!o(t)&&(o(e)?r(t,e.parentNode):"contains"in t?t.contains(e):!!t.compareDocumentPosition&&!!(16&t.compareDocumentPosition(e))))}var o=n(143);t.exports=r},function(t,e,n){"use strict";function r(t){return o(t)&&3==t.nodeType}var o=n(144);t.exports=r},function(t,e){"use strict";function n(t){return!(!t||!("function"==typeof Node?t instanceof Node:"object"==typeof t&&"number"==typeof t.nodeType&&"string"==typeof t.nodeName))}t.exports=n},function(t,e){"use strict";function n(){if("undefined"==typeof document)return null;try{return document.activeElement||document.body}catch(t){return document.body}}t.exports=n},function(t,e){"use strict";var n={xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace"},r={accentHeight:"accent-height",accumulate:0,additive:0,alignmentBaseline:"alignment-baseline",allowReorder:"allowReorder",alphabetic:0,amplitude:0,arabicForm:"arabic-form",ascent:0,attributeName:"attributeName",attributeType:"attributeType",autoReverse:"autoReverse",azimuth:0,baseFrequency:"baseFrequency",baseProfile:"baseProfile",baselineShift:"baseline-shift",bbox:0,begin:0,bias:0,by:0,calcMode:"calcMode",capHeight:"cap-height",clip:0,clipPath:"clip-path",clipRule:"clip-rule",clipPathUnits:"clipPathUnits",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",contentScriptType:"contentScriptType",contentStyleType:"contentStyleType",cursor:0,cx:0,cy:0,d:0,decelerate:0,descent:0,diffuseConstant:"diffuseConstant",direction:0,display:0,divisor:0,dominantBaseline:"dominant-baseline",dur:0,dx:0,dy:0,edgeMode:"edgeMode",elevation:0,enableBackground:"enable-background",end:0,exponent:0,externalResourcesRequired:"externalResourcesRequired",fill:0,fillOpacity:"fill-opacity",fillRule:"fill-rule",filter:0,filterRes:"filterRes",filterUnits:"filterUnits",floodColor:"flood-color",floodOpacity:"flood-opacity",focusable:0,fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",format:0,from:0,fx:0,fy:0,g1:0,g2:0,glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",glyphRef:"glyphRef",gradientTransform:"gradientTransform",gradientUnits:"gradientUnits",hanging:0,horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",ideographic:0,imageRendering:"image-rendering",in:0,in2:0,intercept:0,k:0,k1:0,k2:0,k3:0,k4:0,kernelMatrix:"kernelMatrix",kernelUnitLength:"kernelUnitLength",kerning:0,keyPoints:"keyPoints",keySplines:"keySplines",keyTimes:"keyTimes",lengthAdjust:"lengthAdjust",letterSpacing:"letter-spacing",lightingColor:"lighting-color",limitingConeAngle:"limitingConeAngle",local:0,markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",markerHeight:"markerHeight",markerUnits:"markerUnits",markerWidth:"markerWidth",mask:0,maskContentUnits:"maskContentUnits",maskUnits:"maskUnits",mathematical:0,mode:0,numOctaves:"numOctaves",offset:0,opacity:0,operator:0,order:0,orient:0,orientation:0,origin:0,overflow:0,overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pathLength:"pathLength",patternContentUnits:"patternContentUnits",patternTransform:"patternTransform",patternUnits:"patternUnits",pointerEvents:"pointer-events",points:0,pointsAtX:"pointsAtX",pointsAtY:"pointsAtY",pointsAtZ:"pointsAtZ",preserveAlpha:"preserveAlpha",preserveAspectRatio:"preserveAspectRatio",primitiveUnits:"primitiveUnits",r:0,radius:0,refX:"refX",refY:"refY",renderingIntent:"rendering-intent",repeatCount:"repeatCount",repeatDur:"repeatDur",requiredExtensions:"requiredExtensions",requiredFeatures:"requiredFeatures",restart:0,result:0,rotate:0,rx:0,ry:0,scale:0,seed:0,shapeRendering:"shape-rendering",slope:0,spacing:0,specularConstant:"specularConstant",specularExponent:"specularExponent",speed:0,spreadMethod:"spreadMethod",startOffset:"startOffset",stdDeviation:"stdDeviation",stemh:0,stemv:0,stitchTiles:"stitchTiles",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",string:0,stroke:0,strokeDasharray:"stroke-dasharray",strokeDashoffset:"stroke-dashoffset",strokeLinecap:"stroke-linecap",strokeLinejoin:"stroke-linejoin",strokeMiterlimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",surfaceScale:"surfaceScale",systemLanguage:"systemLanguage",tableValues:"tableValues",targetX:"targetX",targetY:"targetY",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",textLength:"textLength",to:0,transform:0,u1:0,u2:0,underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicode:0,unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",values:0,vectorEffect:"vector-effect",version:0,vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",viewBox:"viewBox",viewTarget:"viewTarget",visibility:0,widths:0,wordSpacing:"word-spacing",writingMode:"writing-mode",x:0,xHeight:"x-height",x1:0,x2:0,xChannelSelector:"xChannelSelector",xlinkActuate:"xlink:actuate",xlinkArcrole:"xlink:arcrole",xlinkHref:"xlink:href",xlinkRole:"xlink:role",xlinkShow:"xlink:show",xlinkTitle:"xlink:title",xlinkType:"xlink:type",xmlBase:"xml:base",xmlns:0,xmlnsXlink:"xmlns:xlink",xmlLang:"xml:lang",xmlSpace:"xml:space",y:0,y1:0,y2:0,yChannelSelector:"yChannelSelector",z:0,zoomAndPan:"zoomAndPan"},o={Properties:{},DOMAttributeNamespaces:{xlinkActuate:n.xlink,xlinkArcrole:n.xlink,xlinkHref:n.xlink,xlinkRole:n.xlink,xlinkShow:n.xlink,xlinkTitle:n.xlink,xlinkType:n.xlink,xmlBase:n.xml,xmlLang:n.xml,xmlSpace:n.xml},DOMAttributeNames:{}};Object.keys(r).forEach(function(t){o.Properties[t]=0,r[t]&&(o.DOMAttributeNames[t]=r[t])}),t.exports=o},function(t,e,n){"use strict";function r(t){if("selectionStart"in t&&l.hasSelectionCapabilities(t))return{start:t.selectionStart,end:t.selectionEnd};if(window.getSelection){var e=window.getSelection();return{anchorNode:e.anchorNode,anchorOffset:e.anchorOffset,focusNode:e.focusNode,focusOffset:e.focusOffset}}if(document.selection){var n=document.selection.createRange();return{parentElement:n.parentElement(),text:n.text,top:n.boundingTop,left:n.boundingLeft}}}function o(t,e){if(y||null==g||g!==c())return null;var n=r(g);if(!m||!d(m,n)){m=n;var o=u.getPooled(h.select,v,t,e);return o.type="select",o.target=g,i.accumulateTwoPhaseDispatches(o),o}return null}var i=n(39),a=n(46),s=n(32),l=n(139),u=n(51),c=n(145),f=n(64),d=n(115),p=a.canUseDOM&&"documentMode"in document&&document.documentMode<=11,h={select:{phasedRegistrationNames:{bubbled:"onSelect",captured:"onSelectCapture"},dependencies:["topBlur","topContextMenu","topFocus","topKeyDown","topKeyUp","topMouseDown","topMouseUp","topSelectionChange"]}},g=null,v=null,m=null,y=!1,b=!1,x={eventTypes:h,extractEvents:function(t,e,n,r){if(!b)return null;var i=e?s.getNodeFromInstance(e):window;switch(t){case"topFocus":(f(i)||"true"===i.contentEditable)&&(g=i,v=e,m=null);break;case"topBlur":g=null,v=null,m=null;break;case"topMouseDown":y=!0;break;case"topContextMenu":case"topMouseUp":return y=!1,o(n,r);case"topSelectionChange":if(p)break;case"topKeyDown":case"topKeyUp":return o(n,r)}return null},didPutListener:function(t,e,n){"onSelect"===e&&(b=!0)}};t.exports=x},function(t,e,n){"use strict";function r(t){return"."+t._rootNodeID}function o(t){return"button"===t||"input"===t||"select"===t||"textarea"===t}var i=n(33),a=n(135),s=n(39),l=n(32),u=n(149),c=n(150),f=n(51),d=n(151),p=n(152),h=n(67),g=n(155),v=n(156),m=n(157),y=n(68),b=n(158),x=n(13),_=n(153),w=(n(9),{}),T={};["abort","animationEnd","animationIteration","animationStart","blur","canPlay","canPlayThrough","click","contextMenu","copy","cut","doubleClick","drag","dragEnd","dragEnter","dragExit","dragLeave","dragOver","dragStart","drop","durationChange","emptied","encrypted","ended","error","focus","input","invalid","keyDown","keyPress","keyUp","load","loadedData","loadedMetadata","loadStart","mouseDown","mouseMove","mouseOut","mouseOver","mouseUp","paste","pause","play","playing","progress","rateChange","reset","scroll","seeked","seeking","stalled","submit","suspend","timeUpdate","touchCancel","touchEnd","touchMove","touchStart","transitionEnd","volumeChange","waiting","wheel"].forEach(function(t){var e=t[0].toUpperCase()+t.slice(1),n="on"+e,r="top"+e,o={phasedRegistrationNames:{bubbled:n,captured:n+"Capture"},dependencies:[r]};w[t]=o,T[r]=o});var C={},k={eventTypes:w,extractEvents:function(t,e,n,r){var o=T[t];if(!o)return null;var a;switch(t){case"topAbort":case"topCanPlay":case"topCanPlayThrough":case"topDurationChange":case"topEmptied":case"topEncrypted":case"topEnded":case"topError":case"topInput":case"topInvalid":case"topLoad":case"topLoadedData":case"topLoadedMetadata":case"topLoadStart":case"topPause":case"topPlay":case"topPlaying":case"topProgress":case"topRateChange":case"topReset":case"topSeeked":case"topSeeking":case"topStalled":case"topSubmit":case"topSuspend":case"topTimeUpdate":case"topVolumeChange":case"topWaiting":a=f;break;case"topKeyPress":if(0===_(n))return null;case"topKeyDown":case"topKeyUp":a=p;break;case"topBlur":case"topFocus":a=d;break;case"topClick":if(2===n.button)return null;case"topDoubleClick":case"topMouseDown":case"topMouseMove":case"topMouseUp":case"topMouseOut":case"topMouseOver":case"topContextMenu":a=h;break;case"topDrag":case"topDragEnd":case"topDragEnter":case"topDragExit":case"topDragLeave":case"topDragOver":case"topDragStart":case"topDrop":a=g;break;case"topTouchCancel":case"topTouchEnd":case"topTouchMove":case"topTouchStart":a=v;break;case"topAnimationEnd":case"topAnimationIteration":case"topAnimationStart":a=u;break;case"topTransitionEnd":a=m;break;case"topScroll":a=y;break;case"topWheel":a=b;break;case"topCopy":case"topCut":case"topPaste":a=c}a?void 0:i("86",t);var l=a.getPooled(o,e,n,r);return s.accumulateTwoPhaseDispatches(l),l},didPutListener:function(t,e,n){if("onClick"===e&&!o(t._tag)){var i=r(t),s=l.getNodeFromInstance(t);C[i]||(C[i]=a.listen(s,"click",x))}},willDeleteListener:function(t,e){if("onClick"===e&&!o(t._tag)){var n=r(t);C[n].remove(),delete C[n]}}};t.exports=k},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(51),i={animationName:null,elapsedTime:null,pseudoElement:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(51),i={clipboardData:function(t){return"clipboardData"in t?t.clipboardData:window.clipboardData}};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(68),i={relatedTarget:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(68),i=n(153),a=n(154),s=n(70),l={key:a,location:null,ctrlKey:null,shiftKey:null,altKey:null,metaKey:null,repeat:null,locale:null,getModifierState:s,charCode:function(t){return"keypress"===t.type?i(t):0},keyCode:function(t){return"keydown"===t.type||"keyup"===t.type?t.keyCode:0},which:function(t){return"keypress"===t.type?i(t):"keydown"===t.type||"keyup"===t.type?t.keyCode:0}};o.augmentClass(r,l),t.exports=r},function(t,e){"use strict";function n(t){var e,n=t.keyCode;return"charCode"in t?(e=t.charCode,0===e&&13===n&&(e=13)):e=n,e>=32||13===e?e:0}t.exports=n},function(t,e,n){"use strict";function r(t){if(t.key){var e=i[t.key]||t.key;if("Unidentified"!==e)return e}if("keypress"===t.type){var n=o(t);return 13===n?"Enter":String.fromCharCode(n)}return"keydown"===t.type||"keyup"===t.type?a[t.keyCode]||"Unidentified":""}var o=n(153),i={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},a={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"};t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(67),i={dataTransfer:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(68),i=n(70),a={touches:null,targetTouches:null,changedTouches:null,altKey:null,metaKey:null,ctrlKey:null,shiftKey:null,getModifierState:i};o.augmentClass(r,a),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(51),i={propertyName:null,elapsedTime:null,pseudoElement:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(67),i={deltaX:function(t){return"deltaX"in t?t.deltaX:"wheelDeltaX"in t?-t.wheelDeltaX:0},deltaY:function(t){return"deltaY"in t?t.deltaY:"wheelDeltaY"in t?-t.wheelDeltaY:"wheelDelta"in t?-t.wheelDelta:0},deltaZ:null,deltaMode:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e){for(var n=Math.min(t.length,e.length),r=0;r<n;r++)if(t.charAt(r)!==e.charAt(r))return r;return t.length===e.length?-1:n}function o(t){return t?t.nodeType===I?t.documentElement:t.firstChild:null}function i(t){return t.getAttribute&&t.getAttribute(A)||""}function a(t,e,n,r,o){var i;if(_.logTopLevelRenders){var a=t._currentElement.props.child,s=a.type;i="React mount: "+("string"==typeof s?s:s.displayName||s.name),console.time(i)}var l=C.mountComponent(t,n,null,b(t,e),o,0);i&&console.timeEnd(i),t._renderedComponent._topLevelWrapper=t,B._mountImageIntoNode(l,e,t,r,n)}function s(t,e,n,r){var o=E.ReactReconcileTransaction.getPooled(!n&&x.useCreateElement);o.perform(a,null,t,e,o,n,r),E.ReactReconcileTransaction.release(o)}function l(t,e,n){for(C.unmountComponent(t,n),e.nodeType===I&&(e=e.documentElement);e.lastChild;)e.removeChild(e.lastChild)}function u(t){var e=o(t);if(e){var n=y.getInstanceFromNode(e);return!(!n||!n._hostParent)}}function c(t){return!(!t||t.nodeType!==D&&t.nodeType!==I&&t.nodeType!==R)}function f(t){var e=o(t),n=e&&y.getInstanceFromNode(e);return n&&!n._hostParent?n:null}function d(t){var e=f(t);return e?e._hostContainerInfo._topLevelWrapper:null}var p=n(33),h=n(74),g=n(34),v=n(4),m=n(98),y=(n(11),n(32)),b=n(160),x=n(161),_=n(56),w=n(109),T=(n(60),n(162)),C=n(57),k=n(128),E=n(54),P=n(21),S=n(112),M=(n(9),n(76)),N=n(116),A=(n(12),g.ID_ATTRIBUTE_NAME),O=g.ROOT_ATTRIBUTE_NAME,D=1,I=9,R=11,L={},F=1,j=function(){this.rootID=F++};j.prototype.isReactComponent={},j.prototype.render=function(){return this.props.child},j.isReactTopLevelWrapper=!0;var B={TopLevelWrapper:j,_instancesByReactRootID:L,scrollMonitor:function(t,e){e()},_updateRootComponent:function(t,e,n,r,o){return B.scrollMonitor(r,function(){k.enqueueElementInternal(t,e,n),o&&k.enqueueCallbackInternal(t,o)}),t},_renderNewRootComponent:function(t,e,n,r){c(e)?void 0:p("37"),m.ensureScrollValueMonitoring();var o=S(t,!1);E.batchedUpdates(s,o,e,n,r);var i=o._instance.rootID;return L[i]=o,o},renderSubtreeIntoContainer:function(t,e,n,r){return null!=t&&w.has(t)?void 0:p("38"),B._renderSubtreeIntoContainer(t,e,n,r)},_renderSubtreeIntoContainer:function(t,e,n,r){k.validateCallback(r,"ReactDOM.render"),v.isValidElement(e)?void 0:p("39","string"==typeof e?" Instead of passing a string like 'div', pass React.createElement('div') or <div />.":"function"==typeof e?" Instead of passing a class like Foo, pass React.createElement(Foo) or <Foo />.":null!=e&&void 0!==e.props?" This may be caused by unintentionally loading two independent copies of React.":"");var a,s=v.createElement(j,{child:e});if(t){var l=w.get(t);a=l._processChildContext(l._context)}else a=P;var c=d(n);if(c){var f=c._currentElement,h=f.props.child;if(N(h,e)){var g=c._renderedComponent.getPublicInstance(),m=r&&function(){r.call(g)};return B._updateRootComponent(c,s,a,n,m),g}B.unmountComponentAtNode(n)}var y=o(n),b=y&&!!i(y),x=u(n),_=b&&!c&&!x,T=B._renderNewRootComponent(s,n,_,a)._renderedComponent.getPublicInstance();return r&&r.call(T),T},render:function(t,e,n){return B._renderSubtreeIntoContainer(null,t,e,n)},unmountComponentAtNode:function(t){c(t)?void 0:p("40");var e=d(t);if(!e){u(t),1===t.nodeType&&t.hasAttribute(O);return!1}return delete L[e._instance.rootID],E.batchedUpdates(l,e,t,!1),!0},_mountImageIntoNode:function(t,e,n,i,a){if(c(e)?void 0:p("41"),i){var s=o(e);if(T.canReuseMarkup(t,s))return void y.precacheNode(n,s);var l=s.getAttribute(T.CHECKSUM_ATTR_NAME);s.removeAttribute(T.CHECKSUM_ATTR_NAME);var u=s.outerHTML;s.setAttribute(T.CHECKSUM_ATTR_NAME,l);var f=t,d=r(f,u),g=" (client) "+f.substring(d-20,d+20)+"\n (server) "+u.substring(d-20,d+20);e.nodeType===I?p("42",g):void 0}if(e.nodeType===I?p("43"):void 0,a.useCreateElement){for(;e.lastChild;)e.removeChild(e.lastChild);h.insertTreeBefore(e,t,null)}else M(e,t),y.precacheNode(n,e.firstChild)}};t.exports=B},function(t,e,n){"use strict";function r(t,e){var n={_topLevelWrapper:t,_idCounter:1,_ownerDocument:e?e.nodeType===o?e:e.ownerDocument:null,_node:e,_tag:e?e.nodeName.toLowerCase():null,_namespaceURI:e?e.namespaceURI:null};return n}var o=(n(129),9);t.exports=r},function(t,e){"use strict";var n={useCreateElement:!0,useFiber:!1};t.exports=n},function(t,e,n){"use strict";var r=n(163),o=/\/?>/,i=/^<\!\-\-/,a={CHECKSUM_ATTR_NAME:"data-react-checksum",addChecksumToMarkup:function(t){var e=r(t);return i.test(t)?t:t.replace(o," "+a.CHECKSUM_ATTR_NAME+'="'+e+'"$&')},canReuseMarkup:function(t,e){var n=e.getAttribute(a.CHECKSUM_ATTR_NAME);n=n&&parseInt(n,10);var o=r(t);return o===n}};t.exports=a},function(t,e){"use strict";function n(t){for(var e=1,n=0,o=0,i=t.length,a=i&-4;o<a;){for(var s=Math.min(o+4096,a);o<s;o+=4)n+=(e+=t.charCodeAt(o))+(e+=t.charCodeAt(o+1))+(e+=t.charCodeAt(o+2))+(e+=t.charCodeAt(o+3));e%=r,n%=r}for(;o<i;o++)n+=e+=t.charCodeAt(o);return e%=r,n%=r,e|n<<16}var r=65521;t.exports=n},function(t,e){"use strict";t.exports="15.4.2"},function(t,e,n){"use strict";function r(t){if(null==t)return null;if(1===t.nodeType)return t;var e=a.get(t);return e?(e=s(e),e?i.getNodeFromInstance(e):null):void("function"==typeof t.render?o("44"):o("45",Object.keys(t)))}var o=n(33),i=(n(11),n(32)),a=n(109),s=n(166);n(9),n(12);t.exports=r},function(t,e,n){"use strict";function r(t){for(var e;(e=t._renderedNodeType)===o.COMPOSITE;)t=t._renderedComponent;return e===o.HOST?t._renderedComponent:e===o.EMPTY?null:void 0}var o=n(114);t.exports=r},function(t,e,n){"use strict";var r=n(159);t.exports=r.renderSubtreeIntoContainer},function(t,e,n){(function(e,r,o,i,a){!function(e,r){t.exports=r(n(3),n(176),n(170))}(this,function(t,e,n){return function(t){function e(r){if(n[r])return n[r].exports;var o=n[r]={exports:{},id:r,loaded:!1};return t[r].call(o.exports,o,o.exports,e),o.loaded=!0,o.exports}var n={};return e.m=t,e.c=n,e.p="",e(0)}([function(t,e,n){"use strict";Object.defineProperty(e,"__esModule",{value:!0}),e.PlotlyAPI=e.Datamaps=e.NVD3Chart=e.MetricsGraphics=e.Table=e.Chart=e.Filter=e.Navs=e.Layout=e.LayoutFactory=e.SimpleChart=e.FilterChart=e.FilterFactory=e.ChartFactory=void 0;var r=n(56);Object.defineProperty(e,"ChartFactory",{enumerable:!0,get:function(){return r.ChartFactory}});var o=n(57);Object.defineProperty(e,"FilterFactory",{enumerable:!0,get:function(){return o.FilterFactory}});var i=n(95);Object.defineProperty(e,"FilterChart",{enumerable:!0,get:function(){return i.FilterChart}});var a=n(96);Object.defineProperty(e,"SimpleChart",{enumerable:!0,get:function(){return a.SimpleChart}});var s=n(149);Object.defineProperty(e,"LayoutFactory",{enumerable:!0,get:function(){return s.LayoutFactory}}),Object.defineProperty(e,"Layout",{enumerable:!0,get:function(){return s.Layout}});var l=n(150);Object.defineProperty(e,"Navs",{enumerable:!0,get:function(){return l.Navs}}),Object.defineProperty(e,"Filter",{enumerable:!0,get:function(){return o.Filter}}),Object.defineProperty(e,"Chart",{enumerable:!0,get:function(){return r.Chart}});var u=n(84);Object.defineProperty(e,"Table",{enumerable:!0,get:function(){return u.Table}});var c=n(85);Object.defineProperty(e,"MetricsGraphics",{enumerable:!0,get:function(){return c.MetricsGraphics}});var f=n(86);Object.defineProperty(e,"NVD3Chart",{enumerable:!0,get:function(){return f.NVD3Chart}}),Object.defineProperty(e,"Datamaps",{enumerable:!0,get:function(){return f.Datamaps}});var d=n(87);Object.defineProperty(e,"PlotlyAPI",{enumerable:!0,get:function(){return d.PlotlyAPI}}),n(43),n(90),n(88),n(91),n(94),n(92),n(89),n(93)},function(e,n){e.exports=t},function(t,e){"use strict";e.__esModule=!0,e.default=function(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(153),i=r(o),a=n(152),s=r(a),l=n(58),u=r(l);e.default=function(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+("undefined"==typeof e?"undefined":(0,u.default)(e)));t.prototype=(0,s.default)(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(i.default?(0,i.default)(t,e):t.__proto__=e)}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(58),i=r(o);e.default=function(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!==("undefined"==typeof e?"undefined":(0,i.default)(e))&&"function"!=typeof e?t:e}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(97),i=r(o);e.default=i.default||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t}},function(t,e,n){var r,o;/*!
		  Copyright (c) 2016 Jed Watson.
		  Licensed under the MIT License (MIT), see
		  http://jedwatson.github.io/classnames
		*/
!function(){"use strict";function n(){for(var t=[],e=0;e<arguments.length;e++){var r=arguments[e];if(r){var o=typeof r;if("string"===o||"number"===o)t.push(r);else if(Array.isArray(r))t.push(n.apply(null,r));else if("object"===o)for(var a in r)i.call(r,a)&&r[a]&&t.push(a)}}return t.join(" ")}var i={}.hasOwnProperty;"undefined"!=typeof t&&t.exports?t.exports=n:(r=[],o=function(){return n}.apply(e,r),!(void 0!==o&&(t.exports=o)))}()},function(t,e){"use strict";e.__esModule=!0,e.default=function(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){return function(){for(var e=arguments.length,n=Array(e),r=0;r<e;r++)n[r]=arguments[r];var o=n[n.length-1];return"function"==typeof o?t.apply(void 0,n):function(e){return t.apply(void 0,n.concat([e]))}}}function i(t,e){return null==t.bsClass?(0,m.default)(!1):void 0,t.bsClass+(e?"-"+e:"")}function a(t){var e,n=(e={},e[i(t)]=!0,e);if(t.bsSize){var r=b.SIZE_MAP[t.bsSize]||t.bsSize;n[i(t,r)]=!0}return t.bsStyle&&(n[i(t,t.bsStyle)]=!0),n}function s(t){return{bsClass:t.bsClass,bsSize:t.bsSize,bsStyle:t.bsStyle,bsRole:t.bsRole}}function l(t){return"bsClass"===t||"bsSize"===t||"bsStyle"===t||"bsRole"===t}function u(t){var e={};return(0,p.default)(t).forEach(function(t){var n=t[0],r=t[1];l(n)||(e[n]=r)}),[s(t),e]}function c(t,e){var n={};e.forEach(function(t){n[t]=!0});var r={};return(0,p.default)(t).forEach(function(t){var e=t[0],o=t[1];l(e)||n[e]||(r[e]=o)}),[s(t),r]}function f(t){for(var e=arguments.length,n=Array(e>1?e-1:0),r=1;r<e;r++)n[r-1]=arguments[r];x(n,t)}e.__esModule=!0,e._curry=e.bsSizes=e.bsStyles=e.bsClass=void 0;var d=n(98),p=r(d),h=n(5),g=r(h);e.prefix=i,e.getClassSet=a,e.splitBsProps=u,e.splitBsPropsAndOmit=c,e.addStyle=f;var v=n(75),m=r(v),y=n(1),b=n(12),x=(e.bsClass=o(function(t,e){var n=e.propTypes||(e.propTypes={}),r=e.defaultProps||(e.defaultProps={});return n.bsClass=y.PropTypes.string,r.bsClass=t,e}),e.bsStyles=o(function(t,e,n){"string"!=typeof e&&(n=e,e=void 0);var r=n.STYLES||[],o=n.propTypes||{};t.forEach(function(t){r.indexOf(t)===-1&&r.push(t)});var i=y.PropTypes.oneOf(r);if(n.STYLES=i._values=r,n.propTypes=(0,g.default)({},o,{bsStyle:i}),void 0!==e){var a=n.defaultProps||(n.defaultProps={});a.bsStyle=e}return n}));e.bsSizes=o(function(t,e,n){"string"!=typeof e&&(n=e,e=void 0);var r=n.SIZES||[],o=n.propTypes||{};t.forEach(function(t){r.indexOf(t)===-1&&r.push(t)});var i=[];r.forEach(function(t){var e=b.SIZE_MAP[t];e&&e!==t&&i.push(e),i.push(t)});var a=y.PropTypes.oneOf(i);return a._values=i,n.SIZES=r,n.propTypes=(0,g.default)({},o,{bsSize:a}),void 0!==e&&(n.defaultProps||(n.defaultProps={}),n.defaultProps.bsSize=e),n}),e._curry=o},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n,r,o){var a=t[e],l="undefined"==typeof a?"undefined":i(a);return s.default.isValidElement(a)?new Error("Invalid "+r+" `"+o+"` of type ReactElement "+("supplied to `"+n+"`, expected an element type (a string ")+"or a ReactClass)."):"function"!==l&&"string"!==l?new Error("Invalid "+r+" `"+o+"` of value `"+a+"` "+("supplied to `"+n+"`, expected an element type (a string ")+"or a ReactClass)."):null}e.__esModule=!0;var i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol?"symbol":typeof t},a=n(1),s=r(a),l=n(53),u=r(l);e.default=(0,u.default)(o)},function(t,e){"use strict";function n(){for(var t=arguments.length,e=Array(t),n=0;n<t;n++)e[n]=arguments[n];return e.filter(function(t){return null!=t}).reduce(function(t,e){if("function"!=typeof e)throw new Error("Invalid Argument Type, must only provide functions, undefined, or null.");return null===t?e:function(){for(var n=arguments.length,r=Array(n),o=0;o<n;o++)r[o]=arguments[o];t.apply(this,r),e.apply(this,r)}},null)}e.__esModule=!0,e.default=n,t.exports=e.default},function(t,n){t.exports=e},function(t,e){"use strict";e.__esModule=!0,e.Size={LARGE:"large",SMALL:"small",XSMALL:"xsmall"},e.SIZE_MAP={large:"lg",medium:"md",small:"sm",xsmall:"xs",lg:"lg",md:"md",sm:"sm",xs:"xs"},e.DEVICE_SIZES=["lg","md","sm","xs"],e.State={SUCCESS:"success",WARNING:"warning",DANGER:"danger",INFO:"info"},e.Style={DEFAULT:"default",PRIMARY:"primary",LINK:"link",INVERSE:"inverse"}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r=0;return p.default.Children.map(t,function(t){return p.default.isValidElement(t)?e.call(n,t,r++):t})}function i(t,e,n){var r=0;p.default.Children.forEach(t,function(t){p.default.isValidElement(t)&&e.call(n,t,r++)})}function a(t){var e=0;return p.default.Children.forEach(t,function(t){p.default.isValidElement(t)&&++e}),e}function s(t,e,n){var r=0,o=[];return p.default.Children.forEach(t,function(t){p.default.isValidElement(t)&&e.call(n,t,r++)&&o.push(t)}),o}function l(t,e,n){var r=0,o=void 0;return p.default.Children.forEach(t,function(t){o||p.default.isValidElement(t)&&e.call(n,t,r++)&&(o=t)}),o}function u(t,e,n){var r=0,o=!0;return p.default.Children.forEach(t,function(t){o&&p.default.isValidElement(t)&&(e.call(n,t,r++)||(o=!1))}),o}function c(t,e,n){var r=0,o=!1;return p.default.Children.forEach(t,function(t){o||p.default.isValidElement(t)&&e.call(n,t,r++)&&(o=!0)}),o}function f(t){var e=[];return p.default.Children.forEach(t,function(t){p.default.isValidElement(t)&&e.push(t)}),e}e.__esModule=!0;var d=n(1),p=r(d);e.default={map:o,forEach:i,count:a,find:l,filter:s,every:u,some:c,toArray:f},t.exports=e.default},function(t,e,n){var r,o;/*!
		 * jQuery JavaScript Library v3.1.1
		 * https://jquery.com/
		 *
		 * Includes Sizzle.js
		 * https://sizzlejs.com/
		 *
		 * Copyright jQuery Foundation and other contributors
		 * Released under the MIT license
		 * https://jquery.org/license
		 *
		 * Date: 2016-09-22T22:30Z
		 */
!function(e,n){"use strict";"object"==typeof t&&"object"==typeof t.exports?t.exports=e.document?n(e,!0):function(t){if(!t.document)throw new Error("jQuery requires a window with a document");return n(t)}:n(e)}("undefined"!=typeof window?window:this,function(n,i){"use strict";function a(t,e){e=e||it;var n=e.createElement("script");n.text=t,e.head.appendChild(n).parentNode.removeChild(n)}function s(t){var e=!!t&&"length"in t&&t.length,n=yt.type(t);return"function"!==n&&!yt.isWindow(t)&&("array"===n||0===e||"number"==typeof e&&e>0&&e-1 in t)}function l(t,e,n){return yt.isFunction(e)?yt.grep(t,function(t,r){return!!e.call(t,r,t)!==n}):e.nodeType?yt.grep(t,function(t){return t===e!==n}):"string"!=typeof e?yt.grep(t,function(t){return ct.call(e,t)>-1!==n}):St.test(e)?yt.filter(e,t,n):(e=yt.filter(e,t),yt.grep(t,function(t){return ct.call(e,t)>-1!==n&&1===t.nodeType}))}function u(t,e){for(;(t=t[e])&&1!==t.nodeType;);return t}function c(t){var e={};return yt.each(t.match(It)||[],function(t,n){e[n]=!0}),e}function f(t){return t}function d(t){throw t}function p(t,e,n){var r;try{t&&yt.isFunction(r=t.promise)?r.call(t).done(e).fail(n):t&&yt.isFunction(r=t.then)?r.call(t,e,n):e.call(void 0,t)}catch(t){n.call(void 0,t)}}function h(){it.removeEventListener("DOMContentLoaded",h),n.removeEventListener("load",h),yt.ready()}function g(){this.expando=yt.expando+g.uid++}function v(t){return"true"===t||"false"!==t&&("null"===t?null:t===+t+""?+t:Ht.test(t)?JSON.parse(t):t)}function m(t,e,n){var r;if(void 0===n&&1===t.nodeType)if(r="data-"+e.replace(zt,"-$&").toLowerCase(),n=t.getAttribute(r),"string"==typeof n){try{n=v(n)}catch(t){}Ut.set(t,e,n)}else n=void 0;return n}function y(t,e,n,r){var o,i=1,a=20,s=r?function(){return r.cur()}:function(){return yt.css(t,e,"")},l=s(),u=n&&n[3]||(yt.cssNumber[e]?"":"px"),c=(yt.cssNumber[e]||"px"!==u&&+l)&&qt.exec(yt.css(t,e));if(c&&c[3]!==u){u=u||c[3],n=n||[],c=+l||1;do i=i||".5",c/=i,yt.style(t,e,c+u);while(i!==(i=s()/l)&&1!==i&&--a)}return n&&(c=+c||+l||0,o=n[1]?c+(n[1]+1)*n[2]:+n[2],r&&(r.unit=u,r.start=c,r.end=o)),o}function b(t){var e,n=t.ownerDocument,r=t.nodeName,o=Gt[r];return o?o:(e=n.body.appendChild(n.createElement(r)),o=yt.css(e,"display"),e.parentNode.removeChild(e),"none"===o&&(o="block"),Gt[r]=o,o)}function x(t,e){for(var n,r,o=[],i=0,a=t.length;i<a;i++)r=t[i],r.style&&(n=r.style.display,e?("none"===n&&(o[i]=Bt.get(r,"display")||null,o[i]||(r.style.display="")),""===r.style.display&&Kt(r)&&(o[i]=b(r))):"none"!==n&&(o[i]="none",Bt.set(r,"display",n)));for(i=0;i<a;i++)null!=o[i]&&(t[i].style.display=o[i]);return t}function _(t,e){var n;return n="undefined"!=typeof t.getElementsByTagName?t.getElementsByTagName(e||"*"):"undefined"!=typeof t.querySelectorAll?t.querySelectorAll(e||"*"):[],void 0===e||e&&yt.nodeName(t,e)?yt.merge([t],n):n}function w(t,e){for(var n=0,r=t.length;n<r;n++)Bt.set(t[n],"globalEval",!e||Bt.get(e[n],"globalEval"))}function T(t,e,n,r,o){for(var i,a,s,l,u,c,f=e.createDocumentFragment(),d=[],p=0,h=t.length;p<h;p++)if(i=t[p],i||0===i)if("object"===yt.type(i))yt.merge(d,i.nodeType?[i]:i);else if(Qt.test(i)){for(a=a||f.appendChild(e.createElement("div")),s=($t.exec(i)||["",""])[1].toLowerCase(),l=Jt[s]||Jt._default,a.innerHTML=l[1]+yt.htmlPrefilter(i)+l[2],c=l[0];c--;)a=a.lastChild;yt.merge(d,a.childNodes),a=f.firstChild,a.textContent=""}else d.push(e.createTextNode(i));for(f.textContent="",p=0;i=d[p++];)if(r&&yt.inArray(i,r)>-1)o&&o.push(i);else if(u=yt.contains(i.ownerDocument,i),a=_(f.appendChild(i),"script"),u&&w(a),n)for(c=0;i=a[c++];)Zt.test(i.type||"")&&n.push(i);return f}function C(){return!0}function k(){return!1}function E(){try{return it.activeElement}catch(t){}}function P(t,e,n,r,o,i){var a,s;if("object"==typeof e){"string"!=typeof n&&(r=r||n,n=void 0);for(s in e)P(t,s,n,r,e[s],i);return t}if(null==r&&null==o?(o=n,r=n=void 0):null==o&&("string"==typeof n?(o=r,r=void 0):(o=r,r=n,n=void 0)),o===!1)o=k;else if(!o)return t;return 1===i&&(a=o,o=function(t){return yt().off(t),a.apply(this,arguments)},o.guid=a.guid||(a.guid=yt.guid++)),t.each(function(){yt.event.add(this,e,o,r,n)})}function S(t,e){return yt.nodeName(t,"table")&&yt.nodeName(11!==e.nodeType?e:e.firstChild,"tr")?t.getElementsByTagName("tbody")[0]||t:t}function M(t){return t.type=(null!==t.getAttribute("type"))+"/"+t.type,t}function N(t){var e=se.exec(t.type);return e?t.type=e[1]:t.removeAttribute("type"),t}function A(t,e){var n,r,o,i,a,s,l,u;if(1===e.nodeType){if(Bt.hasData(t)&&(i=Bt.access(t),a=Bt.set(e,i),u=i.events)){delete a.handle,a.events={};for(o in u)for(n=0,r=u[o].length;n<r;n++)yt.event.add(e,o,u[o][n])}Ut.hasData(t)&&(s=Ut.access(t),l=yt.extend({},s),Ut.set(e,l))}}function O(t,e){var n=e.nodeName.toLowerCase();"input"===n&&Xt.test(t.type)?e.checked=t.checked:"input"!==n&&"textarea"!==n||(e.defaultValue=t.defaultValue)}function D(t,e,n,r){e=lt.apply([],e);var o,i,s,l,u,c,f=0,d=t.length,p=d-1,h=e[0],g=yt.isFunction(h);if(g||d>1&&"string"==typeof h&&!vt.checkClone&&ae.test(h))return t.each(function(o){var i=t.eq(o);g&&(e[0]=h.call(this,o,i.html())),D(i,e,n,r)});if(d&&(o=T(e,t[0].ownerDocument,!1,t,r),i=o.firstChild,1===o.childNodes.length&&(o=i),i||r)){for(s=yt.map(_(o,"script"),M),l=s.length;f<d;f++)u=o,f!==p&&(u=yt.clone(u,!0,!0),l&&yt.merge(s,_(u,"script"))),n.call(t[f],u,f);if(l)for(c=s[s.length-1].ownerDocument,yt.map(s,N),f=0;f<l;f++)u=s[f],Zt.test(u.type||"")&&!Bt.access(u,"globalEval")&&yt.contains(c,u)&&(u.src?yt._evalUrl&&yt._evalUrl(u.src):a(u.textContent.replace(le,""),c))}return t}function I(t,e,n){for(var r,o=e?yt.filter(e,t):t,i=0;null!=(r=o[i]);i++)n||1!==r.nodeType||yt.cleanData(_(r)),r.parentNode&&(n&&yt.contains(r.ownerDocument,r)&&w(_(r,"script")),r.parentNode.removeChild(r));return t}function R(t,e,n){var r,o,i,a,s=t.style;return n=n||fe(t),n&&(a=n.getPropertyValue(e)||n[e],""!==a||yt.contains(t.ownerDocument,t)||(a=yt.style(t,e)),!vt.pixelMarginRight()&&ce.test(a)&&ue.test(e)&&(r=s.width,o=s.minWidth,i=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=r,s.minWidth=o,s.maxWidth=i)),void 0!==a?a+"":a}function L(t,e){return{get:function(){return t()?void delete this.get:(this.get=e).apply(this,arguments)}}}function F(t){if(t in ve)return t;for(var e=t[0].toUpperCase()+t.slice(1),n=ge.length;n--;)if(t=ge[n]+e,t in ve)return t}function j(t,e,n){var r=qt.exec(e);return r?Math.max(0,r[2]-(n||0))+(r[3]||"px"):e}function B(t,e,n,r,o){var i,a=0;for(i=n===(r?"border":"content")?4:"width"===e?1:0;i<4;i+=2)"margin"===n&&(a+=yt.css(t,n+Vt[i],!0,o)),r?("content"===n&&(a-=yt.css(t,"padding"+Vt[i],!0,o)),"margin"!==n&&(a-=yt.css(t,"border"+Vt[i]+"Width",!0,o))):(a+=yt.css(t,"padding"+Vt[i],!0,o),"padding"!==n&&(a+=yt.css(t,"border"+Vt[i]+"Width",!0,o)));return a}function U(t,e,n){var r,o=!0,i=fe(t),a="border-box"===yt.css(t,"boxSizing",!1,i);if(t.getClientRects().length&&(r=t.getBoundingClientRect()[e]),r<=0||null==r){if(r=R(t,e,i),(r<0||null==r)&&(r=t.style[e]),ce.test(r))return r;o=a&&(vt.boxSizingReliable()||r===t.style[e]),r=parseFloat(r)||0}return r+B(t,e,n||(a?"border":"content"),o,i)+"px"}function H(t,e,n,r,o){return new H.prototype.init(t,e,n,r,o)}function z(){ye&&(n.requestAnimationFrame(z),yt.fx.tick())}function W(){return n.setTimeout(function(){me=void 0}),me=yt.now()}function q(t,e){var n,r=0,o={height:t};for(e=e?1:0;r<4;r+=2-e)n=Vt[r],o["margin"+n]=o["padding"+n]=t;return e&&(o.opacity=o.width=t),o}function V(t,e,n){for(var r,o=(G.tweeners[e]||[]).concat(G.tweeners["*"]),i=0,a=o.length;i<a;i++)if(r=o[i].call(n,e,t))return r}function K(t,e,n){var r,o,i,a,s,l,u,c,f="width"in e||"height"in e,d=this,p={},h=t.style,g=t.nodeType&&Kt(t),v=Bt.get(t,"fxshow");n.queue||(a=yt._queueHooks(t,"fx"),null==a.unqueued&&(a.unqueued=0,s=a.empty.fire,a.empty.fire=function(){a.unqueued||s()}),a.unqueued++,d.always(function(){d.always(function(){a.unqueued--,yt.queue(t,"fx").length||a.empty.fire()})}));for(r in e)if(o=e[r],be.test(o)){if(delete e[r],i=i||"toggle"===o,o===(g?"hide":"show")){if("show"!==o||!v||void 0===v[r])continue;g=!0}p[r]=v&&v[r]||yt.style(t,r)}if(l=!yt.isEmptyObject(e),l||!yt.isEmptyObject(p)){f&&1===t.nodeType&&(n.overflow=[h.overflow,h.overflowX,h.overflowY],u=v&&v.display,null==u&&(u=Bt.get(t,"display")),c=yt.css(t,"display"),"none"===c&&(u?c=u:(x([t],!0),u=t.style.display||u,c=yt.css(t,"display"),x([t]))),("inline"===c||"inline-block"===c&&null!=u)&&"none"===yt.css(t,"float")&&(l||(d.done(function(){h.display=u}),null==u&&(c=h.display,u="none"===c?"":c)),h.display="inline-block")),n.overflow&&(h.overflow="hidden",d.always(function(){h.overflow=n.overflow[0],h.overflowX=n.overflow[1],h.overflowY=n.overflow[2]})),l=!1;for(r in p)l||(v?"hidden"in v&&(g=v.hidden):v=Bt.access(t,"fxshow",{display:u}),i&&(v.hidden=!g),g&&x([t],!0),d.done(function(){g||x([t]),Bt.remove(t,"fxshow");for(r in p)yt.style(t,r,p[r])})),l=V(g?v[r]:0,r,d),r in v||(v[r]=l.start,g&&(l.end=l.start,l.start=0))}}function Y(t,e){var n,r,o,i,a;for(n in t)if(r=yt.camelCase(n),o=e[r],i=t[n],yt.isArray(i)&&(o=i[1],i=t[n]=i[0]),n!==r&&(t[r]=i,delete t[n]),a=yt.cssHooks[r],a&&"expand"in a){i=a.expand(i),delete t[r];for(n in i)n in t||(t[n]=i[n],e[n]=o)}else e[r]=o}function G(t,e,n){var r,o,i=0,a=G.prefilters.length,s=yt.Deferred().always(function(){delete l.elem}),l=function(){if(o)return!1;for(var e=me||W(),n=Math.max(0,u.startTime+u.duration-e),r=n/u.duration||0,i=1-r,a=0,l=u.tweens.length;a<l;a++)u.tweens[a].run(i);return s.notifyWith(t,[u,i,n]),i<1&&l?n:(s.resolveWith(t,[u]),!1)},u=s.promise({elem:t,props:yt.extend({},e),opts:yt.extend(!0,{specialEasing:{},easing:yt.easing._default},n),originalProperties:e,originalOptions:n,startTime:me||W(),duration:n.duration,tweens:[],createTween:function(e,n){var r=yt.Tween(t,u.opts,e,n,u.opts.specialEasing[e]||u.opts.easing);return u.tweens.push(r),r},stop:function(e){var n=0,r=e?u.tweens.length:0;if(o)return this;for(o=!0;n<r;n++)u.tweens[n].run(1);return e?(s.notifyWith(t,[u,1,0]),s.resolveWith(t,[u,e])):s.rejectWith(t,[u,e]),this}}),c=u.props;for(Y(c,u.opts.specialEasing);i<a;i++)if(r=G.prefilters[i].call(u,t,c,u.opts))return yt.isFunction(r.stop)&&(yt._queueHooks(u.elem,u.opts.queue).stop=yt.proxy(r.stop,r)),r;return yt.map(c,V,u),yt.isFunction(u.opts.start)&&u.opts.start.call(t,u),yt.fx.timer(yt.extend(l,{elem:t,anim:u,queue:u.opts.queue})),u.progress(u.opts.progress).done(u.opts.done,u.opts.complete).fail(u.opts.fail).always(u.opts.always)}function X(t){var e=t.match(It)||[];return e.join(" ")}function $(t){return t.getAttribute&&t.getAttribute("class")||""}function Z(t,e,n,r){var o;if(yt.isArray(e))yt.each(e,function(e,o){n||Ne.test(t)?r(t,o):Z(t+"["+("object"==typeof o&&null!=o?e:"")+"]",o,n,r)});else if(n||"object"!==yt.type(e))r(t,e);else for(o in e)Z(t+"["+o+"]",e[o],n,r)}function J(t){return function(e,n){"string"!=typeof e&&(n=e,e="*");var r,o=0,i=e.toLowerCase().match(It)||[];if(yt.isFunction(n))for(;r=i[o++];)"+"===r[0]?(r=r.slice(1)||"*",(t[r]=t[r]||[]).unshift(n)):(t[r]=t[r]||[]).push(n)}}function Q(t,e,n,r){function o(s){var l;return i[s]=!0,yt.each(t[s]||[],function(t,s){var u=s(e,n,r);return"string"!=typeof u||a||i[u]?a?!(l=u):void 0:(e.dataTypes.unshift(u),o(u),!1)}),l}var i={},a=t===ze;return o(e.dataTypes[0])||!i["*"]&&o("*")}function tt(t,e){var n,r,o=yt.ajaxSettings.flatOptions||{};for(n in e)void 0!==e[n]&&((o[n]?t:r||(r={}))[n]=e[n]);return r&&yt.extend(!0,t,r),t}function et(t,e,n){for(var r,o,i,a,s=t.contents,l=t.dataTypes;"*"===l[0];)l.shift(),void 0===r&&(r=t.mimeType||e.getResponseHeader("Content-Type"));if(r)for(o in s)if(s[o]&&s[o].test(r)){l.unshift(o);break}if(l[0]in n)i=l[0];else{for(o in n){if(!l[0]||t.converters[o+" "+l[0]]){i=o;break}a||(a=o)}i=i||a}if(i)return i!==l[0]&&l.unshift(i),n[i]}function nt(t,e,n,r){var o,i,a,s,l,u={},c=t.dataTypes.slice();if(c[1])for(a in t.converters)u[a.toLowerCase()]=t.converters[a];for(i=c.shift();i;)if(t.responseFields[i]&&(n[t.responseFields[i]]=e),!l&&r&&t.dataFilter&&(e=t.dataFilter(e,t.dataType)),l=i,i=c.shift())if("*"===i)i=l;else if("*"!==l&&l!==i){if(a=u[l+" "+i]||u["* "+i],!a)for(o in u)if(s=o.split(" "),s[1]===i&&(a=u[l+" "+s[0]]||u["* "+s[0]])){a===!0?a=u[o]:u[o]!==!0&&(i=s[0],c.unshift(s[1]));break}if(a!==!0)if(a&&t.throws)e=a(e);else try{e=a(e)}catch(t){return{state:"parsererror",error:a?t:"No conversion from "+l+" to "+i}}}return{state:"success",data:e}}function rt(t){return yt.isWindow(t)?t:9===t.nodeType&&t.defaultView}var ot=[],it=n.document,at=Object.getPrototypeOf,st=ot.slice,lt=ot.concat,ut=ot.push,ct=ot.indexOf,ft={},dt=ft.toString,pt=ft.hasOwnProperty,ht=pt.toString,gt=ht.call(Object),vt={},mt="3.1.1",yt=function(t,e){return new yt.fn.init(t,e)},bt=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,xt=/^-ms-/,_t=/-([a-z])/g,wt=function(t,e){return e.toUpperCase()};yt.fn=yt.prototype={jquery:mt,constructor:yt,length:0,toArray:function(){return st.call(this)},get:function(t){return null==t?st.call(this):t<0?this[t+this.length]:this[t]},pushStack:function(t){var e=yt.merge(this.constructor(),t);return e.prevObject=this,e},each:function(t){return yt.each(this,t)},map:function(t){return this.pushStack(yt.map(this,function(e,n){return t.call(e,n,e)}))},slice:function(){return this.pushStack(st.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(t){var e=this.length,n=+t+(t<0?e:0);return this.pushStack(n>=0&&n<e?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:ut,sort:ot.sort,splice:ot.splice},yt.extend=yt.fn.extend=function(){var t,e,n,r,o,i,a=arguments[0]||{},s=1,l=arguments.length,u=!1;for("boolean"==typeof a&&(u=a,a=arguments[s]||{},s++),"object"==typeof a||yt.isFunction(a)||(a={}),s===l&&(a=this,s--);s<l;s++)if(null!=(t=arguments[s]))for(e in t)n=a[e],r=t[e],a!==r&&(u&&r&&(yt.isPlainObject(r)||(o=yt.isArray(r)))?(o?(o=!1,i=n&&yt.isArray(n)?n:[]):i=n&&yt.isPlainObject(n)?n:{},a[e]=yt.extend(u,i,r)):void 0!==r&&(a[e]=r));return a},yt.extend({expando:"jQuery"+(mt+Math.random()).replace(/\D/g,""),isReady:!0,error:function(t){throw new Error(t)},noop:function(){},isFunction:function(t){return"function"===yt.type(t)},isArray:Array.isArray,isWindow:function(t){return null!=t&&t===t.window},isNumeric:function(t){var e=yt.type(t);return("number"===e||"string"===e)&&!isNaN(t-parseFloat(t))},isPlainObject:function(t){var e,n;return!(!t||"[object Object]"!==dt.call(t)||(e=at(t))&&(n=pt.call(e,"constructor")&&e.constructor,"function"!=typeof n||ht.call(n)!==gt))},isEmptyObject:function(t){var e;for(e in t)return!1;return!0},type:function(t){return null==t?t+"":"object"==typeof t||"function"==typeof t?ft[dt.call(t)]||"object":typeof t},globalEval:function(t){a(t)},camelCase:function(t){return t.replace(xt,"ms-").replace(_t,wt)},nodeName:function(t,e){return t.nodeName&&t.nodeName.toLowerCase()===e.toLowerCase()},each:function(t,e){var n,r=0;if(s(t))for(n=t.length;r<n&&e.call(t[r],r,t[r])!==!1;r++);else for(r in t)if(e.call(t[r],r,t[r])===!1)break;return t},trim:function(t){return null==t?"":(t+"").replace(bt,"")},makeArray:function(t,e){var n=e||[];return null!=t&&(s(Object(t))?yt.merge(n,"string"==typeof t?[t]:t):ut.call(n,t)),n},inArray:function(t,e,n){return null==e?-1:ct.call(e,t,n)},merge:function(t,e){for(var n=+e.length,r=0,o=t.length;r<n;r++)t[o++]=e[r];return t.length=o,t},grep:function(t,e,n){for(var r,o=[],i=0,a=t.length,s=!n;i<a;i++)r=!e(t[i],i),r!==s&&o.push(t[i]);return o},map:function(t,e,n){var r,o,i=0,a=[];if(s(t))for(r=t.length;i<r;i++)o=e(t[i],i,n),null!=o&&a.push(o);else for(i in t)o=e(t[i],i,n),null!=o&&a.push(o);return lt.apply([],a)},guid:1,proxy:function(t,e){var n,r,o;if("string"==typeof e&&(n=t[e],e=t,t=n),yt.isFunction(t))return r=st.call(arguments,2),o=function(){return t.apply(e||this,r.concat(st.call(arguments)))},o.guid=t.guid=t.guid||yt.guid++,o},now:Date.now,support:vt}),"function"==typeof Symbol&&(yt.fn[Symbol.iterator]=ot[Symbol.iterator]),yt.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(t,e){ft["[object "+e+"]"]=e.toLowerCase()});var Tt=/*!
		 * Sizzle CSS Selector Engine v2.3.3
		 * https://sizzlejs.com/
		 *
		 * Copyright jQuery Foundation and other contributors
		 * Released under the MIT license
		 * http://jquery.org/license
		 *
		 * Date: 2016-08-08
		 */
function(t){function e(t,e,n,r){var o,i,a,s,l,u,c,d=e&&e.ownerDocument,h=e?e.nodeType:9;if(n=n||[],"string"!=typeof t||!t||1!==h&&9!==h&&11!==h)return n;if(!r&&((e?e.ownerDocument||e:H)!==D&&O(e),e=e||D,R)){if(11!==h&&(l=mt.exec(t)))if(o=l[1]){if(9===h){if(!(a=e.getElementById(o)))return n;if(a.id===o)return n.push(a),n}else if(d&&(a=d.getElementById(o))&&B(e,a)&&a.id===o)return n.push(a),n}else{if(l[2])return J.apply(n,e.getElementsByTagName(t)),n;if((o=l[3])&&w.getElementsByClassName&&e.getElementsByClassName)return J.apply(n,e.getElementsByClassName(o)),n}if(w.qsa&&!K[t+" "]&&(!L||!L.test(t))){if(1!==h)d=e,c=t;else if("object"!==e.nodeName.toLowerCase()){for((s=e.getAttribute("id"))?s=s.replace(_t,wt):e.setAttribute("id",s=U),u=E(t),i=u.length;i--;)u[i]="#"+s+" "+p(u[i]);c=u.join(","),d=yt.test(t)&&f(e.parentNode)||e}if(c)try{return J.apply(n,d.querySelectorAll(c)),n}catch(t){}finally{s===U&&e.removeAttribute("id")}}}return S(t.replace(st,"$1"),e,n,r)}function n(){function t(n,r){return e.push(n+" ")>T.cacheLength&&delete t[e.shift()],t[n+" "]=r}var e=[];return t}function r(t){return t[U]=!0,t}function o(t){var e=D.createElement("fieldset");try{return!!t(e)}catch(t){return!1}finally{e.parentNode&&e.parentNode.removeChild(e),e=null}}function i(t,e){for(var n=t.split("|"),r=n.length;r--;)T.attrHandle[n[r]]=e}function a(t,e){var n=e&&t,r=n&&1===t.nodeType&&1===e.nodeType&&t.sourceIndex-e.sourceIndex;if(r)return r;if(n)for(;n=n.nextSibling;)if(n===e)return-1;return t?1:-1}function s(t){return function(e){var n=e.nodeName.toLowerCase();return"input"===n&&e.type===t}}function l(t){return function(e){var n=e.nodeName.toLowerCase();return("input"===n||"button"===n)&&e.type===t}}function u(t){return function(e){return"form"in e?e.parentNode&&e.disabled===!1?"label"in e?"label"in e.parentNode?e.parentNode.disabled===t:e.disabled===t:e.isDisabled===t||e.isDisabled!==!t&&Ct(e)===t:e.disabled===t:"label"in e&&e.disabled===t}}function c(t){return r(function(e){return e=+e,r(function(n,r){for(var o,i=t([],n.length,e),a=i.length;a--;)n[o=i[a]]&&(n[o]=!(r[o]=n[o]))})})}function f(t){return t&&"undefined"!=typeof t.getElementsByTagName&&t}function d(){}function p(t){for(var e=0,n=t.length,r="";e<n;e++)r+=t[e].value;return r}function h(t,e,n){var r=e.dir,o=e.next,i=o||r,a=n&&"parentNode"===i,s=W++;return e.first?function(e,n,o){for(;e=e[r];)if(1===e.nodeType||a)return t(e,n,o);return!1}:function(e,n,l){var u,c,f,d=[z,s];if(l){for(;e=e[r];)if((1===e.nodeType||a)&&t(e,n,l))return!0}else for(;e=e[r];)if(1===e.nodeType||a)if(f=e[U]||(e[U]={}),c=f[e.uniqueID]||(f[e.uniqueID]={}),o&&o===e.nodeName.toLowerCase())e=e[r]||e;else{if((u=c[i])&&u[0]===z&&u[1]===s)return d[2]=u[2];if(c[i]=d,d[2]=t(e,n,l))return!0}return!1}}function g(t){return t.length>1?function(e,n,r){for(var o=t.length;o--;)if(!t[o](e,n,r))return!1;return!0}:t[0]}function v(t,n,r){for(var o=0,i=n.length;o<i;o++)e(t,n[o],r);return r}function m(t,e,n,r,o){for(var i,a=[],s=0,l=t.length,u=null!=e;s<l;s++)(i=t[s])&&(n&&!n(i,r,o)||(a.push(i),u&&e.push(s)));return a}function y(t,e,n,o,i,a){return o&&!o[U]&&(o=y(o)),i&&!i[U]&&(i=y(i,a)),r(function(r,a,s,l){var u,c,f,d=[],p=[],h=a.length,g=r||v(e||"*",s.nodeType?[s]:s,[]),y=!t||!r&&e?g:m(g,d,t,s,l),b=n?i||(r?t:h||o)?[]:a:y;if(n&&n(y,b,s,l),o)for(u=m(b,p),o(u,[],s,l),c=u.length;c--;)(f=u[c])&&(b[p[c]]=!(y[p[c]]=f));if(r){if(i||t){if(i){for(u=[],c=b.length;c--;)(f=b[c])&&u.push(y[c]=f);i(null,b=[],u,l)}for(c=b.length;c--;)(f=b[c])&&(u=i?tt(r,f):d[c])>-1&&(r[u]=!(a[u]=f))}}else b=m(b===a?b.splice(h,b.length):b),i?i(null,a,b,l):J.apply(a,b)})}function b(t){for(var e,n,r,o=t.length,i=T.relative[t[0].type],a=i||T.relative[" "],s=i?1:0,l=h(function(t){return t===e},a,!0),u=h(function(t){return tt(e,t)>-1},a,!0),c=[function(t,n,r){var o=!i&&(r||n!==M)||((e=n).nodeType?l(t,n,r):u(t,n,r));return e=null,o}];s<o;s++)if(n=T.relative[t[s].type])c=[h(g(c),n)];else{if(n=T.filter[t[s].type].apply(null,t[s].matches),n[U]){for(r=++s;r<o&&!T.relative[t[r].type];r++);return y(s>1&&g(c),s>1&&p(t.slice(0,s-1).concat({value:" "===t[s-2].type?"*":""})).replace(st,"$1"),n,s<r&&b(t.slice(s,r)),r<o&&b(t=t.slice(r)),r<o&&p(t))}c.push(n)}return g(c)}function x(t,n){var o=n.length>0,i=t.length>0,a=function(r,a,s,l,u){var c,f,d,p=0,h="0",g=r&&[],v=[],y=M,b=r||i&&T.find.TAG("*",u),x=z+=null==y?1:Math.random()||.1,_=b.length;for(u&&(M=a===D||a||u);h!==_&&null!=(c=b[h]);h++){if(i&&c){for(f=0,a||c.ownerDocument===D||(O(c),s=!R);d=t[f++];)if(d(c,a||D,s)){l.push(c);break}u&&(z=x)}o&&((c=!d&&c)&&p--,r&&g.push(c))}if(p+=h,o&&h!==p){for(f=0;d=n[f++];)d(g,v,a,s);if(r){if(p>0)for(;h--;)g[h]||v[h]||(v[h]=$.call(l));v=m(v)}J.apply(l,v),u&&!r&&v.length>0&&p+n.length>1&&e.uniqueSort(l)}return u&&(z=x,M=y),g};return o?r(a):a}var _,w,T,C,k,E,P,S,M,N,A,O,D,I,R,L,F,j,B,U="sizzle"+1*new Date,H=t.document,z=0,W=0,q=n(),V=n(),K=n(),Y=function(t,e){return t===e&&(A=!0),0},G={}.hasOwnProperty,X=[],$=X.pop,Z=X.push,J=X.push,Q=X.slice,tt=function(t,e){for(var n=0,r=t.length;n<r;n++)if(t[n]===e)return n;return-1},et="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",nt="[\\x20\\t\\r\\n\\f]",rt="(?:\\\\.|[\\w-]|[^\0-\\xa0])+",ot="\\["+nt+"*("+rt+")(?:"+nt+"*([*^$|!~]?=)"+nt+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+rt+"))|)"+nt+"*\\]",it=":("+rt+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+ot+")*)|.*)\\)|)",at=new RegExp(nt+"+","g"),st=new RegExp("^"+nt+"+|((?:^|[^\\\\])(?:\\\\.)*)"+nt+"+$","g"),lt=new RegExp("^"+nt+"*,"+nt+"*"),ut=new RegExp("^"+nt+"*([>+~]|"+nt+")"+nt+"*"),ct=new RegExp("="+nt+"*([^\\]'\"]*?)"+nt+"*\\]","g"),ft=new RegExp(it),dt=new RegExp("^"+rt+"$"),pt={ID:new RegExp("^#("+rt+")"),CLASS:new RegExp("^\\.("+rt+")"),TAG:new RegExp("^("+rt+"|[*])"),ATTR:new RegExp("^"+ot),PSEUDO:new RegExp("^"+it),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+nt+"*(even|odd|(([+-]|)(\\d*)n|)"+nt+"*(?:([+-]|)"+nt+"*(\\d+)|))"+nt+"*\\)|)","i"),bool:new RegExp("^(?:"+et+")$","i"),needsContext:new RegExp("^"+nt+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+nt+"*((?:-\\d)?\\d*)"+nt+"*\\)|)(?=[^-]|$)","i")},ht=/^(?:input|select|textarea|button)$/i,gt=/^h\d$/i,vt=/^[^{]+\{\s*\[native \w/,mt=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,yt=/[+~]/,bt=new RegExp("\\\\([\\da-f]{1,6}"+nt+"?|("+nt+")|.)","ig"),xt=function(t,e,n){var r="0x"+e-65536;return r!==r||n?e:r<0?String.fromCharCode(r+65536):String.fromCharCode(r>>10|55296,1023&r|56320)},_t=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,wt=function(t,e){return e?"\0"===t?"�":t.slice(0,-1)+"\\"+t.charCodeAt(t.length-1).toString(16)+" ":"\\"+t},Tt=function(){O()},Ct=h(function(t){return t.disabled===!0&&("form"in t||"label"in t)},{dir:"parentNode",next:"legend"});try{J.apply(X=Q.call(H.childNodes),H.childNodes),X[H.childNodes.length].nodeType}catch(t){J={apply:X.length?function(t,e){Z.apply(t,Q.call(e))}:function(t,e){for(var n=t.length,r=0;t[n++]=e[r++];);t.length=n-1}}}w=e.support={},k=e.isXML=function(t){var e=t&&(t.ownerDocument||t).documentElement;return!!e&&"HTML"!==e.nodeName},O=e.setDocument=function(t){var e,n,r=t?t.ownerDocument||t:H;return r!==D&&9===r.nodeType&&r.documentElement?(D=r,I=D.documentElement,R=!k(D),H!==D&&(n=D.defaultView)&&n.top!==n&&(n.addEventListener?n.addEventListener("unload",Tt,!1):n.attachEvent&&n.attachEvent("onunload",Tt)),w.attributes=o(function(t){return t.className="i",!t.getAttribute("className")}),w.getElementsByTagName=o(function(t){return t.appendChild(D.createComment("")),!t.getElementsByTagName("*").length}),w.getElementsByClassName=vt.test(D.getElementsByClassName),w.getById=o(function(t){return I.appendChild(t).id=U,!D.getElementsByName||!D.getElementsByName(U).length}),w.getById?(T.filter.ID=function(t){var e=t.replace(bt,xt);return function(t){return t.getAttribute("id")===e}},T.find.ID=function(t,e){if("undefined"!=typeof e.getElementById&&R){var n=e.getElementById(t);return n?[n]:[]}}):(T.filter.ID=function(t){var e=t.replace(bt,xt);return function(t){var n="undefined"!=typeof t.getAttributeNode&&t.getAttributeNode("id");return n&&n.value===e}},T.find.ID=function(t,e){if("undefined"!=typeof e.getElementById&&R){var n,r,o,i=e.getElementById(t);if(i){if(n=i.getAttributeNode("id"),n&&n.value===t)return[i];for(o=e.getElementsByName(t),r=0;i=o[r++];)if(n=i.getAttributeNode("id"),n&&n.value===t)return[i]}return[]}}),T.find.TAG=w.getElementsByTagName?function(t,e){return"undefined"!=typeof e.getElementsByTagName?e.getElementsByTagName(t):w.qsa?e.querySelectorAll(t):void 0}:function(t,e){var n,r=[],o=0,i=e.getElementsByTagName(t);if("*"===t){for(;n=i[o++];)1===n.nodeType&&r.push(n);return r}return i},T.find.CLASS=w.getElementsByClassName&&function(t,e){if("undefined"!=typeof e.getElementsByClassName&&R)return e.getElementsByClassName(t)},F=[],L=[],(w.qsa=vt.test(D.querySelectorAll))&&(o(function(t){I.appendChild(t).innerHTML="<a id='"+U+"'></a><select id='"+U+"-\r\\' msallowcapture=''><option selected=''></option></select>",t.querySelectorAll("[msallowcapture^='']").length&&L.push("[*^$]="+nt+"*(?:''|\"\")"),t.querySelectorAll("[selected]").length||L.push("\\["+nt+"*(?:value|"+et+")"),t.querySelectorAll("[id~="+U+"-]").length||L.push("~="),t.querySelectorAll(":checked").length||L.push(":checked"),t.querySelectorAll("a#"+U+"+*").length||L.push(".#.+[+~]")}),o(function(t){t.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var e=D.createElement("input");e.setAttribute("type","hidden"),t.appendChild(e).setAttribute("name","D"),t.querySelectorAll("[name=d]").length&&L.push("name"+nt+"*[*^$|!~]?="),2!==t.querySelectorAll(":enabled").length&&L.push(":enabled",":disabled"),I.appendChild(t).disabled=!0,2!==t.querySelectorAll(":disabled").length&&L.push(":enabled",":disabled"),t.querySelectorAll("*,:x"),L.push(",.*:")})),(w.matchesSelector=vt.test(j=I.matches||I.webkitMatchesSelector||I.mozMatchesSelector||I.oMatchesSelector||I.msMatchesSelector))&&o(function(t){w.disconnectedMatch=j.call(t,"*"),j.call(t,"[s!='']:x"),F.push("!=",it)}),L=L.length&&new RegExp(L.join("|")),F=F.length&&new RegExp(F.join("|")),e=vt.test(I.compareDocumentPosition),B=e||vt.test(I.contains)?function(t,e){var n=9===t.nodeType?t.documentElement:t,r=e&&e.parentNode;return t===r||!(!r||1!==r.nodeType||!(n.contains?n.contains(r):t.compareDocumentPosition&&16&t.compareDocumentPosition(r)))}:function(t,e){if(e)for(;e=e.parentNode;)if(e===t)return!0;return!1},Y=e?function(t,e){if(t===e)return A=!0,0;var n=!t.compareDocumentPosition-!e.compareDocumentPosition;return n?n:(n=(t.ownerDocument||t)===(e.ownerDocument||e)?t.compareDocumentPosition(e):1,1&n||!w.sortDetached&&e.compareDocumentPosition(t)===n?t===D||t.ownerDocument===H&&B(H,t)?-1:e===D||e.ownerDocument===H&&B(H,e)?1:N?tt(N,t)-tt(N,e):0:4&n?-1:1)}:function(t,e){if(t===e)return A=!0,0;var n,r=0,o=t.parentNode,i=e.parentNode,s=[t],l=[e];if(!o||!i)return t===D?-1:e===D?1:o?-1:i?1:N?tt(N,t)-tt(N,e):0;if(o===i)return a(t,e);for(n=t;n=n.parentNode;)s.unshift(n);for(n=e;n=n.parentNode;)l.unshift(n);for(;s[r]===l[r];)r++;return r?a(s[r],l[r]):s[r]===H?-1:l[r]===H?1:0},D):D},e.matches=function(t,n){return e(t,null,null,n)},e.matchesSelector=function(t,n){if((t.ownerDocument||t)!==D&&O(t),n=n.replace(ct,"='$1']"),w.matchesSelector&&R&&!K[n+" "]&&(!F||!F.test(n))&&(!L||!L.test(n)))try{var r=j.call(t,n);if(r||w.disconnectedMatch||t.document&&11!==t.document.nodeType)return r}catch(t){}return e(n,D,null,[t]).length>0},e.contains=function(t,e){return(t.ownerDocument||t)!==D&&O(t),B(t,e)},e.attr=function(t,e){(t.ownerDocument||t)!==D&&O(t);var n=T.attrHandle[e.toLowerCase()],r=n&&G.call(T.attrHandle,e.toLowerCase())?n(t,e,!R):void 0;return void 0!==r?r:w.attributes||!R?t.getAttribute(e):(r=t.getAttributeNode(e))&&r.specified?r.value:null},e.escape=function(t){return(t+"").replace(_t,wt)},e.error=function(t){throw new Error("Syntax error, unrecognized expression: "+t)},e.uniqueSort=function(t){var e,n=[],r=0,o=0;if(A=!w.detectDuplicates,N=!w.sortStable&&t.slice(0),t.sort(Y),A){for(;e=t[o++];)e===t[o]&&(r=n.push(o));for(;r--;)t.splice(n[r],1)}return N=null,t},C=e.getText=function(t){var e,n="",r=0,o=t.nodeType;if(o){if(1===o||9===o||11===o){if("string"==typeof t.textContent)return t.textContent;for(t=t.firstChild;t;t=t.nextSibling)n+=C(t)}else if(3===o||4===o)return t.nodeValue}else for(;e=t[r++];)n+=C(e);return n},T=e.selectors={cacheLength:50,createPseudo:r,match:pt,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(t){return t[1]=t[1].replace(bt,xt),t[3]=(t[3]||t[4]||t[5]||"").replace(bt,xt),"~="===t[2]&&(t[3]=" "+t[3]+" "),t.slice(0,4)},CHILD:function(t){return t[1]=t[1].toLowerCase(),"nth"===t[1].slice(0,3)?(t[3]||e.error(t[0]),t[4]=+(t[4]?t[5]+(t[6]||1):2*("even"===t[3]||"odd"===t[3])),t[5]=+(t[7]+t[8]||"odd"===t[3])):t[3]&&e.error(t[0]),t},PSEUDO:function(t){var e,n=!t[6]&&t[2];return pt.CHILD.test(t[0])?null:(t[3]?t[2]=t[4]||t[5]||"":n&&ft.test(n)&&(e=E(n,!0))&&(e=n.indexOf(")",n.length-e)-n.length)&&(t[0]=t[0].slice(0,e),t[2]=n.slice(0,e)),t.slice(0,3))}},filter:{TAG:function(t){var e=t.replace(bt,xt).toLowerCase();return"*"===t?function(){return!0}:function(t){return t.nodeName&&t.nodeName.toLowerCase()===e}},CLASS:function(t){var e=q[t+" "];return e||(e=new RegExp("(^|"+nt+")"+t+"("+nt+"|$)"))&&q(t,function(t){return e.test("string"==typeof t.className&&t.className||"undefined"!=typeof t.getAttribute&&t.getAttribute("class")||"")})},ATTR:function(t,n,r){return function(o){var i=e.attr(o,t);return null==i?"!="===n:!n||(i+="","="===n?i===r:"!="===n?i!==r:"^="===n?r&&0===i.indexOf(r):"*="===n?r&&i.indexOf(r)>-1:"$="===n?r&&i.slice(-r.length)===r:"~="===n?(" "+i.replace(at," ")+" ").indexOf(r)>-1:"|="===n&&(i===r||i.slice(0,r.length+1)===r+"-"))}},CHILD:function(t,e,n,r,o){var i="nth"!==t.slice(0,3),a="last"!==t.slice(-4),s="of-type"===e;return 1===r&&0===o?function(t){return!!t.parentNode}:function(e,n,l){var u,c,f,d,p,h,g=i!==a?"nextSibling":"previousSibling",v=e.parentNode,m=s&&e.nodeName.toLowerCase(),y=!l&&!s,b=!1;if(v){if(i){for(;g;){for(d=e;d=d[g];)if(s?d.nodeName.toLowerCase()===m:1===d.nodeType)return!1;h=g="only"===t&&!h&&"nextSibling"}return!0}if(h=[a?v.firstChild:v.lastChild],a&&y){for(d=v,f=d[U]||(d[U]={}),c=f[d.uniqueID]||(f[d.uniqueID]={}),u=c[t]||[],p=u[0]===z&&u[1],b=p&&u[2],d=p&&v.childNodes[p];d=++p&&d&&d[g]||(b=p=0)||h.pop();)if(1===d.nodeType&&++b&&d===e){c[t]=[z,p,b];break}}else if(y&&(d=e,f=d[U]||(d[U]={}),c=f[d.uniqueID]||(f[d.uniqueID]={}),u=c[t]||[],p=u[0]===z&&u[1],b=p),b===!1)for(;(d=++p&&d&&d[g]||(b=p=0)||h.pop())&&((s?d.nodeName.toLowerCase()!==m:1!==d.nodeType)||!++b||(y&&(f=d[U]||(d[U]={}),c=f[d.uniqueID]||(f[d.uniqueID]={}),c[t]=[z,b]),d!==e)););return b-=o,b===r||b%r===0&&b/r>=0}}},PSEUDO:function(t,n){var o,i=T.pseudos[t]||T.setFilters[t.toLowerCase()]||e.error("unsupported pseudo: "+t);return i[U]?i(n):i.length>1?(o=[t,t,"",n],T.setFilters.hasOwnProperty(t.toLowerCase())?r(function(t,e){for(var r,o=i(t,n),a=o.length;a--;)r=tt(t,o[a]),t[r]=!(e[r]=o[a])}):function(t){return i(t,0,o)}):i}},pseudos:{not:r(function(t){var e=[],n=[],o=P(t.replace(st,"$1"));return o[U]?r(function(t,e,n,r){for(var i,a=o(t,null,r,[]),s=t.length;s--;)(i=a[s])&&(t[s]=!(e[s]=i))}):function(t,r,i){return e[0]=t,o(e,null,i,n),e[0]=null,!n.pop()}}),has:r(function(t){return function(n){return e(t,n).length>0}}),contains:r(function(t){return t=t.replace(bt,xt),function(e){return(e.textContent||e.innerText||C(e)).indexOf(t)>-1}}),lang:r(function(t){return dt.test(t||"")||e.error("unsupported lang: "+t),t=t.replace(bt,xt).toLowerCase(),function(e){var n;do if(n=R?e.lang:e.getAttribute("xml:lang")||e.getAttribute("lang"))return n=n.toLowerCase(),n===t||0===n.indexOf(t+"-");while((e=e.parentNode)&&1===e.nodeType);return!1}}),target:function(e){var n=t.location&&t.location.hash;return n&&n.slice(1)===e.id},root:function(t){return t===I},focus:function(t){return t===D.activeElement&&(!D.hasFocus||D.hasFocus())&&!!(t.type||t.href||~t.tabIndex)},enabled:u(!1),disabled:u(!0),checked:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&!!t.checked||"option"===e&&!!t.selected},selected:function(t){return t.parentNode&&t.parentNode.selectedIndex,t.selected===!0},empty:function(t){for(t=t.firstChild;t;t=t.nextSibling)if(t.nodeType<6)return!1;return!0},parent:function(t){return!T.pseudos.empty(t)},header:function(t){return gt.test(t.nodeName)},input:function(t){return ht.test(t.nodeName)},button:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&"button"===t.type||"button"===e},text:function(t){var e;return"input"===t.nodeName.toLowerCase()&&"text"===t.type&&(null==(e=t.getAttribute("type"))||"text"===e.toLowerCase())},first:c(function(){return[0]}),last:c(function(t,e){return[e-1]}),eq:c(function(t,e,n){return[n<0?n+e:n]}),even:c(function(t,e){for(var n=0;n<e;n+=2)t.push(n);return t}),odd:c(function(t,e){for(var n=1;n<e;n+=2)t.push(n);return t}),lt:c(function(t,e,n){for(var r=n<0?n+e:n;--r>=0;)t.push(r);return t}),gt:c(function(t,e,n){for(var r=n<0?n+e:n;++r<e;)t.push(r);return t})}},T.pseudos.nth=T.pseudos.eq;for(_ in{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})T.pseudos[_]=s(_);for(_ in{submit:!0,reset:!0})T.pseudos[_]=l(_);return d.prototype=T.filters=T.pseudos,T.setFilters=new d,E=e.tokenize=function(t,n){var r,o,i,a,s,l,u,c=V[t+" "];if(c)return n?0:c.slice(0);for(s=t,l=[],u=T.preFilter;s;){r&&!(o=lt.exec(s))||(o&&(s=s.slice(o[0].length)||s),l.push(i=[])),r=!1,(o=ut.exec(s))&&(r=o.shift(),i.push({value:r,type:o[0].replace(st," ")}),s=s.slice(r.length));for(a in T.filter)!(o=pt[a].exec(s))||u[a]&&!(o=u[a](o))||(r=o.shift(),i.push({value:r,type:a,matches:o}),s=s.slice(r.length));if(!r)break}return n?s.length:s?e.error(t):V(t,l).slice(0)},P=e.compile=function(t,e){var n,r=[],o=[],i=K[t+" "];if(!i){for(e||(e=E(t)),n=e.length;n--;)i=b(e[n]),i[U]?r.push(i):o.push(i);i=K(t,x(o,r)),i.selector=t}return i},S=e.select=function(t,e,n,r){var o,i,a,s,l,u="function"==typeof t&&t,c=!r&&E(t=u.selector||t);if(n=n||[],1===c.length){if(i=c[0]=c[0].slice(0),i.length>2&&"ID"===(a=i[0]).type&&9===e.nodeType&&R&&T.relative[i[1].type]){if(e=(T.find.ID(a.matches[0].replace(bt,xt),e)||[])[0],!e)return n;u&&(e=e.parentNode),t=t.slice(i.shift().value.length)}for(o=pt.needsContext.test(t)?0:i.length;o--&&(a=i[o],!T.relative[s=a.type]);)if((l=T.find[s])&&(r=l(a.matches[0].replace(bt,xt),yt.test(i[0].type)&&f(e.parentNode)||e))){if(i.splice(o,1),t=r.length&&p(i),!t)return J.apply(n,r),n;break}}return(u||P(t,c))(r,e,!R,n,!e||yt.test(t)&&f(e.parentNode)||e),n},w.sortStable=U.split("").sort(Y).join("")===U,w.detectDuplicates=!!A,O(),w.sortDetached=o(function(t){return 1&t.compareDocumentPosition(D.createElement("fieldset"))}),o(function(t){return t.innerHTML="<a href='#'></a>","#"===t.firstChild.getAttribute("href")})||i("type|href|height|width",function(t,e,n){if(!n)return t.getAttribute(e,"type"===e.toLowerCase()?1:2)}),w.attributes&&o(function(t){return t.innerHTML="<input/>",t.firstChild.setAttribute("value",""),""===t.firstChild.getAttribute("value")})||i("value",function(t,e,n){if(!n&&"input"===t.nodeName.toLowerCase())return t.defaultValue}),o(function(t){return null==t.getAttribute("disabled")})||i(et,function(t,e,n){var r;if(!n)return t[e]===!0?e.toLowerCase():(r=t.getAttributeNode(e))&&r.specified?r.value:null}),e}(n);yt.find=Tt,yt.expr=Tt.selectors,yt.expr[":"]=yt.expr.pseudos,yt.uniqueSort=yt.unique=Tt.uniqueSort,yt.text=Tt.getText,yt.isXMLDoc=Tt.isXML,yt.contains=Tt.contains,yt.escapeSelector=Tt.escape;var Ct=function(t,e,n){for(var r=[],o=void 0!==n;(t=t[e])&&9!==t.nodeType;)if(1===t.nodeType){if(o&&yt(t).is(n))break;r.push(t)}return r},kt=function(t,e){for(var n=[];t;t=t.nextSibling)1===t.nodeType&&t!==e&&n.push(t);return n},Et=yt.expr.match.needsContext,Pt=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i,St=/^.[^:#\[\.,]*$/;yt.filter=function(t,e,n){var r=e[0];return n&&(t=":not("+t+")"),1===e.length&&1===r.nodeType?yt.find.matchesSelector(r,t)?[r]:[]:yt.find.matches(t,yt.grep(e,function(t){return 1===t.nodeType}))},yt.fn.extend({find:function(t){var e,n,r=this.length,o=this;if("string"!=typeof t)return this.pushStack(yt(t).filter(function(){for(e=0;e<r;e++)if(yt.contains(o[e],this))return!0}));for(n=this.pushStack([]),e=0;e<r;e++)yt.find(t,o[e],n);return r>1?yt.uniqueSort(n):n},filter:function(t){return this.pushStack(l(this,t||[],!1))},not:function(t){return this.pushStack(l(this,t||[],!0))},is:function(t){return!!l(this,"string"==typeof t&&Et.test(t)?yt(t):t||[],!1).length}});var Mt,Nt=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/,At=yt.fn.init=function(t,e,n){var r,o;if(!t)return this;if(n=n||Mt,"string"==typeof t){if(r="<"===t[0]&&">"===t[t.length-1]&&t.length>=3?[null,t,null]:Nt.exec(t),!r||!r[1]&&e)return!e||e.jquery?(e||n).find(t):this.constructor(e).find(t);if(r[1]){if(e=e instanceof yt?e[0]:e,yt.merge(this,yt.parseHTML(r[1],e&&e.nodeType?e.ownerDocument||e:it,!0)),Pt.test(r[1])&&yt.isPlainObject(e))for(r in e)yt.isFunction(this[r])?this[r](e[r]):this.attr(r,e[r]);return this}return o=it.getElementById(r[2]),o&&(this[0]=o,this.length=1),this}return t.nodeType?(this[0]=t,this.length=1,this):yt.isFunction(t)?void 0!==n.ready?n.ready(t):t(yt):yt.makeArray(t,this)};At.prototype=yt.fn,Mt=yt(it);var Ot=/^(?:parents|prev(?:Until|All))/,Dt={children:!0,contents:!0,next:!0,prev:!0};yt.fn.extend({has:function(t){var e=yt(t,this),n=e.length;return this.filter(function(){for(var t=0;t<n;t++)if(yt.contains(this,e[t]))return!0})},closest:function(t,e){var n,r=0,o=this.length,i=[],a="string"!=typeof t&&yt(t);if(!Et.test(t))for(;r<o;r++)for(n=this[r];n&&n!==e;n=n.parentNode)if(n.nodeType<11&&(a?a.index(n)>-1:1===n.nodeType&&yt.find.matchesSelector(n,t))){i.push(n);break}return this.pushStack(i.length>1?yt.uniqueSort(i):i)},index:function(t){return t?"string"==typeof t?ct.call(yt(t),this[0]):ct.call(this,t.jquery?t[0]:t):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(t,e){return this.pushStack(yt.uniqueSort(yt.merge(this.get(),yt(t,e))))},addBack:function(t){return this.add(null==t?this.prevObject:this.prevObject.filter(t))}}),yt.each({parent:function(t){var e=t.parentNode;return e&&11!==e.nodeType?e:null},parents:function(t){return Ct(t,"parentNode")},parentsUntil:function(t,e,n){return Ct(t,"parentNode",n)},next:function(t){return u(t,"nextSibling")},prev:function(t){return u(t,"previousSibling")},nextAll:function(t){return Ct(t,"nextSibling")},prevAll:function(t){return Ct(t,"previousSibling")},nextUntil:function(t,e,n){return Ct(t,"nextSibling",n)},prevUntil:function(t,e,n){return Ct(t,"previousSibling",n)},siblings:function(t){return kt((t.parentNode||{}).firstChild,t)},children:function(t){return kt(t.firstChild)},contents:function(t){return t.contentDocument||yt.merge([],t.childNodes)}},function(t,e){yt.fn[t]=function(n,r){var o=yt.map(this,e,n);return"Until"!==t.slice(-5)&&(r=n),r&&"string"==typeof r&&(o=yt.filter(r,o)),this.length>1&&(Dt[t]||yt.uniqueSort(o),Ot.test(t)&&o.reverse()),this.pushStack(o)}});var It=/[^\x20\t\r\n\f]+/g;yt.Callbacks=function(t){t="string"==typeof t?c(t):yt.extend({},t);var e,n,r,o,i=[],a=[],s=-1,l=function(){for(o=t.once,r=e=!0;a.length;s=-1)for(n=a.shift();++s<i.length;)i[s].apply(n[0],n[1])===!1&&t.stopOnFalse&&(s=i.length,n=!1);t.memory||(n=!1),e=!1,o&&(i=n?[]:"")},u={add:function(){return i&&(n&&!e&&(s=i.length-1,a.push(n)),function e(n){yt.each(n,function(n,r){yt.isFunction(r)?t.unique&&u.has(r)||i.push(r):r&&r.length&&"string"!==yt.type(r)&&e(r)})}(arguments),n&&!e&&l()),this},remove:function(){return yt.each(arguments,function(t,e){for(var n;(n=yt.inArray(e,i,n))>-1;)i.splice(n,1),n<=s&&s--}),this},has:function(t){return t?yt.inArray(t,i)>-1:i.length>0},empty:function(){return i&&(i=[]),this},disable:function(){return o=a=[],i=n="",this},disabled:function(){return!i},lock:function(){return o=a=[],n||e||(i=n=""),this},locked:function(){return!!o},fireWith:function(t,n){return o||(n=n||[],n=[t,n.slice?n.slice():n],a.push(n),e||l()),this},fire:function(){return u.fireWith(this,arguments),this},fired:function(){return!!r}};return u},yt.extend({Deferred:function(t){var e=[["notify","progress",yt.Callbacks("memory"),yt.Callbacks("memory"),2],["resolve","done",yt.Callbacks("once memory"),yt.Callbacks("once memory"),0,"resolved"],["reject","fail",yt.Callbacks("once memory"),yt.Callbacks("once memory"),1,"rejected"]],r="pending",o={state:function(){return r},always:function(){return i.done(arguments).fail(arguments),this},catch:function(t){return o.then(null,t)},pipe:function(){var t=arguments;return yt.Deferred(function(n){yt.each(e,function(e,r){var o=yt.isFunction(t[r[4]])&&t[r[4]];i[r[1]](function(){var t=o&&o.apply(this,arguments);t&&yt.isFunction(t.promise)?t.promise().progress(n.notify).done(n.resolve).fail(n.reject):n[r[0]+"With"](this,o?[t]:arguments)})}),t=null}).promise()},then:function(t,r,o){function i(t,e,r,o){return function(){var s=this,l=arguments,u=function(){var n,u;if(!(t<a)){if(n=r.apply(s,l),n===e.promise())throw new TypeError("Thenable self-resolution");u=n&&("object"==typeof n||"function"==typeof n)&&n.then,yt.isFunction(u)?o?u.call(n,i(a,e,f,o),i(a,e,d,o)):(a++,u.call(n,i(a,e,f,o),i(a,e,d,o),i(a,e,f,e.notifyWith))):(r!==f&&(s=void 0,l=[n]),(o||e.resolveWith)(s,l))}},c=o?u:function(){try{u()}catch(n){yt.Deferred.exceptionHook&&yt.Deferred.exceptionHook(n,c.stackTrace),t+1>=a&&(r!==d&&(s=void 0,l=[n]),e.rejectWith(s,l))}};t?c():(yt.Deferred.getStackHook&&(c.stackTrace=yt.Deferred.getStackHook()),n.setTimeout(c))}}var a=0;return yt.Deferred(function(n){e[0][3].add(i(0,n,yt.isFunction(o)?o:f,n.notifyWith)),e[1][3].add(i(0,n,yt.isFunction(t)?t:f)),e[2][3].add(i(0,n,yt.isFunction(r)?r:d))}).promise()},promise:function(t){return null!=t?yt.extend(t,o):o}},i={};return yt.each(e,function(t,n){var a=n[2],s=n[5];o[n[1]]=a.add,s&&a.add(function(){r=s},e[3-t][2].disable,e[0][2].lock),a.add(n[3].fire),i[n[0]]=function(){return i[n[0]+"With"](this===i?void 0:this,arguments),this},i[n[0]+"With"]=a.fireWith}),o.promise(i),t&&t.call(i,i),i},when:function(t){var e=arguments.length,n=e,r=Array(n),o=st.call(arguments),i=yt.Deferred(),a=function(t){return function(n){r[t]=this,o[t]=arguments.length>1?st.call(arguments):n,--e||i.resolveWith(r,o)}};if(e<=1&&(p(t,i.done(a(n)).resolve,i.reject),"pending"===i.state()||yt.isFunction(o[n]&&o[n].then)))return i.then();for(;n--;)p(o[n],a(n),i.reject);return i.promise()}});var Rt=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;yt.Deferred.exceptionHook=function(t,e){n.console&&n.console.warn&&t&&Rt.test(t.name)&&n.console.warn("jQuery.Deferred exception: "+t.message,t.stack,e)},yt.readyException=function(t){n.setTimeout(function(){throw t})};var Lt=yt.Deferred();yt.fn.ready=function(t){return Lt.then(t).catch(function(t){yt.readyException(t)}),this},yt.extend({isReady:!1,readyWait:1,holdReady:function(t){t?yt.readyWait++:yt.ready(!0)},ready:function(t){(t===!0?--yt.readyWait:yt.isReady)||(yt.isReady=!0,t!==!0&&--yt.readyWait>0||Lt.resolveWith(it,[yt]))}}),yt.ready.then=Lt.then,"complete"===it.readyState||"loading"!==it.readyState&&!it.documentElement.doScroll?n.setTimeout(yt.ready):(it.addEventListener("DOMContentLoaded",h),n.addEventListener("load",h));var Ft=function(t,e,n,r,o,i,a){var s=0,l=t.length,u=null==n;if("object"===yt.type(n)){o=!0;for(s in n)Ft(t,e,s,n[s],!0,i,a)}else if(void 0!==r&&(o=!0,yt.isFunction(r)||(a=!0),u&&(a?(e.call(t,r),e=null):(u=e,e=function(t,e,n){return u.call(yt(t),n)})),e))for(;s<l;s++)e(t[s],n,a?r:r.call(t[s],s,e(t[s],n)));return o?t:u?e.call(t):l?e(t[0],n):i},jt=function(t){return 1===t.nodeType||9===t.nodeType||!+t.nodeType};g.uid=1,g.prototype={cache:function(t){var e=t[this.expando];return e||(e={},jt(t)&&(t.nodeType?t[this.expando]=e:Object.defineProperty(t,this.expando,{value:e,configurable:!0}))),e},set:function(t,e,n){var r,o=this.cache(t);if("string"==typeof e)o[yt.camelCase(e)]=n;else for(r in e)o[yt.camelCase(r)]=e[r];return o},get:function(t,e){return void 0===e?this.cache(t):t[this.expando]&&t[this.expando][yt.camelCase(e)]},access:function(t,e,n){return void 0===e||e&&"string"==typeof e&&void 0===n?this.get(t,e):(this.set(t,e,n),void 0!==n?n:e)},remove:function(t,e){var n,r=t[this.expando];if(void 0!==r){if(void 0!==e){yt.isArray(e)?e=e.map(yt.camelCase):(e=yt.camelCase(e),e=e in r?[e]:e.match(It)||[]),n=e.length;for(;n--;)delete r[e[n]]}(void 0===e||yt.isEmptyObject(r))&&(t.nodeType?t[this.expando]=void 0:delete t[this.expando])}},hasData:function(t){var e=t[this.expando];return void 0!==e&&!yt.isEmptyObject(e)}};var Bt=new g,Ut=new g,Ht=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,zt=/[A-Z]/g;yt.extend({hasData:function(t){return Ut.hasData(t)||Bt.hasData(t)},data:function(t,e,n){return Ut.access(t,e,n)},removeData:function(t,e){Ut.remove(t,e)},_data:function(t,e,n){return Bt.access(t,e,n)},_removeData:function(t,e){Bt.remove(t,e)}}),yt.fn.extend({data:function(t,e){var n,r,o,i=this[0],a=i&&i.attributes;if(void 0===t){if(this.length&&(o=Ut.get(i),1===i.nodeType&&!Bt.get(i,"hasDataAttrs"))){for(n=a.length;n--;)a[n]&&(r=a[n].name,0===r.indexOf("data-")&&(r=yt.camelCase(r.slice(5)),m(i,r,o[r])));Bt.set(i,"hasDataAttrs",!0)}return o}return"object"==typeof t?this.each(function(){Ut.set(this,t)}):Ft(this,function(e){var n;if(i&&void 0===e){if(n=Ut.get(i,t),void 0!==n)return n;if(n=m(i,t),void 0!==n)return n}else this.each(function(){Ut.set(this,t,e)})},null,e,arguments.length>1,null,!0)},removeData:function(t){return this.each(function(){Ut.remove(this,t)})}}),yt.extend({queue:function(t,e,n){var r;if(t)return e=(e||"fx")+"queue",r=Bt.get(t,e),n&&(!r||yt.isArray(n)?r=Bt.access(t,e,yt.makeArray(n)):r.push(n)),r||[]},dequeue:function(t,e){e=e||"fx";var n=yt.queue(t,e),r=n.length,o=n.shift(),i=yt._queueHooks(t,e),a=function(){yt.dequeue(t,e)};"inprogress"===o&&(o=n.shift(),r--),o&&("fx"===e&&n.unshift("inprogress"),delete i.stop,o.call(t,a,i)),!r&&i&&i.empty.fire()},_queueHooks:function(t,e){var n=e+"queueHooks";return Bt.get(t,n)||Bt.access(t,n,{empty:yt.Callbacks("once memory").add(function(){Bt.remove(t,[e+"queue",n])})})}}),yt.fn.extend({queue:function(t,e){var n=2;return"string"!=typeof t&&(e=t,t="fx",n--),arguments.length<n?yt.queue(this[0],t):void 0===e?this:this.each(function(){var n=yt.queue(this,t,e);yt._queueHooks(this,t),"fx"===t&&"inprogress"!==n[0]&&yt.dequeue(this,t)})},dequeue:function(t){return this.each(function(){yt.dequeue(this,t)})},clearQueue:function(t){return this.queue(t||"fx",[])},promise:function(t,e){var n,r=1,o=yt.Deferred(),i=this,a=this.length,s=function(){--r||o.resolveWith(i,[i])};for("string"!=typeof t&&(e=t,t=void 0),t=t||"fx";a--;)n=Bt.get(i[a],t+"queueHooks"),n&&n.empty&&(r++,n.empty.add(s));return s(),o.promise(e)}});var Wt=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,qt=new RegExp("^(?:([+-])=|)("+Wt+")([a-z%]*)$","i"),Vt=["Top","Right","Bottom","Left"],Kt=function(t,e){return t=e||t,"none"===t.style.display||""===t.style.display&&yt.contains(t.ownerDocument,t)&&"none"===yt.css(t,"display")},Yt=function(t,e,n,r){var o,i,a={};for(i in e)a[i]=t.style[i],t.style[i]=e[i];o=n.apply(t,r||[]);for(i in e)t.style[i]=a[i];return o},Gt={};yt.fn.extend({show:function(){return x(this,!0)},hide:function(){return x(this)},toggle:function(t){return"boolean"==typeof t?t?this.show():this.hide():this.each(function(){Kt(this)?yt(this).show():yt(this).hide()})}});var Xt=/^(?:checkbox|radio)$/i,$t=/<([a-z][^\/\0>\x20\t\r\n\f]+)/i,Zt=/^$|\/(?:java|ecma)script/i,Jt={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};Jt.optgroup=Jt.option,Jt.tbody=Jt.tfoot=Jt.colgroup=Jt.caption=Jt.thead,Jt.th=Jt.td;
var Qt=/<|&#?\w+;/;!function(){var t=it.createDocumentFragment(),e=t.appendChild(it.createElement("div")),n=it.createElement("input");n.setAttribute("type","radio"),n.setAttribute("checked","checked"),n.setAttribute("name","t"),e.appendChild(n),vt.checkClone=e.cloneNode(!0).cloneNode(!0).lastChild.checked,e.innerHTML="<textarea>x</textarea>",vt.noCloneChecked=!!e.cloneNode(!0).lastChild.defaultValue}();var te=it.documentElement,ee=/^key/,ne=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,re=/^([^.]*)(?:\.(.+)|)/;yt.event={global:{},add:function(t,e,n,r,o){var i,a,s,l,u,c,f,d,p,h,g,v=Bt.get(t);if(v)for(n.handler&&(i=n,n=i.handler,o=i.selector),o&&yt.find.matchesSelector(te,o),n.guid||(n.guid=yt.guid++),(l=v.events)||(l=v.events={}),(a=v.handle)||(a=v.handle=function(e){return"undefined"!=typeof yt&&yt.event.triggered!==e.type?yt.event.dispatch.apply(t,arguments):void 0}),e=(e||"").match(It)||[""],u=e.length;u--;)s=re.exec(e[u])||[],p=g=s[1],h=(s[2]||"").split(".").sort(),p&&(f=yt.event.special[p]||{},p=(o?f.delegateType:f.bindType)||p,f=yt.event.special[p]||{},c=yt.extend({type:p,origType:g,data:r,handler:n,guid:n.guid,selector:o,needsContext:o&&yt.expr.match.needsContext.test(o),namespace:h.join(".")},i),(d=l[p])||(d=l[p]=[],d.delegateCount=0,f.setup&&f.setup.call(t,r,h,a)!==!1||t.addEventListener&&t.addEventListener(p,a)),f.add&&(f.add.call(t,c),c.handler.guid||(c.handler.guid=n.guid)),o?d.splice(d.delegateCount++,0,c):d.push(c),yt.event.global[p]=!0)},remove:function(t,e,n,r,o){var i,a,s,l,u,c,f,d,p,h,g,v=Bt.hasData(t)&&Bt.get(t);if(v&&(l=v.events)){for(e=(e||"").match(It)||[""],u=e.length;u--;)if(s=re.exec(e[u])||[],p=g=s[1],h=(s[2]||"").split(".").sort(),p){for(f=yt.event.special[p]||{},p=(r?f.delegateType:f.bindType)||p,d=l[p]||[],s=s[2]&&new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=i=d.length;i--;)c=d[i],!o&&g!==c.origType||n&&n.guid!==c.guid||s&&!s.test(c.namespace)||r&&r!==c.selector&&("**"!==r||!c.selector)||(d.splice(i,1),c.selector&&d.delegateCount--,f.remove&&f.remove.call(t,c));a&&!d.length&&(f.teardown&&f.teardown.call(t,h,v.handle)!==!1||yt.removeEvent(t,p,v.handle),delete l[p])}else for(p in l)yt.event.remove(t,p+e[u],n,r,!0);yt.isEmptyObject(l)&&Bt.remove(t,"handle events")}},dispatch:function(t){var e,n,r,o,i,a,s=yt.event.fix(t),l=new Array(arguments.length),u=(Bt.get(this,"events")||{})[s.type]||[],c=yt.event.special[s.type]||{};for(l[0]=s,e=1;e<arguments.length;e++)l[e]=arguments[e];if(s.delegateTarget=this,!c.preDispatch||c.preDispatch.call(this,s)!==!1){for(a=yt.event.handlers.call(this,s,u),e=0;(o=a[e++])&&!s.isPropagationStopped();)for(s.currentTarget=o.elem,n=0;(i=o.handlers[n++])&&!s.isImmediatePropagationStopped();)s.rnamespace&&!s.rnamespace.test(i.namespace)||(s.handleObj=i,s.data=i.data,r=((yt.event.special[i.origType]||{}).handle||i.handler).apply(o.elem,l),void 0!==r&&(s.result=r)===!1&&(s.preventDefault(),s.stopPropagation()));return c.postDispatch&&c.postDispatch.call(this,s),s.result}},handlers:function(t,e){var n,r,o,i,a,s=[],l=e.delegateCount,u=t.target;if(l&&u.nodeType&&!("click"===t.type&&t.button>=1))for(;u!==this;u=u.parentNode||this)if(1===u.nodeType&&("click"!==t.type||u.disabled!==!0)){for(i=[],a={},n=0;n<l;n++)r=e[n],o=r.selector+" ",void 0===a[o]&&(a[o]=r.needsContext?yt(o,this).index(u)>-1:yt.find(o,this,null,[u]).length),a[o]&&i.push(r);i.length&&s.push({elem:u,handlers:i})}return u=this,l<e.length&&s.push({elem:u,handlers:e.slice(l)}),s},addProp:function(t,e){Object.defineProperty(yt.Event.prototype,t,{enumerable:!0,configurable:!0,get:yt.isFunction(e)?function(){if(this.originalEvent)return e(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[t]},set:function(e){Object.defineProperty(this,t,{enumerable:!0,configurable:!0,writable:!0,value:e})}})},fix:function(t){return t[yt.expando]?t:new yt.Event(t)},special:{load:{noBubble:!0},focus:{trigger:function(){if(this!==E()&&this.focus)return this.focus(),!1},delegateType:"focusin"},blur:{trigger:function(){if(this===E()&&this.blur)return this.blur(),!1},delegateType:"focusout"},click:{trigger:function(){if("checkbox"===this.type&&this.click&&yt.nodeName(this,"input"))return this.click(),!1},_default:function(t){return yt.nodeName(t.target,"a")}},beforeunload:{postDispatch:function(t){void 0!==t.result&&t.originalEvent&&(t.originalEvent.returnValue=t.result)}}}},yt.removeEvent=function(t,e,n){t.removeEventListener&&t.removeEventListener(e,n)},yt.Event=function(t,e){return this instanceof yt.Event?(t&&t.type?(this.originalEvent=t,this.type=t.type,this.isDefaultPrevented=t.defaultPrevented||void 0===t.defaultPrevented&&t.returnValue===!1?C:k,this.target=t.target&&3===t.target.nodeType?t.target.parentNode:t.target,this.currentTarget=t.currentTarget,this.relatedTarget=t.relatedTarget):this.type=t,e&&yt.extend(this,e),this.timeStamp=t&&t.timeStamp||yt.now(),void(this[yt.expando]=!0)):new yt.Event(t,e)},yt.Event.prototype={constructor:yt.Event,isDefaultPrevented:k,isPropagationStopped:k,isImmediatePropagationStopped:k,isSimulated:!1,preventDefault:function(){var t=this.originalEvent;this.isDefaultPrevented=C,t&&!this.isSimulated&&t.preventDefault()},stopPropagation:function(){var t=this.originalEvent;this.isPropagationStopped=C,t&&!this.isSimulated&&t.stopPropagation()},stopImmediatePropagation:function(){var t=this.originalEvent;this.isImmediatePropagationStopped=C,t&&!this.isSimulated&&t.stopImmediatePropagation(),this.stopPropagation()}},yt.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,char:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:function(t){var e=t.button;return null==t.which&&ee.test(t.type)?null!=t.charCode?t.charCode:t.keyCode:!t.which&&void 0!==e&&ne.test(t.type)?1&e?1:2&e?3:4&e?2:0:t.which}},yt.event.addProp),yt.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(t,e){yt.event.special[t]={delegateType:e,bindType:e,handle:function(t){var n,r=this,o=t.relatedTarget,i=t.handleObj;return o&&(o===r||yt.contains(r,o))||(t.type=i.origType,n=i.handler.apply(this,arguments),t.type=e),n}}}),yt.fn.extend({on:function(t,e,n,r){return P(this,t,e,n,r)},one:function(t,e,n,r){return P(this,t,e,n,r,1)},off:function(t,e,n){var r,o;if(t&&t.preventDefault&&t.handleObj)return r=t.handleObj,yt(t.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof t){for(o in t)this.off(o,e,t[o]);return this}return e!==!1&&"function"!=typeof e||(n=e,e=void 0),n===!1&&(n=k),this.each(function(){yt.event.remove(this,t,n,e)})}});var oe=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([a-z][^\/\0>\x20\t\r\n\f]*)[^>]*)\/>/gi,ie=/<script|<style|<link/i,ae=/checked\s*(?:[^=]|=\s*.checked.)/i,se=/^true\/(.*)/,le=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;yt.extend({htmlPrefilter:function(t){return t.replace(oe,"<$1></$2>")},clone:function(t,e,n){var r,o,i,a,s=t.cloneNode(!0),l=yt.contains(t.ownerDocument,t);if(!(vt.noCloneChecked||1!==t.nodeType&&11!==t.nodeType||yt.isXMLDoc(t)))for(a=_(s),i=_(t),r=0,o=i.length;r<o;r++)O(i[r],a[r]);if(e)if(n)for(i=i||_(t),a=a||_(s),r=0,o=i.length;r<o;r++)A(i[r],a[r]);else A(t,s);return a=_(s,"script"),a.length>0&&w(a,!l&&_(t,"script")),s},cleanData:function(t){for(var e,n,r,o=yt.event.special,i=0;void 0!==(n=t[i]);i++)if(jt(n)){if(e=n[Bt.expando]){if(e.events)for(r in e.events)o[r]?yt.event.remove(n,r):yt.removeEvent(n,r,e.handle);n[Bt.expando]=void 0}n[Ut.expando]&&(n[Ut.expando]=void 0)}}}),yt.fn.extend({detach:function(t){return I(this,t,!0)},remove:function(t){return I(this,t)},text:function(t){return Ft(this,function(t){return void 0===t?yt.text(this):this.empty().each(function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=t)})},null,t,arguments.length)},append:function(){return D(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=S(this,t);e.appendChild(t)}})},prepend:function(){return D(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=S(this,t);e.insertBefore(t,e.firstChild)}})},before:function(){return D(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this)})},after:function(){return D(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this.nextSibling)})},empty:function(){for(var t,e=0;null!=(t=this[e]);e++)1===t.nodeType&&(yt.cleanData(_(t,!1)),t.textContent="");return this},clone:function(t,e){return t=null!=t&&t,e=null==e?t:e,this.map(function(){return yt.clone(this,t,e)})},html:function(t){return Ft(this,function(t){var e=this[0]||{},n=0,r=this.length;if(void 0===t&&1===e.nodeType)return e.innerHTML;if("string"==typeof t&&!ie.test(t)&&!Jt[($t.exec(t)||["",""])[1].toLowerCase()]){t=yt.htmlPrefilter(t);try{for(;n<r;n++)e=this[n]||{},1===e.nodeType&&(yt.cleanData(_(e,!1)),e.innerHTML=t);e=0}catch(t){}}e&&this.empty().append(t)},null,t,arguments.length)},replaceWith:function(){var t=[];return D(this,arguments,function(e){var n=this.parentNode;yt.inArray(this,t)<0&&(yt.cleanData(_(this)),n&&n.replaceChild(e,this))},t)}}),yt.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(t,e){yt.fn[t]=function(t){for(var n,r=[],o=yt(t),i=o.length-1,a=0;a<=i;a++)n=a===i?this:this.clone(!0),yt(o[a])[e](n),ut.apply(r,n.get());return this.pushStack(r)}});var ue=/^margin/,ce=new RegExp("^("+Wt+")(?!px)[a-z%]+$","i"),fe=function(t){var e=t.ownerDocument.defaultView;return e&&e.opener||(e=n),e.getComputedStyle(t)};!function(){function t(){if(s){s.style.cssText="box-sizing:border-box;position:relative;display:block;margin:auto;border:1px;padding:1px;top:1%;width:50%",s.innerHTML="",te.appendChild(a);var t=n.getComputedStyle(s);e="1%"!==t.top,i="2px"===t.marginLeft,r="4px"===t.width,s.style.marginRight="50%",o="4px"===t.marginRight,te.removeChild(a),s=null}}var e,r,o,i,a=it.createElement("div"),s=it.createElement("div");s.style&&(s.style.backgroundClip="content-box",s.cloneNode(!0).style.backgroundClip="",vt.clearCloneStyle="content-box"===s.style.backgroundClip,a.style.cssText="border:0;width:8px;height:0;top:0;left:-9999px;padding:0;margin-top:1px;position:absolute",a.appendChild(s),yt.extend(vt,{pixelPosition:function(){return t(),e},boxSizingReliable:function(){return t(),r},pixelMarginRight:function(){return t(),o},reliableMarginLeft:function(){return t(),i}}))}();var de=/^(none|table(?!-c[ea]).+)/,pe={position:"absolute",visibility:"hidden",display:"block"},he={letterSpacing:"0",fontWeight:"400"},ge=["Webkit","Moz","ms"],ve=it.createElement("div").style;yt.extend({cssHooks:{opacity:{get:function(t,e){if(e){var n=R(t,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{float:"cssFloat"},style:function(t,e,n,r){if(t&&3!==t.nodeType&&8!==t.nodeType&&t.style){var o,i,a,s=yt.camelCase(e),l=t.style;return e=yt.cssProps[s]||(yt.cssProps[s]=F(s)||s),a=yt.cssHooks[e]||yt.cssHooks[s],void 0===n?a&&"get"in a&&void 0!==(o=a.get(t,!1,r))?o:l[e]:(i=typeof n,"string"===i&&(o=qt.exec(n))&&o[1]&&(n=y(t,e,o),i="number"),void(null!=n&&n===n&&("number"===i&&(n+=o&&o[3]||(yt.cssNumber[s]?"":"px")),vt.clearCloneStyle||""!==n||0!==e.indexOf("background")||(l[e]="inherit"),a&&"set"in a&&void 0===(n=a.set(t,n,r))||(l[e]=n))))}},css:function(t,e,n,r){var o,i,a,s=yt.camelCase(e);return e=yt.cssProps[s]||(yt.cssProps[s]=F(s)||s),a=yt.cssHooks[e]||yt.cssHooks[s],a&&"get"in a&&(o=a.get(t,!0,n)),void 0===o&&(o=R(t,e,r)),"normal"===o&&e in he&&(o=he[e]),""===n||n?(i=parseFloat(o),n===!0||isFinite(i)?i||0:o):o}}),yt.each(["height","width"],function(t,e){yt.cssHooks[e]={get:function(t,n,r){if(n)return!de.test(yt.css(t,"display"))||t.getClientRects().length&&t.getBoundingClientRect().width?U(t,e,r):Yt(t,pe,function(){return U(t,e,r)})},set:function(t,n,r){var o,i=r&&fe(t),a=r&&B(t,e,r,"border-box"===yt.css(t,"boxSizing",!1,i),i);return a&&(o=qt.exec(n))&&"px"!==(o[3]||"px")&&(t.style[e]=n,n=yt.css(t,e)),j(t,n,a)}}}),yt.cssHooks.marginLeft=L(vt.reliableMarginLeft,function(t,e){if(e)return(parseFloat(R(t,"marginLeft"))||t.getBoundingClientRect().left-Yt(t,{marginLeft:0},function(){return t.getBoundingClientRect().left}))+"px"}),yt.each({margin:"",padding:"",border:"Width"},function(t,e){yt.cssHooks[t+e]={expand:function(n){for(var r=0,o={},i="string"==typeof n?n.split(" "):[n];r<4;r++)o[t+Vt[r]+e]=i[r]||i[r-2]||i[0];return o}},ue.test(t)||(yt.cssHooks[t+e].set=j)}),yt.fn.extend({css:function(t,e){return Ft(this,function(t,e,n){var r,o,i={},a=0;if(yt.isArray(e)){for(r=fe(t),o=e.length;a<o;a++)i[e[a]]=yt.css(t,e[a],!1,r);return i}return void 0!==n?yt.style(t,e,n):yt.css(t,e)},t,e,arguments.length>1)}}),yt.Tween=H,H.prototype={constructor:H,init:function(t,e,n,r,o,i){this.elem=t,this.prop=n,this.easing=o||yt.easing._default,this.options=e,this.start=this.now=this.cur(),this.end=r,this.unit=i||(yt.cssNumber[n]?"":"px")},cur:function(){var t=H.propHooks[this.prop];return t&&t.get?t.get(this):H.propHooks._default.get(this)},run:function(t){var e,n=H.propHooks[this.prop];return this.options.duration?this.pos=e=yt.easing[this.easing](t,this.options.duration*t,0,1,this.options.duration):this.pos=e=t,this.now=(this.end-this.start)*e+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):H.propHooks._default.set(this),this}},H.prototype.init.prototype=H.prototype,H.propHooks={_default:{get:function(t){var e;return 1!==t.elem.nodeType||null!=t.elem[t.prop]&&null==t.elem.style[t.prop]?t.elem[t.prop]:(e=yt.css(t.elem,t.prop,""),e&&"auto"!==e?e:0)},set:function(t){yt.fx.step[t.prop]?yt.fx.step[t.prop](t):1!==t.elem.nodeType||null==t.elem.style[yt.cssProps[t.prop]]&&!yt.cssHooks[t.prop]?t.elem[t.prop]=t.now:yt.style(t.elem,t.prop,t.now+t.unit)}}},H.propHooks.scrollTop=H.propHooks.scrollLeft={set:function(t){t.elem.nodeType&&t.elem.parentNode&&(t.elem[t.prop]=t.now)}},yt.easing={linear:function(t){return t},swing:function(t){return.5-Math.cos(t*Math.PI)/2},_default:"swing"},yt.fx=H.prototype.init,yt.fx.step={};var me,ye,be=/^(?:toggle|show|hide)$/,xe=/queueHooks$/;yt.Animation=yt.extend(G,{tweeners:{"*":[function(t,e){var n=this.createTween(t,e);return y(n.elem,t,qt.exec(e),n),n}]},tweener:function(t,e){yt.isFunction(t)?(e=t,t=["*"]):t=t.match(It);for(var n,r=0,o=t.length;r<o;r++)n=t[r],G.tweeners[n]=G.tweeners[n]||[],G.tweeners[n].unshift(e)},prefilters:[K],prefilter:function(t,e){e?G.prefilters.unshift(t):G.prefilters.push(t)}}),yt.speed=function(t,e,n){var r=t&&"object"==typeof t?yt.extend({},t):{complete:n||!n&&e||yt.isFunction(t)&&t,duration:t,easing:n&&e||e&&!yt.isFunction(e)&&e};return yt.fx.off||it.hidden?r.duration=0:"number"!=typeof r.duration&&(r.duration in yt.fx.speeds?r.duration=yt.fx.speeds[r.duration]:r.duration=yt.fx.speeds._default),null!=r.queue&&r.queue!==!0||(r.queue="fx"),r.old=r.complete,r.complete=function(){yt.isFunction(r.old)&&r.old.call(this),r.queue&&yt.dequeue(this,r.queue)},r},yt.fn.extend({fadeTo:function(t,e,n,r){return this.filter(Kt).css("opacity",0).show().end().animate({opacity:e},t,n,r)},animate:function(t,e,n,r){var o=yt.isEmptyObject(t),i=yt.speed(e,n,r),a=function(){var e=G(this,yt.extend({},t),i);(o||Bt.get(this,"finish"))&&e.stop(!0)};return a.finish=a,o||i.queue===!1?this.each(a):this.queue(i.queue,a)},stop:function(t,e,n){var r=function(t){var e=t.stop;delete t.stop,e(n)};return"string"!=typeof t&&(n=e,e=t,t=void 0),e&&t!==!1&&this.queue(t||"fx",[]),this.each(function(){var e=!0,o=null!=t&&t+"queueHooks",i=yt.timers,a=Bt.get(this);if(o)a[o]&&a[o].stop&&r(a[o]);else for(o in a)a[o]&&a[o].stop&&xe.test(o)&&r(a[o]);for(o=i.length;o--;)i[o].elem!==this||null!=t&&i[o].queue!==t||(i[o].anim.stop(n),e=!1,i.splice(o,1));!e&&n||yt.dequeue(this,t)})},finish:function(t){return t!==!1&&(t=t||"fx"),this.each(function(){var e,n=Bt.get(this),r=n[t+"queue"],o=n[t+"queueHooks"],i=yt.timers,a=r?r.length:0;for(n.finish=!0,yt.queue(this,t,[]),o&&o.stop&&o.stop.call(this,!0),e=i.length;e--;)i[e].elem===this&&i[e].queue===t&&(i[e].anim.stop(!0),i.splice(e,1));for(e=0;e<a;e++)r[e]&&r[e].finish&&r[e].finish.call(this);delete n.finish})}}),yt.each(["toggle","show","hide"],function(t,e){var n=yt.fn[e];yt.fn[e]=function(t,r,o){return null==t||"boolean"==typeof t?n.apply(this,arguments):this.animate(q(e,!0),t,r,o)}}),yt.each({slideDown:q("show"),slideUp:q("hide"),slideToggle:q("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(t,e){yt.fn[t]=function(t,n,r){return this.animate(e,t,n,r)}}),yt.timers=[],yt.fx.tick=function(){var t,e=0,n=yt.timers;for(me=yt.now();e<n.length;e++)t=n[e],t()||n[e]!==t||n.splice(e--,1);n.length||yt.fx.stop(),me=void 0},yt.fx.timer=function(t){yt.timers.push(t),t()?yt.fx.start():yt.timers.pop()},yt.fx.interval=13,yt.fx.start=function(){ye||(ye=n.requestAnimationFrame?n.requestAnimationFrame(z):n.setInterval(yt.fx.tick,yt.fx.interval))},yt.fx.stop=function(){n.cancelAnimationFrame?n.cancelAnimationFrame(ye):n.clearInterval(ye),ye=null},yt.fx.speeds={slow:600,fast:200,_default:400},yt.fn.delay=function(t,e){return t=yt.fx?yt.fx.speeds[t]||t:t,e=e||"fx",this.queue(e,function(e,r){var o=n.setTimeout(e,t);r.stop=function(){n.clearTimeout(o)}})},function(){var t=it.createElement("input"),e=it.createElement("select"),n=e.appendChild(it.createElement("option"));t.type="checkbox",vt.checkOn=""!==t.value,vt.optSelected=n.selected,t=it.createElement("input"),t.value="t",t.type="radio",vt.radioValue="t"===t.value}();var _e,we=yt.expr.attrHandle;yt.fn.extend({attr:function(t,e){return Ft(this,yt.attr,t,e,arguments.length>1)},removeAttr:function(t){return this.each(function(){yt.removeAttr(this,t)})}}),yt.extend({attr:function(t,e,n){var r,o,i=t.nodeType;if(3!==i&&8!==i&&2!==i)return"undefined"==typeof t.getAttribute?yt.prop(t,e,n):(1===i&&yt.isXMLDoc(t)||(o=yt.attrHooks[e.toLowerCase()]||(yt.expr.match.bool.test(e)?_e:void 0)),void 0!==n?null===n?void yt.removeAttr(t,e):o&&"set"in o&&void 0!==(r=o.set(t,n,e))?r:(t.setAttribute(e,n+""),n):o&&"get"in o&&null!==(r=o.get(t,e))?r:(r=yt.find.attr(t,e),null==r?void 0:r))},attrHooks:{type:{set:function(t,e){if(!vt.radioValue&&"radio"===e&&yt.nodeName(t,"input")){var n=t.value;return t.setAttribute("type",e),n&&(t.value=n),e}}}},removeAttr:function(t,e){var n,r=0,o=e&&e.match(It);if(o&&1===t.nodeType)for(;n=o[r++];)t.removeAttribute(n)}}),_e={set:function(t,e,n){return e===!1?yt.removeAttr(t,n):t.setAttribute(n,n),n}},yt.each(yt.expr.match.bool.source.match(/\w+/g),function(t,e){var n=we[e]||yt.find.attr;we[e]=function(t,e,r){var o,i,a=e.toLowerCase();return r||(i=we[a],we[a]=o,o=null!=n(t,e,r)?a:null,we[a]=i),o}});var Te=/^(?:input|select|textarea|button)$/i,Ce=/^(?:a|area)$/i;yt.fn.extend({prop:function(t,e){return Ft(this,yt.prop,t,e,arguments.length>1)},removeProp:function(t){return this.each(function(){delete this[yt.propFix[t]||t]})}}),yt.extend({prop:function(t,e,n){var r,o,i=t.nodeType;if(3!==i&&8!==i&&2!==i)return 1===i&&yt.isXMLDoc(t)||(e=yt.propFix[e]||e,o=yt.propHooks[e]),void 0!==n?o&&"set"in o&&void 0!==(r=o.set(t,n,e))?r:t[e]=n:o&&"get"in o&&null!==(r=o.get(t,e))?r:t[e]},propHooks:{tabIndex:{get:function(t){var e=yt.find.attr(t,"tabindex");return e?parseInt(e,10):Te.test(t.nodeName)||Ce.test(t.nodeName)&&t.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),vt.optSelected||(yt.propHooks.selected={get:function(t){var e=t.parentNode;return e&&e.parentNode&&e.parentNode.selectedIndex,null},set:function(t){var e=t.parentNode;e&&(e.selectedIndex,e.parentNode&&e.parentNode.selectedIndex)}}),yt.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){yt.propFix[this.toLowerCase()]=this}),yt.fn.extend({addClass:function(t){var e,n,r,o,i,a,s,l=0;if(yt.isFunction(t))return this.each(function(e){yt(this).addClass(t.call(this,e,$(this)))});if("string"==typeof t&&t)for(e=t.match(It)||[];n=this[l++];)if(o=$(n),r=1===n.nodeType&&" "+X(o)+" "){for(a=0;i=e[a++];)r.indexOf(" "+i+" ")<0&&(r+=i+" ");s=X(r),o!==s&&n.setAttribute("class",s)}return this},removeClass:function(t){var e,n,r,o,i,a,s,l=0;if(yt.isFunction(t))return this.each(function(e){yt(this).removeClass(t.call(this,e,$(this)))});if(!arguments.length)return this.attr("class","");if("string"==typeof t&&t)for(e=t.match(It)||[];n=this[l++];)if(o=$(n),r=1===n.nodeType&&" "+X(o)+" "){for(a=0;i=e[a++];)for(;r.indexOf(" "+i+" ")>-1;)r=r.replace(" "+i+" "," ");s=X(r),o!==s&&n.setAttribute("class",s)}return this},toggleClass:function(t,e){var n=typeof t;return"boolean"==typeof e&&"string"===n?e?this.addClass(t):this.removeClass(t):yt.isFunction(t)?this.each(function(n){yt(this).toggleClass(t.call(this,n,$(this),e),e)}):this.each(function(){var e,r,o,i;if("string"===n)for(r=0,o=yt(this),i=t.match(It)||[];e=i[r++];)o.hasClass(e)?o.removeClass(e):o.addClass(e);else void 0!==t&&"boolean"!==n||(e=$(this),e&&Bt.set(this,"__className__",e),this.setAttribute&&this.setAttribute("class",e||t===!1?"":Bt.get(this,"__className__")||""))})},hasClass:function(t){var e,n,r=0;for(e=" "+t+" ";n=this[r++];)if(1===n.nodeType&&(" "+X($(n))+" ").indexOf(e)>-1)return!0;return!1}});var ke=/\r/g;yt.fn.extend({val:function(t){var e,n,r,o=this[0];return arguments.length?(r=yt.isFunction(t),this.each(function(n){var o;1===this.nodeType&&(o=r?t.call(this,n,yt(this).val()):t,null==o?o="":"number"==typeof o?o+="":yt.isArray(o)&&(o=yt.map(o,function(t){return null==t?"":t+""})),e=yt.valHooks[this.type]||yt.valHooks[this.nodeName.toLowerCase()],e&&"set"in e&&void 0!==e.set(this,o,"value")||(this.value=o))})):o?(e=yt.valHooks[o.type]||yt.valHooks[o.nodeName.toLowerCase()],e&&"get"in e&&void 0!==(n=e.get(o,"value"))?n:(n=o.value,"string"==typeof n?n.replace(ke,""):null==n?"":n)):void 0}}),yt.extend({valHooks:{option:{get:function(t){var e=yt.find.attr(t,"value");return null!=e?e:X(yt.text(t))}},select:{get:function(t){var e,n,r,o=t.options,i=t.selectedIndex,a="select-one"===t.type,s=a?null:[],l=a?i+1:o.length;for(r=i<0?l:a?i:0;r<l;r++)if(n=o[r],(n.selected||r===i)&&!n.disabled&&(!n.parentNode.disabled||!yt.nodeName(n.parentNode,"optgroup"))){if(e=yt(n).val(),a)return e;s.push(e)}return s},set:function(t,e){for(var n,r,o=t.options,i=yt.makeArray(e),a=o.length;a--;)r=o[a],(r.selected=yt.inArray(yt.valHooks.option.get(r),i)>-1)&&(n=!0);return n||(t.selectedIndex=-1),i}}}}),yt.each(["radio","checkbox"],function(){yt.valHooks[this]={set:function(t,e){if(yt.isArray(e))return t.checked=yt.inArray(yt(t).val(),e)>-1}},vt.checkOn||(yt.valHooks[this].get=function(t){return null===t.getAttribute("value")?"on":t.value})});var Ee=/^(?:focusinfocus|focusoutblur)$/;yt.extend(yt.event,{trigger:function(t,e,r,o){var i,a,s,l,u,c,f,d=[r||it],p=pt.call(t,"type")?t.type:t,h=pt.call(t,"namespace")?t.namespace.split("."):[];if(a=s=r=r||it,3!==r.nodeType&&8!==r.nodeType&&!Ee.test(p+yt.event.triggered)&&(p.indexOf(".")>-1&&(h=p.split("."),p=h.shift(),h.sort()),u=p.indexOf(":")<0&&"on"+p,t=t[yt.expando]?t:new yt.Event(p,"object"==typeof t&&t),t.isTrigger=o?2:3,t.namespace=h.join("."),t.rnamespace=t.namespace?new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,t.result=void 0,t.target||(t.target=r),e=null==e?[t]:yt.makeArray(e,[t]),f=yt.event.special[p]||{},o||!f.trigger||f.trigger.apply(r,e)!==!1)){if(!o&&!f.noBubble&&!yt.isWindow(r)){for(l=f.delegateType||p,Ee.test(l+p)||(a=a.parentNode);a;a=a.parentNode)d.push(a),s=a;s===(r.ownerDocument||it)&&d.push(s.defaultView||s.parentWindow||n)}for(i=0;(a=d[i++])&&!t.isPropagationStopped();)t.type=i>1?l:f.bindType||p,c=(Bt.get(a,"events")||{})[t.type]&&Bt.get(a,"handle"),c&&c.apply(a,e),c=u&&a[u],c&&c.apply&&jt(a)&&(t.result=c.apply(a,e),t.result===!1&&t.preventDefault());return t.type=p,o||t.isDefaultPrevented()||f._default&&f._default.apply(d.pop(),e)!==!1||!jt(r)||u&&yt.isFunction(r[p])&&!yt.isWindow(r)&&(s=r[u],s&&(r[u]=null),yt.event.triggered=p,r[p](),yt.event.triggered=void 0,s&&(r[u]=s)),t.result}},simulate:function(t,e,n){var r=yt.extend(new yt.Event,n,{type:t,isSimulated:!0});yt.event.trigger(r,null,e)}}),yt.fn.extend({trigger:function(t,e){return this.each(function(){yt.event.trigger(t,e,this)})},triggerHandler:function(t,e){var n=this[0];if(n)return yt.event.trigger(t,e,n,!0)}}),yt.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),function(t,e){yt.fn[e]=function(t,n){return arguments.length>0?this.on(e,null,t,n):this.trigger(e)}}),yt.fn.extend({hover:function(t,e){return this.mouseenter(t).mouseleave(e||t)}}),vt.focusin="onfocusin"in n,vt.focusin||yt.each({focus:"focusin",blur:"focusout"},function(t,e){var n=function(t){yt.event.simulate(e,t.target,yt.event.fix(t))};yt.event.special[e]={setup:function(){var r=this.ownerDocument||this,o=Bt.access(r,e);o||r.addEventListener(t,n,!0),Bt.access(r,e,(o||0)+1)},teardown:function(){var r=this.ownerDocument||this,o=Bt.access(r,e)-1;o?Bt.access(r,e,o):(r.removeEventListener(t,n,!0),Bt.remove(r,e))}}});var Pe=n.location,Se=yt.now(),Me=/\?/;yt.parseXML=function(t){var e;if(!t||"string"!=typeof t)return null;try{e=(new n.DOMParser).parseFromString(t,"text/xml")}catch(t){e=void 0}return e&&!e.getElementsByTagName("parsererror").length||yt.error("Invalid XML: "+t),e};var Ne=/\[\]$/,Ae=/\r?\n/g,Oe=/^(?:submit|button|image|reset|file)$/i,De=/^(?:input|select|textarea|keygen)/i;yt.param=function(t,e){var n,r=[],o=function(t,e){var n=yt.isFunction(e)?e():e;r[r.length]=encodeURIComponent(t)+"="+encodeURIComponent(null==n?"":n)};if(yt.isArray(t)||t.jquery&&!yt.isPlainObject(t))yt.each(t,function(){o(this.name,this.value)});else for(n in t)Z(n,t[n],e,o);return r.join("&")},yt.fn.extend({serialize:function(){return yt.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var t=yt.prop(this,"elements");return t?yt.makeArray(t):this}).filter(function(){var t=this.type;return this.name&&!yt(this).is(":disabled")&&De.test(this.nodeName)&&!Oe.test(t)&&(this.checked||!Xt.test(t))}).map(function(t,e){var n=yt(this).val();return null==n?null:yt.isArray(n)?yt.map(n,function(t){return{name:e.name,value:t.replace(Ae,"\r\n")}}):{name:e.name,value:n.replace(Ae,"\r\n")}}).get()}});var Ie=/%20/g,Re=/#.*$/,Le=/([?&])_=[^&]*/,Fe=/^(.*?):[ \t]*([^\r\n]*)$/gm,je=/^(?:about|app|app-storage|.+-extension|file|res|widget):$/,Be=/^(?:GET|HEAD)$/,Ue=/^\/\//,He={},ze={},We="*/".concat("*"),qe=it.createElement("a");qe.href=Pe.href,yt.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:Pe.href,type:"GET",isLocal:je.test(Pe.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":We,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":yt.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(t,e){return e?tt(tt(t,yt.ajaxSettings),e):tt(yt.ajaxSettings,t)},ajaxPrefilter:J(He),ajaxTransport:J(ze),ajax:function(t,e){function r(t,e,r,s){var u,d,p,x,_,w=e;c||(c=!0,l&&n.clearTimeout(l),o=void 0,a=s||"",T.readyState=t>0?4:0,u=t>=200&&t<300||304===t,r&&(x=et(h,T,r)),x=nt(h,x,T,u),u?(h.ifModified&&(_=T.getResponseHeader("Last-Modified"),_&&(yt.lastModified[i]=_),_=T.getResponseHeader("etag"),_&&(yt.etag[i]=_)),204===t||"HEAD"===h.type?w="nocontent":304===t?w="notmodified":(w=x.state,d=x.data,p=x.error,u=!p)):(p=w,!t&&w||(w="error",t<0&&(t=0))),T.status=t,T.statusText=(e||w)+"",u?m.resolveWith(g,[d,w,T]):m.rejectWith(g,[T,w,p]),T.statusCode(b),b=void 0,f&&v.trigger(u?"ajaxSuccess":"ajaxError",[T,h,u?d:p]),y.fireWith(g,[T,w]),f&&(v.trigger("ajaxComplete",[T,h]),--yt.active||yt.event.trigger("ajaxStop")))}"object"==typeof t&&(e=t,t=void 0),e=e||{};var o,i,a,s,l,u,c,f,d,p,h=yt.ajaxSetup({},e),g=h.context||h,v=h.context&&(g.nodeType||g.jquery)?yt(g):yt.event,m=yt.Deferred(),y=yt.Callbacks("once memory"),b=h.statusCode||{},x={},_={},w="canceled",T={readyState:0,getResponseHeader:function(t){var e;if(c){if(!s)for(s={};e=Fe.exec(a);)s[e[1].toLowerCase()]=e[2];e=s[t.toLowerCase()]}return null==e?null:e},getAllResponseHeaders:function(){return c?a:null},setRequestHeader:function(t,e){return null==c&&(t=_[t.toLowerCase()]=_[t.toLowerCase()]||t,x[t]=e),this},overrideMimeType:function(t){return null==c&&(h.mimeType=t),this},statusCode:function(t){var e;if(t)if(c)T.always(t[T.status]);else for(e in t)b[e]=[b[e],t[e]];return this},abort:function(t){var e=t||w;return o&&o.abort(e),r(0,e),this}};if(m.promise(T),h.url=((t||h.url||Pe.href)+"").replace(Ue,Pe.protocol+"//"),h.type=e.method||e.type||h.method||h.type,h.dataTypes=(h.dataType||"*").toLowerCase().match(It)||[""],null==h.crossDomain){u=it.createElement("a");try{u.href=h.url,u.href=u.href,h.crossDomain=qe.protocol+"//"+qe.host!=u.protocol+"//"+u.host}catch(t){h.crossDomain=!0}}if(h.data&&h.processData&&"string"!=typeof h.data&&(h.data=yt.param(h.data,h.traditional)),Q(He,h,e,T),c)return T;f=yt.event&&h.global,f&&0===yt.active++&&yt.event.trigger("ajaxStart"),h.type=h.type.toUpperCase(),h.hasContent=!Be.test(h.type),i=h.url.replace(Re,""),h.hasContent?h.data&&h.processData&&0===(h.contentType||"").indexOf("application/x-www-form-urlencoded")&&(h.data=h.data.replace(Ie,"+")):(p=h.url.slice(i.length),h.data&&(i+=(Me.test(i)?"&":"?")+h.data,delete h.data),h.cache===!1&&(i=i.replace(Le,"$1"),p=(Me.test(i)?"&":"?")+"_="+Se++ +p),h.url=i+p),h.ifModified&&(yt.lastModified[i]&&T.setRequestHeader("If-Modified-Since",yt.lastModified[i]),yt.etag[i]&&T.setRequestHeader("If-None-Match",yt.etag[i])),(h.data&&h.hasContent&&h.contentType!==!1||e.contentType)&&T.setRequestHeader("Content-Type",h.contentType),T.setRequestHeader("Accept",h.dataTypes[0]&&h.accepts[h.dataTypes[0]]?h.accepts[h.dataTypes[0]]+("*"!==h.dataTypes[0]?", "+We+"; q=0.01":""):h.accepts["*"]);for(d in h.headers)T.setRequestHeader(d,h.headers[d]);if(h.beforeSend&&(h.beforeSend.call(g,T,h)===!1||c))return T.abort();if(w="abort",y.add(h.complete),T.done(h.success),T.fail(h.error),o=Q(ze,h,e,T)){if(T.readyState=1,f&&v.trigger("ajaxSend",[T,h]),c)return T;h.async&&h.timeout>0&&(l=n.setTimeout(function(){T.abort("timeout")},h.timeout));try{c=!1,o.send(x,r)}catch(t){if(c)throw t;r(-1,t)}}else r(-1,"No Transport");return T},getJSON:function(t,e,n){return yt.get(t,e,n,"json")},getScript:function(t,e){return yt.get(t,void 0,e,"script")}}),yt.each(["get","post"],function(t,e){yt[e]=function(t,n,r,o){return yt.isFunction(n)&&(o=o||r,r=n,n=void 0),yt.ajax(yt.extend({url:t,type:e,dataType:o,data:n,success:r},yt.isPlainObject(t)&&t))}}),yt._evalUrl=function(t){return yt.ajax({url:t,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,throws:!0})},yt.fn.extend({wrapAll:function(t){var e;return this[0]&&(yt.isFunction(t)&&(t=t.call(this[0])),e=yt(t,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&e.insertBefore(this[0]),e.map(function(){for(var t=this;t.firstElementChild;)t=t.firstElementChild;return t}).append(this)),this},wrapInner:function(t){return yt.isFunction(t)?this.each(function(e){yt(this).wrapInner(t.call(this,e))}):this.each(function(){var e=yt(this),n=e.contents();n.length?n.wrapAll(t):e.append(t)})},wrap:function(t){var e=yt.isFunction(t);return this.each(function(n){yt(this).wrapAll(e?t.call(this,n):t)})},unwrap:function(t){return this.parent(t).not("body").each(function(){
yt(this).replaceWith(this.childNodes)}),this}}),yt.expr.pseudos.hidden=function(t){return!yt.expr.pseudos.visible(t)},yt.expr.pseudos.visible=function(t){return!!(t.offsetWidth||t.offsetHeight||t.getClientRects().length)},yt.ajaxSettings.xhr=function(){try{return new n.XMLHttpRequest}catch(t){}};var Ve={0:200,1223:204},Ke=yt.ajaxSettings.xhr();vt.cors=!!Ke&&"withCredentials"in Ke,vt.ajax=Ke=!!Ke,yt.ajaxTransport(function(t){var e,r;if(vt.cors||Ke&&!t.crossDomain)return{send:function(o,i){var a,s=t.xhr();if(s.open(t.type,t.url,t.async,t.username,t.password),t.xhrFields)for(a in t.xhrFields)s[a]=t.xhrFields[a];t.mimeType&&s.overrideMimeType&&s.overrideMimeType(t.mimeType),t.crossDomain||o["X-Requested-With"]||(o["X-Requested-With"]="XMLHttpRequest");for(a in o)s.setRequestHeader(a,o[a]);e=function(t){return function(){e&&(e=r=s.onload=s.onerror=s.onabort=s.onreadystatechange=null,"abort"===t?s.abort():"error"===t?"number"!=typeof s.status?i(0,"error"):i(s.status,s.statusText):i(Ve[s.status]||s.status,s.statusText,"text"!==(s.responseType||"text")||"string"!=typeof s.responseText?{binary:s.response}:{text:s.responseText},s.getAllResponseHeaders()))}},s.onload=e(),r=s.onerror=e("error"),void 0!==s.onabort?s.onabort=r:s.onreadystatechange=function(){4===s.readyState&&n.setTimeout(function(){e&&r()})},e=e("abort");try{s.send(t.hasContent&&t.data||null)}catch(t){if(e)throw t}},abort:function(){e&&e()}}}),yt.ajaxPrefilter(function(t){t.crossDomain&&(t.contents.script=!1)}),yt.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(t){return yt.globalEval(t),t}}}),yt.ajaxPrefilter("script",function(t){void 0===t.cache&&(t.cache=!1),t.crossDomain&&(t.type="GET")}),yt.ajaxTransport("script",function(t){if(t.crossDomain){var e,n;return{send:function(r,o){e=yt("<script>").prop({charset:t.scriptCharset,src:t.url}).on("load error",n=function(t){e.remove(),n=null,t&&o("error"===t.type?404:200,t.type)}),it.head.appendChild(e[0])},abort:function(){n&&n()}}}});var Ye=[],Ge=/(=)\?(?=&|$)|\?\?/;yt.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var t=Ye.pop()||yt.expando+"_"+Se++;return this[t]=!0,t}}),yt.ajaxPrefilter("json jsonp",function(t,e,r){var o,i,a,s=t.jsonp!==!1&&(Ge.test(t.url)?"url":"string"==typeof t.data&&0===(t.contentType||"").indexOf("application/x-www-form-urlencoded")&&Ge.test(t.data)&&"data");if(s||"jsonp"===t.dataTypes[0])return o=t.jsonpCallback=yt.isFunction(t.jsonpCallback)?t.jsonpCallback():t.jsonpCallback,s?t[s]=t[s].replace(Ge,"$1"+o):t.jsonp!==!1&&(t.url+=(Me.test(t.url)?"&":"?")+t.jsonp+"="+o),t.converters["script json"]=function(){return a||yt.error(o+" was not called"),a[0]},t.dataTypes[0]="json",i=n[o],n[o]=function(){a=arguments},r.always(function(){void 0===i?yt(n).removeProp(o):n[o]=i,t[o]&&(t.jsonpCallback=e.jsonpCallback,Ye.push(o)),a&&yt.isFunction(i)&&i(a[0]),a=i=void 0}),"script"}),vt.createHTMLDocument=function(){var t=it.implementation.createHTMLDocument("").body;return t.innerHTML="<form></form><form></form>",2===t.childNodes.length}(),yt.parseHTML=function(t,e,n){if("string"!=typeof t)return[];"boolean"==typeof e&&(n=e,e=!1);var r,o,i;return e||(vt.createHTMLDocument?(e=it.implementation.createHTMLDocument(""),r=e.createElement("base"),r.href=it.location.href,e.head.appendChild(r)):e=it),o=Pt.exec(t),i=!n&&[],o?[e.createElement(o[1])]:(o=T([t],e,i),i&&i.length&&yt(i).remove(),yt.merge([],o.childNodes))},yt.fn.load=function(t,e,n){var r,o,i,a=this,s=t.indexOf(" ");return s>-1&&(r=X(t.slice(s)),t=t.slice(0,s)),yt.isFunction(e)?(n=e,e=void 0):e&&"object"==typeof e&&(o="POST"),a.length>0&&yt.ajax({url:t,type:o||"GET",dataType:"html",data:e}).done(function(t){i=arguments,a.html(r?yt("<div>").append(yt.parseHTML(t)).find(r):t)}).always(n&&function(t,e){a.each(function(){n.apply(this,i||[t.responseText,e,t])})}),this},yt.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(t,e){yt.fn[e]=function(t){return this.on(e,t)}}),yt.expr.pseudos.animated=function(t){return yt.grep(yt.timers,function(e){return t===e.elem}).length},yt.offset={setOffset:function(t,e,n){var r,o,i,a,s,l,u,c=yt.css(t,"position"),f=yt(t),d={};"static"===c&&(t.style.position="relative"),s=f.offset(),i=yt.css(t,"top"),l=yt.css(t,"left"),u=("absolute"===c||"fixed"===c)&&(i+l).indexOf("auto")>-1,u?(r=f.position(),a=r.top,o=r.left):(a=parseFloat(i)||0,o=parseFloat(l)||0),yt.isFunction(e)&&(e=e.call(t,n,yt.extend({},s))),null!=e.top&&(d.top=e.top-s.top+a),null!=e.left&&(d.left=e.left-s.left+o),"using"in e?e.using.call(t,d):f.css(d)}},yt.fn.extend({offset:function(t){if(arguments.length)return void 0===t?this:this.each(function(e){yt.offset.setOffset(this,t,e)});var e,n,r,o,i=this[0];return i?i.getClientRects().length?(r=i.getBoundingClientRect(),r.width||r.height?(o=i.ownerDocument,n=rt(o),e=o.documentElement,{top:r.top+n.pageYOffset-e.clientTop,left:r.left+n.pageXOffset-e.clientLeft}):r):{top:0,left:0}:void 0},position:function(){if(this[0]){var t,e,n=this[0],r={top:0,left:0};return"fixed"===yt.css(n,"position")?e=n.getBoundingClientRect():(t=this.offsetParent(),e=this.offset(),yt.nodeName(t[0],"html")||(r=t.offset()),r={top:r.top+yt.css(t[0],"borderTopWidth",!0),left:r.left+yt.css(t[0],"borderLeftWidth",!0)}),{top:e.top-r.top-yt.css(n,"marginTop",!0),left:e.left-r.left-yt.css(n,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){for(var t=this.offsetParent;t&&"static"===yt.css(t,"position");)t=t.offsetParent;return t||te})}}),yt.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(t,e){var n="pageYOffset"===e;yt.fn[t]=function(r){return Ft(this,function(t,r,o){var i=rt(t);return void 0===o?i?i[e]:t[r]:void(i?i.scrollTo(n?i.pageXOffset:o,n?o:i.pageYOffset):t[r]=o)},t,r,arguments.length)}}),yt.each(["top","left"],function(t,e){yt.cssHooks[e]=L(vt.pixelPosition,function(t,n){if(n)return n=R(t,e),ce.test(n)?yt(t).position()[e]+"px":n})}),yt.each({Height:"height",Width:"width"},function(t,e){yt.each({padding:"inner"+t,content:e,"":"outer"+t},function(n,r){yt.fn[r]=function(o,i){var a=arguments.length&&(n||"boolean"!=typeof o),s=n||(o===!0||i===!0?"margin":"border");return Ft(this,function(e,n,o){var i;return yt.isWindow(e)?0===r.indexOf("outer")?e["inner"+t]:e.document.documentElement["client"+t]:9===e.nodeType?(i=e.documentElement,Math.max(e.body["scroll"+t],i["scroll"+t],e.body["offset"+t],i["offset"+t],i["client"+t])):void 0===o?yt.css(e,n,s):yt.style(e,n,o,s)},e,a?o:void 0,a)}})}),yt.fn.extend({bind:function(t,e,n){return this.on(t,null,e,n)},unbind:function(t,e){return this.off(t,null,e)},delegate:function(t,e,n,r){return this.on(e,t,n,r)},undelegate:function(t,e,n){return 1===arguments.length?this.off(t,"**"):this.off(e,t||"**",n)}}),yt.parseJSON=JSON.parse,r=[],o=function(){return yt}.apply(e,r),!(void 0!==o&&(t.exports=o));var Xe=n.jQuery,$e=n.$;return yt.noConflict=function(t){return n.$===yt&&(n.$=$e),t&&n.jQuery===yt&&(n.jQuery=Xe),yt},i||(n.jQuery=n.$=yt),yt})},function(t,e,n){"use strict";var r=function(){};t.exports=r},function(t,e){var n=t.exports={version:"2.4.0"};"number"==typeof __e&&(__e=n)},function(t,e,n){var r=n(68)("wks"),o=n(44),i=n(20).Symbol,a="function"==typeof i,s=t.exports=function(t){return r[t]||(r[t]=a&&i[t]||(a?i:o)("Symbol."+t))};s.store=r},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){return!t||"#"===t.trim()}e.__esModule=!0;var i=n(5),a=r(i),s=n(7),l=r(s),u=n(2),c=r(u),f=n(4),d=r(f),p=n(3),h=r(p),g=n(1),v=r(g),m=n(9),y=r(m),b={href:v.default.PropTypes.string,onClick:v.default.PropTypes.func,disabled:v.default.PropTypes.bool,role:v.default.PropTypes.string,tabIndex:v.default.PropTypes.oneOfType([v.default.PropTypes.number,v.default.PropTypes.string]),componentClass:y.default},x={componentClass:"a"},_=function(t){function e(n,r){(0,c.default)(this,e);var o=(0,d.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o}return(0,h.default)(e,t),e.prototype.handleClick=function(t){var e=this.props,n=e.disabled,r=e.href,i=e.onClick;return(n||o(r))&&t.preventDefault(),n?void t.stopPropagation():void(i&&i(t))},e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.disabled,r=(0,l.default)(t,["componentClass","disabled"]);return o(r.href)&&(r.role=r.role||"button",r.href=r.href||"#"),n&&(r.tabIndex=-1,r.style=(0,a.default)({pointerEvents:"none"},r.style)),v.default.createElement(e,(0,a.default)({},r,{onClick:this.handleClick}))},e}(v.default.Component);_.propTypes=b,_.defaultProps=x,e.default=_,t.exports=e.default},function(t,e,n){var r=n(20),o=n(16),i=n(60),a=n(29),s="prototype",l=function(t,e,n){var u,c,f,d=t&l.F,p=t&l.G,h=t&l.S,g=t&l.P,v=t&l.B,m=t&l.W,y=p?o:o[e]||(o[e]={}),b=y[s],x=p?r:h?r[e]:(r[e]||{})[s];p&&(n=e);for(u in n)c=!d&&x&&void 0!==x[u],c&&u in y||(f=c?x[u]:n[u],y[u]=p&&"function"!=typeof x[u]?n[u]:v&&c?i(f,r):m&&x[u]==f?function(t){var e=function(e,n,r){if(this instanceof t){switch(arguments.length){case 0:return new t;case 1:return new t(e);case 2:return new t(e,n)}return new t(e,n,r)}return t.apply(this,arguments)};return e[s]=t[s],e}(f):g&&"function"==typeof f?i(Function.call,f):f,g&&((y.virtual||(y.virtual={}))[u]=f,t&l.R&&b&&!b[u]&&a(b,u,f)))};l.F=1,l.G=2,l.S=4,l.P=8,l.B=16,l.W=32,l.U=64,l.R=128,t.exports=l},function(t,e){var n=t.exports="undefined"!=typeof window&&window.Math==Math?window:"undefined"!=typeof self&&self.Math==Math?self:Function("return this")();"number"==typeof __g&&(__g=n)},function(t,e,n){var r=n(101),o=n(61);t.exports=function(t){return r(o(t))}},function(t,e,n){"use strict";function r(t){if(t&&t.__esModule)return t;var e={};if(null!=t)for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n]);return e.default=t,e}function o(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0,e.utils=e.Well=e.Tooltip=e.Thumbnail=e.Tabs=e.TabPane=e.Table=e.TabContent=e.TabContainer=e.Tab=e.SplitButton=e.SafeAnchor=e.Row=e.ResponsiveEmbed=e.Radio=e.ProgressBar=e.Popover=e.PanelGroup=e.Panel=e.Pagination=e.Pager=e.PageItem=e.PageHeader=e.OverlayTrigger=e.Overlay=e.NavItem=e.NavDropdown=e.NavbarBrand=e.Navbar=e.Nav=e.ModalTitle=e.ModalHeader=e.ModalFooter=e.ModalBody=e.Modal=e.MenuItem=e.Media=e.ListGroupItem=e.ListGroup=e.Label=e.Jumbotron=e.InputGroup=e.Image=e.HelpBlock=e.Grid=e.Glyphicon=e.FormGroup=e.FormControl=e.Form=e.Fade=e.DropdownButton=e.Dropdown=e.Collapse=e.Col=e.ControlLabel=e.Clearfix=e.Checkbox=e.CarouselItem=e.Carousel=e.ButtonToolbar=e.ButtonGroup=e.Button=e.BreadcrumbItem=e.Breadcrumb=e.Badge=e.Alert=e.Accordion=void 0;var i=n(219),a=o(i),s=n(220),l=o(s),u=n(221),c=o(u),f=n(222),d=o(f),p=n(119),h=o(p),g=n(40),v=o(g),m=n(120),y=o(m),b=n(223),x=o(b),_=n(224),w=o(_),T=n(121),C=o(T),k=n(226),E=o(k),P=n(227),S=o(P),M=n(229),N=o(M),A=n(228),O=o(A),D=n(77),I=o(D),R=n(48),L=o(R),F=n(230),j=o(F),B=n(49),U=o(B),H=n(232),z=o(H),W=n(233),q=o(W),V=n(236),K=o(V),Y=n(78),G=o(Y),X=n(123),$=o(X),Z=n(237),J=o(Z),Q=n(238),tt=o(Q),et=n(239),nt=o(et),rt=n(242),ot=o(rt),it=n(243),at=o(it),st=n(244),lt=o(st),ut=n(124),ct=o(ut),ft=n(79),dt=o(ft),pt=n(251),ht=o(pt),gt=n(252),vt=o(gt),mt=n(125),yt=o(mt),bt=n(126),xt=o(bt),_t=n(127),wt=o(_t),Tt=n(128),Ct=o(Tt),kt=n(129),Et=o(kt),Pt=n(255),St=o(Pt),Mt=n(131),Nt=o(Mt),At=n(254),Ot=o(At),Dt=n(130),It=o(Dt),Rt=n(132),Lt=o(Rt),Ft=n(259),jt=o(Ft),Bt=n(260),Ut=o(Bt),Ht=n(261),zt=o(Ht),Wt=n(262),qt=o(Wt),Vt=n(263),Kt=o(Vt),Yt=n(265),Gt=o(Yt),Xt=n(134),$t=o(Xt),Zt=n(266),Jt=o(Zt),Qt=n(267),te=o(Qt),ee=n(268),ne=o(ee),re=n(269),oe=o(re),ie=n(270),ae=o(ie),se=n(18),le=o(se),ue=n(271),ce=o(ue),fe=n(273),de=o(fe),pe=n(80),he=o(pe),ge=n(81),ve=o(ge),me=n(274),ye=o(me),be=n(135),xe=o(be),_e=n(275),we=o(_e),Te=n(276),Ce=o(Te),ke=n(277),Ee=o(ke),Pe=n(278),Se=o(Pe),Me=n(282),Ne=r(Me);e.Accordion=a.default,e.Alert=l.default,e.Badge=c.default,e.Breadcrumb=d.default,e.BreadcrumbItem=h.default,e.Button=v.default,e.ButtonGroup=y.default,e.ButtonToolbar=x.default,e.Carousel=w.default,e.CarouselItem=C.default,e.Checkbox=E.default,e.Clearfix=S.default,e.ControlLabel=N.default,e.Col=O.default,e.Collapse=I.default,e.Dropdown=L.default,e.DropdownButton=j.default,e.Fade=U.default,e.Form=z.default,e.FormControl=q.default,e.FormGroup=K.default,e.Glyphicon=G.default,e.Grid=$.default,e.HelpBlock=J.default,e.Image=tt.default,e.InputGroup=nt.default,e.Jumbotron=ot.default,e.Label=at.default,e.ListGroup=lt.default,e.ListGroupItem=ct.default,e.Media=dt.default,e.MenuItem=ht.default,e.Modal=vt.default,e.ModalBody=yt.default,e.ModalFooter=xt.default,e.ModalHeader=wt.default,e.ModalTitle=Ct.default,e.Nav=Et.default,e.Navbar=St.default,e.NavbarBrand=Nt.default,e.NavDropdown=Ot.default,e.NavItem=It.default,e.Overlay=Lt.default,e.OverlayTrigger=jt.default,e.PageHeader=Ut.default,e.PageItem=zt.default,e.Pager=qt.default,e.Pagination=Kt.default,e.Panel=Gt.default,e.PanelGroup=$t.default,e.Popover=Jt.default,e.ProgressBar=te.default,e.Radio=ne.default,e.ResponsiveEmbed=oe.default,e.Row=ae.default,e.SafeAnchor=le.default,e.SplitButton=ce.default,e.Tab=de.default,e.TabContainer=he.default,e.TabContent=ve.default,e.Table=ye.default,e.TabPane=xe.default,e.Tabs=we.default,e.Thumbnail=Ce.default,e.Tooltip=Ee.default,e.Well=Se.default,e.utils=Ne},function(t,e){var n={}.hasOwnProperty;t.exports=function(t,e){return n.call(t,e)}},function(t,e,n){var r=n(27),o=n(100),i=n(71),a=Object.defineProperty;e.f=n(28)?Object.defineProperty:function(t,e,n){if(r(t),e=i(e,!0),r(n),o)try{return a(t,e,n)}catch(t){}if("get"in n||"set"in n)throw TypeError("Accessors not supported!");return"value"in n&&(t[e]=n.value),t}},function(t,e){"use strict";t.exports=!("undefined"==typeof window||!window.document||!window.document.createElement)},function(t,e,n){t.exports={default:n(161),__esModule:!0}},function(t,e,n){var r=n(35);t.exports=function(t){if(!r(t))throw TypeError(t+" is not an object!");return t}},function(t,e,n){t.exports=!n(34)(function(){return 7!=Object.defineProperty({},"a",{get:function(){return 7}}).a})},function(t,e,n){var r=n(24),o=n(38);t.exports=n(28)?function(t,e,n){return r.f(t,e,o(1,n))}:function(t,e,n){return t[e]=n,t}},function(t,e,n){var r=n(105),o=n(62);t.exports=Object.keys||function(t){return r(t,o)}},function(t,e){"use strict";function n(t){return t&&t.ownerDocument||document}e.__esModule=!0,e.default=n,t.exports=e.default},function(t,e,n){"use strict";var r=n(25),o=function(){var t=r&&document.documentElement;return t&&t.contains?function(t,e){return t.contains(e)}:t&&t.compareDocumentPosition?function(t,e){return t===e||!!(16&t.compareDocumentPosition(e))}:function(t,e){if(e)do if(e===t)return!0;while(e=e.parentNode);return!1}}();t.exports=o},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0});var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}();n(297);var l=n(1),u=r(l),c=function(t){function e(t){o(this,e);var n=i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t));return n.state={value:null,selected:0},n}return a(e,t),s(e,[{key:"getCurrentState",value:function(){var t={};return t[this.props.options.alias]=this.state.value||this.props.options.default,t}}]),e}(u.default.Component);e.default=c},function(t,e){t.exports=function(t){try{return!!t()}catch(t){return!0}}},function(t,e){t.exports=function(t){return"object"==typeof t?null!==t:"function"==typeof t}},function(t,e){t.exports={}},function(t,e){e.f={}.propertyIsEnumerable},function(t,e){t.exports=function(t,e){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:e}}},function(t,e){t.exports=function(){var t=[];return t.toString=function(){for(var t=[],e=0;e<this.length;e++){var n=this[e];n[2]?t.push("@media "+n[2]+"{"+n[1]+"}"):t.push(n[1])}return t.join("")},t.i=function(e,n){"string"==typeof e&&(e=[[null,e,""]]);for(var r={},o=0;o<this.length;o++){var i=this[o][0];"number"==typeof i&&(r[i]=!0)}for(o=0;o<e.length;o++){var a=e[o];"number"==typeof a[0]&&r[a[0]]||(n&&!a[2]?a[2]=n:n&&(a[2]="("+a[2]+") and ("+n+")"),t.push(a))}},t}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(26),i=r(o),a=n(7),s=r(a),l=n(5),u=r(l),c=n(2),f=r(c),d=n(4),p=r(d),h=n(3),g=r(h),v=n(6),m=r(v),y=n(1),b=r(y),x=n(9),_=r(x),w=n(8),T=n(12),C=n(18),k=r(C),E={active:b.default.PropTypes.bool,disabled:b.default.PropTypes.bool,block:b.default.PropTypes.bool,onClick:b.default.PropTypes.func,componentClass:_.default,href:b.default.PropTypes.string,type:b.default.PropTypes.oneOf(["button","reset","submit"])},P={active:!1,block:!1,disabled:!1},S=function(t){function e(){return(0,f.default)(this,e),(0,p.default)(this,t.apply(this,arguments))}return(0,g.default)(e,t),e.prototype.renderAnchor=function(t,e){return b.default.createElement(k.default,(0,u.default)({},t,{className:(0,m.default)(e,t.disabled&&"disabled")}))},e.prototype.renderButton=function(t,e){var n=t.componentClass,r=(0,s.default)(t,["componentClass"]),o=n||"button";return b.default.createElement(o,(0,u.default)({},r,{type:r.type||"button",className:e}))},e.prototype.render=function(){var t,e=this.props,n=e.active,r=e.block,o=e.className,i=(0,s.default)(e,["active","block","className"]),a=(0,w.splitBsProps)(i),l=a[0],c=a[1],f=(0,u.default)({},(0,w.getClassSet)(l),(t={active:n},t[(0,w.prefix)(l,"block")]=r,t)),d=(0,m.default)(o,f);return c.href?this.renderAnchor(c,d):this.renderButton(c,d)},e}(b.default.Component);S.propTypes=E,S.defaultProps=P,e.default=(0,w.bsClass)("btn",(0,w.bsSizes)([T.Size.LARGE,T.Size.SMALL,T.Size.XSMALL],(0,w.bsStyles)([].concat((0,i.default)(T.State),[T.Style.DEFAULT,T.Style.PRIMARY,T.Style.LINK]),T.Style.DEFAULT,S))),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0}),e.default=function(t){return(0,s.default)(i.default.findDOMNode(t))};var o=n(11),i=r(o),a=n(31),s=r(a);t.exports=e.default},function(t,e,n){function r(t,e){for(var n=0;n<t.length;n++){var r=t[n],o=p[r.id];if(o){o.refs++;for(var i=0;i<o.parts.length;i++)o.parts[i](r.parts[i]);for(;i<r.parts.length;i++)o.parts.push(u(r.parts[i],e))}else{for(var a=[],i=0;i<r.parts.length;i++)a.push(u(r.parts[i],e));p[r.id]={id:r.id,refs:1,parts:a}}}}function o(t){for(var e=[],n={},r=0;r<t.length;r++){var o=t[r],i=o[0],a=o[1],s=o[2],l=o[3],u={css:a,media:s,sourceMap:l};n[i]?n[i].parts.push(u):e.push(n[i]={id:i,parts:[u]})}return e}function i(t,e){var n=v(),r=b[b.length-1];if("top"===t.insertAt)r?r.nextSibling?n.insertBefore(e,r.nextSibling):n.appendChild(e):n.insertBefore(e,n.firstChild),b.push(e);else{if("bottom"!==t.insertAt)throw new Error("Invalid value for parameter 'insertAt'. Must be 'top' or 'bottom'.");n.appendChild(e)}}function a(t){t.parentNode.removeChild(t);var e=b.indexOf(t);e>=0&&b.splice(e,1)}function s(t){var e=document.createElement("style");return e.type="text/css",i(t,e),e}function l(t){var e=document.createElement("link");return e.rel="stylesheet",i(t,e),e}function u(t,e){var n,r,o;if(e.singleton){var i=y++;n=m||(m=s(e)),r=c.bind(null,n,i,!1),o=c.bind(null,n,i,!0)}else t.sourceMap&&"function"==typeof URL&&"function"==typeof URL.createObjectURL&&"function"==typeof URL.revokeObjectURL&&"function"==typeof Blob&&"function"==typeof btoa?(n=l(e),r=d.bind(null,n),o=function(){a(n),n.href&&URL.revokeObjectURL(n.href)}):(n=s(e),r=f.bind(null,n),o=function(){a(n)});return r(t),function(e){if(e){if(e.css===t.css&&e.media===t.media&&e.sourceMap===t.sourceMap)return;r(t=e)}else o()}}function c(t,e,n,r){var o=n?"":r.css;if(t.styleSheet)t.styleSheet.cssText=x(e,o);else{var i=document.createTextNode(o),a=t.childNodes;a[e]&&t.removeChild(a[e]),a.length?t.insertBefore(i,a[e]):t.appendChild(i)}}function f(t,e){var n=e.css,r=e.media;if(r&&t.setAttribute("media",r),t.styleSheet)t.styleSheet.cssText=n;else{for(;t.firstChild;)t.removeChild(t.firstChild);t.appendChild(document.createTextNode(n))}}function d(t,e){var n=e.css,r=e.sourceMap;r&&(n+="\n/*# sourceMappingURL=data:application/json;base64,"+btoa(unescape(encodeURIComponent(JSON.stringify(r))))+" */");var o=new Blob([n],{type:"text/css"}),i=t.href;t.href=URL.createObjectURL(o),i&&URL.revokeObjectURL(i)}var p={},h=function(t){var e;return function(){return"undefined"==typeof e&&(e=t.apply(this,arguments)),e}},g=h(function(){return/msie [6-9]\b/.test(window.navigator.userAgent.toLowerCase())}),v=h(function(){return document.head||document.getElementsByTagName("head")[0]}),m=null,y=0,b=[];t.exports=function(t,e){e=e||{},"undefined"==typeof e.singleton&&(e.singleton=g()),"undefined"==typeof e.insertAt&&(e.insertAt="bottom");var n=o(t);return r(n,e),function(t){for(var i=[],a=0;a<n.length;a++){var s=n[a],l=p[s.id];l.refs--,i.push(l)}if(t){var u=o(t);r(u,e)}for(var a=0;a<i.length;a++){var l=i[a];if(0===l.refs){for(var c=0;c<l.parts.length;c++)l.parts[c]();delete p[l.id]}}}};var x=function(){var t=[];return function(e,n){return t[e]=n,t.filter(Boolean).join("\n")}}()},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.SelectButton=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(33),f=r(c),d=n(22);e.SelectButton=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"_handleClick",value:function(t,e){this.setState({selected:t,value:e});var n={alias:this.props.options.alias,value:e};this.props.onChange([n])}},{key:"render",value:function(){var t=this.props.options.items.map(function(t,e){return u.default.createElement(d.MenuItem,{key:e,onSelect:this._handleClick.bind(this,e,t)},t)}.bind(this)),e=this.state.value||this.props.options.label;return u.default.createElement(d.DropdownButton,{ref:"btn",id:this.props.id,title:e},t)}}]),e}(f.default)},function(t,e){var n=0,r=Math.random();t.exports=function(t){return"Symbol(".concat(void 0===t?"":t,")_",(++n+r).toString(36))}},function(t,e){"use strict";t.exports=function(t){return t===t.window?t:9===t.nodeType&&(t.defaultView||t.parentWindow)}},function(t,e,n){"use strict";var r=n(116),o=n(218),i=n(213),a=n(214),s=Object.prototype.hasOwnProperty;t.exports=function(t,e,n){var l="",u=e;if("string"==typeof e){if(void 0===n)return t.style[r(e)]||i(t).getPropertyValue(o(e));(u={})[e]=n}for(var c in u)s.call(u,c)&&(u[c]||0===u[c]?l+=o(c)+":"+u[c]+";":a(t,o(c)));t.style.cssText+=";"+l}},function(t,e,n){var r,o,i;!function(n,a){o=[e],r=a,i="function"==typeof r?r.apply(e,o):r,!(void 0!==i&&(t.exports=i))}(this,function(t){var e=t;e.interopRequireDefault=function(t){return t&&t.__esModule?t:{default:t}},e._extends=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t}})},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(7),i=r(o),a=n(5),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(111),m=r(v),y=n(32),b=r(y),x=n(76),_=r(x),w=n(1),T=r(w),C=n(11),k=r(C),E=n(51),P=r(E),S=n(9),M=r(S),N=n(52),A=r(N),O=n(55),D=r(O),I=n(15),R=(r(I),n(120)),L=r(R),F=n(231),j=r(F),B=n(122),U=r(B),H=n(8),z=n(10),W=r(z),q=n(279),V=n(13),K=r(V),Y=U.default.defaultProps.bsRole,G=j.default.defaultProps.bsRole,X={dropup:T.default.PropTypes.bool,id:(0,A.default)(T.default.PropTypes.oneOfType([T.default.PropTypes.string,T.default.PropTypes.number])),componentClass:M.default,children:(0,P.default)((0,q.requiredRoles)(Y,G),(0,q.exclusiveRoles)(G)),disabled:T.default.PropTypes.bool,pullRight:T.default.PropTypes.bool,open:T.default.PropTypes.bool,onClose:T.default.PropTypes.func,onToggle:T.default.PropTypes.func,onSelect:T.default.PropTypes.func,role:T.default.PropTypes.string,rootCloseEvent:T.default.PropTypes.oneOf(["click","mousedown"]),onMouseEnter:T.default.PropTypes.func,onMouseLeave:T.default.PropTypes.func},$={componentClass:L.default},Z=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o.handleKeyDown=o.handleKeyDown.bind(o),o.handleClose=o.handleClose.bind(o),o._focusInDropdown=!1,o.lastOpenEventType=null,o}return(0,p.default)(e,t),e.prototype.componentDidMount=function(){this.focusNextOnOpen()},e.prototype.componentWillUpdate=function(t){!t.open&&this.props.open&&(this._focusInDropdown=(0,b.default)(k.default.findDOMNode(this.menu),(0,m.default)(document)))},e.prototype.componentDidUpdate=function(t){var e=this.props.open,n=t.open;e&&!n&&this.focusNextOnOpen(),!e&&n&&this._focusInDropdown&&(this._focusInDropdown=!1,this.focus())},e.prototype.handleClick=function(){this.props.disabled||this.toggleOpen("click")},e.prototype.handleKeyDown=function(t){if(!this.props.disabled)switch(t.keyCode){case _.default.codes.down:this.props.open?this.menu.focusNext&&this.menu.focusNext():this.toggleOpen("keydown"),t.preventDefault();break;case _.default.codes.esc:case _.default.codes.tab:this.handleClose(t)}},e.prototype.toggleOpen=function(t){var e=!this.props.open;e&&(this.lastOpenEventType=t),this.props.onToggle&&this.props.onToggle(e)},e.prototype.handleClose=function(){this.props.open&&this.toggleOpen(null)},e.prototype.focusNextOnOpen=function(){var t=this.menu;t.focusNext&&("keydown"!==this.lastOpenEventType&&"menuitem"!==this.props.role||t.focusNext())},e.prototype.focus=function(){var t=k.default.findDOMNode(this.toggle);t&&t.focus&&t.focus()},e.prototype.renderToggle=function(t,e){var n=this,r=function(t){n.toggle=t};return"string"==typeof t.ref||(r=(0,W.default)(t.ref,r)),(0,w.cloneElement)(t,(0,s.default)({},e,{ref:r,bsClass:(0,H.prefix)(e,"toggle"),onClick:(0,W.default)(t.props.onClick,this.handleClick),onKeyDown:(0,W.default)(t.props.onKeyDown,this.handleKeyDown)}))},e.prototype.renderMenu=function(t,e){var n=this,r=e.id,o=e.onClose,a=e.onSelect,l=e.rootCloseEvent,u=(0,i.default)(e,["id","onClose","onSelect","rootCloseEvent"]),c=function(t){n.menu=t};return"string"==typeof t.ref||(c=(0,W.default)(t.ref,c)),(0,w.cloneElement)(t,(0,s.default)({},u,{ref:c,labelledBy:r,bsClass:(0,H.prefix)(u,"menu"),onClose:(0,W.default)(t.props.onClose,o,this.handleClose),onSelect:(0,W.default)(t.props.onSelect,a,this.handleClose),rootCloseEvent:l}))},e.prototype.render=function(){var t,e=this,n=this.props,r=n.componentClass,o=n.id,a=n.dropup,l=n.disabled,u=n.pullRight,c=n.open,f=n.onClose,d=n.onSelect,p=n.role,h=n.bsClass,v=n.className,m=n.rootCloseEvent,y=n.children,b=(0,i.default)(n,["componentClass","id","dropup","disabled","pullRight","open","onClose","onSelect","role","bsClass","className","rootCloseEvent","children"]);delete b.onToggle;var x=(t={},t[h]=!0,t.open=c,t.disabled=l,t);return a&&(x[h]=!1,x.dropup=!0),T.default.createElement(r,(0,s.default)({},b,{className:(0,g.default)(v,x)}),K.default.map(y,function(t){switch(t.props.bsRole){case Y:return e.renderToggle(t,{id:o,disabled:l,open:c,role:p,bsClass:h});case G:return e.renderMenu(t,{id:o,open:c,pullRight:u,bsClass:h,onClose:f,onSelect:d,rootCloseEvent:m});default:return t}}))},e}(T.default.Component);Z.propTypes=X,Z.defaultProps=$,(0,H.bsClass)("dropdown",Z);var J=(0,D.default)(Z,{open:"onToggle"});J.Toggle=U.default,J.Menu=j.default,e.default=J,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(6),p=r(d),h=n(1),g=r(h),v=n(139),m=r(v),y={in:g.default.PropTypes.bool,unmountOnExit:g.default.PropTypes.bool,transitionAppear:g.default.PropTypes.bool,timeout:g.default.PropTypes.number,onEnter:g.default.PropTypes.func,onEntering:g.default.PropTypes.func,onEntered:g.default.PropTypes.func,onExit:g.default.PropTypes.func,onExiting:g.default.PropTypes.func,onExited:g.default.PropTypes.func},b={in:!1,timeout:300,unmountOnExit:!1,transitionAppear:!1},x=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){return g.default.createElement(m.default,(0,i.default)({},this.props,{className:(0,p.default)(this.props.className,"fade"),enteredClassName:"in",enteringClassName:"in"}))},e}(g.default.Component);x.propTypes=y,x.defaultProps=b,e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n=e.propTypes,r={},o={};return(0,a.default)(t).forEach(function(t){var e=t[0],i=t[1];n[e]?r[e]=i:o[e]=i}),[r,o]}e.__esModule=!0;var i=n(98),a=r(i);e.default=o,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(){function t(){for(var t=arguments.length,e=Array(t),r=0;r<t;r++)e[r]=arguments[r];var o=null;return n.forEach(function(t){if(null==o){var n=t.apply(void 0,e);null!=n&&(o=n)}}),o}for(var e=arguments.length,n=Array(e),r=0;r<e;r++)n[r]=arguments[r];return(0,a.default)(t)}e.__esModule=!0,e.default=o;var i=n(53),a=r(i)},function(t,e){"use strict";function n(t){return function(e,n,r,o,i){var a=r||"<<anonymous>>",s=i||n;if(null==e[n])return new Error("The "+o+" `"+s+"` is required to make "+("`"+a+"` accessible for users of assistive ")+"technologies such as screen readers.");for(var l=arguments.length,u=Array(l>5?l-5:0),c=5;c<l;c++)u[c-5]=arguments[c];return t.apply(void 0,[e,n,r,o,i].concat(u))}}e.__esModule=!0,e.default=n},function(t,e){"use strict";function n(t){function e(e,n,r,o,i,a){var s=o||"<<anonymous>>",l=a||r;if(null==n[r])return e?new Error("Required "+i+" `"+l+"` was not specified "+("in `"+s+"`.")):null;for(var u=arguments.length,c=Array(u>6?u-6:0),f=6;f<u;f++)c[f-6]=arguments[f];return t.apply(void 0,[n,r,s,i,l].concat(c))}var n=e.bind(null,!1);return n.isRequired=e.bind(null,!0),n}e.__esModule=!0,e.default=n},function(t,e,n){/*!
		  Copyright (c) 2016 Jed Watson.
		  Licensed under the MIT License (MIT), see
		  http://jedwatson.github.io/react-select
		*/
"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}function i(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}function a(t){var e=typeof t;return"string"===e?t:"object"===e?JSON.stringify(t):"number"===e||"boolean"===e?String(t):""}Object.defineProperty(e,"__esModule",{value:!0});var s=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},l=n(1),u=r(l),c=n(11),f=r(c),d=n(283),p=r(d),h=n(6),g=r(h),v=n(296),m=r(v),y=n(142),b=r(y),x=n(143),_=r(x),w=n(291),T=r(w),C=n(292),k=r(C),E=n(293),P=r(E),S=n(294),M=r(S),N=n(295),A=r(N),O=u.default.PropTypes.oneOfType([u.default.PropTypes.string,u.default.PropTypes.node]),D=1,I=u.default.createClass({displayName:"Select",propTypes:{addLabelText:u.default.PropTypes.string,"aria-label":u.default.PropTypes.string,"aria-labelledby":u.default.PropTypes.string,arrowRenderer:u.default.PropTypes.func,autoBlur:u.default.PropTypes.bool,autofocus:u.default.PropTypes.bool,autosize:u.default.PropTypes.bool,backspaceRemoves:u.default.PropTypes.bool,backspaceToRemoveMessage:u.default.PropTypes.string,className:u.default.PropTypes.string,clearAllText:O,clearValueText:O,clearable:u.default.PropTypes.bool,delimiter:u.default.PropTypes.string,disabled:u.default.PropTypes.bool,escapeClearsValue:u.default.PropTypes.bool,filterOption:u.default.PropTypes.func,filterOptions:u.default.PropTypes.any,ignoreAccents:u.default.PropTypes.bool,ignoreCase:u.default.PropTypes.bool,inputProps:u.default.PropTypes.object,inputRenderer:u.default.PropTypes.func,instanceId:u.default.PropTypes.string,isLoading:u.default.PropTypes.bool,joinValues:u.default.PropTypes.bool,labelKey:u.default.PropTypes.string,matchPos:u.default.PropTypes.string,matchProp:u.default.PropTypes.string,menuBuffer:u.default.PropTypes.number,menuContainerStyle:u.default.PropTypes.object,menuRenderer:u.default.PropTypes.func,menuStyle:u.default.PropTypes.object,multi:u.default.PropTypes.bool,name:u.default.PropTypes.string,noResultsText:O,onBlur:u.default.PropTypes.func,onBlurResetsInput:u.default.PropTypes.bool,onChange:u.default.PropTypes.func,onClose:u.default.PropTypes.func,onCloseResetsInput:u.default.PropTypes.bool,onFocus:u.default.PropTypes.func,onInputChange:u.default.PropTypes.func,onInputKeyDown:u.default.PropTypes.func,onMenuScrollToBottom:u.default.PropTypes.func,onOpen:u.default.PropTypes.func,onValueClick:u.default.PropTypes.func,openAfterFocus:u.default.PropTypes.bool,openOnFocus:u.default.PropTypes.bool,optionClassName:u.default.PropTypes.string,optionComponent:u.default.PropTypes.func,optionRenderer:u.default.PropTypes.func,options:u.default.PropTypes.array,pageSize:u.default.PropTypes.number,placeholder:O,required:u.default.PropTypes.bool,resetValue:u.default.PropTypes.any,scrollMenuIntoView:u.default.PropTypes.bool,searchable:u.default.PropTypes.bool,simpleValue:u.default.PropTypes.bool,style:u.default.PropTypes.object,tabIndex:u.default.PropTypes.string,tabSelectsValue:u.default.PropTypes.bool,value:u.default.PropTypes.any,valueComponent:u.default.PropTypes.func,valueKey:u.default.PropTypes.string,valueRenderer:u.default.PropTypes.func,wrapperStyle:u.default.PropTypes.object},statics:{Async:T.default,AsyncCreatable:k.default,Creatable:P.default},getDefaultProps:function(){return{addLabelText:'Add "{label}"?',arrowRenderer:m.default,autosize:!0,backspaceRemoves:!0,backspaceToRemoveMessage:"Press backspace to remove {label}",clearable:!0,clearAllText:"Clear all",clearValueText:"Clear value",delimiter:",",disabled:!1,escapeClearsValue:!0,filterOptions:b.default,ignoreAccents:!0,ignoreCase:!0,inputProps:{},isLoading:!1,joinValues:!1,labelKey:"label",matchPos:"any",matchProp:"any",menuBuffer:0,menuRenderer:_.default,multi:!1,noResultsText:"No results found",onBlurResetsInput:!0,onCloseResetsInput:!0,openAfterFocus:!1,optionComponent:M.default,pageSize:5,placeholder:"Select...",required:!1,scrollMenuIntoView:!0,searchable:!0,simpleValue:!1,tabSelectsValue:!0,valueComponent:A.default,valueKey:"value"}},getInitialState:function(){return{inputValue:"",isFocused:!1,isOpen:!1,isPseudoFocused:!1,required:!1}},componentWillMount:function(){this._instancePrefix="react-select-"+(this.props.instanceId||++D)+"-";var t=this.getValueArray(this.props.value);this.props.required&&this.setState({required:this.handleRequired(t[0],this.props.multi)})},componentDidMount:function(){this.props.autofocus&&this.focus()},componentWillReceiveProps:function(t){var e=this.getValueArray(t.value,t);t.required&&this.setState({required:this.handleRequired(e[0],t.multi)})},componentWillUpdate:function(t,e){if(e.isOpen!==this.state.isOpen){this.toggleTouchOutsideEvent(e.isOpen);var n=e.isOpen?t.onOpen:t.onClose;n&&n()}},componentDidUpdate:function(t,e){if(this.menu&&this.focused&&this.state.isOpen&&!this.hasScrolledToOption){var n=f.default.findDOMNode(this.focused),r=f.default.findDOMNode(this.menu);r.scrollTop=n.offsetTop,this.hasScrolledToOption=!0}else this.state.isOpen||(this.hasScrolledToOption=!1);if(this._scrollToFocusedOptionOnUpdate&&this.focused&&this.menu){this._scrollToFocusedOptionOnUpdate=!1;var o=f.default.findDOMNode(this.focused),i=f.default.findDOMNode(this.menu),a=o.getBoundingClientRect(),s=i.getBoundingClientRect();(a.bottom>s.bottom||a.top<s.top)&&(i.scrollTop=o.offsetTop+o.clientHeight-i.offsetHeight)}if(this.props.scrollMenuIntoView&&this.menuContainer){var l=this.menuContainer.getBoundingClientRect();window.innerHeight<l.bottom+this.props.menuBuffer&&window.scrollBy(0,l.bottom+this.props.menuBuffer-window.innerHeight)}t.disabled!==this.props.disabled&&(this.setState({isFocused:!1}),this.closeMenu())},componentWillUnmount:function(){document.removeEventListener("touchstart",this.handleTouchOutside)},toggleTouchOutsideEvent:function(t){t?document.addEventListener("touchstart",this.handleTouchOutside):document.removeEventListener("touchstart",this.handleTouchOutside)},handleTouchOutside:function(t){this.wrapper&&!this.wrapper.contains(t.target)&&this.closeMenu()},focus:function(){this.input&&(this.input.focus(),this.props.openAfterFocus&&this.setState({isOpen:!0}))},blurInput:function(){this.input&&this.input.blur()},handleTouchMove:function(t){this.dragging=!0},handleTouchStart:function(t){this.dragging=!1},handleTouchEnd:function(t){this.dragging||this.handleMouseDown(t)},handleTouchEndClearValue:function(t){this.dragging||this.clearValue(t)},handleMouseDown:function(t){if(!(this.props.disabled||"mousedown"===t.type&&0!==t.button)&&"INPUT"!==t.target.tagName){if(t.stopPropagation(),t.preventDefault(),!this.props.searchable)return this.focus(),this.setState({isOpen:!this.state.isOpen});if(this.state.isFocused){this.focus();var e=this.input;"function"==typeof e.getInput&&(e=e.getInput()),e.value="",this.setState({isOpen:!0,isPseudoFocused:!1})}else this._openAfterFocus=!0,this.focus()}},handleMouseDownOnArrow:function(t){this.props.disabled||"mousedown"===t.type&&0!==t.button||this.state.isOpen&&(t.stopPropagation(),t.preventDefault(),this.closeMenu())},handleMouseDownOnMenu:function(t){this.props.disabled||"mousedown"===t.type&&0!==t.button||(t.stopPropagation(),t.preventDefault(),this._openAfterFocus=!0,this.focus())},closeMenu:function(){this.props.onCloseResetsInput?this.setState({isOpen:!1,isPseudoFocused:this.state.isFocused&&!this.props.multi,inputValue:""}):this.setState({isOpen:!1,isPseudoFocused:this.state.isFocused&&!this.props.multi,inputValue:this.state.inputValue}),this.hasScrolledToOption=!1},handleInputFocus:function(t){if(!this.props.disabled){var e=this.state.isOpen||this._openAfterFocus||this.props.openOnFocus;this.props.onFocus&&this.props.onFocus(t),this.setState({isFocused:!0,isOpen:e}),this._openAfterFocus=!1}},handleInputBlur:function(t){if(this.menu&&(this.menu===document.activeElement||this.menu.contains(document.activeElement)))return void this.focus();this.props.onBlur&&this.props.onBlur(t);var e={isFocused:!1,isOpen:!1,isPseudoFocused:!1};this.props.onBlurResetsInput&&(e.inputValue=""),this.setState(e)},handleInputChange:function(t){var e=t.target.value;if(this.state.inputValue!==t.target.value&&this.props.onInputChange){var n=this.props.onInputChange(e);null!=n&&"object"!=typeof n&&(e=""+n)}this.setState({isOpen:!0,isPseudoFocused:!1,inputValue:e})},handleKeyDown:function(t){if(!(this.props.disabled||"function"==typeof this.props.onInputKeyDown&&(this.props.onInputKeyDown(t),t.defaultPrevented))){switch(t.keyCode){case 8:return void(!this.state.inputValue&&this.props.backspaceRemoves&&(t.preventDefault(),this.popValue()));case 9:if(t.shiftKey||!this.state.isOpen||!this.props.tabSelectsValue)return;return void this.selectFocusedOption();case 13:if(!this.state.isOpen)return;t.stopPropagation(),this.selectFocusedOption();break;case 27:this.state.isOpen?(this.closeMenu(),t.stopPropagation()):this.props.clearable&&this.props.escapeClearsValue&&(this.clearValue(t),t.stopPropagation());break;case 38:this.focusPreviousOption();break;case 40:this.focusNextOption();break;case 33:this.focusPageUpOption();break;case 34:this.focusPageDownOption();break;case 35:if(t.shiftKey)return;this.focusEndOption();break;case 36:if(t.shiftKey)return;this.focusStartOption();break;default:return}t.preventDefault()}},handleValueClick:function(t,e){this.props.onValueClick&&this.props.onValueClick(t,e)},handleMenuScroll:function(t){if(this.props.onMenuScrollToBottom){var e=t.target;e.scrollHeight>e.offsetHeight&&!(e.scrollHeight-e.offsetHeight-e.scrollTop)&&this.props.onMenuScrollToBottom()}},handleRequired:function(t,e){return!t||(e?0===t.length:0===Object.keys(t).length)},getOptionLabel:function(t){return t[this.props.labelKey]},getValueArray:function(t,e){var n=this,r="object"==typeof e?e:this.props;if(r.multi){if("string"==typeof t&&(t=t.split(r.delimiter)),!Array.isArray(t)){if(null===t||void 0===t)return[];t=[t]}return t.map(function(t){return n.expandValue(t,r)}).filter(function(t){return t})}var o=this.expandValue(t,r);return o?[o]:[]},expandValue:function(t,e){var n=typeof t;if("string"!==n&&"number"!==n&&"boolean"!==n)return t;var r=e.options,o=e.valueKey;if(r)for(var i=0;i<r.length;i++)if(r[i][o]===t)return r[i]},setValue:function(t){var e=this;if(this.props.autoBlur&&this.blurInput(),this.props.onChange){if(this.props.required){var n=this.handleRequired(t,this.props.multi);this.setState({required:n})}this.props.simpleValue&&t&&(t=this.props.multi?t.map(function(t){return t[e.props.valueKey]}).join(this.props.delimiter):t[this.props.valueKey]),this.props.onChange(t)}},selectValue:function(t){var e=this;this.hasScrolledToOption=!1,this.props.multi?this.setState({inputValue:"",focusedIndex:null},function(){e.addValue(t)}):this.setState({isOpen:!1,inputValue:"",isPseudoFocused:this.state.isFocused},function(){e.setValue(t)})},addValue:function(t){var e=this.getValueArray(this.props.value);this.setValue(e.concat(t))},popValue:function(){var t=this.getValueArray(this.props.value);t.length&&t[t.length-1].clearableValue!==!1&&this.setValue(t.slice(0,t.length-1))},removeValue:function(t){var e=this.getValueArray(this.props.value);this.setValue(e.filter(function(e){return e!==t})),this.focus()},clearValue:function(t){t&&"mousedown"===t.type&&0!==t.button||(t.stopPropagation(),t.preventDefault(),this.setValue(this.getResetValue()),this.setState({isOpen:!1,inputValue:""},this.focus))},getResetValue:function(){return void 0!==this.props.resetValue?this.props.resetValue:this.props.multi?[]:null},focusOption:function(t){this.setState({focusedOption:t})},focusNextOption:function(){this.focusAdjacentOption("next")},focusPreviousOption:function(){this.focusAdjacentOption("previous")},focusPageUpOption:function(){this.focusAdjacentOption("page_up")},focusPageDownOption:function(){this.focusAdjacentOption("page_down")},focusStartOption:function(){this.focusAdjacentOption("start")},focusEndOption:function(){this.focusAdjacentOption("end")},focusAdjacentOption:function(t){var e=this._visibleOptions.map(function(t,e){return{option:t,index:e}}).filter(function(t){return!t.option.disabled});if(this._scrollToFocusedOptionOnUpdate=!0,!this.state.isOpen)return void this.setState({isOpen:!0,inputValue:"",focusedOption:this._focusedOption||e["next"===t?0:e.length-1].option});if(e.length){for(var n=-1,r=0;r<e.length;r++)if(this._focusedOption===e[r].option){n=r;break}if("next"===t&&n!==-1)n=(n+1)%e.length;else if("previous"===t)n>0?n-=1:n=e.length-1;else if("start"===t)n=0;else if("end"===t)n=e.length-1;else if("page_up"===t){var o=n-this.props.pageSize;n=o<0?0:o}else if("page_down"===t){var o=n+this.props.pageSize;n=o>e.length-1?e.length-1:o}n===-1&&(n=0),this.setState({focusedIndex:e[n].index,focusedOption:e[n].option})}},getFocusedOption:function(){return this._focusedOption},getInputValue:function(){return this.state.inputValue},selectFocusedOption:function(){if(this._focusedOption)return this.selectValue(this._focusedOption)},renderLoading:function(){if(this.props.isLoading)return u.default.createElement("span",{className:"Select-loading-zone","aria-hidden":"true"},u.default.createElement("span",{className:"Select-loading"}))},renderValue:function(t,e){var n=this,r=this.props.valueRenderer||this.getOptionLabel,o=this.props.valueComponent;if(!t.length)return this.state.inputValue?null:u.default.createElement("div",{className:"Select-placeholder"},this.props.placeholder);var i=this.props.onValueClick?this.handleValueClick:null;return this.props.multi?t.map(function(t,e){return u.default.createElement(o,{id:n._instancePrefix+"-value-"+e,instancePrefix:n._instancePrefix,disabled:n.props.disabled||t.clearableValue===!1,key:"value-"+e+"-"+t[n.props.valueKey],onClick:i,onRemove:n.removeValue,value:t},r(t,e),u.default.createElement("span",{className:"Select-aria-only"}," "))}):this.state.inputValue?void 0:(e&&(i=null),u.default.createElement(o,{id:this._instancePrefix+"-value-item",disabled:this.props.disabled,instancePrefix:this._instancePrefix,onClick:i,value:t[0]},r(t[0])))},renderInput:function(t,e){var n=this;if(this.props.inputRenderer)return this.props.inputRenderer();var r,a=(0,g.default)("Select-input",this.props.inputProps.className),l=!!this.state.isOpen,c=(0,g.default)((r={},i(r,this._instancePrefix+"-list",l),i(r,this._instancePrefix+"-backspace-remove-message",this.props.multi&&!this.props.disabled&&this.state.isFocused&&!this.state.inputValue),r)),f=s({},this.props.inputProps,{role:"combobox","aria-expanded":""+l,"aria-owns":c,"aria-haspopup":""+l,"aria-activedescendant":l?this._instancePrefix+"-option-"+e:this._instancePrefix+"-value","aria-labelledby":this.props["aria-labelledby"],"aria-label":this.props["aria-label"],className:a,tabIndex:this.props.tabIndex,onBlur:this.handleInputBlur,onChange:this.handleInputChange,onFocus:this.handleInputFocus,ref:function(t){return n.input=t},required:this.state.required,value:this.state.inputValue});if(this.props.disabled||!this.props.searchable){var d=this.props.inputProps,h=(d.inputClassName,o(d,["inputClassName"]));return u.default.createElement("div",s({},h,{role:"combobox","aria-expanded":l,"aria-owns":l?this._instancePrefix+"-list":this._instancePrefix+"-value","aria-activedescendant":l?this._instancePrefix+"-option-"+e:this._instancePrefix+"-value",className:a,tabIndex:this.props.tabIndex||0,onBlur:this.handleInputBlur,onFocus:this.handleInputFocus,ref:function(t){return n.input=t},"aria-readonly":""+!!this.props.disabled,style:{border:0,width:1,display:"inline-block"}}))}return this.props.autosize?u.default.createElement(p.default,s({},f,{minWidth:"5px"})):u.default.createElement("div",{className:a},u.default.createElement("input",f))},renderClear:function(){if(this.props.clearable&&this.props.value&&0!==this.props.value&&(!this.props.multi||this.props.value.length)&&!this.props.disabled&&!this.props.isLoading)return u.default.createElement("span",{className:"Select-clear-zone",title:this.props.multi?this.props.clearAllText:this.props.clearValueText,"aria-label":this.props.multi?this.props.clearAllText:this.props.clearValueText,onMouseDown:this.clearValue,onTouchStart:this.handleTouchStart,onTouchMove:this.handleTouchMove,onTouchEnd:this.handleTouchEndClearValue},u.default.createElement("span",{className:"Select-clear",dangerouslySetInnerHTML:{__html:"&times;"}}))},renderArrow:function(){var t=this.handleMouseDownOnArrow,e=this.props.arrowRenderer({onMouseDown:t});return u.default.createElement("span",{className:"Select-arrow-zone",onMouseDown:t},e)},filterOptions:function t(e){var n=this.state.inputValue,r=this.props.options||[];if(this.props.filterOptions){var t="function"==typeof this.props.filterOptions?this.props.filterOptions:b.default;return t(r,n,e,{filterOption:this.props.filterOption,ignoreAccents:this.props.ignoreAccents,ignoreCase:this.props.ignoreCase,labelKey:this.props.labelKey,matchPos:this.props.matchPos,matchProp:this.props.matchProp,valueKey:this.props.valueKey})}return r},onOptionRef:function(t,e){e&&(this.focused=t)},renderMenu:function(t,e,n){return t&&t.length?this.props.menuRenderer({focusedOption:n,focusOption:this.focusOption,instancePrefix:this._instancePrefix,labelKey:this.props.labelKey,onFocus:this.focusOption,onSelect:this.selectValue,optionClassName:this.props.optionClassName,optionComponent:this.props.optionComponent,optionRenderer:this.props.optionRenderer||this.getOptionLabel,options:t,selectValue:this.selectValue,valueArray:e,valueKey:this.props.valueKey,onOptionRef:this.onOptionRef}):this.props.noResultsText?u.default.createElement("div",{className:"Select-noresults"},this.props.noResultsText):null},renderHiddenField:function(t){var e=this;if(this.props.name){if(this.props.joinValues){var n=t.map(function(t){return a(t[e.props.valueKey])}).join(this.props.delimiter);return u.default.createElement("input",{type:"hidden",ref:function(t){return e.value=t},name:this.props.name,value:n,disabled:this.props.disabled})}return t.map(function(t,n){return u.default.createElement("input",{key:"hidden."+n,type:"hidden",ref:"value"+n,name:e.props.name,value:a(t[e.props.valueKey]),disabled:e.props.disabled})})}},getFocusableOptionIndex:function(t){var e=this._visibleOptions;if(!e.length)return null;var n=this.state.focusedOption||t;if(n&&!n.disabled){var r=e.indexOf(n);if(r!==-1)return r}for(var o=0;o<e.length;o++)if(!e[o].disabled)return o;return null},renderOuter:function(t,e,n){var r=this,o=this.renderMenu(t,e,n);return o?u.default.createElement("div",{ref:function(t){return r.menuContainer=t},className:"Select-menu-outer",style:this.props.menuContainerStyle},u.default.createElement("div",{ref:function(t){return r.menu=t},role:"listbox",className:"Select-menu",id:this._instancePrefix+"-list",style:this.props.menuStyle,onScroll:this.handleMenuScroll,onMouseDown:this.handleMouseDownOnMenu},o)):null},render:function(){var t=this,e=this.getValueArray(this.props.value),n=this._visibleOptions=this.filterOptions(this.props.multi?this.getValueArray(this.props.value):null),r=this.state.isOpen;this.props.multi&&!n.length&&e.length&&!this.state.inputValue&&(r=!1);var o=this.getFocusableOptionIndex(e[0]),i=null;i=null!==o?this._focusedOption=n[o]:this._focusedOption=null;var a=(0,g.default)("Select",this.props.className,{"Select--multi":this.props.multi,"Select--single":!this.props.multi,"is-disabled":this.props.disabled,"is-focused":this.state.isFocused,"is-loading":this.props.isLoading,"is-open":r,"is-pseudo-focused":this.state.isPseudoFocused,"is-searchable":this.props.searchable,"has-value":e.length}),s=null;return this.props.multi&&!this.props.disabled&&e.length&&!this.state.inputValue&&this.state.isFocused&&this.props.backspaceRemoves&&(s=u.default.createElement("span",{id:this._instancePrefix+"-backspace-remove-message",className:"Select-aria-only","aria-live":"assertive"},this.props.backspaceToRemoveMessage.replace("{label}",e[e.length-1][this.props.labelKey]))),u.default.createElement("div",{ref:function(e){return t.wrapper=e},className:a,style:this.props.wrapperStyle},this.renderHiddenField(e),u.default.createElement("div",{ref:function(e){return t.control=e},className:"Select-control",style:this.props.style,onKeyDown:this.handleKeyDown,onMouseDown:this.handleMouseDown,onTouchEnd:this.handleTouchEnd,onTouchStart:this.handleTouchStart,onTouchMove:this.handleTouchMove},u.default.createElement("span",{className:"Select-multi-value-wrapper",id:this._instancePrefix+"-value"},this.renderValue(e,r),this.renderInput(e,o)),s,this.renderLoading(),this.renderClear(),this.renderArrow()),r?this.renderOuter(n,this.props.multi?null:e,i):null)}});e.default=I,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n,r,o){n&&(t._notifying=!0,n.call.apply(n,[t,r].concat(o)),t._notifying=!1),t._values[e]=r,t.isMounted()&&t.forceUpdate()}e.__esModule=!0;var i=n(302),a=r(i),s={shouldComponentUpdate:function(){return!this._notifying}};e.default=(0,a.default)([s],o),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.ChartFactory=e.Chart=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(85),f=n(86),d=n(84),p=n(146),h=n(87),g=function t(e){if("function"!=typeof t[e])throw new Error(e+" is not a valid chart type.");return t[e]};g.MetricsGraphics=c.MetricsGraphics,g.Table=d.Table,g.NVD3Chart=f.NVD3Chart,g.Datamaps=p.Datamaps,g.PlotlyAPI=h.PlotlyAPI;var v=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"update",value:function(t){this.refs.chart._update(t)}},{key:"render",value:function(){var t=this.props.factory(this.props.type);return u.default.createElement(t,{ref:"chart",options:this.props.options})}}]),e}(u.default.Component);v.defaultProps={type:u.default.PropTypes.string,factory:g,options:u.default.PropTypes.object},e.Chart=v,e.ChartFactory=g},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.FilterFactory=e.Filter=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(43),f=n(90),d=n(88),p=n(91),h=n(94),g=n(92),v=n(89),m=n(93),y=function t(e){if("function"!=typeof t[e])throw new Error(e+" is not a valid filter.");return t[e]};y.SliderInput=h.SliderInput,y.SelectButton=c.SelectButton,y.ConditionalSelectButton=f.ConditionalSelectButton,y.ApiButton=d.ApiButton,y.DownloadButton=p.DownloadButton,y.DynamicSearch=g.DynamicSearchInput,y.CheckboxGroup=v.CheckboxGroup,y.ReactSelect=m.ReactSelect;var b=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"render",value:function(){var t=this.props.filter_factory(this.props.type);return u.default.createElement(t,{ref:"filter",id:this.props.id,onChange:this.props.onChange,options:this.props.options})}}]),e}(u.default.Component);b.defaultProps={filter_factory:y},e.Filter=b,e.FilterFactory=y},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(155),i=r(o),a=n(154),s=r(a),l="function"==typeof s.default&&"symbol"==typeof i.default?function(t){return typeof t}:function(t){return t&&"function"==typeof s.default&&t.constructor===s.default&&t!==s.default.prototype?"symbol":typeof t};e.default="function"==typeof s.default&&"symbol"===l(i.default)?function(t){return"undefined"==typeof t?"undefined":l(t)}:function(t){return t&&"function"==typeof s.default&&t.constructor===s.default&&t!==s.default.prototype?"symbol":"undefined"==typeof t?"undefined":l(t)}},function(t,e){var n={}.toString;t.exports=function(t){return n.call(t).slice(8,-1)}},function(t,e,n){var r=n(164);t.exports=function(t,e,n){if(r(t),void 0===e)return t;switch(n){case 1:return function(n){return t.call(e,n)};case 2:return function(n,r){return t.call(e,n,r)};case 3:return function(n,r,o){return t.call(e,n,r,o)}}return function(){return t.apply(e,arguments)}}},function(t,e){t.exports=function(t){if(void 0==t)throw TypeError("Can't call method on  "+t);return t}},function(t,e){t.exports="constructor,hasOwnProperty,isPrototypeOf,propertyIsEnumerable,toLocaleString,toString,valueOf".split(",")},function(t,e){t.exports=!0},function(t,e,n){var r=n(27),o=n(180),i=n(62),a=n(67)("IE_PROTO"),s=function(){},l="prototype",u=function(){var t,e=n(99)("iframe"),r=i.length,o="<",a=">";for(e.style.display="none",n(170).appendChild(e),e.src="javascript:",t=e.contentWindow.document,t.open(),t.write(o+"script"+a+"document.F=Object"+o+"/script"+a),t.close(),u=t.F;r--;)delete u[l][i[r]];return u()};t.exports=Object.create||function(t,e){var n;return null!==t?(s[l]=r(t),n=new s,s[l]=null,n[a]=t):n=u(),void 0===e?n:o(n,e)}},function(t,e){e.f=Object.getOwnPropertySymbols},function(t,e,n){var r=n(24).f,o=n(23),i=n(17)("toStringTag");t.exports=function(t,e,n){t&&!o(t=n?t:t.prototype,i)&&r(t,i,{configurable:!0,value:e})}},function(t,e,n){var r=n(68)("keys"),o=n(44);t.exports=function(t){return r[t]||(r[t]=o(t))}},function(t,e,n){var r=n(20),o="__core-js_shared__",i=r[o]||(r[o]={});t.exports=function(t){return i[t]||(i[t]={})}},function(t,e){var n=Math.ceil,r=Math.floor;t.exports=function(t){return isNaN(t=+t)?0:(t>0?r:n)(t)}},function(t,e,n){var r=n(61);t.exports=function(t){return Object(r(t))}},function(t,e,n){var r=n(35);t.exports=function(t,e){if(!r(t))return t;var n,o;if(e&&"function"==typeof(n=t.toString)&&!r(o=n.call(t)))return o;if("function"==typeof(n=t.valueOf)&&!r(o=n.call(t)))return o;if(!e&&"function"==typeof(n=t.toString)&&!r(o=n.call(t)))return o;throw TypeError("Can't convert object to primitive value")}},function(t,e,n){var r=n(20),o=n(16),i=n(63),a=n(73),s=n(24).f;t.exports=function(t){var e=o.Symbol||(o.Symbol=i?{}:r.Symbol||{});"_"==t.charAt(0)||t in e||s(e,t,{value:a.f(t)})}},function(t,e,n){e.f=n(17)},function(t,e,n){"use strict";var r=n(25),o=function(){};r&&(o=function(){return document.addEventListener?function(t,e,n,r){return t.addEventListener(e,n,r||!1)}:document.attachEvent?function(t,e,n){return t.attachEvent("on"+e,n)}:void 0}()),t.exports=o},function(t,e,n){"use strict";var r=function(t,e,n,r,o,i,a,s){if(!t){var l;if(void 0===e)l=new Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var u=[n,r,o,i,a,s],c=0;l=new Error(e.replace(/%s/g,function(){return u[c++]})),l.name="Invariant Violation"}throw l.framesToPop=1,l}};t.exports=r},function(t,e){e=t.exports=function(t){if(t&&"object"==typeof t){var e=t.which||t.keyCode||t.charCode;e&&(t=e)}if("number"==typeof t)return i[t];var o=String(t),a=n[o.toLowerCase()];if(a)return a;var a=r[o.toLowerCase()];return a?a:1===o.length?o.charCodeAt(0):void 0};var n=e.code=e.codes={backspace:8,tab:9,enter:13,shift:16,ctrl:17,alt:18,"pause/break":19,"caps lock":20,esc:27,space:32,"page up":33,"page down":34,end:35,home:36,left:37,up:38,right:39,down:40,insert:45,delete:46,command:91,"left command":91,"right command":93,"numpad *":106,"numpad +":107,"numpad -":109,"numpad .":110,"numpad /":111,"num lock":144,"scroll lock":145,"my computer":182,"my calculator":183,";":186,"=":187,",":188,"-":189,".":190,"/":191,"`":192,"[":219,"\\":220,"]":221,"'":222},r=e.aliases={windows:91,"⇧":16,"⌥":18,"⌃":17,"⌘":91,ctl:17,control:17,option:18,pause:19,break:19,caps:20,return:13,escape:27,spc:32,pgup:33,pgdn:34,ins:45,del:46,cmd:91};/*!
		 * Programatically add the following
		 */
for(o=97;o<123;o++)n[String.fromCharCode(o)]=o-32;for(var o=48;o<58;o++)n[o-48]=o;for(o=1;o<13;o++)n["f"+o]=o+111;for(o=0;o<10;o++)n["numpad "+o]=o+96;var i=e.names=e.title={};for(o in n)i[n[o]]=o;for(var a in r)n[a]=r[a]},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){t.offsetHeight}function i(t,e){var n=e["offset"+(0,k.default)(t)],r=S[t];return n+parseInt((0,b.default)(e,r[0]),10)+parseInt((0,b.default)(e,r[1]),10)}e.__esModule=!0;var a=n(5),s=r(a),l=n(7),u=r(l),c=n(2),f=r(c),d=n(4),p=r(d),h=n(3),g=r(h),v=n(6),m=r(v),y=n(46),b=r(y),x=n(1),_=r(x),w=n(139),T=r(w),C=n(136),k=r(C),E=n(10),P=r(E),S={height:["marginTop","marginBottom"],width:["marginLeft","marginRight"]},M={in:_.default.PropTypes.bool,unmountOnExit:_.default.PropTypes.bool,transitionAppear:_.default.PropTypes.bool,timeout:_.default.PropTypes.number,onEnter:_.default.PropTypes.func,onEntering:_.default.PropTypes.func,onEntered:_.default.PropTypes.func,onExit:_.default.PropTypes.func,onExiting:_.default.PropTypes.func,onExited:_.default.PropTypes.func,dimension:_.default.PropTypes.oneOfType([_.default.PropTypes.oneOf(["height","width"]),_.default.PropTypes.func]),getDimensionValue:_.default.PropTypes.func,role:_.default.PropTypes.string},N={in:!1,timeout:300,unmountOnExit:!1,transitionAppear:!1,dimension:"height",getDimensionValue:i},A=function(t){function e(n,r){(0,f.default)(this,e);var o=(0,p.default)(this,t.call(this,n,r));return o.handleEnter=o.handleEnter.bind(o),o.handleEntering=o.handleEntering.bind(o),o.handleEntered=o.handleEntered.bind(o),o.handleExit=o.handleExit.bind(o),o.handleExiting=o.handleExiting.bind(o),o}return(0,g.default)(e,t),e.prototype.handleEnter=function(t){var e=this._dimension();t.style[e]="0"},e.prototype.handleEntering=function(t){var e=this._dimension();t.style[e]=this._getScrollDimensionValue(t,e)},e.prototype.handleEntered=function(t){var e=this._dimension();t.style[e]=null},e.prototype.handleExit=function(t){var e=this._dimension();t.style[e]=this.props.getDimensionValue(e,t)+"px",o(t)},e.prototype.handleExiting=function(t){var e=this._dimension();t.style[e]="0"},e.prototype._dimension=function(){return"function"==typeof this.props.dimension?this.props.dimension():this.props.dimension},e.prototype._getScrollDimensionValue=function(t,e){return t["scroll"+(0,k.default)(e)]+"px"},e.prototype.render=function(){var t=this.props,e=t.onEnter,n=t.onEntering,r=t.onEntered,o=t.onExit,i=t.onExiting,a=t.className,l=(0,u.default)(t,["onEnter","onEntering","onEntered","onExit","onExiting","className"]);delete l.dimension,delete l.getDimensionValue;var c=(0,P.default)(this.handleEnter,e),f=(0,P.default)(this.handleEntering,n),d=(0,P.default)(this.handleEntered,r),p=(0,P.default)(this.handleExit,o),h=(0,P.default)(this.handleExiting,i),g={width:"width"===this._dimension()};return _.default.createElement(T.default,(0,s.default)({},l,{"aria-expanded":l.role?l.in:null,className:(0,m.default)(a,g),exitedClassName:"collapse",exitingClassName:"collapsing",enteredClassName:"collapse in",enteringClassName:"collapsing",onEnter:c,onEntering:f,onEntered:d,onExit:p,onExiting:h}))},e}(_.default.Component);A.propTypes=M,A.defaultProps=N,e.default=A,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b={glyph:m.default.PropTypes.string.isRequired},x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.glyph,r=e.className,o=(0,s.default)(e,["glyph","className"]),a=(0,y.splitBsProps)(o),l=a[0],u=a[1],c=(0,i.default)({},(0,y.getClassSet)(l),(t={},t[(0,y.prefix)(l,n)]=!0,t));return m.default.createElement("span",(0,i.default)({},u,{className:(0,g.default)(r,c)}))},e}(m.default.Component);x.propTypes=b,e.default=(0,y.bsClass)("glyphicon",x),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(245),_=r(x),w=n(246),T=r(w),C=n(247),k=r(C),E=n(248),P=r(E),S=n(249),M=r(S),N=n(250),A=r(N),O=n(8),D={componentClass:b.default},I={componentClass:"div"},R=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,O.splitBsProps)(r),a=o[0],l=o[1],u=(0,O.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);R.propTypes=D,R.defaultProps=I,R.Heading=T.default,R.Body=_.default,R.Left=k.default,R.Right=A.default,R.List=P.default,R.ListItem=M.default,e.default=(0,O.bsClass)("media",R),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(7),i=r(o),a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(1),p=r(d),h=n(55),g=r(h),v="tab",m="pane",y=d.PropTypes.oneOfType([d.PropTypes.string,d.PropTypes.number]),b={id:function(t){var e=null;if(!t.generateChildId){for(var n=arguments.length,r=Array(n>1?n-1:0),o=1;o<n;o++)r[o-1]=arguments[o];e=y.apply(void 0,[t].concat(r)),e||t.id||(e=new Error("In order to properly initialize Tabs in a way that is accessible to assistive technologies (such as screen readers) an `id` or a `generateChildId` prop to TabContainer is required"))}return e},generateChildId:d.PropTypes.func,onSelect:d.PropTypes.func,activeKey:d.PropTypes.any},x={$bs_tabContainer:p.default.PropTypes.shape({activeKey:d.PropTypes.any,onSelect:d.PropTypes.func.isRequired,getTabId:d.PropTypes.func.isRequired,getPaneId:d.PropTypes.func.isRequired})},_=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.getChildContext=function(){var t=this.props,e=t.activeKey,n=t.onSelect,r=t.generateChildId,o=t.id,i=r||function(t,e){return o?o+"-"+e+"-"+t:null};return{$bs_tabContainer:{activeKey:e,onSelect:n,getTabId:function(t){return i(t,v)},getPaneId:function(t){return i(t,m)}}}},e.prototype.render=function(){var t=this.props,e=t.children,n=(0,i.default)(t,["children"]);return delete n.generateChildId,delete n.onSelect,delete n.activeKey,p.default.cloneElement(p.default.Children.only(e),n)},e}(p.default.Component);_.propTypes=b,_.childContextTypes=x,e.default=(0,g.default)(_,{activeKey:"onSelect"}),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={componentClass:b.default,animation:v.PropTypes.oneOfType([v.PropTypes.bool,b.default]),unmountOnExit:v.PropTypes.bool},w={componentClass:"div",animation:!0,unmountOnExit:!1},T={$bs_tabContainer:v.PropTypes.shape({activeKey:v.PropTypes.any})},C={$bs_tabContent:v.PropTypes.shape({bsClass:v.PropTypes.string,animation:v.PropTypes.oneOfType([v.PropTypes.bool,b.default]),activeKey:v.PropTypes.any,unmountOnExit:v.PropTypes.bool,onPaneEnter:v.PropTypes.func.isRequired,onPaneExited:v.PropTypes.func.isRequired,exiting:v.PropTypes.bool.isRequired})},k=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handlePaneEnter=o.handlePaneEnter.bind(o),o.handlePaneExited=o.handlePaneExited.bind(o),o.state={activeKey:null,activeChild:null},o}return(0,p.default)(e,t),e.prototype.getChildContext=function(){var t=this.props,e=t.bsClass,n=t.animation,r=t.unmountOnExit,o=this.state.activeKey,i=this.getContainerActiveKey(),a=null!=o?o:i,s=null!=o&&o!==i;return{$bs_tabContent:{bsClass:e,animation:n,activeKey:a,unmountOnExit:r,onPaneEnter:this.handlePaneEnter,onPaneExited:this.handlePaneExited,exiting:s}}},e.prototype.componentWillReceiveProps=function(t){!t.animation&&this.state.activeChild&&this.setState({activeKey:null,activeChild:null})},e.prototype.componentWillUnmount=function(){this.isUnmounted=!0},e.prototype.handlePaneEnter=function(t,e){return!!this.props.animation&&e===this.getContainerActiveKey()&&(this.setState({activeKey:e,activeChild:t}),!0)},e.prototype.handlePaneExited=function(t){this.isUnmounted||this.setState(function(e){var n=e.activeChild;return n!==t?null:{activeKey:null,activeChild:null}})},e.prototype.getContainerActiveKey=function(){var t=this.context.$bs_tabContainer;return t&&t.activeKey},e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsPropsAndOmit)(r,["animation","unmountOnExit"]),a=o[0],l=o[1];return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,(0,x.prefix)(a,"content"))}))},e}(m.default.Component);k.propTypes=_,k.defaultProps=w,k.contextTypes=T,k.childContextTypes=C,e.default=(0,x.bsClass)("tab",k),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){return t="function"==typeof t?t():t,a.default.findDOMNode(t)||e}Object.defineProperty(e,"__esModule",{value:!0}),e.default=o;var i=n(11),a=r(i);t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n,r,o){var a=t[e],l="undefined"==typeof a?"undefined":i(a);return s.default.isValidElement(a)?new Error("Invalid "+r+" `"+o+"` of type ReactElement "+("supplied to `"+n+"`, expected a ReactComponent or a ")+"DOMElement. You can usually obtain a ReactComponent or DOMElement from a ReactElement by attaching a ref to it."):"object"===l&&"function"==typeof a.render||1===a.nodeType?null:new Error("Invalid "+r+" `"+o+"` of value `"+a+"` "+("supplied to `"+n+"`, expected a ReactComponent or a ")+"DOMElement.")}e.__esModule=!0;var i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol?"symbol":typeof t},a=n(1),s=r(a),l=n(53),u=r(l);e.default=(0,u.default)(o)},function(t,e,n){(function(t){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.Table=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}();n(298);var l=n(1),u=r(l);n(110),t.dataTable=n(110),e.Table=function(e){function n(t){o(this,n);var e=i(this,(n.__proto__||Object.getPrototypeOf(n)).call(this,t));return e.state={columns:[]},e}return a(n,e),s(n,[{key:"componentWillMount",value:function(){this._initialize()}},{key:"_initialize",value:function(){var e=this.props.options.url.concat("?",t.param(this.props.options.params));t.get(e,function(e){this.setState({columns:e.columns});var n=this.props.options.table_options;n.data=e.data,n.columns=e.columns,n.aaData=e.data,"columnDefs"in this.props.options.table_options&&(n.columnDefs=this.props.options.table_options.columnDefs,n.columnDefs.forEach(function(t){t.render=new Function("return '"+t.render+"';")})),n.initComplete=new Function("settings","json",this.props.options.table_options.initComplete),n.drawCallback=new Function("settings",this.props.options.table_options.drawCallback),t("#".concat(this.props.options.id)).dataTable(n)}.bind(this))}},{key:"_update",value:function(e){var n=t("#".concat(this.props.options.id)).dataTable();n.api().ajax.url(this.props.options.url.concat("?",t.param(e))).load()}},{key:"render",value:function(){var t=this.state.columns.map(function(t,e){return u.default.createElement("th",{key:e},t.data)});return u.default.createElement("div",null,u.default.createElement("table",{id:this.props.options.id,className:this.props.options.className,cellPadding:"0",cellSpacing:"0",width:"100%"},u.default.createElement("thead",null,u.default.createElement("tr",null,t))))}}]),n}(u.default.Component)}).call(e,n(14))},function(t,e,n){(function(t){"use strict";function i(t){return t&&t.__esModule?t:{default:t}}function a(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function s(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function l(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.MetricsGraphics=void 0;var u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}();n(299);var c=n(1),f=i(c);e.MetricsGraphics=function(e){function n(t){return a(this,n),s(this,(n.__proto__||Object.getPrototypeOf(n)).call(this,t))}return l(n,e),u(n,[{key:"componentDidMount",value:function(){this._initialize(this.props.options.params.init_params)}},{key:"_initialize",value:function(e){r.json(this.props.options.url.concat("?",t.param(e)),function(t,e){var n=this.props.options.params;if(e.date)for(var r=0;r<e.result.length;r++)e.result[r]=o.convert.date(e.result[r],"x",this.props.options.date_format);n.data=e.result,o.data_graphic(n)}.bind(this))}},{key:"_update",value:function(e){r.json(this.props.options.url.concat("?",t.param(e)),function(t,e){var n=this.props.options.params;if(e.date)for(var r=0;r<e.result.length;r++)e.result[r]=o.convert.date(e.result[r],"x",this.props.options.date_format);n.data=e.result,o.data_graphic(n)}.bind(this))}},{key:"render",value:function(){var t={width:this.props.options.params.width};return f.default.createElement("div",{id:this.props.options.chart_id,style:t})}}]),n}(f.default.Component)}).call(e,n(14))},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.NVD3Chart=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}();n(300);var l=n(1),u=r(l),c=n(148),f=r(c),d=n(147),p=r(d),h=function t(e,n){var r;if("function"!=typeof t[e])throw new Error(e+" is not a valid NVD3 type.");return t.prototype=t[e].prototype,r=new t[e],r.initialize(n),r};h.TwoAxisFocus=f.default,h.PieChart=p.default,e.NVD3Chart=function(t){function e(t){o(this,e);var n=i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t));return n.state={chart:null},n}return a(e,t),s(e,[{key:"componentWillMount",value:function(){this.setState({chart:this._initialize(this.state.chart)})}},{key:"_initialize",value:function(t){return t=h(this.props.options.type,this.props.options),t.get(this.props.options.chartid,this.props.options.url,this.props.options.init_params),t}},{key:"_update",value:function(t){this.state.chart.get(this.props.options.chartid,this.props.options.url,t)}},{key:"render",value:function(){return u.default.createElement("div",{id:this.props.options.chartid},u.default.createElement("svg",null))}}]),e}(u.default.Component)},function(t,e,n){(function(t){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.PlotlyAPI=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(11);r(c),e.PlotlyAPI=function(e){function n(t){return o(this,n),i(this,(n.__proto__||Object.getPrototypeOf(n)).call(this,t))}return a(n,e),s(n,[{key:"_update",value:function(e){var n=this.props.options.url.concat("?",t.param(e));t.get(n,function(t){Plotly.newPlot(this.props.options.chartid,t.data,t.layout,t.config)}.bind(this))}},{key:"componentDidMount",value:function(){this._update(this.props.options.params)}},{key:"render",value:function(){return u.default.createElement("div",null,u.default.createElement("div",{id:this.props.options.chartid}))}}]),n}(u.default.Component)}).call(e,n(14))},function(t,e,n){(function(t){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.ApiButton=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(33),f=(r(c),n(43));e.ApiButton=function(e){function n(t){o(this,n);var e=i(this,(n.__proto__||Object.getPrototypeOf(n)).call(this,t));return e.state={items:[]},e}return a(n,e),s(n,[{key:"getCurrentState",value:function(){return this.refs.apiBtn.getCurrentState()}},{key:"componentDidMount",value:function(){this._fetchAPIData({})}},{key:"_fetchAPIData",value:function(e){t.get(this.props.options.url.concat("?",t.param(e)),function(t){this.setState({items:t.data})}.bind(this))}},{key:"update",value:function(t){this._fetchAPIData(t)}},{key:"render",value:function(){var t={items:this.state.items,alias:this.props.options.alias,default:this.props.options.default,label:this.props.options.label};return u.default.createElement(f.SelectButton,{ref:"apiBtn",id:this.props.id,onChange:this.props.onChange,options:t})}}]),n}(u.default.Component)}).call(e,n(14))},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.CheckboxGroup=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(22);e.CheckboxGroup=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"getCurrentState",value:function(){for(var t={},e=0;e<this.props.options.labels.length;e++)t[this.props.options.aliases[e]]=this.refs["checkbox_".concat(e)].getChecked();return t}},{key:"_resetChecked",value:function(){for(var t=0;t<this.props.options.labels.length;t++)this.refs["checkbox_".concat(t)].getInputDOMNode().checked=!1}},{key:"render",value:function(){var t=this.props.options.labels.map(function(t,e){return u.default.createElement(c.Input,{ref:"checkbox_".concat(e),type:"checkbox",label:t})});return u.default.createElement("div",{className:"inputgrp"},u.default.createElement("div",{className:"btn-group horizontal"},u.default.createElement(c.Button,{onClick:this.props.onChange.bind(this)},"Submit"),u.default.createElement(c.Button,{onClick:this._resetChecked.bind(this)},"Reset")),t)}}]),e}(u.default.Component)},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.ConditionalSelectButton=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(33),f=r(c),d=n(43),p=n(22);e.ConditionalSelectButton=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"_handleClick",value:function(t,e,n){this.setState({selected:t,value:e});var r=[{alias:this.props.options.aliases[0],value:e},{alias:this.props.options.aliases[1],value:"All"}];this.props.onChange(r),this.refs.secondary.setState({value:"All"})}},{key:"getCurrentState",value:function(){var t={};return t[this.props.options.aliases[0]]=this.state.value||this.props.options.defaults[0],t[this.props.options.aliases[1]]=this.refs.secondary.state.value||this.props.options.defaults[1],t}},{key:"render",value:function(){var t=this.props.options.items.map(function(t,e){return u.default.createElement(p.MenuItem,{key:e,onSelect:this._handleClick.bind(this,e,t.primary)},t.primary)}.bind(this)),e=this.state.value||this.props.options.labels[0],n={items:this.props.options.items[this.state.selected].secondary,label:this.props.options.labels[1],alias:this.props.options.aliases[1],default:this.props.options.defaults[1]};return u.default.createElement("div",null,u.default.createElement(p.DropdownButton,{id:this.props.id,ref:"primary",title:e},t),u.default.createElement(d.SelectButton,{ref:"secondary",onChange:this.props.onChange,options:n}))}}]),e}(f.default)},function(t,e,n){(function(t){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.DownloadButton=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(22),f=n(33),d=r(f);e.DownloadButton=function(e){function n(t){return o(this,n),i(this,(n.__proto__||Object.getPrototypeOf(n)).call(this,t))}return a(n,e),s(n,[{key:"_onClick",value:function(){var e=this.props.onChange(),n=this.props.options.url.concat("?",t.param(e));window.location.href=n}},{key:"render",value:function(){return u.default.createElement(c.Button,{onClick:this._onClick.bind(this)},this.props.options.label)}}]),n}(d.default)}).call(e,n(14))},function(t,e,n){(function(t){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.DynamicSearchInput=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(11),f=(r(c),n(22)),d=n(6),p=(r(d),function(t){function e(t){o(this,e);var n=i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t));return n.state={value:""},n.onChange=function(t){return n.setState({value:t.target.value})},n}return a(e,t),s(e,[{key:"filterChildren",value:function(){var t=this.props.children,e=[];return u.default.Children.forEach(t,function(t){e.push(t)}),e}},{key:"render",value:function(){return u.default.createElement("ul",{className:"dropdown-menu"},this.filterChildren())}}]),e}(u.default.Component));e.DynamicSearchInput=function(e){function n(t){o(this,n);var e=i(this,(n.__proto__||Object.getPrototypeOf(n)).call(this,t));return e.state={value:null,searchString:"",items:[]},e}return a(n,e),s(n,[{key:"getCurrentState",value:function(){var t={};return t[this.props.options.alias]=this.state.value||this.props.options.default,t}},{key:"_fetchAPIData",value:function(e){var n=this.props.options.url.concat("?",t.param(e));t.get(n,function(t){this.setState({items:t.data})}.bind(this))}},{key:"update",value:function(t){this._fetchAPIData(t)}},{key:"componentDidMount",value:function(){this._fetchAPIData({})}},{key:"_handleItemSelect",value:function(t,e){this.setState({value:t}),this.dd.refs.inner.toggleOpen(!1);var n={alias:this.props.options.alias,value:t};this.props.onChange([n])}},{key:"_filterItems",value:function(){var t=this.state.items,e=this.state.searchString.trim().toLowerCase();e.length>0&&(t=t.filter(function(t){return t.toLowerCase().match(e)}));var n=t.length,r="Results Left: #";return t.map(function(t,e){return e<this.props.options.max?u.default.createElement(f.MenuItem,{key:e,onSelect:this._handleItemSelect.bind(this,t)},t):e==this.props.options.max?u.default.createElement(f.MenuItem,{key:e},r.replace("#",n-e)):void 0}.bind(this))}},{key:"_handleChange",value:function(t){this.setState({searchString:t.target.value,value:t.target.value})}},{key:"render",value:function(){var t=this;return u.default.createElement(f.Dropdown,{id:"dropdown-custom-menu",ref:function(e){return t.dd=e}},u.default.createElement(f.Input,{bsRole:"toggle",type:"text",ref:"input",value:this.state.value,placeholder:this.props.options.placeholder,help:this.props.options.help,onChange:this._handleChange.bind(this)}),u.default.createElement(p,{placeholder:this.props.options.placeholder,bsRole:"menu"},this._filterItems()))}}]),n}(u.default.Component)}).call(e,n(14))},function(t,e,n){(function(t){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.ReactSelect=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(54),f=r(c);n(301);var d=function(e){function n(t){o(this,n);var e=i(this,(n.__proto__||Object.getPrototypeOf(n)).call(this,t));return e.state={options:[],value:null},e}return a(n,e),s(n,[{key:"_fetch",value:function(e){var n=this.props.options.url.concat("?",t.param(e));t.get(n,function(t){this.setState({options:t.data})}.bind(this))}},{key:"componentWillMount",value:function(){this._fetch({})}},{key:"update",value:function(t){this._fetch(t)}},{key:"getCurrentState",value:function(){var t={},e=this.state.value?this.state.value:this.props.options.default;return t[this.props.options.alias]=e,t}},{key:"handleSelectChange",value:function(t){this.setState({value:t});var e={alias:this.props.options.alias,value:t};this.props.onChange([e])}},{key:"render",value:function(){var t=this.props.options.options;return t.value=this.state.value,t.onChange=this.handleSelectChange.bind(this),t.options=this.state.options,u.default.createElement(f.default,t)}}]),n}(u.default.Component);d.defaultProps={options:{autosize:!0,style:{width:"200px",float:"left"},joinValues:!0,delimiter:"|",simpleValue:!0}},e.ReactSelect=d}).call(e,n(14))},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);
t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.SliderInput=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(11),f=r(c),d=n(33),p=r(d);e.SliderInput=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"_handleChange",value:function(){var t=f.default.findDOMNode(this);this.setState({value:t.value});var e={alias:this.props.options.alias,value:t.value};this.props.onChange([e])}},{key:"render",value:function(){return u.default.createElement("input",{id:"pyx-slider",className:"pyx-slider",ref:"slider",type:"range",name:this.props.options.label,min:this.props.options.min,max:this.props.options.max,onInput:this._handleChange.bind(this),step:this.props.options.step})}}]),e}(p.default)},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.FilterChart=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(22),f=n(57),d=n(56),p=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"_gatherParams",value:function(t){for(var e={},n=0;n<this.props.filters.length;n++){var r="filter_".concat(n),o=this.refs[r].refs.filter.getCurrentState();for(var i in o)e[i]=o[i]}if(t)for(var n=0;n<t.length;n++)e[t[n].alias]=t[n].value;return e}},{key:"_handleClick",value:function(t){for(var e=this._gatherParams(t),n=0;n<this.props.charts.length;n++)this.refs["chart_".concat(n)].update(e);for(var n=0;n<this.props.filters.length;n++){var r="filter_".concat(n);"function"==typeof this.refs[r].refs.filter.update&&this.refs[r].refs.filter.update(e)}return e}},{key:"get_filters",value:function(t,e){var n=[];return t.length>0&&(n=t.map(function(t,n){return u.default.createElement(f.Filter,{key:"filter_".concat(n,"_",e),ref:"filter_".concat(n),id:"filter_".concat(n),onChange:this._handleClick.bind(this),type:t.type,options:t.options})}.bind(this))),n}},{key:"get_charts",value:function(t){var e=[];return t.length>0&&(e=t.map(function(t,e){return u.default.createElement(d.Chart,{ref:"chart_".concat(e),id:"chart_".concat(e),key:"chart_".concat(e),type:t.type,options:t.options})})),e}},{key:"render",value:function(){var t=[];for(var e in this.props.filters){var n=this.get_filters(this.props.filters[e],e);t.push(u.default.createElement("div",{className:e},n))}var r=this.get_charts(this.props.charts);return u.default.createElement(c.Grid,null,u.default.createElement(c.Col,{xs:6,md:2},t),u.default.createElement(c.Col,{xs:12,md:10},r))}}]),e}(u.default.Component);e.FilterChart=p},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.SimpleChart=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(22),f=n(57),d=n(56),p=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"_gatherParams",value:function(t){for(var e={},n=0;n<this.props.filters.length;n++){var r="filter_".concat(n),o=this.refs[r].refs.filter.getCurrentState();for(var i in o)e[i]=o[i]}if(t)for(var n=0;n<t.length;n++)e[t[n].alias]=t[n].value;return e}},{key:"_handleClick",value:function(t){for(var e=this._gatherParams(t),n=0;n<this.props.charts.length;n++)this.refs["chart_".concat(n)].update(e);for(var n=0;n<this.props.filters.length;n++){var r="filter_".concat(n);"function"==typeof this.refs[r].refs.filter.update&&this.refs[r].refs.filter.update(e)}return e}},{key:"get_filters",value:function(t,e){var n=[];return t.length>0&&(n=t.map(function(t,n){return u.default.createElement(f.Filter,{key:"filter_".concat(n,"_",e),ref:"filter_".concat(n),id:"filter_".concat(n),onChange:this._handleClick.bind(this),type:t.type,options:t.options})}.bind(this))),n}},{key:"get_charts",value:function(t){var e=[];return t.length>0&&(e=t.map(function(t,e){return u.default.createElement(d.Chart,{ref:"chart_".concat(e),id:"chart_".concat(e),key:"chart_".concat(e),type:t.type,options:t.options})})),e}},{key:"render",value:function(){var t=[];for(var e in this.props.filters){var n=this.get_filters(this.props.filters[e],e);t.push(u.default.createElement("div",{className:e},n))}var r=this.get_charts(this.props.charts);return u.default.createElement(c.Grid,null,u.default.createElement(c.Row,null,t),u.default.createElement(c.Row,null,r))}}]),e}(u.default.Component);e.SimpleChart=p},function(t,e,n){t.exports={default:n(157),__esModule:!0}},function(t,e,n){t.exports={default:n(159),__esModule:!0}},function(t,e,n){var r=n(35),o=n(20).document,i=r(o)&&r(o.createElement);t.exports=function(t){return i?o.createElement(t):{}}},function(t,e,n){t.exports=!n(28)&&!n(34)(function(){return 7!=Object.defineProperty(n(99)("div"),"a",{get:function(){return 7}}).a})},function(t,e,n){var r=n(59);t.exports=Object("z").propertyIsEnumerable(0)?Object:function(t){return"String"==r(t)?t.split(""):Object(t)}},function(t,e,n){"use strict";var r=n(63),o=n(19),i=n(107),a=n(29),s=n(23),l=n(36),u=n(174),c=n(66),f=n(182),d=n(17)("iterator"),p=!([].keys&&"next"in[].keys()),h="@@iterator",g="keys",v="values",m=function(){return this};t.exports=function(t,e,n,y,b,x,_){u(n,e,y);var w,T,C,k=function(t){if(!p&&t in M)return M[t];switch(t){case g:return function(){return new n(this,t)};case v:return function(){return new n(this,t)}}return function(){return new n(this,t)}},E=e+" Iterator",P=b==v,S=!1,M=t.prototype,N=M[d]||M[h]||b&&M[b],A=N||k(b),O=b?P?k("entries"):A:void 0,D="Array"==e?M.entries||N:N;if(D&&(C=f(D.call(new t)),C!==Object.prototype&&(c(C,E,!0),r||s(C,d)||a(C,d,m))),P&&N&&N.name!==v&&(S=!0,A=function(){return N.call(this)}),r&&!_||!p&&!S&&M[d]||a(M,d,A),l[e]=A,l[E]=m,b)if(w={values:P?A:k(v),keys:x?A:k(g),entries:O},_)for(T in w)T in M||i(M,T,w[T]);else o(o.P+o.F*(p||S),e,w);return w}},function(t,e,n){var r=n(37),o=n(38),i=n(21),a=n(71),s=n(23),l=n(100),u=Object.getOwnPropertyDescriptor;e.f=n(28)?u:function(t,e){if(t=i(t),e=a(e,!0),l)try{return u(t,e)}catch(t){}if(s(t,e))return o(!r.f.call(t,e),t[e])}},function(t,e,n){var r=n(105),o=n(62).concat("length","prototype");e.f=Object.getOwnPropertyNames||function(t){return r(t,o)}},function(t,e,n){var r=n(23),o=n(21),i=n(166)(!1),a=n(67)("IE_PROTO");t.exports=function(t,e){var n,s=o(t),l=0,u=[];for(n in s)n!=a&&r(s,n)&&u.push(n);for(;e.length>l;)r(s,n=e[l++])&&(~i(u,n)||u.push(n));return u}},function(t,e,n){var r=n(30),o=n(21),i=n(37).f;t.exports=function(t){return function(e){for(var n,a=o(e),s=r(a),l=s.length,u=0,c=[];l>u;)i.call(a,n=s[u++])&&c.push(t?[n,a[n]]:a[n]);return c}}},function(t,e,n){t.exports=n(29)},function(t,e,n){var r=n(69),o=Math.min;t.exports=function(t){return t>0?o(r(t),9007199254740991):0}},function(t,e,n){"use strict";var r=n(184)(!0);n(102)(String,"String",function(t){this._t=String(t),this._i=0},function(){var t,e=this._t,n=this._i;return n>=e.length?{value:void 0,done:!0}:(t=r(e,n),this._i+=t.length,{value:t,done:!1})})},function(t,e,n){var r,o;/*! DataTables 1.10.13
		 * ©2008-2016 SpryMedia Ltd - datatables.net/license
		 */
!function(i){"use strict";r=[n(14)],o=function(t){return i(t,window,document)}.apply(e,r),!(void 0!==o&&(t.exports=o))}(function(t,e,n,r){"use strict";function o(e){var n,r,i="a aa ai ao as b fn i m o s ",a={};t.each(e,function(t,s){n=t.match(/^([^A-Z]+?)([A-Z])/),n&&i.indexOf(n[1]+" ")!==-1&&(r=t.replace(n[0],n[2].toLowerCase()),a[r]=t,"o"===n[1]&&o(e[t]))}),e._hungarianMap=a}function i(e,n,a){e._hungarianMap||o(e);var s;t.each(n,function(o,l){s=e._hungarianMap[o],s===r||!a&&n[s]!==r||("o"===s.charAt(0)?(n[s]||(n[s]={}),t.extend(!0,n[s],n[o]),i(e[s],n[s],a)):n[s]=n[o])})}function a(t){var e=Gt.defaults.oLanguage,n=t.sZeroRecords;!t.sEmptyTable&&n&&"No data available in table"===e.sEmptyTable&&Dt(t,t,"sZeroRecords","sEmptyTable"),!t.sLoadingRecords&&n&&"Loading..."===e.sLoadingRecords&&Dt(t,t,"sZeroRecords","sLoadingRecords"),t.sInfoThousands&&(t.sThousands=t.sInfoThousands);var r=t.sDecimal;r&&zt(r)}function s(t){pe(t,"ordering","bSort"),pe(t,"orderMulti","bSortMulti"),pe(t,"orderClasses","bSortClasses"),pe(t,"orderCellsTop","bSortCellsTop"),pe(t,"order","aaSorting"),pe(t,"orderFixed","aaSortingFixed"),pe(t,"paging","bPaginate"),pe(t,"pagingType","sPaginationType"),pe(t,"pageLength","iDisplayLength"),pe(t,"searching","bFilter"),"boolean"==typeof t.sScrollX&&(t.sScrollX=t.sScrollX?"100%":""),"boolean"==typeof t.scrollX&&(t.scrollX=t.scrollX?"100%":"");var e=t.aoSearchCols;if(e)for(var n=0,r=e.length;n<r;n++)e[n]&&i(Gt.models.oSearch,e[n])}function l(e){pe(e,"orderable","bSortable"),pe(e,"orderData","aDataSort"),pe(e,"orderSequence","asSorting"),pe(e,"orderDataType","sortDataType");var n=e.aDataSort;n&&!t.isArray(n)&&(e.aDataSort=[n])}function u(n){if(!Gt.__browser){var r={};Gt.__browser=r;var o=t("<div/>").css({position:"fixed",top:0,left:t(e).scrollLeft()*-1,height:1,width:1,overflow:"hidden"}).append(t("<div/>").css({position:"absolute",top:1,left:1,width:100,overflow:"scroll"}).append(t("<div/>").css({width:"100%",height:10}))).appendTo("body"),i=o.children(),a=i.children();r.barWidth=i[0].offsetWidth-i[0].clientWidth,r.bScrollOversize=100===a[0].offsetWidth&&100!==i[0].clientWidth,r.bScrollbarLeft=1!==Math.round(a.offset().left),r.bBounding=!!o[0].getBoundingClientRect().width,o.remove()}t.extend(n.oBrowser,Gt.__browser),n.oScroll.iBarWidth=Gt.__browser.barWidth}function c(t,e,n,o,i,a){var s,l=o,u=!1;for(n!==r&&(s=n,u=!0);l!==i;)t.hasOwnProperty(l)&&(s=u?e(s,t[l],l,t):t[l],u=!0,l+=a);return s}function f(e,r){var o=Gt.defaults.column,i=e.aoColumns.length,a=t.extend({},Gt.models.oColumn,o,{nTh:r?r:n.createElement("th"),sTitle:o.sTitle?o.sTitle:r?r.innerHTML:"",aDataSort:o.aDataSort?o.aDataSort:[i],mData:o.mData?o.mData:i,idx:i});e.aoColumns.push(a);var s=e.aoPreSearchCols;s[i]=t.extend({},Gt.models.oSearch,s[i]),d(e,i,t(r).data())}function d(e,n,o){var a=e.aoColumns[n],s=e.oClasses,u=t(a.nTh);if(!a.sWidthOrig){a.sWidthOrig=u.attr("width")||null;var c=(u.attr("style")||"").match(/width:\s*(\d+[pxem%]+)/);c&&(a.sWidthOrig=c[1])}o!==r&&null!==o&&(l(o),i(Gt.defaults.column,o),o.mDataProp===r||o.mData||(o.mData=o.mDataProp),o.sType&&(a._sManualType=o.sType),o.className&&!o.sClass&&(o.sClass=o.className),t.extend(a,o),Dt(a,o,"sWidth","sWidthOrig"),o.iDataSort!==r&&(a.aDataSort=[o.iDataSort]),Dt(a,o,"aDataSort"));var f=a.mData,d=P(f),p=a.mRender?P(a.mRender):null,h=function(t){return"string"==typeof t&&t.indexOf("@")!==-1};a._bAttrSrc=t.isPlainObject(f)&&(h(f.sort)||h(f.type)||h(f.filter)),a._setter=null,a.fnGetData=function(t,e,n){var o=d(t,e,r,n);return p&&e?p(o,e,t,n):o},a.fnSetData=function(t,e,n){return S(f)(t,e,n)},"number"!=typeof f&&(e._rowReadObject=!0),e.oFeatures.bSort||(a.bSortable=!1,u.addClass(s.sSortableNone));var g=t.inArray("asc",a.asSorting)!==-1,v=t.inArray("desc",a.asSorting)!==-1;a.bSortable&&(g||v)?g&&!v?(a.sSortingClass=s.sSortableAsc,a.sSortingClassJUI=s.sSortJUIAscAllowed):!g&&v?(a.sSortingClass=s.sSortableDesc,a.sSortingClassJUI=s.sSortJUIDescAllowed):(a.sSortingClass=s.sSortable,a.sSortingClassJUI=s.sSortJUI):(a.sSortingClass=s.sSortableNone,a.sSortingClassJUI="")}function p(t){if(t.oFeatures.bAutoWidth!==!1){var e=t.aoColumns;mt(t);for(var n=0,r=e.length;n<r;n++)e[n].nTh.style.width=e[n].sWidth}var o=t.oScroll;""===o.sY&&""===o.sX||gt(t),Ft(t,null,"column-sizing",[t])}function h(t,e){var n=m(t,"bVisible");return"number"==typeof n[e]?n[e]:null}function g(e,n){var r=m(e,"bVisible"),o=t.inArray(n,r);return o!==-1?o:null}function v(e){var n=0;return t.each(e.aoColumns,function(e,r){r.bVisible&&"none"!==t(r.nTh).css("display")&&n++}),n}function m(e,n){var r=[];return t.map(e.aoColumns,function(t,e){t[n]&&r.push(e)}),r}function y(t){var e,n,o,i,a,s,l,u,c,f=t.aoColumns,d=t.aoData,p=Gt.ext.type.detect;for(e=0,n=f.length;e<n;e++)if(l=f[e],c=[],!l.sType&&l._sManualType)l.sType=l._sManualType;else if(!l.sType){for(o=0,i=p.length;o<i;o++){for(a=0,s=d.length;a<s&&(c[a]===r&&(c[a]=C(t,a,e,"type")),u=p[o](c[a],t),u||o===p.length-1)&&"html"!==u;a++);if(u){l.sType=u;break}}l.sType||(l.sType="string")}}function b(e,n,o,i){var a,s,l,u,c,d,p,h=e.aoColumns;if(n)for(a=n.length-1;a>=0;a--){p=n[a];var g=p.targets!==r?p.targets:p.aTargets;for(t.isArray(g)||(g=[g]),l=0,u=g.length;l<u;l++)if("number"==typeof g[l]&&g[l]>=0){for(;h.length<=g[l];)f(e);i(g[l],p)}else if("number"==typeof g[l]&&g[l]<0)i(h.length+g[l],p);else if("string"==typeof g[l])for(c=0,d=h.length;c<d;c++)("_all"==g[l]||t(h[c].nTh).hasClass(g[l]))&&i(c,p)}if(o)for(a=0,s=o.length;a<s;a++)i(a,o[a])}function x(e,n,o,i){var a=e.aoData.length,s=t.extend(!0,{},Gt.models.oRow,{src:o?"dom":"data",idx:a});s._aData=n,e.aoData.push(s);for(var l=e.aoColumns,u=0,c=l.length;u<c;u++)l[u].sType=null;e.aiDisplayMaster.push(a);var f=e.rowIdFn(n);return f!==r&&(e.aIds[f]=s),!o&&e.oFeatures.bDeferRender||I(e,a,o,i),a}function _(e,n){var r;return n instanceof t||(n=t(n)),n.map(function(t,n){return r=D(e,n),x(e,r.data,n,r.cells)})}function w(t,e){return e._DT_RowIndex!==r?e._DT_RowIndex:null}function T(e,n,r){return t.inArray(r,e.aoData[n].anCells)}function C(t,e,n,o){var i=t.iDraw,a=t.aoColumns[n],s=t.aoData[e]._aData,l=a.sDefaultContent,u=a.fnGetData(s,o,{settings:t,row:e,col:n});if(u===r)return t.iDrawError!=i&&null===l&&(Ot(t,0,"Requested unknown parameter "+("function"==typeof a.mData?"{function}":"'"+a.mData+"'")+" for row "+e+", column "+n,4),t.iDrawError=i),l;if(u!==s&&null!==u||null===l||o===r){if("function"==typeof u)return u.call(s)}else u=l;return null===u&&"display"==o?"":u}function k(t,e,n,r){var o=t.aoColumns[n],i=t.aoData[e]._aData;o.fnSetData(i,r,{settings:t,row:e,col:n})}function E(e){return t.map(e.match(/(\\.|[^\.])+/g)||[""],function(t){return t.replace(/\\\./g,".")})}function P(e){if(t.isPlainObject(e)){var n={};return t.each(e,function(t,e){e&&(n[t]=P(e))}),function(t,e,o,i){var a=n[e]||n._;return a!==r?a(t,e,o,i):t}}if(null===e)return function(t){return t};if("function"==typeof e)return function(t,n,r,o){return e(t,n,r,o)};if("string"!=typeof e||e.indexOf(".")===-1&&e.indexOf("[")===-1&&e.indexOf("(")===-1)return function(t,n){return t[e]};var o=function(e,n,i){var a,s,l,u;if(""!==i)for(var c=E(i),f=0,d=c.length;f<d;f++){if(a=c[f].match(he),s=c[f].match(ge),a){if(c[f]=c[f].replace(he,""),""!==c[f]&&(e=e[c[f]]),l=[],c.splice(0,f+1),u=c.join("."),t.isArray(e))for(var p=0,h=e.length;p<h;p++)l.push(o(e[p],n,u));var g=a[0].substring(1,a[0].length-1);e=""===g?l:l.join(g);break}if(s)c[f]=c[f].replace(ge,""),e=e[c[f]]();else{if(null===e||e[c[f]]===r)return r;e=e[c[f]]}}return e};return function(t,n){return o(t,n,e)}}function S(e){if(t.isPlainObject(e))return S(e._);if(null===e)return function(){};if("function"==typeof e)return function(t,n,r){e(t,"set",n,r)};if("string"!=typeof e||e.indexOf(".")===-1&&e.indexOf("[")===-1&&e.indexOf("(")===-1)return function(t,n){t[e]=n};var n=function(e,o,i){for(var a,s,l,u,c,f=E(i),d=f[f.length-1],p=0,h=f.length-1;p<h;p++){if(s=f[p].match(he),l=f[p].match(ge),s){if(f[p]=f[p].replace(he,""),e[f[p]]=[],a=f.slice(),a.splice(0,p+1),c=a.join("."),t.isArray(o))for(var g=0,v=o.length;g<v;g++)u={},n(u,o[g],c),e[f[p]].push(u);else e[f[p]]=o;return}l&&(f[p]=f[p].replace(ge,""),e=e[f[p]](o)),null!==e[f[p]]&&e[f[p]]!==r||(e[f[p]]={}),e=e[f[p]]}d.match(ge)?e=e[d.replace(ge,"")](o):e[d.replace(he,"")]=o};return function(t,r){return n(t,r,e)}}function M(t){return se(t.aoData,"_aData")}function N(t){t.aoData.length=0,t.aiDisplayMaster.length=0,t.aiDisplay.length=0,t.aIds={}}function A(t,e,n){for(var o=-1,i=0,a=t.length;i<a;i++)t[i]==e?o=i:t[i]>e&&t[i]--;o!=-1&&n===r&&t.splice(o,1)}function O(t,e,n,o){var i,a,s=t.aoData[e],l=function(n,r){for(;n.childNodes.length;)n.removeChild(n.firstChild);n.innerHTML=C(t,e,r,"display")};if("dom"!==n&&(n&&"auto"!==n||"dom"!==s.src)){var u=s.anCells;if(u)if(o!==r)l(u[o],o);else for(i=0,a=u.length;i<a;i++)l(u[i],i)}else s._aData=D(t,s,o,o===r?r:s._aData).data;s._aSortData=null,s._aFilterData=null;var c=t.aoColumns;if(o!==r)c[o].sType=null;else{for(i=0,a=c.length;i<a;i++)c[i].sType=null;R(t,s)}}function D(e,n,o,i){var a,s,l,u=[],c=n.firstChild,f=0,d=e.aoColumns,p=e._rowReadObject;i=i!==r?i:p?{}:[];var h=function(t,e){if("string"==typeof t){var n=t.indexOf("@");if(n!==-1){var r=t.substring(n+1),o=S(t);o(i,e.getAttribute(r))}}},g=function(e){if(o===r||o===f)if(s=d[f],l=t.trim(e.innerHTML),s&&s._bAttrSrc){var n=S(s.mData._);n(i,l),h(s.mData.sort,e),h(s.mData.type,e),h(s.mData.filter,e)}else p?(s._setter||(s._setter=S(s.mData)),s._setter(i,l)):i[f]=l;f++};if(c)for(;c;)a=c.nodeName.toUpperCase(),"TD"!=a&&"TH"!=a||(g(c),u.push(c)),c=c.nextSibling;else{u=n.anCells;for(var v=0,m=u.length;v<m;v++)g(u[v])}var y=n.firstChild?n:n.nTr;if(y){var b=y.getAttribute("id");b&&S(e.rowId)(i,b)}return{data:i,cells:u}}function I(e,r,o,i){var a,s,l,u,c,f=e.aoData[r],d=f._aData,p=[];if(null===f.nTr){for(a=o||n.createElement("tr"),f.nTr=a,f.anCells=p,a._DT_RowIndex=r,R(e,f),u=0,c=e.aoColumns.length;u<c;u++)l=e.aoColumns[u],s=o?i[u]:n.createElement(l.sCellType),s._DT_CellIndex={row:r,column:u},p.push(s),o&&!l.mRender&&l.mData===u||t.isPlainObject(l.mData)&&l.mData._===u+".display"||(s.innerHTML=C(e,r,u,"display")),l.sClass&&(s.className+=" "+l.sClass),l.bVisible&&!o?a.appendChild(s):!l.bVisible&&o&&s.parentNode.removeChild(s),l.fnCreatedCell&&l.fnCreatedCell.call(e.oInstance,s,C(e,r,u),d,r,u);Ft(e,"aoRowCreatedCallback",null,[a,d,r])}f.nTr.setAttribute("role","row")}function R(e,n){var r=n.nTr,o=n._aData;if(r){var i=e.rowIdFn(o);if(i&&(r.id=i),o.DT_RowClass){var a=o.DT_RowClass.split(" ");n.__rowc=n.__rowc?de(n.__rowc.concat(a)):a,t(r).removeClass(n.__rowc.join(" ")).addClass(o.DT_RowClass)}o.DT_RowAttr&&t(r).attr(o.DT_RowAttr),o.DT_RowData&&t(r).data(o.DT_RowData)}}function L(e){var n,r,o,i,a,s=e.nTHead,l=e.nTFoot,u=0===t("th, td",s).length,c=e.oClasses,f=e.aoColumns;for(u&&(i=t("<tr/>").appendTo(s)),n=0,r=f.length;n<r;n++)a=f[n],o=t(a.nTh).addClass(a.sClass),u&&o.appendTo(i),e.oFeatures.bSort&&(o.addClass(a.sSortingClass),a.bSortable!==!1&&(o.attr("tabindex",e.iTabIndex).attr("aria-controls",e.sTableId),Et(e,a.nTh,n))),a.sTitle!=o[0].innerHTML&&o.html(a.sTitle),Bt(e,"header")(e,o,a,c);if(u&&H(e.aoHeader,s),t(s).find(">tr").attr("role","row"),t(s).find(">tr>th, >tr>td").addClass(c.sHeaderTH),t(l).find(">tr>th, >tr>td").addClass(c.sFooterTH),null!==l){var d=e.aoFooter[0];for(n=0,r=d.length;n<r;n++)a=f[n],a.nTf=d[n].cell,a.sClass&&t(a.nTf).addClass(a.sClass)}}function F(e,n,o){var i,a,s,l,u,c,f,d,p,h=[],g=[],v=e.aoColumns.length;if(n){for(o===r&&(o=!1),i=0,a=n.length;i<a;i++){for(h[i]=n[i].slice(),h[i].nTr=n[i].nTr,s=v-1;s>=0;s--)e.aoColumns[s].bVisible||o||h[i].splice(s,1);g.push([])}for(i=0,a=h.length;i<a;i++){if(f=h[i].nTr)for(;c=f.firstChild;)f.removeChild(c);for(s=0,l=h[i].length;s<l;s++)if(d=1,p=1,g[i][s]===r){for(f.appendChild(h[i][s].cell),g[i][s]=1;h[i+d]!==r&&h[i][s].cell==h[i+d][s].cell;)g[i+d][s]=1,d++;for(;h[i][s+p]!==r&&h[i][s].cell==h[i][s+p].cell;){for(u=0;u<d;u++)g[i+u][s+p]=1;p++}t(h[i][s].cell).attr("rowspan",d).attr("colspan",p)}}}}function j(e){var n=Ft(e,"aoPreDrawCallback","preDraw",[e]);if(t.inArray(!1,n)!==-1)return void pt(e,!1);var o=[],i=0,a=e.asStripeClasses,s=a.length,l=(e.aoOpenRows.length,e.oLanguage),u=e.iInitDisplayStart,c="ssp"==Ut(e),f=e.aiDisplay;e.bDrawing=!0,u!==r&&u!==-1&&(e._iDisplayStart=c?u:u>=e.fnRecordsDisplay()?0:u,e.iInitDisplayStart=-1);var d=e._iDisplayStart,p=e.fnDisplayEnd();if(e.bDeferLoading)e.bDeferLoading=!1,e.iDraw++,pt(e,!1);else if(c){if(!e.bDestroying&&!q(e))return}else e.iDraw++;if(0!==f.length)for(var h=c?0:d,g=c?e.aoData.length:p,m=h;m<g;m++){var y=f[m],b=e.aoData[y];null===b.nTr&&I(e,y);var x=b.nTr;if(0!==s){var _=a[i%s];b._sRowStripe!=_&&(t(x).removeClass(b._sRowStripe).addClass(_),b._sRowStripe=_)}Ft(e,"aoRowCallback",null,[x,b._aData,i,m]),o.push(x),i++}else{var w=l.sZeroRecords;1==e.iDraw&&"ajax"==Ut(e)?w=l.sLoadingRecords:l.sEmptyTable&&0===e.fnRecordsTotal()&&(w=l.sEmptyTable),o[0]=t("<tr/>",{class:s?a[0]:""}).append(t("<td />",{valign:"top",colSpan:v(e),class:e.oClasses.sRowEmpty}).html(w))[0]}Ft(e,"aoHeaderCallback","header",[t(e.nTHead).children("tr")[0],M(e),d,p,f]),Ft(e,"aoFooterCallback","footer",[t(e.nTFoot).children("tr")[0],M(e),d,p,f]);var T=t(e.nTBody);T.children().detach(),T.append(t(o)),Ft(e,"aoDrawCallback","draw",[e]),e.bSorted=!1,e.bFiltered=!1,e.bDrawing=!1}function B(t,e){var n=t.oFeatures,r=n.bSort,o=n.bFilter;r&&Tt(t),o?X(t,t.oPreviousSearch):t.aiDisplay=t.aiDisplayMaster.slice(),e!==!0&&(t._iDisplayStart=0),t._drawHold=e,j(t),t._drawHold=!1}function U(e){var n=e.oClasses,r=t(e.nTable),o=t("<div/>").insertBefore(r),i=e.oFeatures,a=t("<div/>",{id:e.sTableId+"_wrapper",class:n.sWrapper+(e.nTFoot?"":" "+n.sNoFooter)});e.nHolding=o[0],e.nTableWrapper=a[0],e.nTableReinsertBefore=e.nTable.nextSibling;for(var s,l,u,c,f,d,p=e.sDom.split(""),h=0;h<p.length;h++){if(s=null,l=p[h],"<"==l){if(u=t("<div/>")[0],c=p[h+1],"'"==c||'"'==c){for(f="",d=2;p[h+d]!=c;)f+=p[h+d],d++;if("H"==f?f=n.sJUIHeader:"F"==f&&(f=n.sJUIFooter),f.indexOf(".")!=-1){var g=f.split(".");u.id=g[0].substr(1,g[0].length-1),u.className=g[1]}else"#"==f.charAt(0)?u.id=f.substr(1,f.length-1):u.className=f;h+=d}a.append(u),a=t(u)}else if(">"==l)a=a.parent();else if("l"==l&&i.bPaginate&&i.bLengthChange)s=ut(e);else if("f"==l&&i.bFilter)s=G(e);else if("r"==l&&i.bProcessing)s=dt(e);else if("t"==l)s=ht(e);else if("i"==l&&i.bInfo)s=rt(e);else if("p"==l&&i.bPaginate)s=ct(e);else if(0!==Gt.ext.feature.length)for(var v=Gt.ext.feature,m=0,y=v.length;m<y;m++)if(l==v[m].cFeature){s=v[m].fnInit(e);break}if(s){var b=e.aanFeatures;b[l]||(b[l]=[]),b[l].push(s),a.append(s)}}o.replaceWith(a),e.nHolding=null}function H(e,n){var r,o,i,a,s,l,u,c,f,d,p,h=t(n).children("tr"),g=function(t,e,n){for(var r=t[e];r[n];)n++;return n};for(e.splice(0,e.length),i=0,l=h.length;i<l;i++)e.push([]);for(i=0,l=h.length;i<l;i++)for(r=h[i],c=0,o=r.firstChild;o;){if("TD"==o.nodeName.toUpperCase()||"TH"==o.nodeName.toUpperCase())for(f=1*o.getAttribute("colspan"),d=1*o.getAttribute("rowspan"),f=f&&0!==f&&1!==f?f:1,d=d&&0!==d&&1!==d?d:1,u=g(e,i,c),p=1===f,s=0;s<f;s++)for(a=0;a<d;a++)e[i+a][u+s]={cell:o,unique:p},e[i+a].nTr=r;o=o.nextSibling}}function z(t,e,n){var r=[];n||(n=t.aoHeader,e&&(n=[],H(n,e)));for(var o=0,i=n.length;o<i;o++)for(var a=0,s=n[o].length;a<s;a++)!n[o][a].unique||r[a]&&t.bSortCellsTop||(r[a]=n[o][a].cell);return r}function W(e,n,r){if(Ft(e,"aoServerParams","serverParams",[n]),n&&t.isArray(n)){var o={},i=/(.*?)\[\]$/;t.each(n,function(t,e){var n=e.name.match(i);if(n){var r=n[0];o[r]||(o[r]=[]),o[r].push(e.value)}else o[e.name]=e.value}),n=o}var a,s=e.ajax,l=e.oInstance,u=function(t){Ft(e,null,"xhr",[e,t,e.jqXHR]),r(t)};if(t.isPlainObject(s)&&s.data){a=s.data;var c=t.isFunction(a)?a(n,e):a;n=t.isFunction(a)&&c?c:t.extend(!0,n,c),delete s.data}var f={data:n,success:function(t){var n=t.error||t.sError;n&&Ot(e,0,n),e.json=t,u(t)},dataType:"json",cache:!1,type:e.sServerMethod,error:function(n,r,o){var i=Ft(e,null,"xhr",[e,null,e.jqXHR]);t.inArray(!0,i)===-1&&("parsererror"==r?Ot(e,0,"Invalid JSON response",1):4===n.readyState&&Ot(e,0,"Ajax error",7)),pt(e,!1)}};e.oAjaxData=n,Ft(e,null,"preXhr",[e,n]),e.fnServerData?e.fnServerData.call(l,e.sAjaxSource,t.map(n,function(t,e){return{name:e,value:t}}),u,e):e.sAjaxSource||"string"==typeof s?e.jqXHR=t.ajax(t.extend(f,{url:s||e.sAjaxSource})):t.isFunction(s)?e.jqXHR=s.call(l,n,u,e):(e.jqXHR=t.ajax(t.extend(f,s)),s.data=a)}function q(t){return!t.bAjaxDataGet||(t.iDraw++,pt(t,!0),W(t,V(t),function(e){K(t,e)}),!1)}function V(e){var n,r,o,i,a=e.aoColumns,s=a.length,l=e.oFeatures,u=e.oPreviousSearch,c=e.aoPreSearchCols,f=[],d=wt(e),p=e._iDisplayStart,h=l.bPaginate!==!1?e._iDisplayLength:-1,g=function(t,e){f.push({name:t,value:e})};g("sEcho",e.iDraw),g("iColumns",s),g("sColumns",se(a,"sName").join(",")),g("iDisplayStart",p),g("iDisplayLength",h);var v={draw:e.iDraw,columns:[],order:[],start:p,length:h,search:{value:u.sSearch,regex:u.bRegex}};for(n=0;n<s;n++)o=a[n],i=c[n],r="function"==typeof o.mData?"function":o.mData,v.columns.push({data:r,name:o.sName,searchable:o.bSearchable,orderable:o.bSortable,search:{value:i.sSearch,regex:i.bRegex}}),g("mDataProp_"+n,r),l.bFilter&&(g("sSearch_"+n,i.sSearch),g("bRegex_"+n,i.bRegex),g("bSearchable_"+n,o.bSearchable)),l.bSort&&g("bSortable_"+n,o.bSortable);l.bFilter&&(g("sSearch",u.sSearch),g("bRegex",u.bRegex)),l.bSort&&(t.each(d,function(t,e){v.order.push({column:e.col,dir:e.dir}),g("iSortCol_"+t,e.col),g("sSortDir_"+t,e.dir)}),g("iSortingCols",d.length));var m=Gt.ext.legacy.ajax;return null===m?e.sAjaxSource?f:v:m?f:v}function K(t,e){var n=function(t,n){return e[t]!==r?e[t]:e[n]},o=Y(t,e),i=n("sEcho","draw"),a=n("iTotalRecords","recordsTotal"),s=n("iTotalDisplayRecords","recordsFiltered");if(i){if(1*i<t.iDraw)return;t.iDraw=1*i}N(t),t._iRecordsTotal=parseInt(a,10),t._iRecordsDisplay=parseInt(s,10);for(var l=0,u=o.length;l<u;l++)x(t,o[l]);t.aiDisplay=t.aiDisplayMaster.slice(),t.bAjaxDataGet=!1,j(t),t._bInitComplete||st(t,e),t.bAjaxDataGet=!0,pt(t,!1)}function Y(e,n){var o=t.isPlainObject(e.ajax)&&e.ajax.dataSrc!==r?e.ajax.dataSrc:e.sAjaxDataProp;return"data"===o?n.aaData||n[o]:""!==o?P(o)(n):n}function G(e){var r=e.oClasses,o=e.sTableId,i=e.oLanguage,a=e.oPreviousSearch,s=e.aanFeatures,l='<input type="search" class="'+r.sFilterInput+'"/>',u=i.sSearch;u=u.match(/_INPUT_/)?u.replace("_INPUT_",l):u+l;var c=t("<div/>",{id:s.f?null:o+"_filter",class:r.sFilter}).append(t("<label/>").append(u)),f=function(){var t=(s.f,this.value?this.value:"");t!=a.sSearch&&(X(e,{sSearch:t,bRegex:a.bRegex,bSmart:a.bSmart,bCaseInsensitive:a.bCaseInsensitive}),e._iDisplayStart=0,j(e))},d=null!==e.searchDelay?e.searchDelay:"ssp"===Ut(e)?400:0,p=t("input",c).val(a.sSearch).attr("placeholder",i.sSearchPlaceholder).on("keyup.DT search.DT input.DT paste.DT cut.DT",d?xe(f,d):f).on("keypress.DT",function(t){if(13==t.keyCode)return!1}).attr("aria-controls",o);return t(e.nTable).on("search.dt.DT",function(t,r){if(e===r)try{p[0]!==n.activeElement&&p.val(a.sSearch)}catch(t){}}),c[0]}function X(t,e,n){var o=t.oPreviousSearch,i=t.aoPreSearchCols,a=function(t){o.sSearch=t.sSearch,o.bRegex=t.bRegex,o.bSmart=t.bSmart,o.bCaseInsensitive=t.bCaseInsensitive},s=function(t){return t.bEscapeRegex!==r?!t.bEscapeRegex:t.bRegex};if(y(t),"ssp"!=Ut(t)){J(t,e.sSearch,n,s(e),e.bSmart,e.bCaseInsensitive),a(e);for(var l=0;l<i.length;l++)Z(t,i[l].sSearch,l,s(i[l]),i[l].bSmart,i[l].bCaseInsensitive);$(t)}else a(e);t.bFiltered=!0,Ft(t,null,"search",[t])}function $(e){for(var n,r,o=Gt.ext.search,i=e.aiDisplay,a=0,s=o.length;a<s;a++){for(var l=[],u=0,c=i.length;u<c;u++)r=i[u],n=e.aoData[r],o[a](e,n._aFilterData,r,n._aData,u)&&l.push(r);i.length=0,t.merge(i,l)}}function Z(t,e,n,r,o,i){if(""!==e){for(var a,s=[],l=t.aiDisplay,u=Q(e,r,o,i),c=0;c<l.length;c++)a=t.aoData[l[c]]._aFilterData[n],u.test(a)&&s.push(l[c]);t.aiDisplay=s}}function J(t,e,n,r,o,i){var a,s,l,u=Q(e,r,o,i),c=t.oPreviousSearch.sSearch,f=t.aiDisplayMaster,d=[];if(0!==Gt.ext.search.length&&(n=!0),s=tt(t),e.length<=0)t.aiDisplay=f.slice();else{for((s||n||c.length>e.length||0!==e.indexOf(c)||t.bSorted)&&(t.aiDisplay=f.slice()),a=t.aiDisplay,l=0;l<a.length;l++)u.test(t.aoData[a[l]]._sFilterRow)&&d.push(a[l]);t.aiDisplay=d}}function Q(e,n,r,o){if(e=n?e:ve(e),r){var i=t.map(e.match(/"[^"]+"|[^ ]+/g)||[""],function(t){if('"'===t.charAt(0)){var e=t.match(/^"(.*)"$/);t=e?e[1]:t}return t.replace('"',"")});e="^(?=.*?"+i.join(")(?=.*?")+").*$"}return new RegExp(e,o?"i":"")}function tt(t){var e,n,r,o,i,a,s,l,u=t.aoColumns,c=Gt.ext.type.search,f=!1;for(n=0,o=t.aoData.length;n<o;n++)if(l=t.aoData[n],!l._aFilterData){for(a=[],r=0,i=u.length;r<i;r++)e=u[r],e.bSearchable?(s=C(t,n,r,"filter"),c[e.sType]&&(s=c[e.sType](s)),null===s&&(s=""),"string"!=typeof s&&s.toString&&(s=s.toString())):s="",s.indexOf&&s.indexOf("&")!==-1&&(me.innerHTML=s,s=ye?me.textContent:me.innerText),s.replace&&(s=s.replace(/[\r\n]/g,"")),a.push(s);l._aFilterData=a,l._sFilterRow=a.join("  "),f=!0}return f}function et(t){return{search:t.sSearch,smart:t.bSmart,regex:t.bRegex,caseInsensitive:t.bCaseInsensitive}}function nt(t){return{sSearch:t.search,bSmart:t.smart,bRegex:t.regex,bCaseInsensitive:t.caseInsensitive}}function rt(e){var n=e.sTableId,r=e.aanFeatures.i,o=t("<div/>",{class:e.oClasses.sInfo,id:r?null:n+"_info"});return r||(e.aoDrawCallback.push({fn:ot,sName:"information"}),o.attr("role","status").attr("aria-live","polite"),t(e.nTable).attr("aria-describedby",n+"_info")),o[0]}function ot(e){var n=e.aanFeatures.i;if(0!==n.length){var r=e.oLanguage,o=e._iDisplayStart+1,i=e.fnDisplayEnd(),a=e.fnRecordsTotal(),s=e.fnRecordsDisplay(),l=s?r.sInfo:r.sInfoEmpty;s!==a&&(l+=" "+r.sInfoFiltered),l+=r.sInfoPostFix,l=it(e,l);var u=r.fnInfoCallback;null!==u&&(l=u.call(e.oInstance,e,o,i,a,s,l)),t(n).html(l)}}function it(t,e){var n=t.fnFormatNumber,r=t._iDisplayStart+1,o=t._iDisplayLength,i=t.fnRecordsDisplay(),a=o===-1;return e.replace(/_START_/g,n.call(t,r)).replace(/_END_/g,n.call(t,t.fnDisplayEnd())).replace(/_MAX_/g,n.call(t,t.fnRecordsTotal())).replace(/_TOTAL_/g,n.call(t,i)).replace(/_PAGE_/g,n.call(t,a?1:Math.ceil(r/o))).replace(/_PAGES_/g,n.call(t,a?1:Math.ceil(i/o)))}function at(t){var e,n,r,o=t.iInitDisplayStart,i=t.aoColumns,a=t.oFeatures,s=t.bDeferLoading;if(!t.bInitialised)return void setTimeout(function(){at(t)},200);for(U(t),L(t),F(t,t.aoHeader),F(t,t.aoFooter),pt(t,!0),a.bAutoWidth&&mt(t),e=0,n=i.length;e<n;e++)r=i[e],r.sWidth&&(r.nTh.style.width=_t(r.sWidth));Ft(t,null,"preInit",[t]),B(t);var l=Ut(t);("ssp"!=l||s)&&("ajax"==l?W(t,[],function(n){var r=Y(t,n);for(e=0;e<r.length;e++)x(t,r[e]);t.iInitDisplayStart=o,B(t),pt(t,!1),st(t,n)},t):(pt(t,!1),st(t)))}function st(t,e){t._bInitComplete=!0,(e||t.oInit.aaData)&&p(t),Ft(t,null,"plugin-init",[t,e]),Ft(t,"aoInitComplete","init",[t,e])}function lt(t,e){var n=parseInt(e,10);t._iDisplayLength=n,jt(t),Ft(t,null,"length",[t,n])}function ut(e){for(var n=e.oClasses,r=e.sTableId,o=e.aLengthMenu,i=t.isArray(o[0]),a=i?o[0]:o,s=i?o[1]:o,l=t("<select/>",{name:r+"_length","aria-controls":r,class:n.sLengthSelect}),u=0,c=a.length;u<c;u++)l[0][u]=new Option(s[u],a[u]);var f=t("<div><label/></div>").addClass(n.sLength);return e.aanFeatures.l||(f[0].id=r+"_length"),f.children().append(e.oLanguage.sLengthMenu.replace("_MENU_",l[0].outerHTML)),t("select",f).val(e._iDisplayLength).on("change.DT",function(n){lt(e,t(this).val()),j(e)}),t(e.nTable).on("length.dt.DT",function(n,r,o){e===r&&t("select",f).val(o)}),f[0]}function ct(e){var n=e.sPaginationType,r=Gt.ext.pager[n],o="function"==typeof r,i=function(t){j(t)},a=t("<div/>").addClass(e.oClasses.sPaging+n)[0],s=e.aanFeatures;return o||r.fnInit(e,a,i),s.p||(a.id=e.sTableId+"_paginate",e.aoDrawCallback.push({fn:function(t){if(o){var e,n,a=t._iDisplayStart,l=t._iDisplayLength,u=t.fnRecordsDisplay(),c=l===-1,f=c?0:Math.ceil(a/l),d=c?1:Math.ceil(u/l),p=r(f,d);for(e=0,n=s.p.length;e<n;e++)Bt(t,"pageButton")(t,s.p[e],e,p,f,d)}else r.fnUpdate(t,i)},sName:"pagination"})),a}function ft(t,e,n){var r=t._iDisplayStart,o=t._iDisplayLength,i=t.fnRecordsDisplay();0===i||o===-1?r=0:"number"==typeof e?(r=e*o,r>i&&(r=0)):"first"==e?r=0:"previous"==e?(r=o>=0?r-o:0,r<0&&(r=0)):"next"==e?r+o<i&&(r+=o):"last"==e?r=Math.floor((i-1)/o)*o:Ot(t,0,"Unknown paging action: "+e,5);var a=t._iDisplayStart!==r;return t._iDisplayStart=r,a&&(Ft(t,null,"page",[t]),n&&j(t)),a}function dt(e){return t("<div/>",{id:e.aanFeatures.r?null:e.sTableId+"_processing",class:e.oClasses.sProcessing}).html(e.oLanguage.sProcessing).insertBefore(e.nTable)[0]}function pt(e,n){e.oFeatures.bProcessing&&t(e.aanFeatures.r).css("display",n?"block":"none"),Ft(e,null,"processing",[e,n])}function ht(e){var n=t(e.nTable);n.attr("role","grid");var r=e.oScroll;if(""===r.sX&&""===r.sY)return e.nTable;var o=r.sX,i=r.sY,a=e.oClasses,s=n.children("caption"),l=s.length?s[0]._captionSide:null,u=t(n[0].cloneNode(!1)),c=t(n[0].cloneNode(!1)),f=n.children("tfoot"),d="<div/>",p=function(t){return t?_t(t):null};f.length||(f=null);var h=t(d,{class:a.sScrollWrapper}).append(t(d,{class:a.sScrollHead}).css({overflow:"hidden",position:"relative",border:0,width:o?p(o):"100%"}).append(t(d,{class:a.sScrollHeadInner}).css({"box-sizing":"content-box",width:r.sXInner||"100%"}).append(u.removeAttr("id").css("margin-left",0).append("top"===l?s:null).append(n.children("thead"))))).append(t(d,{class:a.sScrollBody}).css({position:"relative",overflow:"auto",width:p(o)}).append(n));f&&h.append(t(d,{class:a.sScrollFoot}).css({overflow:"hidden",border:0,width:o?p(o):"100%"}).append(t(d,{class:a.sScrollFootInner}).append(c.removeAttr("id").css("margin-left",0).append("bottom"===l?s:null).append(n.children("tfoot")))));var g=h.children(),v=g[0],m=g[1],y=f?g[2]:null;return o&&t(m).on("scroll.DT",function(t){var e=this.scrollLeft;v.scrollLeft=e,f&&(y.scrollLeft=e)}),t(m).css(i&&r.bCollapse?"max-height":"height",i),e.nScrollHead=v,e.nScrollBody=m,e.nScrollFoot=y,e.aoDrawCallback.push({fn:gt,sName:"scrolling"}),h[0]}function gt(e){var n,o,i,a,s,l,u,c,f,d=e.oScroll,g=d.sX,v=d.sXInner,m=d.sY,y=d.iBarWidth,b=t(e.nScrollHead),x=b[0].style,_=b.children("div"),w=_[0].style,T=_.children("table"),C=e.nScrollBody,k=t(C),E=C.style,P=t(e.nScrollFoot),S=P.children("div"),M=S.children("table"),N=t(e.nTHead),A=t(e.nTable),O=A[0],D=O.style,I=e.nTFoot?t(e.nTFoot):null,R=e.oBrowser,L=R.bScrollOversize,F=se(e.aoColumns,"nTh"),j=[],B=[],U=[],H=[],W=function(t){var e=t.style;e.paddingTop="0",e.paddingBottom="0",e.borderTopWidth="0",e.borderBottomWidth="0",e.height=0},q=C.scrollHeight>C.clientHeight;if(e.scrollBarVis!==q&&e.scrollBarVis!==r)return e.scrollBarVis=q,void p(e);e.scrollBarVis=q,A.children("thead, tfoot").remove(),I&&(l=I.clone().prependTo(A),o=I.find("tr"),a=l.find("tr")),s=N.clone().prependTo(A),n=N.find("tr"),i=s.find("tr"),s.find("th, td").removeAttr("tabindex"),g||(E.width="100%",b[0].style.width="100%"),t.each(z(e,s),function(t,n){u=h(e,t),n.style.width=e.aoColumns[u].sWidth}),I&&vt(function(t){t.style.width=""},a),f=A.outerWidth(),""===g?(D.width="100%",L&&(A.find("tbody").height()>C.offsetHeight||"scroll"==k.css("overflow-y"))&&(D.width=_t(A.outerWidth()-y)),f=A.outerWidth()):""!==v&&(D.width=_t(v),f=A.outerWidth()),vt(W,i),vt(function(e){U.push(e.innerHTML),j.push(_t(t(e).css("width")))},i),vt(function(e,n){t.inArray(e,F)!==-1&&(e.style.width=j[n])},n),t(i).height(0),I&&(vt(W,a),vt(function(e){H.push(e.innerHTML),B.push(_t(t(e).css("width")))},a),vt(function(t,e){t.style.width=B[e]},o),t(a).height(0)),vt(function(t,e){t.innerHTML='<div class="dataTables_sizing" style="height:0;overflow:hidden;">'+U[e]+"</div>",t.style.width=j[e]},i),I&&vt(function(t,e){t.innerHTML='<div class="dataTables_sizing" style="height:0;overflow:hidden;">'+H[e]+"</div>",t.style.width=B[e]},a),A.outerWidth()<f?(c=C.scrollHeight>C.offsetHeight||"scroll"==k.css("overflow-y")?f+y:f,L&&(C.scrollHeight>C.offsetHeight||"scroll"==k.css("overflow-y"))&&(D.width=_t(c-y)),""!==g&&""===v||Ot(e,1,"Possible column misalignment",6)):c="100%",E.width=_t(c),x.width=_t(c),I&&(e.nScrollFoot.style.width=_t(c)),m||L&&(E.height=_t(O.offsetHeight+y));var V=A.outerWidth();T[0].style.width=_t(V),w.width=_t(V);var K=A.height()>C.clientHeight||"scroll"==k.css("overflow-y"),Y="padding"+(R.bScrollbarLeft?"Left":"Right");w[Y]=K?y+"px":"0px",I&&(M[0].style.width=_t(V),S[0].style.width=_t(V),S[0].style[Y]=K?y+"px":"0px"),A.children("colgroup").insertBefore(A.children("thead")),k.scroll(),!e.bSorted&&!e.bFiltered||e._drawHold||(C.scrollTop=0)}function vt(t,e,n){for(var r,o,i=0,a=0,s=e.length;a<s;){for(r=e[a].firstChild,o=n?n[a].firstChild:null;r;)1===r.nodeType&&(n?t(r,o,i):t(r,i),i++),r=r.nextSibling,o=n?o.nextSibling:null;a++}}function mt(n){var r,o,i,a=n.nTable,s=n.aoColumns,l=n.oScroll,u=l.sY,c=l.sX,f=l.sXInner,d=s.length,g=m(n,"bVisible"),y=t("th",n.nTHead),b=a.getAttribute("width"),x=a.parentNode,_=!1,w=n.oBrowser,T=w.bScrollOversize,C=a.style.width;for(C&&C.indexOf("%")!==-1&&(b=C),r=0;r<g.length;r++)o=s[g[r]],null!==o.sWidth&&(o.sWidth=yt(o.sWidthOrig,x),_=!0);if(T||!_&&!c&&!u&&d==v(n)&&d==y.length)for(r=0;r<d;r++){var k=h(n,r);null!==k&&(s[k].sWidth=_t(y.eq(r).width()))}else{var E=t(a).clone().css("visibility","hidden").removeAttr("id");E.find("tbody tr").remove();var P=t("<tr/>").appendTo(E.find("tbody"));for(E.find("thead, tfoot").remove(),E.append(t(n.nTHead).clone()).append(t(n.nTFoot).clone()),E.find("tfoot th, tfoot td").css("width",""),y=z(n,E.find("thead")[0]),r=0;r<g.length;r++)o=s[g[r]],y[r].style.width=null!==o.sWidthOrig&&""!==o.sWidthOrig?_t(o.sWidthOrig):"",o.sWidthOrig&&c&&t(y[r]).append(t("<div/>").css({width:o.sWidthOrig,margin:0,padding:0,border:0,height:1}));if(n.aoData.length)for(r=0;r<g.length;r++)i=g[r],o=s[i],t(bt(n,i)).clone(!1).append(o.sContentPadding).appendTo(P);t("[name]",E).removeAttr("name");var S=t("<div/>").css(c||u?{position:"absolute",top:0,left:0,height:1,right:0,overflow:"hidden"}:{}).append(E).appendTo(x);c&&f?E.width(f):c?(E.css("width","auto"),E.removeAttr("width"),E.width()<x.clientWidth&&b&&E.width(x.clientWidth)):u?E.width(x.clientWidth):b&&E.width(b);var M=0;for(r=0;r<g.length;r++){var N=t(y[r]),A=N.outerWidth()-N.width(),O=w.bBounding?Math.ceil(y[r].getBoundingClientRect().width):N.outerWidth();M+=O,s[g[r]].sWidth=_t(O-A)}a.style.width=_t(M),S.remove()}if(b&&(a.style.width=_t(b)),(b||c)&&!n._reszEvt){var D=function(){t(e).on("resize.DT-"+n.sInstance,xe(function(){p(n)}))};T?setTimeout(D,1e3):D(),n._reszEvt=!0}}function yt(e,r){if(!e)return 0;var o=t("<div/>").css("width",_t(e)).appendTo(r||n.body),i=o[0].offsetWidth;return o.remove(),i}function bt(e,n){var r=xt(e,n);if(r<0)return null;var o=e.aoData[r];return o.nTr?o.anCells[n]:t("<td/>").html(C(e,r,n,"display"))[0]}function xt(t,e){for(var n,r=-1,o=-1,i=0,a=t.aoData.length;i<a;i++)n=C(t,i,e,"display")+"",n=n.replace(be,""),n=n.replace(/&nbsp;/g," "),n.length>r&&(r=n.length,o=i);return o}function _t(t){return null===t?"0px":"number"==typeof t?t<0?"0px":t+"px":t.match(/\d$/)?t+"px":t}function wt(e){var n,o,i,a,s,l,u,c=[],f=e.aoColumns,d=e.aaSortingFixed,p=t.isPlainObject(d),h=[],g=function(e){e.length&&!t.isArray(e[0])?h.push(e):t.merge(h,e)};for(t.isArray(d)&&g(d),p&&d.pre&&g(d.pre),g(e.aaSorting),p&&d.post&&g(d.post),n=0;n<h.length;n++)for(u=h[n][0],a=f[u].aDataSort,o=0,i=a.length;o<i;o++)s=a[o],l=f[s].sType||"string",h[n]._idx===r&&(h[n]._idx=t.inArray(h[n][1],f[s].asSorting)),c.push({src:u,col:s,dir:h[n][1],index:h[n]._idx,type:l,formatter:Gt.ext.type.order[l+"-pre"]});return c}function Tt(t){var e,n,r,o,i,a=[],s=Gt.ext.type.order,l=t.aoData,u=(t.aoColumns,0),c=t.aiDisplayMaster;for(y(t),i=wt(t),e=0,n=i.length;e<n;e++)o=i[e],o.formatter&&u++,St(t,o.col);if("ssp"!=Ut(t)&&0!==i.length){for(e=0,r=c.length;e<r;e++)a[c[e]]=e;u===i.length?c.sort(function(t,e){var n,r,o,s,u,c=i.length,f=l[t]._aSortData,d=l[e]._aSortData;for(o=0;o<c;o++)if(u=i[o],n=f[u.col],r=d[u.col],s=n<r?-1:n>r?1:0,0!==s)return"asc"===u.dir?s:-s;return n=a[t],r=a[e],n<r?-1:n>r?1:0}):c.sort(function(t,e){var n,r,o,u,c,f,d=i.length,p=l[t]._aSortData,h=l[e]._aSortData;for(o=0;o<d;o++)if(c=i[o],
n=p[c.col],r=h[c.col],f=s[c.type+"-"+c.dir]||s["string-"+c.dir],u=f(n,r),0!==u)return u;return n=a[t],r=a[e],n<r?-1:n>r?1:0})}t.bSorted=!0}function Ct(t){for(var e,n,r=t.aoColumns,o=wt(t),i=t.oLanguage.oAria,a=0,s=r.length;a<s;a++){var l=r[a],u=l.asSorting,c=l.sTitle.replace(/<.*?>/g,""),f=l.nTh;f.removeAttribute("aria-sort"),l.bSortable?(o.length>0&&o[0].col==a?(f.setAttribute("aria-sort","asc"==o[0].dir?"ascending":"descending"),n=u[o[0].index+1]||u[0]):n=u[0],e=c+("asc"===n?i.sSortAscending:i.sSortDescending)):e=c,f.setAttribute("aria-label",e)}}function kt(e,n,o,i){var a,s=e.aoColumns[n],l=e.aaSorting,u=s.asSorting,c=function(e,n){var o=e._idx;return o===r&&(o=t.inArray(e[1],u)),o+1<u.length?o+1:n?null:0};if("number"==typeof l[0]&&(l=e.aaSorting=[l]),o&&e.oFeatures.bSortMulti){var f=t.inArray(n,se(l,"0"));f!==-1?(a=c(l[f],!0),null===a&&1===l.length&&(a=0),null===a?l.splice(f,1):(l[f][1]=u[a],l[f]._idx=a)):(l.push([n,u[0],0]),l[l.length-1]._idx=0)}else l.length&&l[0][0]==n?(a=c(l[0]),l.length=1,l[0][1]=u[a],l[0]._idx=a):(l.length=0,l.push([n,u[0]]),l[0]._idx=0);B(e),"function"==typeof i&&i(e)}function Et(t,e,n,r){var o=t.aoColumns[n];Rt(e,{},function(e){o.bSortable!==!1&&(t.oFeatures.bProcessing?(pt(t,!0),setTimeout(function(){kt(t,n,e.shiftKey,r),"ssp"!==Ut(t)&&pt(t,!1)},0)):kt(t,n,e.shiftKey,r))})}function Pt(e){var n,r,o,i=e.aLastSort,a=e.oClasses.sSortColumn,s=wt(e),l=e.oFeatures;if(l.bSort&&l.bSortClasses){for(n=0,r=i.length;n<r;n++)o=i[n].src,t(se(e.aoData,"anCells",o)).removeClass(a+(n<2?n+1:3));for(n=0,r=s.length;n<r;n++)o=s[n].src,t(se(e.aoData,"anCells",o)).addClass(a+(n<2?n+1:3))}e.aLastSort=s}function St(t,e){var n,r=t.aoColumns[e],o=Gt.ext.order[r.sSortDataType];o&&(n=o.call(t.oInstance,t,e,g(t,e)));for(var i,a,s=Gt.ext.type.order[r.sType+"-pre"],l=0,u=t.aoData.length;l<u;l++)i=t.aoData[l],i._aSortData||(i._aSortData=[]),i._aSortData[e]&&!o||(a=o?n[l]:C(t,l,e,"sort"),i._aSortData[e]=s?s(a):a)}function Mt(e){if(e.oFeatures.bStateSave&&!e.bDestroying){var n={time:+new Date,start:e._iDisplayStart,length:e._iDisplayLength,order:t.extend(!0,[],e.aaSorting),search:et(e.oPreviousSearch),columns:t.map(e.aoColumns,function(t,n){return{visible:t.bVisible,search:et(e.aoPreSearchCols[n])}})};Ft(e,"aoStateSaveParams","stateSaveParams",[e,n]),e.oSavedState=n,e.fnStateSaveCallback.call(e.oInstance,e,n)}}function Nt(e,n,o){var i,a,s=e.aoColumns,l=function(n){if(!n||!n.time)return void o();var l=Ft(e,"aoStateLoadParams","stateLoadParams",[e,u]);if(t.inArray(!1,l)!==-1)return void o();var c=e.iStateDuration;if(c>0&&n.time<+new Date-1e3*c)return void o();if(n.columns&&s.length!==n.columns.length)return void o();if(e.oLoadedState=t.extend(!0,{},u),n.start!==r&&(e._iDisplayStart=n.start,e.iInitDisplayStart=n.start),n.length!==r&&(e._iDisplayLength=n.length),n.order!==r&&(e.aaSorting=[],t.each(n.order,function(t,n){e.aaSorting.push(n[0]>=s.length?[0,n[1]]:n)})),n.search!==r&&t.extend(e.oPreviousSearch,nt(n.search)),n.columns)for(i=0,a=n.columns.length;i<a;i++){var f=n.columns[i];f.visible!==r&&(s[i].bVisible=f.visible),f.search!==r&&t.extend(e.aoPreSearchCols[i],nt(f.search))}Ft(e,"aoStateLoaded","stateLoaded",[e,u]),o()};if(!e.oFeatures.bStateSave)return void o();var u=e.fnStateLoadCallback.call(e.oInstance,e,l);u!==r&&l(u)}function At(e){var n=Gt.settings,r=t.inArray(e,se(n,"nTable"));return r!==-1?n[r]:null}function Ot(t,n,r,o){if(r="DataTables warning: "+(t?"table id="+t.sTableId+" - ":"")+r,o&&(r+=". For more information about this error, please see http://datatables.net/tn/"+o),n)e.console&&console.log&&console.log(r);else{var i=Gt.ext,a=i.sErrMode||i.errMode;if(t&&Ft(t,null,"error",[t,o,r]),"alert"==a)alert(r);else{if("throw"==a)throw new Error(r);"function"==typeof a&&a(t,o,r)}}}function Dt(e,n,o,i){return t.isArray(o)?void t.each(o,function(r,o){t.isArray(o)?Dt(e,n,o[0],o[1]):Dt(e,n,o)}):(i===r&&(i=o),void(n[o]!==r&&(e[i]=n[o])))}function It(e,n,r){var o;for(var i in n)n.hasOwnProperty(i)&&(o=n[i],t.isPlainObject(o)?(t.isPlainObject(e[i])||(e[i]={}),t.extend(!0,e[i],o)):r&&"data"!==i&&"aaData"!==i&&t.isArray(o)?e[i]=o.slice():e[i]=o);return e}function Rt(e,n,r){t(e).on("click.DT",n,function(t){e.blur(),r(t)}).on("keypress.DT",n,function(t){13===t.which&&(t.preventDefault(),r(t))}).on("selectstart.DT",function(){return!1})}function Lt(t,e,n,r){n&&t[e].push({fn:n,sName:r})}function Ft(e,n,r,o){var i=[];if(n&&(i=t.map(e[n].slice().reverse(),function(t,n){return t.fn.apply(e.oInstance,o)})),null!==r){var a=t.Event(r+".dt");t(e.nTable).trigger(a,o),i.push(a.result)}return i}function jt(t){var e=t._iDisplayStart,n=t.fnDisplayEnd(),r=t._iDisplayLength;e>=n&&(e=n-r),e-=e%r,(r===-1||e<0)&&(e=0),t._iDisplayStart=e}function Bt(e,n){var r=e.renderer,o=Gt.ext.renderer[n];return t.isPlainObject(r)&&r[n]?o[r[n]]||o._:"string"==typeof r?o[r]||o._:o._}function Ut(t){return t.oFeatures.bServerSide?"ssp":t.ajax||t.sAjaxSource?"ajax":"dom"}function Ht(t,e){var n=[],r=We.numbers_length,o=Math.floor(r/2);return e<=r?n=ue(0,e):t<=o?(n=ue(0,r-2),n.push("ellipsis"),n.push(e-1)):t>=e-1-o?(n=ue(e-(r-2),e),n.splice(0,0,"ellipsis"),n.splice(0,0,0)):(n=ue(t-o+2,t+o-1),n.push("ellipsis"),n.push(e-1),n.splice(0,0,"ellipsis"),n.splice(0,0,0)),n.DT_el="span",n}function zt(e){t.each({num:function(t){return qe(t,e)},"num-fmt":function(t){return qe(t,e,te)},"html-num":function(t){return qe(t,e,Zt)},"html-num-fmt":function(t){return qe(t,e,Zt,te)}},function(t,n){qt.type.order[t+e+"-pre"]=n,t.match(/^html\-/)&&(qt.type.search[t+e]=qt.type.search.html)})}function Wt(t){return function(){var e=[At(this[Gt.ext.iApiIndex])].concat(Array.prototype.slice.call(arguments));return Gt.ext.internal[t].apply(this,e)}}var qt,Vt,Kt,Yt,Gt=function(e){this.$=function(t,e){return this.api(!0).$(t,e)},this._=function(t,e){return this.api(!0).rows(t,e).data()},this.api=function(t){return new Vt(t?At(this[qt.iApiIndex]):this)},this.fnAddData=function(e,n){var o=this.api(!0),i=t.isArray(e)&&(t.isArray(e[0])||t.isPlainObject(e[0]))?o.rows.add(e):o.row.add(e);return(n===r||n)&&o.draw(),i.flatten().toArray()},this.fnAdjustColumnSizing=function(t){var e=this.api(!0).columns.adjust(),n=e.settings()[0],o=n.oScroll;t===r||t?e.draw(!1):""===o.sX&&""===o.sY||gt(n)},this.fnClearTable=function(t){var e=this.api(!0).clear();(t===r||t)&&e.draw()},this.fnClose=function(t){this.api(!0).row(t).child.hide()},this.fnDeleteRow=function(t,e,n){var o=this.api(!0),i=o.rows(t),a=i.settings()[0],s=a.aoData[i[0][0]];return i.remove(),e&&e.call(this,a,s),(n===r||n)&&o.draw(),s},this.fnDestroy=function(t){this.api(!0).destroy(t)},this.fnDraw=function(t){this.api(!0).draw(t)},this.fnFilter=function(t,e,n,o,i,a){var s=this.api(!0);null===e||e===r?s.search(t,n,o,a):s.column(e).search(t,n,o,a),s.draw()},this.fnGetData=function(t,e){var n=this.api(!0);if(t!==r){var o=t.nodeName?t.nodeName.toLowerCase():"";return e!==r||"td"==o||"th"==o?n.cell(t,e).data():n.row(t).data()||null}return n.data().toArray()},this.fnGetNodes=function(t){var e=this.api(!0);return t!==r?e.row(t).node():e.rows().nodes().flatten().toArray()},this.fnGetPosition=function(t){var e=this.api(!0),n=t.nodeName.toUpperCase();if("TR"==n)return e.row(t).index();if("TD"==n||"TH"==n){var r=e.cell(t).index();return[r.row,r.columnVisible,r.column]}return null},this.fnIsOpen=function(t){return this.api(!0).row(t).child.isShown()},this.fnOpen=function(t,e,n){return this.api(!0).row(t).child(e,n).show().child()[0]},this.fnPageChange=function(t,e){var n=this.api(!0).page(t);(e===r||e)&&n.draw(!1)},this.fnSetColumnVis=function(t,e,n){var o=this.api(!0).column(t).visible(e);(n===r||n)&&o.columns.adjust().draw()},this.fnSettings=function(){return At(this[qt.iApiIndex])},this.fnSort=function(t){this.api(!0).order(t).draw()},this.fnSortListener=function(t,e,n){this.api(!0).order.listener(t,e,n)},this.fnUpdate=function(t,e,n,o,i){var a=this.api(!0);return n===r||null===n?a.row(e).data(t):a.cell(e,n).data(t),(i===r||i)&&a.columns.adjust(),(o===r||o)&&a.draw(),0},this.fnVersionCheck=qt.fnVersionCheck;var n=this,o=e===r,c=this.length;o&&(e={}),this.oApi=this.internal=qt.internal;for(var p in Gt.ext.internal)p&&(this[p]=Wt(p));return this.each(function(){var p,h={},g=c>1?It(h,e,!0):e,v=0,m=this.getAttribute("id"),y=!1,w=Gt.defaults,T=t(this);if("table"!=this.nodeName.toLowerCase())return void Ot(null,0,"Non-table node initialisation ("+this.nodeName+")",2);s(w),l(w.column),i(w,w,!0),i(w.column,w.column,!0),i(w,t.extend(g,T.data()));var C=Gt.settings;for(v=0,p=C.length;v<p;v++){var k=C[v];if(k.nTable==this||k.nTHead.parentNode==this||k.nTFoot&&k.nTFoot.parentNode==this){var E=g.bRetrieve!==r?g.bRetrieve:w.bRetrieve,S=g.bDestroy!==r?g.bDestroy:w.bDestroy;if(o||E)return k.oInstance;if(S){k.oInstance.fnDestroy();break}return void Ot(k,0,"Cannot reinitialise DataTable",3)}if(k.sTableId==this.id){C.splice(v,1);break}}null!==m&&""!==m||(m="DataTables_Table_"+Gt.ext._unique++,this.id=m);var M=t.extend(!0,{},Gt.models.oSettings,{sDestroyWidth:T[0].style.width,sInstance:m,sTableId:m});M.nTable=this,M.oApi=n.internal,M.oInit=g,C.push(M),M.oInstance=1===n.length?n:T.dataTable(),s(g),g.oLanguage&&a(g.oLanguage),g.aLengthMenu&&!g.iDisplayLength&&(g.iDisplayLength=t.isArray(g.aLengthMenu[0])?g.aLengthMenu[0][0]:g.aLengthMenu[0]),g=It(t.extend(!0,{},w),g),Dt(M.oFeatures,g,["bPaginate","bLengthChange","bFilter","bSort","bSortMulti","bInfo","bProcessing","bAutoWidth","bSortClasses","bServerSide","bDeferRender"]),Dt(M,g,["asStripeClasses","ajax","fnServerData","fnFormatNumber","sServerMethod","aaSorting","aaSortingFixed","aLengthMenu","sPaginationType","sAjaxSource","sAjaxDataProp","iStateDuration","sDom","bSortCellsTop","iTabIndex","fnStateLoadCallback","fnStateSaveCallback","renderer","searchDelay","rowId",["iCookieDuration","iStateDuration"],["oSearch","oPreviousSearch"],["aoSearchCols","aoPreSearchCols"],["iDisplayLength","_iDisplayLength"],["bJQueryUI","bJUI"]]),Dt(M.oScroll,g,[["sScrollX","sX"],["sScrollXInner","sXInner"],["sScrollY","sY"],["bScrollCollapse","bCollapse"]]),Dt(M.oLanguage,g,"fnInfoCallback"),Lt(M,"aoDrawCallback",g.fnDrawCallback,"user"),Lt(M,"aoServerParams",g.fnServerParams,"user"),Lt(M,"aoStateSaveParams",g.fnStateSaveParams,"user"),Lt(M,"aoStateLoadParams",g.fnStateLoadParams,"user"),Lt(M,"aoStateLoaded",g.fnStateLoaded,"user"),Lt(M,"aoRowCallback",g.fnRowCallback,"user"),Lt(M,"aoRowCreatedCallback",g.fnCreatedRow,"user"),Lt(M,"aoHeaderCallback",g.fnHeaderCallback,"user"),Lt(M,"aoFooterCallback",g.fnFooterCallback,"user"),Lt(M,"aoInitComplete",g.fnInitComplete,"user"),Lt(M,"aoPreDrawCallback",g.fnPreDrawCallback,"user"),M.rowIdFn=P(g.rowId),u(M);var N=M.oClasses;if(g.bJQueryUI?(t.extend(N,Gt.ext.oJUIClasses,g.oClasses),g.sDom===w.sDom&&"lfrtip"===w.sDom&&(M.sDom='<"H"lfr>t<"F"ip>'),M.renderer?t.isPlainObject(M.renderer)&&!M.renderer.header&&(M.renderer.header="jqueryui"):M.renderer="jqueryui"):t.extend(N,Gt.ext.classes,g.oClasses),T.addClass(N.sTable),M.iInitDisplayStart===r&&(M.iInitDisplayStart=g.iDisplayStart,M._iDisplayStart=g.iDisplayStart),null!==g.iDeferLoading){M.bDeferLoading=!0;var A=t.isArray(g.iDeferLoading);M._iRecordsDisplay=A?g.iDeferLoading[0]:g.iDeferLoading,M._iRecordsTotal=A?g.iDeferLoading[1]:g.iDeferLoading}var O=M.oLanguage;t.extend(!0,O,g.oLanguage),O.sUrl&&(t.ajax({dataType:"json",url:O.sUrl,success:function(e){a(e),i(w.oLanguage,e),t.extend(!0,O,e),at(M)},error:function(){at(M)}}),y=!0),null===g.asStripeClasses&&(M.asStripeClasses=[N.sStripeOdd,N.sStripeEven]);var D=M.asStripeClasses,I=T.children("tbody").find("tr").eq(0);t.inArray(!0,t.map(D,function(t,e){return I.hasClass(t)}))!==-1&&(t("tbody tr",this).removeClass(D.join(" ")),M.asDestroyStripes=D.slice());var R,L=[],F=this.getElementsByTagName("thead");if(0!==F.length&&(H(M.aoHeader,F[0]),L=z(M)),null===g.aoColumns)for(R=[],v=0,p=L.length;v<p;v++)R.push(null);else R=g.aoColumns;for(v=0,p=R.length;v<p;v++)f(M,L?L[v]:null);if(b(M,g.aoColumnDefs,R,function(t,e){d(M,t,e)}),I.length){var j=function(t,e){return null!==t.getAttribute("data-"+e)?e:null};t(I[0]).children("th, td").each(function(t,e){var n=M.aoColumns[t];if(n.mData===t){var o=j(e,"sort")||j(e,"order"),i=j(e,"filter")||j(e,"search");null===o&&null===i||(n.mData={_:t+".display",sort:null!==o?t+".@data-"+o:r,type:null!==o?t+".@data-"+o:r,filter:null!==i?t+".@data-"+i:r},d(M,t))}})}var B=M.oFeatures,U=function(){if(g.aaSorting===r){var e=M.aaSorting;for(v=0,p=e.length;v<p;v++)e[v][1]=M.aoColumns[v].asSorting[0]}Pt(M),B.bSort&&Lt(M,"aoDrawCallback",function(){if(M.bSorted){var e=wt(M),n={};t.each(e,function(t,e){n[e.src]=e.dir}),Ft(M,null,"order",[M,e,n]),Ct(M)}}),Lt(M,"aoDrawCallback",function(){(M.bSorted||"ssp"===Ut(M)||B.bDeferRender)&&Pt(M)},"sc");var n=T.children("caption").each(function(){this._captionSide=t(this).css("caption-side")}),o=T.children("thead");0===o.length&&(o=t("<thead/>").appendTo(T)),M.nTHead=o[0];var i=T.children("tbody");0===i.length&&(i=t("<tbody/>").appendTo(T)),M.nTBody=i[0];var a=T.children("tfoot");if(0===a.length&&n.length>0&&(""!==M.oScroll.sX||""!==M.oScroll.sY)&&(a=t("<tfoot/>").appendTo(T)),0===a.length||0===a.children().length?T.addClass(N.sNoFooter):a.length>0&&(M.nTFoot=a[0],H(M.aoFooter,M.nTFoot)),g.aaData)for(v=0;v<g.aaData.length;v++)x(M,g.aaData[v]);else(M.bDeferLoading||"dom"==Ut(M))&&_(M,t(M.nTBody).children("tr"));M.aiDisplay=M.aiDisplayMaster.slice(),M.bInitialised=!0,y===!1&&at(M)};g.bStateSave?(B.bStateSave=!0,Lt(M,"aoDrawCallback",Mt,"state_save"),Nt(M,g,U)):U()}),n=null,this},Xt={},$t=/[\r\n]/g,Zt=/<.*?>/g,Jt=/^\d{2,4}[\.\/\-]\d{1,2}[\.\/\-]\d{1,2}([T ]{1}\d{1,2}[:\.]\d{2}([\.:]\d{2})?)?$/,Qt=new RegExp("(\\"+["/",".","*","+","?","|","(",")","[","]","{","}","\\","$","^","-"].join("|\\")+")","g"),te=/[',$£€¥%\u2009\u202F\u20BD\u20a9\u20BArfk]/gi,ee=function(t){return!t||t===!0||"-"===t},ne=function(t){var e=parseInt(t,10);return!isNaN(e)&&isFinite(t)?e:null},re=function(t,e){return Xt[e]||(Xt[e]=new RegExp(ve(e),"g")),"string"==typeof t&&"."!==e?t.replace(/\./g,"").replace(Xt[e],"."):t},oe=function(t,e,n){var r="string"==typeof t;return!!ee(t)||(e&&r&&(t=re(t,e)),n&&r&&(t=t.replace(te,"")),!isNaN(parseFloat(t))&&isFinite(t))},ie=function(t){return ee(t)||"string"==typeof t},ae=function(t,e,n){if(ee(t))return!0;var r=ie(t);return r?!!oe(fe(t),e,n)||null:null},se=function(t,e,n){var o=[],i=0,a=t.length;if(n!==r)for(;i<a;i++)t[i]&&t[i][e]&&o.push(t[i][e][n]);else for(;i<a;i++)t[i]&&o.push(t[i][e]);return o},le=function(t,e,n,o){var i=[],a=0,s=e.length;if(o!==r)for(;a<s;a++)t[e[a]][n]&&i.push(t[e[a]][n][o]);else for(;a<s;a++)i.push(t[e[a]][n]);return i},ue=function(t,e){var n,o=[];e===r?(e=0,n=t):(n=e,e=t);for(var i=e;i<n;i++)o.push(i);return o},ce=function(t){for(var e=[],n=0,r=t.length;n<r;n++)t[n]&&e.push(t[n]);return e},fe=function(t){return t.replace(Zt,"")},de=function(t){var e,n,r,o=[],i=t.length,a=0;t:for(n=0;n<i;n++){for(e=t[n],r=0;r<a;r++)if(o[r]===e)continue t;o.push(e),a++}return o};Gt.util={throttle:function(t,e){var n,o,i=e!==r?e:200;return function(){var e=this,a=+new Date,s=arguments;n&&a<n+i?(clearTimeout(o),o=setTimeout(function(){n=r,t.apply(e,s)},i)):(n=a,t.apply(e,s))}},escapeRegex:function(t){return t.replace(Qt,"\\$1")}};var pe=function(t,e,n){t[e]!==r&&(t[n]=t[e])},he=/\[.*?\]$/,ge=/\(\)$/,ve=Gt.util.escapeRegex,me=t("<div>")[0],ye=me.textContent!==r,be=/<.*?>/g,xe=Gt.util.throttle,_e=[],we=Array.prototype,Te=function(e){var n,r,o=Gt.settings,i=t.map(o,function(t,e){return t.nTable});return e?e.nTable&&e.oApi?[e]:e.nodeName&&"table"===e.nodeName.toLowerCase()?(n=t.inArray(e,i),n!==-1?[o[n]]:null):e&&"function"==typeof e.settings?e.settings().toArray():("string"==typeof e?r=t(e):e instanceof t&&(r=e),r?r.map(function(e){return n=t.inArray(this,i),n!==-1?o[n]:null}).toArray():void 0):[]};Vt=function(e,n){if(!(this instanceof Vt))return new Vt(e,n);var r=[],o=function(t){var e=Te(t);e&&(r=r.concat(e))};if(t.isArray(e))for(var i=0,a=e.length;i<a;i++)o(e[i]);else o(e);this.context=de(r),n&&t.merge(this,n),this.selector={rows:null,cols:null,opts:null},Vt.extend(this,this,_e)},Gt.Api=Vt,t.extend(Vt.prototype,{any:function(){return 0!==this.count()},concat:we.concat,context:[],count:function(){return this.flatten().length},each:function(t){for(var e=0,n=this.length;e<n;e++)t.call(this,this[e],e,this);return this},eq:function(t){var e=this.context;return e.length>t?new Vt(e[t],this[t]):null},filter:function(t){var e=[];if(we.filter)e=we.filter.call(this,t,this);else for(var n=0,r=this.length;n<r;n++)t.call(this,this[n],n,this)&&e.push(this[n]);return new Vt(this.context,e)},flatten:function(){var t=[];return new Vt(this.context,t.concat.apply(t,this.toArray()))},join:we.join,indexOf:we.indexOf||function(t,e){for(var n=e||0,r=this.length;n<r;n++)if(this[n]===t)return n;return-1},iterator:function(t,e,n,o){var i,a,s,l,u,c,f,d,p=[],h=this.context,g=this.selector;for("string"==typeof t&&(o=n,n=e,e=t,t=!1),a=0,s=h.length;a<s;a++){var v=new Vt(h[a]);if("table"===e)i=n.call(v,h[a],a),i!==r&&p.push(i);else if("columns"===e||"rows"===e)i=n.call(v,h[a],this[a],a),i!==r&&p.push(i);else if("column"===e||"column-rows"===e||"row"===e||"cell"===e)for(f=this[a],"column-rows"===e&&(c=Me(h[a],g.opts)),l=0,u=f.length;l<u;l++)d=f[l],i="cell"===e?n.call(v,h[a],d.row,d.column,a,l):n.call(v,h[a],d,a,l,c),i!==r&&p.push(i)}if(p.length||o){var m=new Vt(h,t?p.concat.apply([],p):p),y=m.selector;return y.rows=g.rows,y.cols=g.cols,y.opts=g.opts,m}return this},lastIndexOf:we.lastIndexOf||function(t,e){return this.indexOf.apply(this.toArray.reverse(),arguments)},length:0,map:function(t){var e=[];if(we.map)e=we.map.call(this,t,this);else for(var n=0,r=this.length;n<r;n++)e.push(t.call(this,this[n],n));return new Vt(this.context,e)},pluck:function(t){return this.map(function(e){return e[t]})},pop:we.pop,push:we.push,reduce:we.reduce||function(t,e){return c(this,t,e,0,this.length,1)},reduceRight:we.reduceRight||function(t,e){return c(this,t,e,this.length-1,-1,-1)},reverse:we.reverse,selector:null,shift:we.shift,sort:we.sort,splice:we.splice,toArray:function(){return we.slice.call(this)},to$:function(){return t(this)},toJQuery:function(){return t(this)},unique:function(){return new Vt(this.context,de(this))},unshift:we.unshift}),Vt.extend=function(e,n,r){if(r.length&&n&&(n instanceof Vt||n.__dt_wrapper)){var o,i,a,s=function(t,e,n){return function(){var r=e.apply(t,arguments);return Vt.extend(r,r,n.methodExt),r}};for(o=0,i=r.length;o<i;o++)a=r[o],n[a.name]="function"==typeof a.val?s(e,a.val,a):t.isPlainObject(a.val)?{}:a.val,n[a.name].__dt_wrapper=!0,Vt.extend(e,n[a.name],a.propExt)}},Vt.register=Kt=function(e,n){if(t.isArray(e))for(var r=0,o=e.length;r<o;r++)Vt.register(e[r],n);else{var i,a,s,l,u=e.split("."),c=_e,f=function(t,e){for(var n=0,r=t.length;n<r;n++)if(t[n].name===e)return t[n];return null};for(i=0,a=u.length;i<a;i++){l=u[i].indexOf("()")!==-1,s=l?u[i].replace("()",""):u[i];var d=f(c,s);d||(d={name:s,val:{},methodExt:[],propExt:[]},c.push(d)),i===a-1?d.val=n:c=l?d.methodExt:d.propExt}}},Vt.registerPlural=Yt=function(e,n,o){Vt.register(e,o),Vt.register(n,function(){var e=o.apply(this,arguments);return e===this?this:e instanceof Vt?e.length?t.isArray(e[0])?new Vt(e.context,e[0]):e[0]:r:e})};var Ce=function(e,n){if("number"==typeof e)return[n[e]];var r=t.map(n,function(t,e){return t.nTable});return t(r).filter(e).map(function(e){var o=t.inArray(this,r);return n[o]}).toArray()};Kt("tables()",function(t){return t?new Vt(Ce(t,this.context)):this}),Kt("table()",function(t){var e=this.tables(t),n=e.context;return n.length?new Vt(n[0]):e}),Yt("tables().nodes()","table().node()",function(){return this.iterator("table",function(t){return t.nTable},1)}),Yt("tables().body()","table().body()",function(){return this.iterator("table",function(t){return t.nTBody},1)}),Yt("tables().header()","table().header()",function(){return this.iterator("table",function(t){return t.nTHead},1)}),Yt("tables().footer()","table().footer()",function(){return this.iterator("table",function(t){return t.nTFoot},1)}),Yt("tables().containers()","table().container()",function(){return this.iterator("table",function(t){return t.nTableWrapper},1)}),Kt("draw()",function(t){return this.iterator("table",function(e){"page"===t?j(e):("string"==typeof t&&(t="full-hold"!==t),B(e,t===!1))})}),Kt("page()",function(t){return t===r?this.page.info().page:this.iterator("table",function(e){ft(e,t)})}),Kt("page.info()",function(t){if(0===this.context.length)return r;var e=this.context[0],n=e._iDisplayStart,o=e.oFeatures.bPaginate?e._iDisplayLength:-1,i=e.fnRecordsDisplay(),a=o===-1;return{page:a?0:Math.floor(n/o),pages:a?1:Math.ceil(i/o),start:n,end:e.fnDisplayEnd(),length:o,recordsTotal:e.fnRecordsTotal(),recordsDisplay:i,serverSide:"ssp"===Ut(e)}}),Kt("page.len()",function(t){return t===r?0!==this.context.length?this.context[0]._iDisplayLength:r:this.iterator("table",function(e){lt(e,t)})});var ke=function(t,e,n){if(n){var r=new Vt(t);r.one("draw",function(){n(r.ajax.json())})}if("ssp"==Ut(t))B(t,e);else{pt(t,!0);var o=t.jqXHR;o&&4!==o.readyState&&o.abort(),W(t,[],function(n){N(t);for(var r=Y(t,n),o=0,i=r.length;o<i;o++)x(t,r[o]);B(t,e),pt(t,!1)})}};Kt("ajax.json()",function(){var t=this.context;if(t.length>0)return t[0].json}),Kt("ajax.params()",function(){var t=this.context;if(t.length>0)return t[0].oAjaxData}),Kt("ajax.reload()",function(t,e){return this.iterator("table",function(n){ke(n,e===!1,t)})}),Kt("ajax.url()",function(e){var n=this.context;return e===r?0===n.length?r:(n=n[0],n.ajax?t.isPlainObject(n.ajax)?n.ajax.url:n.ajax:n.sAjaxSource):this.iterator("table",function(n){t.isPlainObject(n.ajax)?n.ajax.url=e:n.ajax=e})}),Kt("ajax.url().load()",function(t,e){return this.iterator("table",function(n){ke(n,e===!1,t)})});var Ee=function(e,n,o,i,a){var s,l,u,c,f,d,p=[],h=typeof n;for(n&&"string"!==h&&"function"!==h&&n.length!==r||(n=[n]),u=0,c=n.length;u<c;u++)for(l=n[u]&&n[u].split&&!n[u].match(/[\[\(:]/)?n[u].split(","):[n[u]],f=0,d=l.length;f<d;f++)s=o("string"==typeof l[f]?t.trim(l[f]):l[f]),s&&s.length&&(p=p.concat(s));var g=qt.selector[e];if(g.length)for(u=0,c=g.length;u<c;u++)p=g[u](i,a,p);return de(p)},Pe=function(e){return e||(e={}),e.filter&&e.search===r&&(e.search=e.filter),t.extend({search:"none",order:"current",page:"all"},e)},Se=function(t){for(var e=0,n=t.length;e<n;e++)if(t[e].length>0)return t[0]=t[e],t[0].length=1,t.length=1,t.context=[t.context[e]],t;return t.length=0,t},Me=function(e,n){var r,o,i,a=[],s=e.aiDisplay,l=e.aiDisplayMaster,u=n.search,c=n.order,f=n.page;if("ssp"==Ut(e))return"removed"===u?[]:ue(0,l.length);if("current"==f)for(r=e._iDisplayStart,o=e.fnDisplayEnd();r<o;r++)a.push(s[r]);else if("current"==c||"applied"==c)a="none"==u?l.slice():"applied"==u?s.slice():t.map(l,function(e,n){return t.inArray(e,s)===-1?e:null});else if("index"==c||"original"==c)for(r=0,o=e.aoData.length;r<o;r++)"none"==u?a.push(r):(i=t.inArray(r,s),(i===-1&&"removed"==u||i>=0&&"applied"==u)&&a.push(r));return a},Ne=function(e,n,o){var i,a=function(n){var a=ne(n);if(null!==a&&!o)return[a];if(i||(i=Me(e,o)),null!==a&&t.inArray(a,i)!==-1)return[a];if(null===n||n===r||""===n)return i;if("function"==typeof n)return t.map(i,function(t){var r=e.aoData[t];return n(t,r._aData,r.nTr)?t:null});var s=ce(le(e.aoData,i,"nTr"));if(n.nodeName){if(n._DT_RowIndex!==r)return[n._DT_RowIndex];if(n._DT_CellIndex)return[n._DT_CellIndex.row];var l=t(n).closest("*[data-dt-row]");return l.length?[l.data("dt-row")]:[]}if("string"==typeof n&&"#"===n.charAt(0)){var u=e.aIds[n.replace(/^#/,"")];if(u!==r)return[u.idx]}return t(s).filter(n).map(function(){return this._DT_RowIndex}).toArray()};return Ee("row",n,a,e,o)};Kt("rows()",function(e,n){e===r?e="":t.isPlainObject(e)&&(n=e,e=""),n=Pe(n);var o=this.iterator("table",function(t){return Ne(t,e,n)},1);return o.selector.rows=e,o.selector.opts=n,o}),Kt("rows().nodes()",function(){return this.iterator("row",function(t,e){return t.aoData[e].nTr||r},1)}),Kt("rows().data()",function(){return this.iterator(!0,"rows",function(t,e){return le(t.aoData,e,"_aData")},1)}),Yt("rows().cache()","row().cache()",function(t){return this.iterator("row",function(e,n){var r=e.aoData[n];return"search"===t?r._aFilterData:r._aSortData},1)}),Yt("rows().invalidate()","row().invalidate()",function(t){return this.iterator("row",function(e,n){O(e,n,t)})}),Yt("rows().indexes()","row().index()",function(){return this.iterator("row",function(t,e){return e},1)}),Yt("rows().ids()","row().id()",function(t){for(var e=[],n=this.context,r=0,o=n.length;r<o;r++)for(var i=0,a=this[r].length;i<a;i++){var s=n[r].rowIdFn(n[r].aoData[this[r][i]]._aData);e.push((t===!0?"#":"")+s)}return new Vt(n,e)}),Yt("rows().remove()","row().remove()",function(){var t=this;return this.iterator("row",function(e,n,o){var i,a,s,l,u,c,f=e.aoData,d=f[n];for(f.splice(n,1),i=0,a=f.length;i<a;i++)if(u=f[i],c=u.anCells,null!==u.nTr&&(u.nTr._DT_RowIndex=i),null!==c)for(s=0,l=c.length;s<l;s++)c[s]._DT_CellIndex.row=i;A(e.aiDisplayMaster,n),A(e.aiDisplay,n),A(t[o],n,!1),jt(e);var p=e.rowIdFn(d._aData);p!==r&&delete e.aIds[p]}),this.iterator("table",function(t){for(var e=0,n=t.aoData.length;e<n;e++)t.aoData[e].idx=e}),this}),Kt("rows.add()",function(e){var n=this.iterator("table",function(t){var n,r,o,i=[];for(r=0,o=e.length;r<o;r++)n=e[r],n.nodeName&&"TR"===n.nodeName.toUpperCase()?i.push(_(t,n)[0]):i.push(x(t,n));return i},1),r=this.rows(-1);return r.pop(),t.merge(r,n),r}),Kt("row()",function(t,e){return Se(this.rows(t,e))}),Kt("row().data()",function(t){var e=this.context;return t===r?e.length&&this.length?e[0].aoData[this[0]]._aData:r:(e[0].aoData[this[0]]._aData=t,O(e[0],this[0],"data"),this)}),Kt("row().node()",function(){var t=this.context;return t.length&&this.length?t[0].aoData[this[0]].nTr||null:null}),Kt("row.add()",function(e){e instanceof t&&e.length&&(e=e[0]);var n=this.iterator("table",function(t){return e.nodeName&&"TR"===e.nodeName.toUpperCase()?_(t,e)[0]:x(t,e)});return this.row(n[0])});var Ae=function(e,n,r,o){var i=[],a=function(n,r){if(t.isArray(n)||n instanceof t)for(var o=0,s=n.length;o<s;o++)a(n[o],r);else if(n.nodeName&&"tr"===n.nodeName.toLowerCase())i.push(n);else{var l=t("<tr><td/></tr>").addClass(r);t("td",l).addClass(r).html(n)[0].colSpan=v(e),i.push(l[0])}};a(r,o),n._details&&n._details.detach(),n._details=t(i),n._detailsShow&&n._details.insertAfter(n.nTr)},Oe=function(t,e){var n=t.context;if(n.length){var o=n[0].aoData[e!==r?e:t[0]];o&&o._details&&(o._details.remove(),o._detailsShow=r,o._details=r)}},De=function(t,e){var n=t.context;if(n.length&&t.length){var r=n[0].aoData[t[0]];r._details&&(r._detailsShow=e,e?r._details.insertAfter(r.nTr):r._details.detach(),Ie(n[0]))}},Ie=function(t){var e=new Vt(t),n=".dt.DT_details",r="draw"+n,o="column-visibility"+n,i="destroy"+n,a=t.aoData;e.off(r+" "+o+" "+i),se(a,"_details").length>0&&(e.on(r,function(n,r){t===r&&e.rows({page:"current"}).eq(0).each(function(t){var e=a[t];e._detailsShow&&e._details.insertAfter(e.nTr)})}),e.on(o,function(e,n,r,o){if(t===n)for(var i,s=v(n),l=0,u=a.length;l<u;l++)i=a[l],i._details&&i._details.children("td[colspan]").attr("colspan",s)}),e.on(i,function(n,r){if(t===r)for(var o=0,i=a.length;o<i;o++)a[o]._details&&Oe(e,o)}))},Re="",Le=Re+"row().child",Fe=Le+"()";Kt(Fe,function(t,e){var n=this.context;return t===r?n.length&&this.length?n[0].aoData[this[0]]._details:r:(t===!0?this.child.show():t===!1?Oe(this):n.length&&this.length&&Ae(n[0],n[0].aoData[this[0]],t,e),this)}),Kt([Le+".show()",Fe+".show()"],function(t){return De(this,!0),this}),Kt([Le+".hide()",Fe+".hide()"],function(){return De(this,!1),this}),Kt([Le+".remove()",Fe+".remove()"],function(){return Oe(this),this}),Kt(Le+".isShown()",function(){var t=this.context;return!(!t.length||!this.length)&&(t[0].aoData[this[0]]._detailsShow||!1)});var je=/^([^:]+):(name|visIdx|visible)$/,Be=function(t,e,n,r,o){for(var i=[],a=0,s=o.length;a<s;a++)i.push(C(t,o[a],e));return i},Ue=function(e,n,r){var o=e.aoColumns,i=se(o,"sName"),a=se(o,"nTh"),s=function(n){var s=ne(n);if(""===n)return ue(o.length);if(null!==s)return[s>=0?s:o.length+s];if("function"==typeof n){var l=Me(e,r);return t.map(o,function(t,r){return n(r,Be(e,r,0,0,l),a[r])?r:null})}var u="string"==typeof n?n.match(je):"";if(u)switch(u[2]){case"visIdx":case"visible":var c=parseInt(u[1],10);if(c<0){var f=t.map(o,function(t,e){return t.bVisible?e:null});return[f[f.length+c]]}return[h(e,c)];case"name":return t.map(i,function(t,e){return t===u[1]?e:null});default:return[]}if(n.nodeName&&n._DT_CellIndex)return[n._DT_CellIndex.column];var d=t(a).filter(n).map(function(){return t.inArray(this,a)}).toArray();if(d.length||!n.nodeName)return d;var p=t(n).closest("*[data-dt-column]");return p.length?[p.data("dt-column")]:[]};return Ee("column",n,s,e,r)},He=function(e,n,o){var i,a,s,l,u=e.aoColumns,c=u[n],f=e.aoData;if(o===r)return c.bVisible;if(c.bVisible!==o){if(o){var d=t.inArray(!0,se(u,"bVisible"),n+1);for(a=0,s=f.length;a<s;a++)l=f[a].nTr,i=f[a].anCells,l&&l.insertBefore(i[n],i[d]||null)}else t(se(e.aoData,"anCells",n)).detach();c.bVisible=o,F(e,e.aoHeader),F(e,e.aoFooter),Mt(e)}};Kt("columns()",function(e,n){e===r?e="":t.isPlainObject(e)&&(n=e,e=""),n=Pe(n);var o=this.iterator("table",function(t){return Ue(t,e,n)},1);return o.selector.cols=e,o.selector.opts=n,o}),Yt("columns().header()","column().header()",function(t,e){return this.iterator("column",function(t,e){return t.aoColumns[e].nTh},1)}),Yt("columns().footer()","column().footer()",function(t,e){return this.iterator("column",function(t,e){return t.aoColumns[e].nTf},1)}),Yt("columns().data()","column().data()",function(){return this.iterator("column-rows",Be,1)}),Yt("columns().dataSrc()","column().dataSrc()",function(){return this.iterator("column",function(t,e){return t.aoColumns[e].mData},1)}),Yt("columns().cache()","column().cache()",function(t){return this.iterator("column-rows",function(e,n,r,o,i){return le(e.aoData,i,"search"===t?"_aFilterData":"_aSortData",n)},1)}),Yt("columns().nodes()","column().nodes()",function(){return this.iterator("column-rows",function(t,e,n,r,o){return le(t.aoData,o,"anCells",e)},1)}),Yt("columns().visible()","column().visible()",function(t,e){var n=this.iterator("column",function(e,n){return t===r?e.aoColumns[n].bVisible:void He(e,n,t)});return t!==r&&(this.iterator("column",function(n,r){Ft(n,null,"column-visibility",[n,r,t,e])}),(e===r||e)&&this.columns.adjust()),n}),Yt("columns().indexes()","column().index()",function(t){return this.iterator("column",function(e,n){return"visible"===t?g(e,n):n},1)}),Kt("columns.adjust()",function(){return this.iterator("table",function(t){p(t)},1)}),Kt("column.index()",function(t,e){if(0!==this.context.length){var n=this.context[0];if("fromVisible"===t||"toData"===t)return h(n,e);if("fromData"===t||"toVisible"===t)return g(n,e)}}),Kt("column()",function(t,e){return Se(this.columns(t,e))});var ze=function(e,n,o){var i,a,s,l,u,c,f,d=e.aoData,p=Me(e,o),h=ce(le(d,p,"anCells")),g=t([].concat.apply([],h)),v=e.aoColumns.length,m=function(n){var o="function"==typeof n;if(null===n||n===r||o){for(a=[],s=0,l=p.length;s<l;s++)for(i=p[s],u=0;u<v;u++)c={row:i,column:u},o?(f=d[i],n(c,C(e,i,u),f.anCells?f.anCells[u]:null)&&a.push(c)):a.push(c);return a}if(t.isPlainObject(n))return[n];var h=g.filter(n).map(function(t,e){return{row:e._DT_CellIndex.row,column:e._DT_CellIndex.column}}).toArray();return h.length||!n.nodeName?h:(f=t(n).closest("*[data-dt-row]"),f.length?[{row:f.data("dt-row"),column:f.data("dt-column")}]:[])};return Ee("cell",n,m,e,o)};Kt("cells()",function(e,n,o){if(t.isPlainObject(e)&&(e.row===r?(o=e,e=null):(o=n,n=null)),t.isPlainObject(n)&&(o=n,n=null),null===n||n===r)return this.iterator("table",function(t){return ze(t,e,Pe(o))});var i,a,s,l,u,c=this.columns(n,o),f=this.rows(e,o),d=this.iterator("table",function(t,e){for(i=[],a=0,s=f[e].length;a<s;a++)for(l=0,u=c[e].length;l<u;l++)i.push({row:f[e][a],column:c[e][l]});return i},1);return t.extend(d.selector,{cols:n,rows:e,opts:o}),d}),Yt("cells().nodes()","cell().node()",function(){
return this.iterator("cell",function(t,e,n){var o=t.aoData[e];return o&&o.anCells?o.anCells[n]:r},1)}),Kt("cells().data()",function(){return this.iterator("cell",function(t,e,n){return C(t,e,n)},1)}),Yt("cells().cache()","cell().cache()",function(t){return t="search"===t?"_aFilterData":"_aSortData",this.iterator("cell",function(e,n,r){return e.aoData[n][t][r]},1)}),Yt("cells().render()","cell().render()",function(t){return this.iterator("cell",function(e,n,r){return C(e,n,r,t)},1)}),Yt("cells().indexes()","cell().index()",function(){return this.iterator("cell",function(t,e,n){return{row:e,column:n,columnVisible:g(t,n)}},1)}),Yt("cells().invalidate()","cell().invalidate()",function(t){return this.iterator("cell",function(e,n,r){O(e,n,t,r)})}),Kt("cell()",function(t,e,n){return Se(this.cells(t,e,n))}),Kt("cell().data()",function(t){var e=this.context,n=this[0];return t===r?e.length&&n.length?C(e[0],n[0].row,n[0].column):r:(k(e[0],n[0].row,n[0].column,t),O(e[0],n[0].row,"data",n[0].column),this)}),Kt("order()",function(e,n){var o=this.context;return e===r?0!==o.length?o[0].aaSorting:r:("number"==typeof e?e=[[e,n]]:e.length&&!t.isArray(e[0])&&(e=Array.prototype.slice.call(arguments)),this.iterator("table",function(t){t.aaSorting=e.slice()}))}),Kt("order.listener()",function(t,e,n){return this.iterator("table",function(r){Et(r,t,e,n)})}),Kt("order.fixed()",function(e){if(!e){var n=this.context,o=n.length?n[0].aaSortingFixed:r;return t.isArray(o)?{pre:o}:o}return this.iterator("table",function(n){n.aaSortingFixed=t.extend(!0,{},e)})}),Kt(["columns().order()","column().order()"],function(e){var n=this;return this.iterator("table",function(r,o){var i=[];t.each(n[o],function(t,n){i.push([n,e])}),r.aaSorting=i})}),Kt("search()",function(e,n,o,i){var a=this.context;return e===r?0!==a.length?a[0].oPreviousSearch.sSearch:r:this.iterator("table",function(r){r.oFeatures.bFilter&&X(r,t.extend({},r.oPreviousSearch,{sSearch:e+"",bRegex:null!==n&&n,bSmart:null===o||o,bCaseInsensitive:null===i||i}),1)})}),Yt("columns().search()","column().search()",function(e,n,o,i){return this.iterator("column",function(a,s){var l=a.aoPreSearchCols;return e===r?l[s].sSearch:void(a.oFeatures.bFilter&&(t.extend(l[s],{sSearch:e+"",bRegex:null!==n&&n,bSmart:null===o||o,bCaseInsensitive:null===i||i}),X(a,a.oPreviousSearch,1)))})}),Kt("state()",function(){return this.context.length?this.context[0].oSavedState:null}),Kt("state.clear()",function(){return this.iterator("table",function(t){t.fnStateSaveCallback.call(t.oInstance,t,{})})}),Kt("state.loaded()",function(){return this.context.length?this.context[0].oLoadedState:null}),Kt("state.save()",function(){return this.iterator("table",function(t){Mt(t)})}),Gt.versionCheck=Gt.fnVersionCheck=function(t){for(var e,n,r=Gt.version.split("."),o=t.split("."),i=0,a=o.length;i<a;i++)if(e=parseInt(r[i],10)||0,n=parseInt(o[i],10)||0,e!==n)return e>n;return!0},Gt.isDataTable=Gt.fnIsDataTable=function(e){var n=t(e).get(0),r=!1;return e instanceof Gt.Api||(t.each(Gt.settings,function(e,o){var i=o.nScrollHead?t("table",o.nScrollHead)[0]:null,a=o.nScrollFoot?t("table",o.nScrollFoot)[0]:null;o.nTable!==n&&i!==n&&a!==n||(r=!0)}),r)},Gt.tables=Gt.fnTables=function(e){var n=!1;t.isPlainObject(e)&&(n=e.api,e=e.visible);var r=t.map(Gt.settings,function(n){if(!e||e&&t(n.nTable).is(":visible"))return n.nTable});return n?new Vt(r):r},Gt.camelToHungarian=i,Kt("$()",function(e,n){var r=this.rows(n).nodes(),o=t(r);return t([].concat(o.filter(e).toArray(),o.find(e).toArray()))}),t.each(["on","one","off"],function(e,n){Kt(n+"()",function(){var e=Array.prototype.slice.call(arguments);e[0]=t.map(e[0].split(/\s/),function(t){return t.match(/\.dt\b/)?t:t+".dt"}).join(" ");var r=t(this.tables().nodes());return r[n].apply(r,e),this})}),Kt("clear()",function(){return this.iterator("table",function(t){N(t)})}),Kt("settings()",function(){return new Vt(this.context,this.context)}),Kt("init()",function(){var t=this.context;return t.length?t[0].oInit:null}),Kt("data()",function(){return this.iterator("table",function(t){return se(t.aoData,"_aData")}).flatten()}),Kt("destroy()",function(n){return n=n||!1,this.iterator("table",function(r){var o,i=r.nTableWrapper.parentNode,a=r.oClasses,s=r.nTable,l=r.nTBody,u=r.nTHead,c=r.nTFoot,f=t(s),d=t(l),p=t(r.nTableWrapper),h=t.map(r.aoData,function(t){return t.nTr});r.bDestroying=!0,Ft(r,"aoDestroyCallback","destroy",[r]),n||new Vt(r).columns().visible(!0),p.off(".DT").find(":not(tbody *)").off(".DT"),t(e).off(".DT-"+r.sInstance),s!=u.parentNode&&(f.children("thead").detach(),f.append(u)),c&&s!=c.parentNode&&(f.children("tfoot").detach(),f.append(c)),r.aaSorting=[],r.aaSortingFixed=[],Pt(r),t(h).removeClass(r.asStripeClasses.join(" ")),t("th, td",u).removeClass(a.sSortable+" "+a.sSortableAsc+" "+a.sSortableDesc+" "+a.sSortableNone),r.bJUI&&(t("th span."+a.sSortIcon+", td span."+a.sSortIcon,u).detach(),t("th, td",u).each(function(){var e=t("div."+a.sSortJUIWrapper,this);t(this).append(e.contents()),e.detach()})),d.children().detach(),d.append(h);var g=n?"remove":"detach";f[g](),p[g](),!n&&i&&(i.insertBefore(s,r.nTableReinsertBefore),f.css("width",r.sDestroyWidth).removeClass(a.sTable),o=r.asDestroyStripes.length,o&&d.children().each(function(e){t(this).addClass(r.asDestroyStripes[e%o])}));var v=t.inArray(r,Gt.settings);v!==-1&&Gt.settings.splice(v,1)})}),t.each(["column","row","cell"],function(t,e){Kt(e+"s().every()",function(t){var n=this.selector.opts,o=this;return this.iterator(e,function(i,a,s,l,u){t.call(o[e](a,"cell"===e?s:n,"cell"===e?n:r),a,s,l,u)})})}),Kt("i18n()",function(e,n,o){var i=this.context[0],a=P(e)(i.oLanguage);return a===r&&(a=n),o!==r&&t.isPlainObject(a)&&(a=a[o]!==r?a[o]:a._),a.replace("%d",o)}),Gt.version="1.10.13",Gt.settings=[],Gt.models={},Gt.models.oSearch={bCaseInsensitive:!0,sSearch:"",bRegex:!1,bSmart:!0},Gt.models.oRow={nTr:null,anCells:null,_aData:[],_aSortData:null,_aFilterData:null,_sFilterRow:null,_sRowStripe:"",src:null,idx:-1},Gt.models.oColumn={idx:null,aDataSort:null,asSorting:null,bSearchable:null,bSortable:null,bVisible:null,_sManualType:null,_bAttrSrc:!1,fnCreatedCell:null,fnGetData:null,fnSetData:null,mData:null,mRender:null,nTh:null,nTf:null,sClass:null,sContentPadding:null,sDefaultContent:null,sName:null,sSortDataType:"std",sSortingClass:null,sSortingClassJUI:null,sTitle:null,sType:null,sWidth:null,sWidthOrig:null},Gt.defaults={aaData:null,aaSorting:[[0,"asc"]],aaSortingFixed:[],ajax:null,aLengthMenu:[10,25,50,100],aoColumns:null,aoColumnDefs:null,aoSearchCols:[],asStripeClasses:null,bAutoWidth:!0,bDeferRender:!1,bDestroy:!1,bFilter:!0,bInfo:!0,bJQueryUI:!1,bLengthChange:!0,bPaginate:!0,bProcessing:!1,bRetrieve:!1,bScrollCollapse:!1,bServerSide:!1,bSort:!0,bSortMulti:!0,bSortCellsTop:!1,bSortClasses:!0,bStateSave:!1,fnCreatedRow:null,fnDrawCallback:null,fnFooterCallback:null,fnFormatNumber:function(t){return t.toString().replace(/\B(?=(\d{3})+(?!\d))/g,this.oLanguage.sThousands)},fnHeaderCallback:null,fnInfoCallback:null,fnInitComplete:null,fnPreDrawCallback:null,fnRowCallback:null,fnServerData:null,fnServerParams:null,fnStateLoadCallback:function(t){try{return JSON.parse((t.iStateDuration===-1?sessionStorage:localStorage).getItem("DataTables_"+t.sInstance+"_"+location.pathname))}catch(t){}},fnStateLoadParams:null,fnStateLoaded:null,fnStateSaveCallback:function(t,e){try{(t.iStateDuration===-1?sessionStorage:localStorage).setItem("DataTables_"+t.sInstance+"_"+location.pathname,JSON.stringify(e))}catch(t){}},fnStateSaveParams:null,iStateDuration:7200,iDeferLoading:null,iDisplayLength:10,iDisplayStart:0,iTabIndex:0,oClasses:{},oLanguage:{oAria:{sSortAscending:": activate to sort column ascending",sSortDescending:": activate to sort column descending"},oPaginate:{sFirst:"First",sLast:"Last",sNext:"Next",sPrevious:"Previous"},sEmptyTable:"No data available in table",sInfo:"Showing _START_ to _END_ of _TOTAL_ entries",sInfoEmpty:"Showing 0 to 0 of 0 entries",sInfoFiltered:"(filtered from _MAX_ total entries)",sInfoPostFix:"",sDecimal:"",sThousands:",",sLengthMenu:"Show _MENU_ entries",sLoadingRecords:"Loading...",sProcessing:"Processing...",sSearch:"Search:",sSearchPlaceholder:"",sUrl:"",sZeroRecords:"No matching records found"},oSearch:t.extend({},Gt.models.oSearch),sAjaxDataProp:"data",sAjaxSource:null,sDom:"lfrtip",searchDelay:null,sPaginationType:"simple_numbers",sScrollX:"",sScrollXInner:"",sScrollY:"",sServerMethod:"GET",renderer:null,rowId:"DT_RowId"},o(Gt.defaults),Gt.defaults.column={aDataSort:null,iDataSort:-1,asSorting:["asc","desc"],bSearchable:!0,bSortable:!0,bVisible:!0,fnCreatedCell:null,mData:null,mRender:null,sCellType:"td",sClass:"",sContentPadding:"",sDefaultContent:null,sName:"",sSortDataType:"std",sTitle:null,sType:null,sWidth:null},o(Gt.defaults.column),Gt.models.oSettings={oFeatures:{bAutoWidth:null,bDeferRender:null,bFilter:null,bInfo:null,bLengthChange:null,bPaginate:null,bProcessing:null,bServerSide:null,bSort:null,bSortMulti:null,bSortClasses:null,bStateSave:null},oScroll:{bCollapse:null,iBarWidth:0,sX:null,sXInner:null,sY:null},oLanguage:{fnInfoCallback:null},oBrowser:{bScrollOversize:!1,bScrollbarLeft:!1,bBounding:!1,barWidth:0},ajax:null,aanFeatures:[],aoData:[],aiDisplay:[],aiDisplayMaster:[],aIds:{},aoColumns:[],aoHeader:[],aoFooter:[],oPreviousSearch:{},aoPreSearchCols:[],aaSorting:null,aaSortingFixed:[],asStripeClasses:null,asDestroyStripes:[],sDestroyWidth:0,aoRowCallback:[],aoHeaderCallback:[],aoFooterCallback:[],aoDrawCallback:[],aoRowCreatedCallback:[],aoPreDrawCallback:[],aoInitComplete:[],aoStateSaveParams:[],aoStateLoadParams:[],aoStateLoaded:[],sTableId:"",nTable:null,nTHead:null,nTFoot:null,nTBody:null,nTableWrapper:null,bDeferLoading:!1,bInitialised:!1,aoOpenRows:[],sDom:null,searchDelay:null,sPaginationType:"two_button",iStateDuration:0,aoStateSave:[],aoStateLoad:[],oSavedState:null,oLoadedState:null,sAjaxSource:null,sAjaxDataProp:null,bAjaxDataGet:!0,jqXHR:null,json:r,oAjaxData:r,fnServerData:null,aoServerParams:[],sServerMethod:null,fnFormatNumber:null,aLengthMenu:null,iDraw:0,bDrawing:!1,iDrawError:-1,_iDisplayLength:10,_iDisplayStart:0,_iRecordsTotal:0,_iRecordsDisplay:0,bJUI:null,oClasses:{},bFiltered:!1,bSorted:!1,bSortCellsTop:null,oInit:null,aoDestroyCallback:[],fnRecordsTotal:function(){return"ssp"==Ut(this)?1*this._iRecordsTotal:this.aiDisplayMaster.length},fnRecordsDisplay:function(){return"ssp"==Ut(this)?1*this._iRecordsDisplay:this.aiDisplay.length},fnDisplayEnd:function(){var t=this._iDisplayLength,e=this._iDisplayStart,n=e+t,r=this.aiDisplay.length,o=this.oFeatures,i=o.bPaginate;return o.bServerSide?i===!1||t===-1?e+r:Math.min(e+t,this._iRecordsDisplay):!i||n>r||t===-1?r:n},oInstance:null,sInstance:null,iTabIndex:0,nScrollHead:null,nScrollFoot:null,aLastSort:[],oPlugins:{},rowIdFn:null,rowId:null},Gt.ext=qt={buttons:{},classes:{},builder:"-source-",errMode:"alert",feature:[],search:[],selector:{cell:[],column:[],row:[]},internal:{},legacy:{ajax:null},pager:{},renderer:{pageButton:{},header:{}},order:{},type:{detect:[],search:{},order:{}},_unique:0,fnVersionCheck:Gt.fnVersionCheck,iApiIndex:0,oJUIClasses:{},sVersion:Gt.version},t.extend(qt,{afnFiltering:qt.search,aTypes:qt.type.detect,ofnSearch:qt.type.search,oSort:qt.type.order,afnSortData:qt.order,aoFeatures:qt.feature,oApi:qt.internal,oStdClasses:qt.classes,oPagination:qt.pager}),t.extend(Gt.ext.classes,{sTable:"dataTable",sNoFooter:"no-footer",sPageButton:"paginate_button",sPageButtonActive:"current",sPageButtonDisabled:"disabled",sStripeOdd:"odd",sStripeEven:"even",sRowEmpty:"dataTables_empty",sWrapper:"dataTables_wrapper",sFilter:"dataTables_filter",sInfo:"dataTables_info",sPaging:"dataTables_paginate paging_",sLength:"dataTables_length",sProcessing:"dataTables_processing",sSortAsc:"sorting_asc",sSortDesc:"sorting_desc",sSortable:"sorting",sSortableAsc:"sorting_asc_disabled",sSortableDesc:"sorting_desc_disabled",sSortableNone:"sorting_disabled",sSortColumn:"sorting_",sFilterInput:"",sLengthSelect:"",sScrollWrapper:"dataTables_scroll",sScrollHead:"dataTables_scrollHead",sScrollHeadInner:"dataTables_scrollHeadInner",sScrollBody:"dataTables_scrollBody",sScrollFoot:"dataTables_scrollFoot",sScrollFootInner:"dataTables_scrollFootInner",sHeaderTH:"",sFooterTH:"",sSortJUIAsc:"",sSortJUIDesc:"",sSortJUI:"",sSortJUIAscAllowed:"",sSortJUIDescAllowed:"",sSortJUIWrapper:"",sSortIcon:"",sJUIHeader:"",sJUIFooter:""}),function(){var e="";e="";var n=e+"ui-state-default",r=e+"css_right ui-icon ui-icon-",o=e+"fg-toolbar ui-toolbar ui-widget-header ui-helper-clearfix";t.extend(Gt.ext.oJUIClasses,Gt.ext.classes,{sPageButton:"fg-button ui-button "+n,sPageButtonActive:"ui-state-disabled",sPageButtonDisabled:"ui-state-disabled",sPaging:"dataTables_paginate fg-buttonset ui-buttonset fg-buttonset-multi ui-buttonset-multi paging_",sSortAsc:n+" sorting_asc",sSortDesc:n+" sorting_desc",sSortable:n+" sorting",sSortableAsc:n+" sorting_asc_disabled",sSortableDesc:n+" sorting_desc_disabled",sSortableNone:n+" sorting_disabled",sSortJUIAsc:r+"triangle-1-n",sSortJUIDesc:r+"triangle-1-s",sSortJUI:r+"carat-2-n-s",sSortJUIAscAllowed:r+"carat-1-n",sSortJUIDescAllowed:r+"carat-1-s",sSortJUIWrapper:"DataTables_sort_wrapper",sSortIcon:"DataTables_sort_icon",sScrollHead:"dataTables_scrollHead "+n,sScrollFoot:"dataTables_scrollFoot "+n,sHeaderTH:n,sFooterTH:n,sJUIHeader:o+" ui-corner-tl ui-corner-tr",sJUIFooter:o+" ui-corner-bl ui-corner-br"})}();var We=Gt.ext.pager;t.extend(We,{simple:function(t,e){return["previous","next"]},full:function(t,e){return["first","previous","next","last"]},numbers:function(t,e){return[Ht(t,e)]},simple_numbers:function(t,e){return["previous",Ht(t,e),"next"]},full_numbers:function(t,e){return["first","previous",Ht(t,e),"next","last"]},first_last_numbers:function(t,e){return["first",Ht(t,e),"last"]},_numbers:Ht,numbers_length:7}),t.extend(!0,Gt.ext.renderer,{pageButton:{_:function(e,o,i,a,s,l){var u,c,f,d=e.oClasses,p=e.oLanguage.oPaginate,h=e.oLanguage.oAria.paginate||{},g=0,v=function(n,r){var o,a,f,m,y=function(t){ft(e,t.data.action,!0)};for(o=0,a=r.length;o<a;o++)if(m=r[o],t.isArray(m)){var b=t("<"+(m.DT_el||"div")+"/>").appendTo(n);v(b,m)}else{switch(u=null,c="",m){case"ellipsis":n.append('<span class="ellipsis">&#x2026;</span>');break;case"first":u=p.sFirst,c=m+(s>0?"":" "+d.sPageButtonDisabled);break;case"previous":u=p.sPrevious,c=m+(s>0?"":" "+d.sPageButtonDisabled);break;case"next":u=p.sNext,c=m+(s<l-1?"":" "+d.sPageButtonDisabled);break;case"last":u=p.sLast,c=m+(s<l-1?"":" "+d.sPageButtonDisabled);break;default:u=m+1,c=s===m?d.sPageButtonActive:""}null!==u&&(f=t("<a>",{class:d.sPageButton+" "+c,"aria-controls":e.sTableId,"aria-label":h[m],"data-dt-idx":g,tabindex:e.iTabIndex,id:0===i&&"string"==typeof m?e.sTableId+"_"+m:null}).html(u).appendTo(n),Rt(f,{action:m},y),g++)}};try{f=t(o).find(n.activeElement).data("dt-idx")}catch(t){}v(t(o).empty(),a),f!==r&&t(o).find("[data-dt-idx="+f+"]").focus()}}}),t.extend(Gt.ext.type.detect,[function(t,e){var n=e.oLanguage.sDecimal;return oe(t,n)?"num"+n:null},function(t,e){if(t&&!(t instanceof Date)&&!Jt.test(t))return null;var n=Date.parse(t);return null!==n&&!isNaN(n)||ee(t)?"date":null},function(t,e){var n=e.oLanguage.sDecimal;return oe(t,n,!0)?"num-fmt"+n:null},function(t,e){var n=e.oLanguage.sDecimal;return ae(t,n)?"html-num"+n:null},function(t,e){var n=e.oLanguage.sDecimal;return ae(t,n,!0)?"html-num-fmt"+n:null},function(t,e){return ee(t)||"string"==typeof t&&t.indexOf("<")!==-1?"html":null}]),t.extend(Gt.ext.type.search,{html:function(t){return ee(t)?t:"string"==typeof t?t.replace($t," ").replace(Zt,""):""},string:function(t){return ee(t)?t:"string"==typeof t?t.replace($t," "):t}});var qe=function(t,e,n,r){return 0===t||t&&"-"!==t?(e&&(t=re(t,e)),t.replace&&(n&&(t=t.replace(n,"")),r&&(t=t.replace(r,""))),1*t):-(1/0)};t.extend(qt.type.order,{"date-pre":function(t){return Date.parse(t)||-(1/0)},"html-pre":function(t){return ee(t)?"":t.replace?t.replace(/<.*?>/g,"").toLowerCase():t+""},"string-pre":function(t){return ee(t)?"":"string"==typeof t?t.toLowerCase():t.toString?t.toString():""},"string-asc":function(t,e){return t<e?-1:t>e?1:0},"string-desc":function(t,e){return t<e?1:t>e?-1:0}}),zt(""),t.extend(!0,Gt.ext.renderer,{header:{_:function(e,n,r,o){t(e.nTable).on("order.dt.DT",function(t,i,a,s){if(e===i){var l=r.idx;n.removeClass(r.sSortingClass+" "+o.sSortAsc+" "+o.sSortDesc).addClass("asc"==s[l]?o.sSortAsc:"desc"==s[l]?o.sSortDesc:r.sSortingClass)}})},jqueryui:function(e,n,r,o){t("<div/>").addClass(o.sSortJUIWrapper).append(n.contents()).append(t("<span/>").addClass(o.sSortIcon+" "+r.sSortingClassJUI)).appendTo(n),t(e.nTable).on("order.dt.DT",function(t,i,a,s){if(e===i){var l=r.idx;n.removeClass(o.sSortAsc+" "+o.sSortDesc).addClass("asc"==s[l]?o.sSortAsc:"desc"==s[l]?o.sSortDesc:r.sSortingClass),n.find("span."+o.sSortIcon).removeClass(o.sSortJUIAsc+" "+o.sSortJUIDesc+" "+o.sSortJUI+" "+o.sSortJUIAscAllowed+" "+o.sSortJUIDescAllowed).addClass("asc"==s[l]?o.sSortJUIAsc:"desc"==s[l]?o.sSortJUIDesc:r.sSortingClassJUI)}})}}});var Ve=function(t){return"string"==typeof t?t.replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;"):t};return Gt.render={number:function(t,e,n,r,o){return{display:function(i){if("number"!=typeof i&&"string"!=typeof i)return i;var a=i<0?"-":"",s=parseFloat(i);if(isNaN(s))return Ve(i);s=s.toFixed(n),i=Math.abs(s);var l=parseInt(i,10),u=n?e+(i-l).toFixed(n).substring(2):"";return a+(r||"")+l.toString().replace(/\B(?=(\d{3})+(?!\d))/g,t)+u+(o||"")}}},text:function(){return{display:Ve}}},t.extend(Gt.ext.internal,{_fnExternApiFunc:Wt,_fnBuildAjax:W,_fnAjaxUpdate:q,_fnAjaxParameters:V,_fnAjaxUpdateDraw:K,_fnAjaxDataSrc:Y,_fnAddColumn:f,_fnColumnOptions:d,_fnAdjustColumnSizing:p,_fnVisibleToColumnIndex:h,_fnColumnIndexToVisible:g,_fnVisbleColumns:v,_fnGetColumns:m,_fnColumnTypes:y,_fnApplyColumnDefs:b,_fnHungarianMap:o,_fnCamelToHungarian:i,_fnLanguageCompat:a,_fnBrowserDetect:u,_fnAddData:x,_fnAddTr:_,_fnNodeToDataIndex:w,_fnNodeToColumnIndex:T,_fnGetCellData:C,_fnSetCellData:k,_fnSplitObjNotation:E,_fnGetObjectDataFn:P,_fnSetObjectDataFn:S,_fnGetDataMaster:M,_fnClearTable:N,_fnDeleteIndex:A,_fnInvalidate:O,_fnGetRowElements:D,_fnCreateTr:I,_fnBuildHead:L,_fnDrawHead:F,_fnDraw:j,_fnReDraw:B,_fnAddOptionsHtml:U,_fnDetectHeader:H,_fnGetUniqueThs:z,_fnFeatureHtmlFilter:G,_fnFilterComplete:X,_fnFilterCustom:$,_fnFilterColumn:Z,_fnFilter:J,_fnFilterCreateSearch:Q,_fnEscapeRegex:ve,_fnFilterData:tt,_fnFeatureHtmlInfo:rt,_fnUpdateInfo:ot,_fnInfoMacros:it,_fnInitialise:at,_fnInitComplete:st,_fnLengthChange:lt,_fnFeatureHtmlLength:ut,_fnFeatureHtmlPaginate:ct,_fnPageChange:ft,_fnFeatureHtmlProcessing:dt,_fnProcessingDisplay:pt,_fnFeatureHtmlTable:ht,_fnScrollDraw:gt,_fnApplyToChildren:vt,_fnCalculateColumnWidths:mt,_fnThrottle:xe,_fnConvertToWidth:yt,_fnGetWidestNode:bt,_fnGetMaxLenString:xt,_fnStringToCss:_t,_fnSortFlatten:wt,_fnSort:Tt,_fnSortAria:Ct,_fnSortListener:kt,_fnSortAttachListener:Et,_fnSortingClasses:Pt,_fnSortData:St,_fnSaveState:Mt,_fnLoadState:Nt,_fnSettingsFromNode:At,_fnLog:Ot,_fnMap:Dt,_fnBindAction:Rt,_fnCallbackReg:Lt,_fnCallbackFire:Ft,_fnLengthOverflow:jt,_fnRenderer:Bt,_fnDataSource:Ut,_fnRowAttributes:R,_fnCalculateEnd:function(){}}),t.fn.dataTable=Gt,Gt.$=t,t.fn.dataTableSettings=Gt.settings,t.fn.dataTableExt=Gt.ext,t.fn.DataTable=function(e){return t(this).dataTable(e).api()},t.each(Gt,function(e,n){t.fn.DataTable[e]=n}),t.fn.dataTable})},function(t,e,n){"use strict";function r(){var t=void 0===arguments[0]?document:arguments[0];try{return t.activeElement}catch(t){}}var o=n(47);e.__esModule=!0,e.default=r;var i=n(31);o.interopRequireDefault(i),t.exports=e.default},function(t,e){"use strict";t.exports=function(t,e){return t.classList?!!e&&t.classList.contains(e):(" "+t.className+" ").indexOf(" "+e+" ")!==-1}},function(t,e,n){"use strict";var r=n(25),o=function(){};r&&(o=function(){return document.addEventListener?function(t,e,n,r){return t.removeEventListener(e,n,r||!1)}:document.attachEvent?function(t,e,n){return t.detachEvent("on"+e,n)}:void 0}()),t.exports=o},function(t,e,n){"use strict";var r=n(32),o=n(45),i=n(31);t.exports=function(t){var e=i(t),n=o(e),a=e&&e.documentElement,s={top:0,left:0,height:0,width:0};if(e)return r(a,t)?(void 0!==t.getBoundingClientRect&&(s=t.getBoundingClientRect()),(s.width||s.height)&&(s={top:s.top+(n.pageYOffset||a.scrollTop)-(a.clientTop||0),left:s.left+(n.pageXOffset||a.scrollLeft)-(a.clientLeft||0),width:(null==s.width?t.offsetWidth:s.width)||0,height:(null==s.height?t.offsetHeight:s.height)||0}),s):s}},function(t,e,n){"use strict";var r=n(45);t.exports=function(t,e){var n=r(t);return void 0===e?n?"pageYOffset"in n?n.pageYOffset:n.document.documentElement.scrollTop:t.scrollTop:void(n?n.scrollTo("pageXOffset"in n?n.pageXOffset:n.document.documentElement.scrollLeft,e):t.scrollTop=e)}},function(t,e,n){"use strict";var r=n(216),o=/^-ms-/;t.exports=function(t){return r(t.replace(o,"ms-"))}},function(t,e,n){"use strict";var r,o=n(25);t.exports=function(t){if((!r||t)&&o){var e=document.createElement("div");e.style.position="absolute",e.style.top="-9999px",e.style.width="50px",e.style.height="50px",e.style.overflow="scroll",document.body.appendChild(e),r=e.offsetWidth-e.clientWidth,document.body.removeChild(e)}return r}},function(t,e,n){t.exports=n.p+"f4769f9bdb7466be65088239c12046d1.eot"},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(18),b=r(y),x={active:m.default.PropTypes.bool,href:m.default.PropTypes.string,title:m.default.PropTypes.node,target:m.default.PropTypes.string},_={active:!1},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.active,n=t.href,r=t.title,o=t.target,a=t.className,l=(0,s.default)(t,["active","href","title","target","className"]),u={href:n,title:r,target:o};return m.default.createElement("li",{className:(0,g.default)(a,{active:e})},e?m.default.createElement("span",l):m.default.createElement(b.default,(0,i.default)({},l,u)))},e}(m.default.Component);w.propTypes=x,w.defaultProps=_,e.default=w,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(51),b=r(y),x=n(40),_=r(x),w=n(8),T={vertical:m.default.PropTypes.bool,justified:m.default.PropTypes.bool,block:(0,b.default)(m.default.PropTypes.bool,function(t){var e=t.block,n=t.vertical;return e&&!n?new Error("`block` requires `vertical` to be set to have any effect"):null})},C={block:!1,justified:!1,vertical:!1},k=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.block,r=e.justified,o=e.vertical,a=e.className,l=(0,s.default)(e,["block","justified","vertical","className"]),u=(0,w.splitBsProps)(l),c=u[0],f=u[1],d=(0,i.default)({},(0,w.getClassSet)(c),(t={},t[(0,w.prefix)(c)]=!o,t[(0,w.prefix)(c,"vertical")]=o,t[(0,w.prefix)(c,"justified")]=r,t[(0,w.prefix)(_.default.defaultProps,"block")]=n,t));return m.default.createElement("div",(0,i.default)({},f,{className:(0,g.default)(a,d)}))},e}(m.default.Component);k.propTypes=T,k.defaultProps=C,e.default=(0,w.bsClass)("btn-group",k),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(11),b=r(y),x=n(280),_=r(x),w={direction:m.default.PropTypes.oneOf(["prev","next"]),onAnimateOutEnd:m.default.PropTypes.func,active:m.default.PropTypes.bool,animateIn:m.default.PropTypes.bool,animateOut:m.default.PropTypes.bool,index:m.default.PropTypes.number},T={active:!1,animateIn:!1,animateOut:!1},C=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleAnimateOutEnd=o.handleAnimateOutEnd.bind(o),o.state={direction:null},o.isUnmounted=!1,o}return(0,p.default)(e,t),e.prototype.componentWillReceiveProps=function(t){this.props.active!==t.active&&this.setState({direction:null})},e.prototype.componentDidUpdate=function(t){var e=this,n=this.props.active,r=t.active;!n&&r&&_.default.addEndEventListener(b.default.findDOMNode(this),this.handleAnimateOutEnd),n!==r&&setTimeout(function(){return e.startAnimation()},20)},e.prototype.componentWillUnmount=function(){this.isUnmounted=!0},e.prototype.handleAnimateOutEnd=function(){this.isUnmounted||this.props.onAnimateOutEnd&&this.props.onAnimateOutEnd(this.props.index)},e.prototype.startAnimation=function(){this.isUnmounted||this.setState({direction:"prev"===this.props.direction?"right":"left"})},e.prototype.render=function(){var t=this.props,e=t.direction,n=t.active,r=t.animateIn,o=t.animateOut,a=t.className,l=(0,s.default)(t,["direction","active","animateIn","animateOut","className"]);delete l.onAnimateOutEnd,delete l.index;var u={item:!0,active:n&&!r||o};return e&&n&&r&&(u[e]=!0),this.state.direction&&(r||o)&&(u[this.state.direction]=!0),m.default.createElement("div",(0,i.default)({},l,{className:(0,g.default)(a,u)}))},e}(m.default.Component);C.propTypes=w,C.defaultProps=T,e.default=C,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(1),g=r(h),v=n(6),m=r(v),y=n(40),b=r(y),x=n(18),_=r(x),w=n(8),T={noCaret:g.default.PropTypes.bool,open:g.default.PropTypes.bool,title:g.default.PropTypes.string,useAnchor:g.default.PropTypes.bool},C={open:!1,useAnchor:!1,bsRole:"toggle"},k=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.noCaret,n=t.open,r=t.useAnchor,o=t.bsClass,a=t.className,l=t.children,u=(0,s.default)(t,["noCaret","open","useAnchor","bsClass","className","children"]);delete u.bsRole;var c=r?_.default:b.default,f=!e;return g.default.createElement(c,(0,i.default)({},u,{role:"button",className:(0,m.default)(a,o),"aria-haspopup":!0,"aria-expanded":n}),l||u.title,f&&" ",f&&g.default.createElement("span",{className:"caret"}))},e}(g.default.Component);k.propTypes=T,k.defaultProps=C,e.default=(0,w.bsClass)("dropdown-toggle",k),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={fluid:m.default.PropTypes.bool,componentClass:b.default},w={componentClass:"div",fluid:!1},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.fluid,n=t.componentClass,r=t.className,o=(0,s.default)(t,["fluid","componentClass","className"]),a=(0,x.splitBsProps)(o),l=a[0],u=a[1],c=(0,x.prefix)(l,e&&"fluid");return m.default.createElement(n,(0,i.default)({},u,{className:(0,g.default)(r,c)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("container",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(26),i=r(o),a=n(5),s=r(a),l=n(7),u=r(l),c=n(2),f=r(c),d=n(4),p=r(d),h=n(3),g=r(h),v=n(6),m=r(v),y=n(1),b=r(y),x=n(8),_=n(12),w={active:b.default.PropTypes.any,disabled:b.default.PropTypes.any,header:b.default.PropTypes.node,listItem:b.default.PropTypes.bool,onClick:b.default.PropTypes.func,href:b.default.PropTypes.string,type:b.default.PropTypes.string},T={listItem:!1},C=function(t){function e(){return(0,f.default)(this,e),(0,p.default)(this,t.apply(this,arguments))}return(0,g.default)(e,t),e.prototype.renderHeader=function(t,e){return b.default.isValidElement(t)?(0,y.cloneElement)(t,{className:(0,m.default)(t.props.className,e)}):b.default.createElement("h4",{className:e},t)},e.prototype.render=function(){var t=this.props,e=t.active,n=t.disabled,r=t.className,o=t.header,i=t.listItem,a=t.children,l=(0,u.default)(t,["active","disabled","className","header","listItem","children"]),c=(0,x.splitBsProps)(l),f=c[0],d=c[1],p=(0,s.default)({},(0,x.getClassSet)(f),{active:e,disabled:n}),h=void 0;return d.href?h="a":d.onClick?(h="button",d.type=d.type||"button"):h=i?"li":"span",d.className=(0,m.default)(r,p),o?b.default.createElement(h,d,this.renderHeader(o,(0,x.prefix)(f,"heading")),b.default.createElement("p",{className:(0,x.prefix)(f,"text")},a)):b.default.createElement(h,d,a)},e}(b.default.Component);C.propTypes=w,C.defaultProps=T,e.default=(0,x.bsClass)("list-group-item",(0,x.bsStyles)((0,i.default)(_.State),C)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("modal-body",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("modal-footer",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=n(10),x=r(b),_={"aria-label":m.default.PropTypes.string,closeButton:m.default.PropTypes.bool,onHide:m.default.PropTypes.func},w={"aria-label":"Close",closeButton:!1},T={$bs_modal:m.default.PropTypes.shape({onHide:m.default.PropTypes.func})},C=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t["aria-label"],n=t.closeButton,r=t.onHide,o=t.className,a=t.children,l=(0,s.default)(t,["aria-label","closeButton","onHide","className","children"]),u=this.context.$bs_modal,c=(0,y.splitBsProps)(l),f=c[0],d=c[1],p=(0,y.getClassSet)(f);return m.default.createElement("div",(0,i.default)({},d,{className:(0,g.default)(o,p)}),n&&m.default.createElement("button",{type:"button",className:"close","aria-label":e,onClick:(0,x.default)(u.onHide,r)},m.default.createElement("span",{"aria-hidden":"true"},"×")),a)},e}(m.default.Component);C.propTypes=_,C.defaultProps=w,C.contextTypes=T,e.default=(0,y.bsClass)("modal-header",C),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={
componentClass:b.default},w={componentClass:"h4"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("modal-title",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(76),m=r(v),y=n(1),b=r(y),x=n(11),_=r(x),w=n(51),T=r(w),C=n(15),k=(r(C),n(8)),E=n(10),P=r(E),S=n(13),M=r(S),N={activeKey:b.default.PropTypes.any,activeHref:b.default.PropTypes.string,stacked:b.default.PropTypes.bool,justified:(0,T.default)(b.default.PropTypes.bool,function(t){var e=t.justified,n=t.navbar;return e&&n?Error("justified navbar `Nav`s are not supported"):null}),onSelect:b.default.PropTypes.func,role:b.default.PropTypes.string,navbar:b.default.PropTypes.bool,pullRight:b.default.PropTypes.bool,pullLeft:b.default.PropTypes.bool},A={justified:!1,pullRight:!1,pullLeft:!1,stacked:!1},O={$bs_navbar:b.default.PropTypes.shape({bsClass:b.default.PropTypes.string,onSelect:b.default.PropTypes.func}),$bs_tabContainer:b.default.PropTypes.shape({activeKey:b.default.PropTypes.any,onSelect:b.default.PropTypes.func.isRequired,getTabId:b.default.PropTypes.func.isRequired,getPaneId:b.default.PropTypes.func.isRequired})},D=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.componentDidUpdate=function(){var t=this;if(this._needsRefocus){this._needsRefocus=!1;var e=this.props.children,n=this.getActiveProps(),r=n.activeKey,o=n.activeHref,i=M.default.find(e,function(e){return t.isActive(e,r,o)}),a=M.default.toArray(e),s=a.indexOf(i),l=_.default.findDOMNode(this).children,u=l&&l[s];u&&u.firstChild&&u.firstChild.focus()}},e.prototype.handleTabKeyDown=function(t,e){var n=void 0;switch(e.keyCode){case m.default.codes.left:case m.default.codes.up:n=this.getNextActiveChild(-1);break;case m.default.codes.right:case m.default.codes.down:n=this.getNextActiveChild(1);break;default:return}e.preventDefault(),t&&n&&n.props.eventKey&&t(n.props.eventKey),this._needsRefocus=!0},e.prototype.getNextActiveChild=function(t){var e=this,n=this.props.children,r=n.filter(function(t){return t.props.eventKey&&!t.props.disabled}),o=this.getActiveProps(),i=o.activeKey,a=o.activeHref,s=M.default.find(n,function(t){return e.isActive(t,i,a)}),l=r.indexOf(s);if(l===-1)return r[0];var u=l+t,c=r.length;return u>=c?u=0:u<0&&(u=c-1),r[u]},e.prototype.getActiveProps=function(){var t=this.context.$bs_tabContainer;return t?t:this.props},e.prototype.isActive=function(t,e,n){var r=t.props;return!!(r.active||null!=e&&r.eventKey===e||n&&r.href===n)||r.active},e.prototype.getTabProps=function(t,e,n,r,o){var i=this;if(!e&&"tablist"!==n)return null;var a=t.props,s=a.id,l=a["aria-controls"],u=a.eventKey,c=a.role,f=a.onKeyDown,d=a.tabIndex;return e&&(s=e.getTabId(u),l=e.getPaneId(u)),"tablist"===n&&(c=c||"tab",f=(0,P.default)(function(t){return i.handleTabKeyDown(o,t)},f),d=r?d:-1),{id:s,role:c,onKeyDown:f,"aria-controls":l,tabIndex:d}},e.prototype.render=function(){var t,e=this,n=this.props,r=n.stacked,o=n.justified,a=n.onSelect,l=n.role,u=n.navbar,c=n.pullRight,f=n.pullLeft,d=n.className,p=n.children,h=(0,s.default)(n,["stacked","justified","onSelect","role","navbar","pullRight","pullLeft","className","children"]),v=this.context.$bs_tabContainer,m=l||(v?"tablist":null),x=this.getActiveProps(),_=x.activeKey,w=x.activeHref;delete h.activeKey,delete h.activeHref;var T=(0,k.splitBsProps)(h),C=T[0],E=T[1],S=(0,i.default)({},(0,k.getClassSet)(C),(t={},t[(0,k.prefix)(C,"stacked")]=r,t[(0,k.prefix)(C,"justified")]=o,t)),N=null!=u?u:this.context.$bs_navbar,A=void 0,O=void 0;if(N){var D=this.context.$bs_navbar||{bsClass:"navbar"};S[(0,k.prefix)(D,"nav")]=!0,O=(0,k.prefix)(D,"right"),A=(0,k.prefix)(D,"left")}else O="pull-right",A="pull-left";return S[O]=c,S[A]=f,b.default.createElement("ul",(0,i.default)({},E,{role:m,className:(0,g.default)(d,S)}),M.default.map(p,function(t){var n=e.isActive(t,_,w),r=(0,P.default)(t.props.onSelect,a,N&&N.onSelect,v&&v.onSelect);return(0,y.cloneElement)(t,(0,i.default)({},e.getTabProps(t,v,m,n,r),{active:n,activeKey:_,activeHref:w,onSelect:r}))}))},e}(b.default.Component);D.propTypes=N,D.defaultProps=A,D.contextTypes=O,e.default=(0,k.bsClass)("nav",(0,k.bsStyles)(["tabs","pills"],D)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(18),b=r(y),x=n(10),_=r(x),w={active:m.default.PropTypes.bool,disabled:m.default.PropTypes.bool,role:m.default.PropTypes.string,href:m.default.PropTypes.string,onClick:m.default.PropTypes.func,onSelect:m.default.PropTypes.func,eventKey:m.default.PropTypes.any},T={active:!1,disabled:!1},C=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o}return(0,p.default)(e,t),e.prototype.handleClick=function(t){this.props.onSelect&&(t.preventDefault(),this.props.disabled||this.props.onSelect(this.props.eventKey,t))},e.prototype.render=function(){var t=this.props,e=t.active,n=t.disabled,r=t.onClick,o=t.className,a=t.style,l=(0,s.default)(t,["active","disabled","onClick","className","style"]);return delete l.onSelect,delete l.eventKey,delete l.activeKey,delete l.activeHref,l.role?"tab"===l.role&&(l["aria-selected"]=e):"#"===l.href&&(l.role="button"),m.default.createElement("li",{role:"presentation",className:(0,g.default)(o,{active:e,disabled:n}),style:a},m.default.createElement(b.default,(0,i.default)({},l,{disabled:n,onClick:(0,_.default)(r,this.handleClick)})))},e}(m.default.Component);C.propTypes=w,C.defaultProps=T,e.default=C,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b={$bs_navbar:m.default.PropTypes.shape({bsClass:m.default.PropTypes.string})},x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=t.children,r=(0,s.default)(t,["className","children"]),o=this.context.$bs_navbar||{bsClass:"navbar"},a=(0,y.prefix)(o,"brand");return m.default.isValidElement(n)?m.default.cloneElement(n,{className:(0,g.default)(n.props.className,e,a)}):m.default.createElement("span",(0,i.default)({},r,{className:(0,g.default)(e,a)}),n)},e}(m.default.Component);x.contextTypes=b,e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(7),i=r(o),a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(5),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(286),b=r(y),x=n(9),_=r(x),w=n(49),T=r(w),C=(0,p.default)({},b.default.propTypes,{show:m.default.PropTypes.bool,rootClose:m.default.PropTypes.bool,onHide:m.default.PropTypes.func,animation:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,_.default]),onEnter:m.default.PropTypes.func,onEntering:m.default.PropTypes.func,onEntered:m.default.PropTypes.func,onExit:m.default.PropTypes.func,onExiting:m.default.PropTypes.func,onExited:m.default.PropTypes.func,placement:m.default.PropTypes.oneOf(["top","right","bottom","left"])}),k={animation:T.default,rootClose:!1,show:!1,placement:"right"},E=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.animation,n=t.children,r=(0,i.default)(t,["animation","children"]),o=e===!0?T.default:e||null,a=void 0;return a=o?n:(0,v.cloneElement)(n,{className:(0,g.default)(n.props.className,"in")}),m.default.createElement(b.default,(0,p.default)({},r,{transition:o}),a)},e}(m.default.Component);E.propTypes=C,E.defaultProps=k,e.default=E,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(18),b=r(y),x=n(10),_=r(x),w={disabled:m.default.PropTypes.bool,previous:m.default.PropTypes.bool,next:m.default.PropTypes.bool,onClick:m.default.PropTypes.func,onSelect:m.default.PropTypes.func,eventKey:m.default.PropTypes.any},T={disabled:!1,previous:!1,next:!1},C=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleSelect=o.handleSelect.bind(o),o}return(0,p.default)(e,t),e.prototype.handleSelect=function(t){var e=this.props,n=e.disabled,r=e.onSelect,o=e.eventKey;(r||n)&&t.preventDefault(),n||r&&r(o,t)},e.prototype.render=function(){var t=this.props,e=t.disabled,n=t.previous,r=t.next,o=t.onClick,a=t.className,l=t.style,u=(0,s.default)(t,["disabled","previous","next","onClick","className","style"]);return delete u.onSelect,delete u.eventKey,m.default.createElement("li",{className:(0,g.default)(a,{disabled:e,previous:n,next:r}),style:l},m.default.createElement(b.default,(0,i.default)({},u,{disabled:e,onClick:(0,_.default)(o,this.handleSelect)})))},e}(m.default.Component);C.propTypes=w,C.defaultProps=T,e.default=C,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(97),s=r(a),l=n(7),u=r(l),c=n(2),f=r(c),d=n(4),p=r(d),h=n(3),g=r(h),v=n(6),m=r(v),y=n(1),b=r(y),x=n(8),_=n(10),w=r(_),T=n(13),C=r(T),k={accordion:b.default.PropTypes.bool,activeKey:b.default.PropTypes.any,defaultActiveKey:b.default.PropTypes.any,onSelect:b.default.PropTypes.func,role:b.default.PropTypes.string},E={accordion:!1},P=function(t){function e(n,r){(0,f.default)(this,e);var o=(0,p.default)(this,t.call(this,n,r));return o.handleSelect=o.handleSelect.bind(o),o.state={activeKey:n.defaultActiveKey},o}return(0,g.default)(e,t),e.prototype.handleSelect=function(t,e){e.preventDefault(),this.props.onSelect&&this.props.onSelect(t,e),this.state.activeKey===t&&(t=null),this.setState({activeKey:t})},e.prototype.render=function(){var t=this,e=this.props,n=e.accordion,r=e.activeKey,o=e.className,a=e.children,l=(0,u.default)(e,["accordion","activeKey","className","children"]),c=(0,x.splitBsPropsAndOmit)(l,["defaultActiveKey","onSelect"]),f=c[0],d=c[1],p=void 0;n&&(p=null!=r?r:this.state.activeKey,d.role=d.role||"tablist");var h=(0,x.getClassSet)(f);return b.default.createElement("div",(0,i.default)({},d,{className:(0,m.default)(o,h)}),C.default.map(a,function(e){var r={bsStyle:e.props.bsStyle||f.bsStyle};return n&&(0,s.default)(r,{headerRole:"tab",panelRole:"tabpanel",collapsible:!0,expanded:e.props.eventKey===p,onSelect:(0,w.default)(t.handleSelect,e.props.onSelect)}),(0,y.cloneElement)(e,r)}))},e}(b.default.Component);P.propTypes=k,P.defaultProps=E,e.default=(0,x.bsClass)("panel-group",P),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(15),_=(r(x),n(8)),w=n(10),T=r(w),C=n(49),k=r(C),E={eventKey:v.PropTypes.any,animation:v.PropTypes.oneOfType([v.PropTypes.bool,b.default]),id:v.PropTypes.string,"aria-labelledby":v.PropTypes.string,bsClass:m.default.PropTypes.string,onEnter:v.PropTypes.func,onEntering:v.PropTypes.func,onEntered:v.PropTypes.func,onExit:v.PropTypes.func,onExiting:v.PropTypes.func,onExited:v.PropTypes.func,unmountOnExit:v.PropTypes.bool},P={$bs_tabContainer:v.PropTypes.shape({getId:v.PropTypes.func,unmountOnExit:v.PropTypes.bool}),$bs_tabContent:v.PropTypes.shape({bsClass:v.PropTypes.string,animation:v.PropTypes.oneOfType([v.PropTypes.bool,b.default]),activeKey:v.PropTypes.any,unmountOnExit:v.PropTypes.bool,onPaneEnter:v.PropTypes.func.isRequired,onPaneExited:v.PropTypes.func.isRequired,exiting:v.PropTypes.bool.isRequired})},S={$bs_tabContainer:v.PropTypes.oneOf([null])},M=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleEnter=o.handleEnter.bind(o),o.handleExited=o.handleExited.bind(o),o.in=!1,o}return(0,p.default)(e,t),e.prototype.getChildContext=function(){return{$bs_tabContainer:null}},e.prototype.componentDidMount=function(){this.shouldBeIn()&&this.handleEnter()},e.prototype.componentDidUpdate=function(){this.in?this.shouldBeIn()||this.handleExited():this.shouldBeIn()&&this.handleEnter()},e.prototype.componentWillUnmount=function(){this.in&&this.handleExited()},e.prototype.handleEnter=function(){var t=this.context.$bs_tabContent;t&&(this.in=t.onPaneEnter(this,this.props.eventKey))},e.prototype.handleExited=function(){var t=this.context.$bs_tabContent;t&&(t.onPaneExited(this),this.in=!1)},e.prototype.getAnimation=function(){if(null!=this.props.animation)return this.props.animation;var t=this.context.$bs_tabContent;return t&&t.animation},e.prototype.isActive=function(){var t=this.context.$bs_tabContent,e=t&&t.activeKey;return this.props.eventKey===e},e.prototype.shouldBeIn=function(){return this.getAnimation()&&this.isActive()},e.prototype.render=function(){var t=this.props,e=t.eventKey,n=t.className,r=t.onEnter,o=t.onEntering,a=t.onEntered,l=t.onExit,u=t.onExiting,c=t.onExited,f=t.unmountOnExit,d=(0,s.default)(t,["eventKey","className","onEnter","onEntering","onEntered","onExit","onExiting","onExited","unmountOnExit"]),p=this.context,h=p.$bs_tabContent,v=p.$bs_tabContainer,y=(0,_.splitBsPropsAndOmit)(d,["animation"]),b=y[0],x=y[1],w=this.isActive(),C=this.getAnimation(),E=null!=f?f:h&&h.unmountOnExit;if(!w&&!C&&E)return null;var P=C===!0?k.default:C||null;h&&(b.bsClass=(0,_.prefix)(h,"pane"));var S=(0,i.default)({},(0,_.getClassSet)(b),{active:w});v&&(x.id=v.getPaneId(e),x["aria-labelledby"]=v.getTabId(e));var M=m.default.createElement("div",(0,i.default)({},x,{role:"tabpanel","aria-hidden":!w,className:(0,g.default)(n,S)}));if(P){var N=h&&h.exiting;return m.default.createElement(P,{in:w&&!N,onEnter:(0,T.default)(this.handleEnter,r),onEntering:o,onEntered:a,onExit:l,onExiting:u,onExited:(0,T.default)(this.handleExited,c),unmountOnExit:E},M)}return M},e}(m.default.Component);M.propTypes=E,M.contextTypes=P,M.childContextTypes=S,e.default=(0,_.bsClass)("tab-pane",M),t.exports=e.default},function(t,e){"use strict";function n(t){return""+t.charAt(0).toUpperCase()+t.slice(1)}e.__esModule=!0,e.default=n,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0});var o=n(1),i=r(o),a=n(11),s=r(a),l=n(83),u=r(l),c=n(41),f=r(c),d=n(82),p=r(d),h=i.default.createClass({displayName:"Portal",propTypes:{container:i.default.PropTypes.oneOfType([u.default,i.default.PropTypes.func])},componentDidMount:function(){this._renderOverlay()},componentDidUpdate:function(){this._renderOverlay()},componentWillReceiveProps:function(t){this._overlayTarget&&t.container!==this.props.container&&(this._portalContainerNode.removeChild(this._overlayTarget),this._portalContainerNode=(0,p.default)(t.container,(0,f.default)(this).body),this._portalContainerNode.appendChild(this._overlayTarget))},componentWillUnmount:function(){this._unrenderOverlay(),this._unmountOverlayTarget()},_mountOverlayTarget:function(){this._overlayTarget||(this._overlayTarget=document.createElement("div"),this._portalContainerNode=(0,p.default)(this.props.container,(0,f.default)(this).body),this._portalContainerNode.appendChild(this._overlayTarget))},_unmountOverlayTarget:function(){this._overlayTarget&&(this._portalContainerNode.removeChild(this._overlayTarget),this._overlayTarget=null),this._portalContainerNode=null},_renderOverlay:function(){var t=this.props.children?i.default.Children.only(this.props.children):null;null!==t?(this._mountOverlayTarget(),this._overlayInstance=s.default.unstable_renderSubtreeIntoContainer(this,t,this._overlayTarget)):(this._unrenderOverlay(),this._unmountOverlayTarget())},_unrenderOverlay:function(){this._overlayTarget&&(s.default.unmountComponentAtNode(this._overlayTarget),this._overlayInstance=null)},render:function(){return null},getMountNode:function(){return this._overlayTarget},getOverlayDOMNode:function(){if(!this.isMounted())throw new Error("getOverlayDOMNode(): A component must be mounted to have a DOM node.");return this._overlayInstance?s.default.findDOMNode(this._overlayInstance):null}});e.default=h,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}function s(t){return 0===t.button}function l(t){return!!(t.metaKey||t.altKey||t.ctrlKey||t.shiftKey)}Object.defineProperty(e,"__esModule",{value:!0});var u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),c=n(32),f=r(c),d=n(1),p=r(d),h=n(11),g=r(h),v=n(140),m=r(v),y=n(41),b=r(y),x=function(t){function e(t,n){o(this,e);var r=i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t,n));return r.handleMouseCapture=function(t){r.preventMouseRootClose=l(t)||!s(t)||(0,f.default)(g.default.findDOMNode(r),t.target)},r.handleMouse=function(){!r.preventMouseRootClose&&r.props.onRootClose&&r.props.onRootClose()},r.handleKeyUp=function(t){27===t.keyCode&&r.props.onRootClose&&r.props.onRootClose()},r.preventMouseRootClose=!1,r}return a(e,t),u(e,[{key:"componentDidMount",value:function(){this.props.disabled||this.addEventListeners()}},{key:"componentDidUpdate",value:function(t){!this.props.disabled&&t.disabled?this.addEventListeners():this.props.disabled&&!t.disabled&&this.removeEventListeners()}},{key:"componentWillUnmount",value:function(){this.props.disabled||this.removeEventListeners()}},{key:"addEventListeners",value:function(){var t=this.props.event,e=(0,b.default)(this);this.documentMouseCaptureListener=(0,m.default)(e,t,this.handleMouseCapture,!0),this.documentMouseListener=(0,m.default)(e,t,this.handleMouse),this.documentKeyupListener=(0,m.default)(e,"keyup",this.handleKeyUp)}},{key:"removeEventListeners",value:function(){this.documentMouseCaptureListener&&this.documentMouseCaptureListener.remove(),this.documentMouseListener&&this.documentMouseListener.remove(),this.documentKeyupListener&&this.documentKeyupListener.remove()}},{key:"render",value:function(){return this.props.children}}]),e}(p.default.Component);e.default=x,x.displayName="RootCloseWrapper",x.propTypes={onRootClose:p.default.PropTypes.func,children:p.default.PropTypes.element,disabled:p.default.PropTypes.bool,event:p.default.PropTypes.oneOf(["click","mousedown"])},x.defaultProps={event:"click"},t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}function i(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function a(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}function l(){}Object.defineProperty(e,"__esModule",{value:!0}),e.EXITING=e.ENTERED=e.ENTERING=e.EXITED=e.UNMOUNTED=void 0;var u=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},c=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),f=n(1),d=r(f),p=n(11),h=r(p),g=n(215),v=r(g),m=n(74),y=r(m),b=n(6),x=r(b),_=v.default.end,w=e.UNMOUNTED=0,T=e.EXITED=1,C=e.ENTERING=2,k=e.ENTERED=3,E=e.EXITING=4,P=function(t){function e(t,n){i(this,e);var r=a(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t,n)),o=void 0;return o=t.in?t.transitionAppear?T:k:t.unmountOnExit?w:T,r.state={status:o},r.nextCallback=null,r}return s(e,t),c(e,[{key:"componentDidMount",value:function(){this.props.transitionAppear&&this.props.in&&this.performEnter(this.props)}},{key:"componentWillReceiveProps",value:function(t){t.in&&this.props.unmountOnExit?this.state.status===w&&this.setState({status:T}):this._needsUpdate=!0}},{key:"componentDidUpdate",value:function(){var t=this.state.status;return this.props.unmountOnExit&&t===T?void(this.props.in?this.performEnter(this.props):this.setState({status:w})):void(this._needsUpdate&&(this._needsUpdate=!1,this.props.in?t===E?this.performEnter(this.props):t===T&&this.performEnter(this.props):t!==C&&t!==k||this.performExit(this.props)))}},{key:"componentWillUnmount",value:function(){this.cancelNextCallback()}},{key:"performEnter",value:function(t){var e=this;this.cancelNextCallback();var n=h.default.findDOMNode(this);t.onEnter(n),this.safeSetState({status:C},function(){e.props.onEntering(n),e.onTransitionEnd(n,function(){e.safeSetState({status:k},function(){e.props.onEntered(n)})})})}},{key:"performExit",value:function(t){var e=this;this.cancelNextCallback();var n=h.default.findDOMNode(this);t.onExit(n),this.safeSetState({status:E},function(){e.props.onExiting(n),e.onTransitionEnd(n,function(){e.safeSetState({status:T},function(){e.props.onExited(n)})})})}},{key:"cancelNextCallback",value:function(){null!==this.nextCallback&&(this.nextCallback.cancel(),this.nextCallback=null)}},{key:"safeSetState",value:function(t,e){this.setState(t,this.setNextCallback(e))}},{key:"setNextCallback",value:function(t){var e=this,n=!0;return this.nextCallback=function(r){n&&(n=!1,e.nextCallback=null,t(r))},this.nextCallback.cancel=function(){n=!1},this.nextCallback}},{key:"onTransitionEnd",value:function(t,e){this.setNextCallback(e),t?((0,y.default)(t,_,this.nextCallback),setTimeout(this.nextCallback,this.props.timeout)):setTimeout(this.nextCallback,0)}},{key:"render",value:function(){var t=this.state.status;if(t===w)return null;var n=this.props,r=n.children,i=n.className,a=o(n,["children","className"]);Object.keys(e.propTypes).forEach(function(t){return delete a[t]});var s=void 0;t===T?s=this.props.exitedClassName:t===C?s=this.props.enteringClassName:t===k?s=this.props.enteredClassName:t===E&&(s=this.props.exitingClassName);var l=d.default.Children.only(r);return d.default.cloneElement(l,u({},a,{className:(0,x.default)(l.props.className,i,s)}))}}]),e}(d.default.Component);P.propTypes={in:d.default.PropTypes.bool,unmountOnExit:d.default.PropTypes.bool,transitionAppear:d.default.PropTypes.bool,timeout:d.default.PropTypes.number,exitedClassName:d.default.PropTypes.string,exitingClassName:d.default.PropTypes.string,enteredClassName:d.default.PropTypes.string,enteringClassName:d.default.PropTypes.string,onEnter:d.default.PropTypes.func,onEntering:d.default.PropTypes.func,onEntered:d.default.PropTypes.func,onExit:d.default.PropTypes.func,onExiting:d.default.PropTypes.func,onExited:d.default.PropTypes.func},P.displayName="Transition",P.defaultProps={in:!1,unmountOnExit:!1,transitionAppear:!1,timeout:5e3,onEnter:l,onEntering:l,onEntered:l,onExit:l,onExiting:l,onExited:l},e.default=P},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0}),e.default=function(t,e,n,r){return(0,i.default)(t,e,n,r),{remove:function(){(0,s.default)(t,e,n,r)}}};var o=n(74),i=r(o),a=n(113),s=r(a);t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){return t&&"body"===t.tagName.toLowerCase()}function i(t){var e=(0,c.default)(t),n=(0,l.default)(e),r=n.innerWidth;if(!r){var o=e.documentElement.getBoundingClientRect();r=o.right-Math.abs(o.left)}return e.body.clientWidth<r}function a(t){var e=(0,l.default)(t);return e||o(t)?i(t):t.scrollHeight>t.clientHeight}Object.defineProperty(e,"__esModule",{value:!0}),e.default=a;var s=n(45),l=r(s),u=n(31),c=r(u);t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n,r){var o=this;return r.ignoreAccents&&(e=(0,a.default)(e)),r.ignoreCase&&(e=e.toLowerCase()),n&&(n=n.map(function(t){return t[r.valueKey]})),t.filter(function(t){if(n&&n.indexOf(t[r.valueKey])>-1)return!1;if(r.filterOption)return r.filterOption.call(o,t,e);if(!e)return!0;var i=String(t[r.valueKey]),s=String(t[r.labelKey]);return r.ignoreAccents&&("label"!==r.matchProp&&(i=(0,a.default)(i)),"value"!==r.matchProp&&(s=(0,a.default)(s))),r.ignoreCase&&("label"!==r.matchProp&&(i=i.toLowerCase()),"value"!==r.matchProp&&(s=s.toLowerCase())),"start"===r.matchPos?"label"!==r.matchProp&&i.substr(0,e.length)===e||"value"!==r.matchProp&&s.substr(0,e.length)===e:"label"!==r.matchProp&&i.indexOf(e)>=0||"value"!==r.matchProp&&s.indexOf(e)>=0})}var i=n(144),a=r(i);t.exports=o},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){var e=t.focusedOption,n=t.instancePrefix,r=(t.labelKey,t.onFocus),o=t.onSelect,i=t.optionClassName,s=t.optionComponent,u=t.optionRenderer,c=t.options,f=t.valueArray,d=t.valueKey,p=t.onOptionRef,h=s;return c.map(function(t,s){var c=f&&f.indexOf(t)>-1,g=t===e,v=(0,a.default)(i,{"Select-option":!0,"is-selected":c,"is-focused":g,"is-disabled":t.disabled});return l.default.createElement(h,{className:v,instancePrefix:n,isDisabled:t.disabled,isFocused:g,isSelected:c,key:"option-"+s+"-"+t[d],onFocus:r,onSelect:o,option:t,optionIndex:s,ref:function(t){p(t,g)}},u(t,s))})}var i=n(6),a=r(i),s=n(1),l=r(s);t.exports=o},function(t,e){"use strict";var n=[{base:"A",letters:/[\u0041\u24B6\uFF21\u00C0\u00C1\u00C2\u1EA6\u1EA4\u1EAA\u1EA8\u00C3\u0100\u0102\u1EB0\u1EAE\u1EB4\u1EB2\u0226\u01E0\u00C4\u01DE\u1EA2\u00C5\u01FA\u01CD\u0200\u0202\u1EA0\u1EAC\u1EB6\u1E00\u0104\u023A\u2C6F]/g},{base:"AA",letters:/[\uA732]/g},{base:"AE",letters:/[\u00C6\u01FC\u01E2]/g},{base:"AO",letters:/[\uA734]/g},{base:"AU",letters:/[\uA736]/g},{base:"AV",letters:/[\uA738\uA73A]/g},{base:"AY",letters:/[\uA73C]/g},{base:"B",letters:/[\u0042\u24B7\uFF22\u1E02\u1E04\u1E06\u0243\u0182\u0181]/g},{base:"C",letters:/[\u0043\u24B8\uFF23\u0106\u0108\u010A\u010C\u00C7\u1E08\u0187\u023B\uA73E]/g},{base:"D",letters:/[\u0044\u24B9\uFF24\u1E0A\u010E\u1E0C\u1E10\u1E12\u1E0E\u0110\u018B\u018A\u0189\uA779]/g},{base:"DZ",letters:/[\u01F1\u01C4]/g},{base:"Dz",letters:/[\u01F2\u01C5]/g},{base:"E",letters:/[\u0045\u24BA\uFF25\u00C8\u00C9\u00CA\u1EC0\u1EBE\u1EC4\u1EC2\u1EBC\u0112\u1E14\u1E16\u0114\u0116\u00CB\u1EBA\u011A\u0204\u0206\u1EB8\u1EC6\u0228\u1E1C\u0118\u1E18\u1E1A\u0190\u018E]/g},{base:"F",letters:/[\u0046\u24BB\uFF26\u1E1E\u0191\uA77B]/g},{base:"G",letters:/[\u0047\u24BC\uFF27\u01F4\u011C\u1E20\u011E\u0120\u01E6\u0122\u01E4\u0193\uA7A0\uA77D\uA77E]/g},{base:"H",letters:/[\u0048\u24BD\uFF28\u0124\u1E22\u1E26\u021E\u1E24\u1E28\u1E2A\u0126\u2C67\u2C75\uA78D]/g},{base:"I",letters:/[\u0049\u24BE\uFF29\u00CC\u00CD\u00CE\u0128\u012A\u012C\u0130\u00CF\u1E2E\u1EC8\u01CF\u0208\u020A\u1ECA\u012E\u1E2C\u0197]/g},{base:"J",letters:/[\u004A\u24BF\uFF2A\u0134\u0248]/g},{base:"K",letters:/[\u004B\u24C0\uFF2B\u1E30\u01E8\u1E32\u0136\u1E34\u0198\u2C69\uA740\uA742\uA744\uA7A2]/g},{base:"L",letters:/[\u004C\u24C1\uFF2C\u013F\u0139\u013D\u1E36\u1E38\u013B\u1E3C\u1E3A\u0141\u023D\u2C62\u2C60\uA748\uA746\uA780]/g},{base:"LJ",letters:/[\u01C7]/g},{base:"Lj",letters:/[\u01C8]/g},{base:"M",letters:/[\u004D\u24C2\uFF2D\u1E3E\u1E40\u1E42\u2C6E\u019C]/g},{base:"N",letters:/[\u004E\u24C3\uFF2E\u01F8\u0143\u00D1\u1E44\u0147\u1E46\u0145\u1E4A\u1E48\u0220\u019D\uA790\uA7A4]/g},{base:"NJ",letters:/[\u01CA]/g},{base:"Nj",letters:/[\u01CB]/g},{base:"O",letters:/[\u004F\u24C4\uFF2F\u00D2\u00D3\u00D4\u1ED2\u1ED0\u1ED6\u1ED4\u00D5\u1E4C\u022C\u1E4E\u014C\u1E50\u1E52\u014E\u022E\u0230\u00D6\u022A\u1ECE\u0150\u01D1\u020C\u020E\u01A0\u1EDC\u1EDA\u1EE0\u1EDE\u1EE2\u1ECC\u1ED8\u01EA\u01EC\u00D8\u01FE\u0186\u019F\uA74A\uA74C]/g},{base:"OI",letters:/[\u01A2]/g},{base:"OO",letters:/[\uA74E]/g},{base:"OU",letters:/[\u0222]/g},{base:"P",letters:/[\u0050\u24C5\uFF30\u1E54\u1E56\u01A4\u2C63\uA750\uA752\uA754]/g},{base:"Q",letters:/[\u0051\u24C6\uFF31\uA756\uA758\u024A]/g},{base:"R",letters:/[\u0052\u24C7\uFF32\u0154\u1E58\u0158\u0210\u0212\u1E5A\u1E5C\u0156\u1E5E\u024C\u2C64\uA75A\uA7A6\uA782]/g},{base:"S",letters:/[\u0053\u24C8\uFF33\u1E9E\u015A\u1E64\u015C\u1E60\u0160\u1E66\u1E62\u1E68\u0218\u015E\u2C7E\uA7A8\uA784]/g},{base:"T",letters:/[\u0054\u24C9\uFF34\u1E6A\u0164\u1E6C\u021A\u0162\u1E70\u1E6E\u0166\u01AC\u01AE\u023E\uA786]/g},{base:"TZ",letters:/[\uA728]/g},{base:"U",letters:/[\u0055\u24CA\uFF35\u00D9\u00DA\u00DB\u0168\u1E78\u016A\u1E7A\u016C\u00DC\u01DB\u01D7\u01D5\u01D9\u1EE6\u016E\u0170\u01D3\u0214\u0216\u01AF\u1EEA\u1EE8\u1EEE\u1EEC\u1EF0\u1EE4\u1E72\u0172\u1E76\u1E74\u0244]/g},{base:"V",letters:/[\u0056\u24CB\uFF36\u1E7C\u1E7E\u01B2\uA75E\u0245]/g},{base:"VY",letters:/[\uA760]/g},{base:"W",letters:/[\u0057\u24CC\uFF37\u1E80\u1E82\u0174\u1E86\u1E84\u1E88\u2C72]/g},{base:"X",letters:/[\u0058\u24CD\uFF38\u1E8A\u1E8C]/g},{base:"Y",letters:/[\u0059\u24CE\uFF39\u1EF2\u00DD\u0176\u1EF8\u0232\u1E8E\u0178\u1EF6\u1EF4\u01B3\u024E\u1EFE]/g},{base:"Z",letters:/[\u005A\u24CF\uFF3A\u0179\u1E90\u017B\u017D\u1E92\u1E94\u01B5\u0224\u2C7F\u2C6B\uA762]/g},{base:"a",letters:/[\u0061\u24D0\uFF41\u1E9A\u00E0\u00E1\u00E2\u1EA7\u1EA5\u1EAB\u1EA9\u00E3\u0101\u0103\u1EB1\u1EAF\u1EB5\u1EB3\u0227\u01E1\u00E4\u01DF\u1EA3\u00E5\u01FB\u01CE\u0201\u0203\u1EA1\u1EAD\u1EB7\u1E01\u0105\u2C65\u0250]/g},{base:"aa",letters:/[\uA733]/g},{base:"ae",letters:/[\u00E6\u01FD\u01E3]/g},{base:"ao",letters:/[\uA735]/g},{base:"au",letters:/[\uA737]/g},{base:"av",letters:/[\uA739\uA73B]/g},{base:"ay",letters:/[\uA73D]/g},{base:"b",letters:/[\u0062\u24D1\uFF42\u1E03\u1E05\u1E07\u0180\u0183\u0253]/g},{base:"c",letters:/[\u0063\u24D2\uFF43\u0107\u0109\u010B\u010D\u00E7\u1E09\u0188\u023C\uA73F\u2184]/g},{base:"d",letters:/[\u0064\u24D3\uFF44\u1E0B\u010F\u1E0D\u1E11\u1E13\u1E0F\u0111\u018C\u0256\u0257\uA77A]/g},{base:"dz",letters:/[\u01F3\u01C6]/g},{base:"e",letters:/[\u0065\u24D4\uFF45\u00E8\u00E9\u00EA\u1EC1\u1EBF\u1EC5\u1EC3\u1EBD\u0113\u1E15\u1E17\u0115\u0117\u00EB\u1EBB\u011B\u0205\u0207\u1EB9\u1EC7\u0229\u1E1D\u0119\u1E19\u1E1B\u0247\u025B\u01DD]/g},{base:"f",letters:/[\u0066\u24D5\uFF46\u1E1F\u0192\uA77C]/g},{base:"g",letters:/[\u0067\u24D6\uFF47\u01F5\u011D\u1E21\u011F\u0121\u01E7\u0123\u01E5\u0260\uA7A1\u1D79\uA77F]/g},{base:"h",letters:/[\u0068\u24D7\uFF48\u0125\u1E23\u1E27\u021F\u1E25\u1E29\u1E2B\u1E96\u0127\u2C68\u2C76\u0265]/g},{base:"hv",letters:/[\u0195]/g},{base:"i",letters:/[\u0069\u24D8\uFF49\u00EC\u00ED\u00EE\u0129\u012B\u012D\u00EF\u1E2F\u1EC9\u01D0\u0209\u020B\u1ECB\u012F\u1E2D\u0268\u0131]/g
},{base:"j",letters:/[\u006A\u24D9\uFF4A\u0135\u01F0\u0249]/g},{base:"k",letters:/[\u006B\u24DA\uFF4B\u1E31\u01E9\u1E33\u0137\u1E35\u0199\u2C6A\uA741\uA743\uA745\uA7A3]/g},{base:"l",letters:/[\u006C\u24DB\uFF4C\u0140\u013A\u013E\u1E37\u1E39\u013C\u1E3D\u1E3B\u017F\u0142\u019A\u026B\u2C61\uA749\uA781\uA747]/g},{base:"lj",letters:/[\u01C9]/g},{base:"m",letters:/[\u006D\u24DC\uFF4D\u1E3F\u1E41\u1E43\u0271\u026F]/g},{base:"n",letters:/[\u006E\u24DD\uFF4E\u01F9\u0144\u00F1\u1E45\u0148\u1E47\u0146\u1E4B\u1E49\u019E\u0272\u0149\uA791\uA7A5]/g},{base:"nj",letters:/[\u01CC]/g},{base:"o",letters:/[\u006F\u24DE\uFF4F\u00F2\u00F3\u00F4\u1ED3\u1ED1\u1ED7\u1ED5\u00F5\u1E4D\u022D\u1E4F\u014D\u1E51\u1E53\u014F\u022F\u0231\u00F6\u022B\u1ECF\u0151\u01D2\u020D\u020F\u01A1\u1EDD\u1EDB\u1EE1\u1EDF\u1EE3\u1ECD\u1ED9\u01EB\u01ED\u00F8\u01FF\u0254\uA74B\uA74D\u0275]/g},{base:"oi",letters:/[\u01A3]/g},{base:"ou",letters:/[\u0223]/g},{base:"oo",letters:/[\uA74F]/g},{base:"p",letters:/[\u0070\u24DF\uFF50\u1E55\u1E57\u01A5\u1D7D\uA751\uA753\uA755]/g},{base:"q",letters:/[\u0071\u24E0\uFF51\u024B\uA757\uA759]/g},{base:"r",letters:/[\u0072\u24E1\uFF52\u0155\u1E59\u0159\u0211\u0213\u1E5B\u1E5D\u0157\u1E5F\u024D\u027D\uA75B\uA7A7\uA783]/g},{base:"s",letters:/[\u0073\u24E2\uFF53\u00DF\u015B\u1E65\u015D\u1E61\u0161\u1E67\u1E63\u1E69\u0219\u015F\u023F\uA7A9\uA785\u1E9B]/g},{base:"t",letters:/[\u0074\u24E3\uFF54\u1E6B\u1E97\u0165\u1E6D\u021B\u0163\u1E71\u1E6F\u0167\u01AD\u0288\u2C66\uA787]/g},{base:"tz",letters:/[\uA729]/g},{base:"u",letters:/[\u0075\u24E4\uFF55\u00F9\u00FA\u00FB\u0169\u1E79\u016B\u1E7B\u016D\u00FC\u01DC\u01D8\u01D6\u01DA\u1EE7\u016F\u0171\u01D4\u0215\u0217\u01B0\u1EEB\u1EE9\u1EEF\u1EED\u1EF1\u1EE5\u1E73\u0173\u1E77\u1E75\u0289]/g},{base:"v",letters:/[\u0076\u24E5\uFF56\u1E7D\u1E7F\u028B\uA75F\u028C]/g},{base:"vy",letters:/[\uA761]/g},{base:"w",letters:/[\u0077\u24E6\uFF57\u1E81\u1E83\u0175\u1E87\u1E85\u1E98\u1E89\u2C73]/g},{base:"x",letters:/[\u0078\u24E7\uFF58\u1E8B\u1E8D]/g},{base:"y",letters:/[\u0079\u24E8\uFF59\u1EF3\u00FD\u0177\u1EF9\u0233\u1E8F\u00FF\u1EF7\u1E99\u1EF5\u01B4\u024F\u1EFF]/g},{base:"z",letters:/[\u007A\u24E9\uFF5A\u017A\u1E91\u017C\u017E\u1E93\u1E95\u01B6\u0225\u0240\u2C6C\uA763]/g}];t.exports=function(t){for(var e=0;e<n.length;e++)t=t.replace(n[e].letters,n[e].base);return t}},function(t,e){t.exports=n},function(t,e,n){(function(t){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function a(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.Datamaps=void 0;var l=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),u=n(1),c=r(u);e.Datamaps=function(e){function n(t){o(this,n);var e=a(this,(n.__proto__||Object.getPrototypeOf(n)).call(this,t));return e.state={chart:null},e}return s(n,e),l(n,[{key:"componentDidMount",value:function(){this._initialize(this.props.options.params)}},{key:"_initialize",value:function(e){var n=this.props.options.url.concat("?",t.param(e));t.get(n,function(t){this.state.chart=new i({element:document.getElementById(this.props.options.chartid),scope:"usa",fills:t.fills,data:t.data})}.bind(this))}},{key:"_update",value:function(e){var n=this.props.options.url.concat("?",t.param(e));t.get(n,function(t){this.state.chart.updateChoropleth(t.data)}.bind(this))}},{key:"render",value:function(){return c.default.createElement("div",{id:this.props.options.chartid,className:"pyDataMap"})}}]),n}(c.default.Component)}).call(e,n(14))},function(t,e,n){(function(t){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0});var o=n(1),i=(r(o),n(145)),s=r(i),l=function(){this.chart=a.models.pieChart()};l.prototype.initialize=function(t){this.chart.x(function(t){return t.label}).y(function(t){return t.value}).showLabels(!0).labelType(t.labelType).showLegend(!0).labelsOutside(!1).color(t.colors),this.chart.tooltip.contentGenerator(function(t){return'<h3 style="background-color: '+t.color+'">'+t.data.label+"</h3><p>"+100*t.data.value+"%</p>"})},l.prototype.get=function(e,n,r){s.default.json(n.concat("?",t.param(r)),function(t,n){s.default.select("#".concat(e," svg")).datum(n.data).transition().duration(500).call(this.chart),a.utils.windowResize(this.chart.update)}.bind(this))},e.default=l}).call(e,n(14))},function(t,e,n){(function(t){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0});var o=n(145),i=r(o),s=function(){function t(O){return O.each(function(O){function H(t){var e=2===O[t.seriesIndex].yAxis?b:y;t.value=t.point.x,t.series={value:t.point.y,color:t.point.color},D.duration(100).valueFormatter(function(t,n){return e.tickFormat()(t,n)}).data(t).position(t.pos).hidden(!1)}function z(t){var e=+("e"==t),n=e?1:-1,r=G/3;return"M"+.5*n+","+r+"A6,6 0 0 "+e+" "+6.5*n+","+(r+6)+"V"+(2*r-6)+"A6,6 0 0 "+e+" "+.5*n+","+2*r+"ZM"+2.5*n+","+(r+8)+"V"+(2*r-8)+"M"+4.5*n+","+(r+8)+"V"+(2*r-8)}function W(){T.empty()||T.extent(A),lt.data([T.empty()?o.domain():A]).each(function(t,n){var r=o(t[0])-e.range()[0],a=e.range()[1]-o(t[1]);i.default.select(this).select(".left").attr("width",r<0?0:r),i.default.select(this).select(".right").attr("x",o(t[1])).attr("width",a<0?0:a)})}function q(){A=T.empty()?null:T.extent();var t=T.empty()?o.domain():T.extent();if(!(Math.abs(t[0]-t[1])<=1)){R.brush({extent:t,brush:T}),W();var n=rt.select(".nv-focus .nv-lines1Wrap").datum(X.filter(function(t){return!t.disabled}).map(function(e,n){return{key:e.key,area:e.area,values:e.values.filter(function(e,n){return h.x()(e,n)>=t[0]&&h.x()(e,n)<=t[1]})}})),r=rt.select(".nv-focus .nv-lines2Wrap").datum($.filter(function(t){return!t.disabled}).map(function(e,n){return{key:e.key,area:e.area,values:e.values.filter(function(e,n){return g.x()(e,n)>=t[0]&&g.x()(e,n)<=t[1]})}}));n.transition().duration(L).call(h),r.transition().duration(L).call(g),rt.select(".nv-focus .nv-x.nv-axis").transition().duration(L).call(m),rt.select(".nv-focus .nv-y1.nv-axis").transition().duration(L).call(y),rt.select(".nv-focus .nv-y2.nv-axis").attr("transform","translate("+e.range()[1]+",0)").transition().duration(L).call(b)}}var V=i.default.select(this);a.utils.initSVG(V);var K=(P||parseInt(V.style("width"))||960)-C.left-C.right,Y=(S||parseInt(V.style("height"))||400)-C.top-C.bottom-M,G=M-k.top-k.bottom,X=O.filter(function(t){return 1==t.yAxis}),$=O.filter(function(t){return 2==t.yAxis});if(t.update=function(){V.transition().duration(L).call(t)},t.container=this,F.setter(U(O),t.update).getter(B(O)).update(),F.disabled=O.map(function(t){return!!t.disabled}),!j){var Z;j={};for(Z in F)F[Z]instanceof Array?j[Z]=F[Z].slice(0):j[Z]=F[Z]}if(!(O&&O.length&&O.filter(function(t){return t.values.length}).length)){var J=V.selectAll(".nv-noData").data([I]);return J.enter().append("text").attr("class","nvd3 nv-noData").attr("dy","-.7em").style("text-anchor","middle"),J.attr("x",C.left+K/2).attr("y",C.top+Y/2).text(function(t){return t}),t}V.selectAll(".nv-noData").remove();var Q=O.filter(function(t){return!t.disabled&&1==t.yAxis}).map(function(t){return t.values.map(function(t,e){return{x:t.x,y:t.y}})}),tt=O.filter(function(t){return!t.disabled&&2==t.yAxis}).map(function(t){return t.values.map(function(t,e){return{x:t.x,y:t.y}})});e=h.xScale(),n=h.yScale(),r=g.yScale(),o=v.xScale(),s=v.yScale();var et=V.selectAll("g.nv-wrap.nv-twoAxisFocusChart").data([O]),nt=et.enter().append("g").attr("class","nvd3 nv-wrap nv-twoAxisFocusChart").append("g"),rt=et.select("g");nt.append("g").attr("class","legendWrap");var ot=nt.append("g").attr("class","nv-focus");ot.append("g").attr("class","nv-x nv-axis"),ot.append("g").attr("class","nv-y1 nv-axis"),ot.append("g").attr("class","nv-y2 nv-axis"),ot.append("g").attr("class","nv-lines1Wrap"),ot.append("g").attr("class","nv-lines2Wrap");var it=nt.append("g").attr("class","nv-context");it.append("g").attr("class","nv-x nv-axis"),it.append("g").attr("class","nv-y nv-axis"),it.append("g").attr("class","nv-lines1Wrap"),it.append("g").attr("class","nv-brushBackground"),it.append("g").attr("class","nv-x nv-brush");var at=O.map(function(t,e){return O[e].color||E(t,e)});N&&(w.color(at),w.width(K/2),rt.select(".legendWrap").datum(O.map(function(t){return t.originalKey=void 0===t.originalKey?t.key:t.originalKey,t.key=t.originalKey+(1==t.yAxis?"":" (right axis)"),t})).call(w),C.top!=w.height()&&(C.top=w.height(),Y=(S||parseInt(V.style("height"))||400)-C.top-C.bottom-M,G=M-k.top-k.bottom),rt.select(".legendWrap").attr("transform","translate("+K/2+","+-C.top+")")),et.attr("transform","translate("+C.left+","+C.top+")"),h.width(K).height(Y).color(at.filter(function(t,e){return!O[e].disabled&&1==O[e].yAxis})),g.width(K).height(Y).color(at.filter(function(t,e){return!O[e].disabled&&2==O[e].yAxis})),v.width(K).height(G).color(at.filter(function(t,e){return 2==O[e].yAxis})),rt.select(".nv-context").attr("transform","translate(0,"+(Y+C.bottom+k.top)+")"),f.domain(l||i.default.extent(Q,function(t){return t.y})).range([0,Y]),d.domain(u||i.default.extent(tt,function(t){return t.y})).range([0,Y]),p.domain(c||i.default.extent(tt,function(t){return t.y})).range([G,0]),h.yDomain(f.domain()),g.yDomain(d.domain()),v.yDomain(p.domain());var st=rt.select(".nv-context .nv-lines1Wrap").datum($);$.length&&i.default.transition(st).call(v),m.scale(e).ticks(a.utils.calcTicksX(K/100,X)).tickSize(-Y,0),y.ticks(a.utils.calcTicksY(Y/36,X)).tickSize(-K,0),b.ticks(a.utils.calcTicksY(Y/36,$)).tickSize(-K,0),rt.select(".nv-focus .nv-x.nv-axis").attr("transform","translate(0,"+Y+")"),T.x(o).on("brush",function(){var e=t.duration();t.duration(0),q(),t.duration(e)}),A&&T.extent(A);var lt=rt.select(".nv-brushBackground").selectAll("g").data([A||T.extent()]),ut=lt.enter().append("g");ut.append("rect").attr("class","left").attr("x",0).attr("y",0).attr("height",G),ut.append("rect").attr("class","right").attr("x",0).attr("y",0).attr("height",G);var ct=rt.select(".nv-x.nv-brush").call(T);ct.selectAll("rect").attr("height",G),ct.selectAll(".resize").append("path").attr("d",z),q(),x.scale(o).ticks(a.utils.calcTicksX(K/100,$)).tickSize(-G,0),rt.select(".nv-context .nv-x.nv-axis").attr("transform","translate(0,"+p.range()[0]+")"),i.default.transition(rt.select(".nv-context .nv-x.nv-axis")).call(x),_.ticks(a.utils.calcTicksY(G/36,$)).tickSize(-K,0),i.default.transition(rt.select(".nv-context .nv-y.nv-axis")).call(_),rt.select(".nv-context .nv-x.nv-axis").attr("transform","translate(0,"+p.range()[0]+")"),w.dispatch.on("stateChange",function(e){for(var n in e)F[n]=e[n];R.stateChange(F),t.update()}),R.on("changeState",function(e){"undefined"!=typeof e.disabled&&O.forEach(function(t,n){t.disabled=e.disabled[n]}),t.update()}),h.dispatch.on("elementMouseover.tooltip",H),g.dispatch.on("elementMouseover.tooltip",H),h.dispatch.on("elementMouseout.tooltip",function(t){D.hidden(!0)}),g.dispatch.on("elementMouseout.tooltip",function(t){D.hidden(!0)})}),t}var e,n,r,o,s,l,u,c,f=i.default.scale.linear(),d=i.default.scale.linear(),p=i.default.scale.linear(),h=a.models.line().yScale(f),g=a.models.line().yScale(d),v=a.models.line().yScale(p),m=a.models.axis().orient("bottom").tickPadding(5),y=a.models.axis().scale(f).orient("left"),b=a.models.axis().scale(d).orient("right"),x=a.models.axis().orient("bottom").tickPadding(5),_=a.models.axis().scale(p).orient("left"),w=a.models.legend(),T=i.default.svg.brush(),C={top:30,right:30,bottom:30,left:60},k={top:10,right:30,bottom:20,left:60},E=a.utils.defaultColor(),P=null,S=null,M=100,N=!0,A=null,O=!0,D=a.models.tooltip(),I="No Data Available.",R=i.default.dispatch("tooltipShow","tooltipHide","brush","stateChange","changeState"),L=250,F=a.utils.state(),j=null;h.clipEdge(!0),g.clipEdge(!0),v.interactive(!1).clipEdge(!0);var B=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},U=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return t.dispatch=R,t.legend=w,t.lines1=h,t.lines2=g,t.linesC=v,t.xAxis=m,t.y1Axis=y,t.y2Axis=b,t.xCAxis=x,t.yCAxis=_,t.options=a.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return P},set:function(t){P=t}},height:{get:function(){return S},set:function(t){S=t}},focusHeight:{get:function(){return M},set:function(t){M=t}},showLegend:{get:function(){return N},set:function(t){N=t}},yDomain1:{get:function(){return l},set:function(t){l=t}},yDomain2:{get:function(){return u},set:function(t){u=t}},yDomainC:{get:function(){return c},set:function(t){c=t}},brushExtent:{get:function(){return A},set:function(t){A=t}},tooltips:{get:function(){return O},set:function(t){O=t}},tooltipContent:{get:function(){return D},set:function(t){D=t}},defaultState:{get:function(){return j},set:function(t){j=t}},noData:{get:function(){return I},set:function(t){I=t}},margin:{get:function(){return C},set:function(t){C.top=void 0!==t.top?t.top:C.top,C.right=void 0!==t.right?t.right:C.right,C.bottom=void 0!==t.bottom?t.bottom:C.bottom,C.left=void 0!==t.left?t.left:C.left}},color:{get:function(){return E},set:function(t){E=a.utils.getColor(t),w.color(E)}},interpolate:{get:function(){return h.interpolate()},set:function(t){h.interpolate(t),g.interpolate(t),v.interpolate(t)}},xTickFormat:{get:function(){return m.xTickFormat()},set:function(t){m.xTickFormat(t),x.xTickFormat(t)}},yTickFormat:{get:function(){return y.yTickFormat()},set:function(t){y.yTickFormat(t),b.yTickFormat(t),_.yTickFormat(t)}},duration:{get:function(){return L},set:function(t){L=t,y.duration(L),b.duration(L),_.duration(L),m.duration(L)}},x:{get:function(){return lines.x()},set:function(t){h.x(t),g.x(t),v.x(t)}},y:{get:function(){return lines.y()},set:function(t){h.y(t),g.y(t),v.y(t)}}}),a.utils.initOptions(t),t},l=function(){this.chart=s()};l.prototype.initialize=function(t){this.chart.margin(t.margin).color(t.colors),this.chart.lines1.interpolate("monotone"),this.chart.lines2.interpolate("monotone"),this.chart.linesC.interpolate("monotone"),this.chart.xAxis.showMaxMin(!1).axisLabel(t.labels.xAxis).tickFormat(function(t){return i.default.time.format("%X")(new Date(t))}),this.chart.xCAxis.showMaxMin(!1).axisLabel(t.labels.xAxis).tickFormat(function(t){return i.default.time.format("%X")(new Date(t))}),this.chart.y1Axis.axisLabel(t.labels.yAxis1).tickFormat(i.default.format(",.2f")),this.chart.y2Axis.axisLabel(t.labels.yAxis2).tickFormat(i.default.format(",.2f")),this.chart.yCAxis.axisLabel(t.labels.yAxis2).tickFormat(i.default.format(",.2f"))},l.prototype.get=function(e,n,r){i.default.json(n.concat("?",t.param(r)),function(t,n){n.data.forEach(function(t){t.values.forEach(function(t){t.x=new Date(1e3*t.x)})}),this.chart.yDomain1(n.yAxis1.bounds),this.chart.yDomain2(n.yAxis2.bounds),this.chart.yDomainC(n.yAxis2.bounds),i.default.select("#".concat(e," svg")).datum(n.data).call(this.chart),a.utils.windowResize(this.chart.update)}.bind(this))},e.default=l}).call(e,n(14))},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.LayoutFactory=e.Layout=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(1),u=r(l),c=n(95),f=n(96),d=function t(e){if("function"!=typeof t[e])throw new Error(e+" is not a valid layout.");return t[e]};d.FilterChart=c.FilterChart,d.SimpleChart=f.SimpleChart;var p=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"render",value:function(){var t=this.props.layout_factory(this.props.type);return u.default.createElement(t,{ref:"layout",id:this.props.id,nav:this.props.nav,filters:this.props.filters,charts:this.props.charts})}}]),e}(u.default.Component);p.defaultProps={layout_factory:d},e.Layout=p,e.LayoutFactory=d},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.Navs=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(22),u=n(1),c=r(u),f=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"render",value:function(){var t=this.props.navlinks.map(function(t,e){if("/"!==t.path){var n="navlink_".concat(e);return c.default.createElement(l.NavItem,{eventKey:e,key:n,href:t.path},t.label)}});return c.default.createElement(l.Navbar,null,c.default.createElement(l.Navbar.Header,null,c.default.createElement(l.Navbar.Brand,null,c.default.createElement("a",{href:"#"},this.props.brand))),c.default.createElement(l.Nav,{pullRight:!0},t))}}]),e}(c.default.Component);f.defaultProps={navlinks:[],brand:"Pyxley"},e.Navs=f},function(t,e,n){t.exports={default:n(156),__esModule:!0}},function(t,e,n){t.exports={default:n(158),__esModule:!0}},function(t,e,n){t.exports={default:n(160),__esModule:!0}},function(t,e,n){t.exports={default:n(162),__esModule:!0}},function(t,e,n){t.exports={default:n(163),__esModule:!0}},function(t,e,n){n(109),n(187),t.exports=n(16).Array.from},function(t,e,n){n(189),t.exports=n(16).Object.assign},function(t,e,n){n(190);var r=n(16).Object;t.exports=function(t,e){return r.create(t,e)}},function(t,e,n){n(194),t.exports=n(16).Object.entries},function(t,e,n){n(191),t.exports=n(16).Object.setPrototypeOf},function(t,e,n){n(195),t.exports=n(16).Object.values},function(t,e,n){n(193),n(192),n(196),n(197),t.exports=n(16).Symbol},function(t,e,n){n(109),n(198),t.exports=n(73).f("iterator")},function(t,e){t.exports=function(t){if("function"!=typeof t)throw TypeError(t+" is not a function!");return t}},function(t,e){t.exports=function(){}},function(t,e,n){var r=n(21),o=n(108),i=n(185);t.exports=function(t){return function(e,n,a){var s,l=r(e),u=o(l.length),c=i(a,u);if(t&&n!=n){for(;u>c;)if(s=l[c++],s!=s)return!0}else for(;u>c;c++)if((t||c in l)&&l[c]===n)return t||c||0;return!t&&-1}}},function(t,e,n){var r=n(59),o=n(17)("toStringTag"),i="Arguments"==r(function(){return arguments}()),a=function(t,e){try{return t[e]}catch(t){}};t.exports=function(t){var e,n,s;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(n=a(e=Object(t),o))?n:i?r(e):"Object"==(s=r(e))&&"function"==typeof e.callee?"Arguments":s}},function(t,e,n){"use strict";var r=n(24),o=n(38);t.exports=function(t,e,n){e in t?r.f(t,e,o(0,n)):t[e]=n}},function(t,e,n){var r=n(30),o=n(65),i=n(37);t.exports=function(t){var e=r(t),n=o.f;if(n)for(var a,s=n(t),l=i.f,u=0;s.length>u;)l.call(t,a=s[u++])&&e.push(a);return e}},function(t,e,n){t.exports=n(20).document&&document.documentElement},function(t,e,n){var r=n(36),o=n(17)("iterator"),i=Array.prototype;t.exports=function(t){return void 0!==t&&(r.Array===t||i[o]===t)}},function(t,e,n){var r=n(59);t.exports=Array.isArray||function(t){return"Array"==r(t)}},function(t,e,n){var r=n(27);t.exports=function(t,e,n,o){try{return o?e(r(n)[0],n[1]):e(n)}catch(e){var i=t.return;throw void 0!==i&&r(i.call(t)),e}}},function(t,e,n){"use strict";var r=n(64),o=n(38),i=n(66),a={};n(29)(a,n(17)("iterator"),function(){return this}),t.exports=function(t,e,n){t.prototype=r(a,{next:o(1,n)}),i(t,e+" Iterator")}},function(t,e,n){var r=n(17)("iterator"),o=!1;try{var i=[7][r]();i.return=function(){o=!0},Array.from(i,function(){throw 2})}catch(t){}t.exports=function(t,e){if(!e&&!o)return!1;var n=!1;try{var i=[7],a=i[r]();a.next=function(){return{done:n=!0}},i[r]=function(){return a},t(i)}catch(t){}return n}},function(t,e){t.exports=function(t,e){return{value:e,done:!!t}}},function(t,e,n){var r=n(30),o=n(21);t.exports=function(t,e){for(var n,i=o(t),a=r(i),s=a.length,l=0;s>l;)if(i[n=a[l++]]===e)return n}},function(t,e,n){var r=n(44)("meta"),o=n(35),i=n(23),a=n(24).f,s=0,l=Object.isExtensible||function(){return!0},u=!n(34)(function(){return l(Object.preventExtensions({}))}),c=function(t){a(t,r,{value:{i:"O"+ ++s,w:{}}})},f=function(t,e){if(!o(t))return"symbol"==typeof t?t:("string"==typeof t?"S":"P")+t;if(!i(t,r)){if(!l(t))return"F";if(!e)return"E";c(t)}return t[r].i},d=function(t,e){if(!i(t,r)){if(!l(t))return!0;if(!e)return!1;c(t)}return t[r].w},p=function(t){return u&&h.NEED&&l(t)&&!i(t,r)&&c(t),t},h=t.exports={KEY:r,NEED:!1,fastKey:f,getWeak:d,onFreeze:p}},function(t,e,n){"use strict";var r=n(30),o=n(65),i=n(37),a=n(70),s=n(101),l=Object.assign;t.exports=!l||n(34)(function(){var t={},e={},n=Symbol(),r="abcdefghijklmnopqrst";return t[n]=7,r.split("").forEach(function(t){e[t]=t}),7!=l({},t)[n]||Object.keys(l({},e)).join("")!=r})?function(t,e){for(var n=a(t),l=arguments.length,u=1,c=o.f,f=i.f;l>u;)for(var d,p=s(arguments[u++]),h=c?r(p).concat(c(p)):r(p),g=h.length,v=0;g>v;)f.call(p,d=h[v++])&&(n[d]=p[d]);return n}:l},function(t,e,n){var r=n(24),o=n(27),i=n(30);t.exports=n(28)?Object.defineProperties:function(t,e){o(t);for(var n,a=i(e),s=a.length,l=0;s>l;)r.f(t,n=a[l++],e[n]);return t}},function(t,e,n){var r=n(21),o=n(104).f,i={}.toString,a="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],s=function(t){try{return o(t)}catch(t){return a.slice()}};t.exports.f=function(t){return a&&"[object Window]"==i.call(t)?s(t):o(r(t))}},function(t,e,n){var r=n(23),o=n(70),i=n(67)("IE_PROTO"),a=Object.prototype;t.exports=Object.getPrototypeOf||function(t){return t=o(t),r(t,i)?t[i]:"function"==typeof t.constructor&&t instanceof t.constructor?t.constructor.prototype:t instanceof Object?a:null}},function(t,e,n){var r=n(35),o=n(27),i=function(t,e){if(o(t),!r(e)&&null!==e)throw TypeError(e+": can't set as prototype!")};t.exports={set:Object.setPrototypeOf||("__proto__"in{}?function(t,e,r){try{r=n(60)(Function.call,n(103).f(Object.prototype,"__proto__").set,2),r(t,[]),e=!(t instanceof Array)}catch(t){e=!0}return function(t,n){return i(t,n),e?t.__proto__=n:r(t,n),t}}({},!1):void 0),check:i}},function(t,e,n){var r=n(69),o=n(61);t.exports=function(t){return function(e,n){var i,a,s=String(o(e)),l=r(n),u=s.length;return l<0||l>=u?t?"":void 0:(i=s.charCodeAt(l),i<55296||i>56319||l+1===u||(a=s.charCodeAt(l+1))<56320||a>57343?t?s.charAt(l):i:t?s.slice(l,l+2):(i-55296<<10)+(a-56320)+65536)}}},function(t,e,n){var r=n(69),o=Math.max,i=Math.min;t.exports=function(t,e){return t=r(t),t<0?o(t+e,0):i(t,e)}},function(t,e,n){var r=n(167),o=n(17)("iterator"),i=n(36);t.exports=n(16).getIteratorMethod=function(t){if(void 0!=t)return t[o]||t["@@iterator"]||i[r(t)]}},function(t,e,n){"use strict";var r=n(60),o=n(19),i=n(70),a=n(173),s=n(171),l=n(108),u=n(168),c=n(186);o(o.S+o.F*!n(175)(function(t){Array.from(t)}),"Array",{from:function(t){var e,n,o,f,d=i(t),p="function"==typeof this?this:Array,h=arguments.length,g=h>1?arguments[1]:void 0,v=void 0!==g,m=0,y=c(d);if(v&&(g=r(g,h>2?arguments[2]:void 0,2)),void 0==y||p==Array&&s(y))for(e=l(d.length),n=new p(e);e>m;m++)u(n,m,v?g(d[m],m):d[m]);else for(f=y.call(d),n=new p;!(o=f.next()).done;m++)u(n,m,v?a(f,g,[o.value,m],!0):o.value);return n.length=m,n}})},function(t,e,n){"use strict";var r=n(165),o=n(176),i=n(36),a=n(21);t.exports=n(102)(Array,"Array",function(t,e){this._t=a(t),this._i=0,this._k=e},function(){var t=this._t,e=this._k,n=this._i++;return!t||n>=t.length?(this._t=void 0,o(1)):"keys"==e?o(0,n):"values"==e?o(0,t[n]):o(0,[n,t[n]])},"values"),i.Arguments=i.Array,r("keys"),r("values"),r("entries")},function(t,e,n){var r=n(19);r(r.S+r.F,"Object",{assign:n(179)})},function(t,e,n){var r=n(19);r(r.S,"Object",{create:n(64)})},function(t,e,n){var r=n(19);r(r.S,"Object",{setPrototypeOf:n(183).set})},function(t,e){},function(t,e,n){"use strict";var r=n(20),o=n(23),i=n(28),a=n(19),s=n(107),l=n(178).KEY,u=n(34),c=n(68),f=n(66),d=n(44),p=n(17),h=n(73),g=n(72),v=n(177),m=n(169),y=n(172),b=n(27),x=n(21),_=n(71),w=n(38),T=n(64),C=n(181),k=n(103),E=n(24),P=n(30),S=k.f,M=E.f,N=C.f,A=r.Symbol,O=r.JSON,D=O&&O.stringify,I="prototype",R=p("_hidden"),L=p("toPrimitive"),F={}.propertyIsEnumerable,j=c("symbol-registry"),B=c("symbols"),U=c("op-symbols"),H=Object[I],z="function"==typeof A,W=r.QObject,q=!W||!W[I]||!W[I].findChild,V=i&&u(function(){return 7!=T(M({},"a",{get:function(){return M(this,"a",{value:7}).a}})).a})?function(t,e,n){var r=S(H,e);r&&delete H[e],M(t,e,n),r&&t!==H&&M(H,e,r)}:M,K=function(t){var e=B[t]=T(A[I]);return e._k=t,e},Y=z&&"symbol"==typeof A.iterator?function(t){return"symbol"==typeof t}:function(t){return t instanceof A},G=function(t,e,n){return t===H&&G(U,e,n),b(t),e=_(e,!0),b(n),o(B,e)?(n.enumerable?(o(t,R)&&t[R][e]&&(t[R][e]=!1),n=T(n,{enumerable:w(0,!1)})):(o(t,R)||M(t,R,w(1,{})),t[R][e]=!0),V(t,e,n)):M(t,e,n)},X=function(t,e){b(t);for(var n,r=m(e=x(e)),o=0,i=r.length;i>o;)G(t,n=r[o++],e[n]);return t},$=function(t,e){return void 0===e?T(t):X(T(t),e)},Z=function(t){var e=F.call(this,t=_(t,!0));return!(this===H&&o(B,t)&&!o(U,t))&&(!(e||!o(this,t)||!o(B,t)||o(this,R)&&this[R][t])||e)},J=function(t,e){if(t=x(t),e=_(e,!0),t!==H||!o(B,e)||o(U,e)){var n=S(t,e);return!n||!o(B,e)||o(t,R)&&t[R][e]||(n.enumerable=!0),n}},Q=function(t){for(var e,n=N(x(t)),r=[],i=0;n.length>i;)o(B,e=n[i++])||e==R||e==l||r.push(e);return r},tt=function(t){for(var e,n=t===H,r=N(n?U:x(t)),i=[],a=0;r.length>a;)!o(B,e=r[a++])||n&&!o(H,e)||i.push(B[e]);return i};z||(A=function(){if(this instanceof A)throw TypeError("Symbol is not a constructor!");var t=d(arguments.length>0?arguments[0]:void 0),e=function(n){this===H&&e.call(U,n),o(this,R)&&o(this[R],t)&&(this[R][t]=!1),V(this,t,w(1,n))};return i&&q&&V(H,t,{configurable:!0,set:e}),K(t)},s(A[I],"toString",function(){return this._k}),k.f=J,E.f=G,n(104).f=C.f=Q,n(37).f=Z,n(65).f=tt,i&&!n(63)&&s(H,"propertyIsEnumerable",Z,!0),h.f=function(t){return K(p(t))}),a(a.G+a.W+a.F*!z,{Symbol:A});for(var et="hasInstance,isConcatSpreadable,iterator,match,replace,search,species,split,toPrimitive,toStringTag,unscopables".split(","),nt=0;et.length>nt;)p(et[nt++]);for(var et=P(p.store),nt=0;et.length>nt;)g(et[nt++]);a(a.S+a.F*!z,"Symbol",{for:function(t){return o(j,t+="")?j[t]:j[t]=A(t)},keyFor:function(t){if(Y(t))return v(j,t);throw TypeError(t+" is not a symbol!")},useSetter:function(){q=!0},useSimple:function(){q=!1}}),a(a.S+a.F*!z,"Object",{create:$,defineProperty:G,defineProperties:X,getOwnPropertyDescriptor:J,getOwnPropertyNames:Q,getOwnPropertySymbols:tt}),O&&a(a.S+a.F*(!z||u(function(){var t=A();return"[null]"!=D([t])||"{}"!=D({a:t})||"{}"!=D(Object(t))})),"JSON",{stringify:function(t){if(void 0!==t&&!Y(t)){for(var e,n,r=[t],o=1;arguments.length>o;)r.push(arguments[o++]);return e=r[1],"function"==typeof e&&(n=e),!n&&y(e)||(e=function(t,e){if(n&&(e=n.call(this,t,e)),!Y(e))return e}),r[1]=e,D.apply(O,r)}}}),A[I][L]||n(29)(A[I],L,A[I].valueOf),f(A,"Symbol"),f(Math,"Math",!0),f(r.JSON,"JSON",!0)},function(t,e,n){var r=n(19),o=n(106)(!0);r(r.S,"Object",{entries:function(t){return o(t)}})},function(t,e,n){var r=n(19),o=n(106)(!1);r(r.S,"Object",{values:function(t){return o(t)}})},function(t,e,n){n(72)("asyncIterator")},function(t,e,n){n(72)("observable")},function(t,e,n){n(188);for(var r=n(20),o=n(29),i=n(36),a=n(17)("toStringTag"),s=["NodeList","DOMTokenList","MediaList","StyleSheetList","CSSRuleList"],l=0;l<5;l++){var u=s[l],c=r[u],f=c&&c.prototype;f&&!f[a]&&o(f,a,u),i[u]=i.Array}},function(t,e,n){e=t.exports=n(39)(),e.push([t.id,'/*!\n * Bootstrap v3.3.7 (http://getbootstrap.com)\n * Copyright 2011-2016 Twitter, Inc.\n * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)\n *//*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */html{font-family:sans-serif;-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%}body{margin:0}article,aside,details,figcaption,figure,footer,header,hgroup,main,menu,nav,section,summary{display:block}audio,canvas,progress,video{display:inline-block;vertical-align:baseline}audio:not([controls]){display:none;height:0}[hidden],template{display:none}a{background-color:transparent}a:active,a:hover{outline:0}abbr[title]{border-bottom:1px dotted}b,strong{font-weight:700}dfn{font-style:italic}h1{margin:.67em 0;font-size:2em}mark{color:#000;background:#ff0}small{font-size:80%}sub,sup{position:relative;font-size:75%;line-height:0;vertical-align:baseline}sup{top:-.5em}sub{bottom:-.25em}img{border:0}svg:not(:root){overflow:hidden}figure{margin:1em 40px}hr{height:0;-webkit-box-sizing:content-box;-moz-box-sizing:content-box;box-sizing:content-box}pre{overflow:auto}code,kbd,pre,samp{font-family:monospace,monospace;font-size:1em}button,input,optgroup,select,textarea{margin:0;font:inherit;color:inherit}button{overflow:visible}button,select{text-transform:none}button,html input[type=button],input[type=reset],input[type=submit]{-webkit-appearance:button;cursor:pointer}button[disabled],html input[disabled]{cursor:default}button::-moz-focus-inner,input::-moz-focus-inner{padding:0;border:0}input{line-height:normal}input[type=checkbox],input[type=radio]{-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;padding:0}input[type=number]::-webkit-inner-spin-button,input[type=number]::-webkit-outer-spin-button{height:auto}input[type=search]{-webkit-box-sizing:content-box;-moz-box-sizing:content-box;box-sizing:content-box;-webkit-appearance:textfield}input[type=search]::-webkit-search-cancel-button,input[type=search]::-webkit-search-decoration{-webkit-appearance:none}fieldset{padding:.35em .625em .75em;margin:0 2px;border:1px solid silver}legend{padding:0;border:0}textarea{overflow:auto}optgroup{font-weight:700}table{border-spacing:0;border-collapse:collapse}td,th{padding:0}/*! Source: https://github.com/h5bp/html5-boilerplate/blob/master/src/css/main.css */@media print{*,:after,:before{color:#000!important;text-shadow:none!important;background:0 0!important;-webkit-box-shadow:none!important;box-shadow:none!important}a,a:visited{text-decoration:underline}a[href]:after{content:" (" attr(href) ")"}abbr[title]:after{content:" (" attr(title) ")"}a[href^="#"]:after,a[href^="javascript:"]:after{content:""}blockquote,pre{border:1px solid #999;page-break-inside:avoid}thead{display:table-header-group}img,tr{page-break-inside:avoid}img{max-width:100%!important}h2,h3,p{orphans:3;widows:3}h2,h3{page-break-after:avoid}.navbar{display:none}.btn>.caret,.dropup>.btn>.caret{border-top-color:#000!important}.label{border:1px solid #000}.table{border-collapse:collapse!important}.table td,.table th{background-color:#fff!important}.table-bordered td,.table-bordered th{border:1px solid #ddd!important}}@font-face{font-family:Glyphicons Halflings;src:url('+n(118)+");src:url("+n(118)+'?#iefix) format("embedded-opentype"),url('+n(312)+') format("woff2"),url('+n(311)+') format("woff"),url('+n(304)+') format("truetype"),url('+n(305)+'#glyphicons_halflingsregular) format("svg")}.glyphicon{position:relative;top:1px;display:inline-block;font-family:Glyphicons Halflings;font-style:normal;font-weight:400;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.glyphicon-asterisk:before{content:"*"}.glyphicon-plus:before{content:"+"}.glyphicon-eur:before,.glyphicon-euro:before{content:"\\20AC"}.glyphicon-minus:before{content:"\\2212"}.glyphicon-cloud:before{content:"\\2601"}.glyphicon-envelope:before{content:"\\2709"}.glyphicon-pencil:before{content:"\\270F"}.glyphicon-glass:before{content:"\\E001"}.glyphicon-music:before{content:"\\E002"}.glyphicon-search:before{content:"\\E003"}.glyphicon-heart:before{content:"\\E005"}.glyphicon-star:before{content:"\\E006"}.glyphicon-star-empty:before{content:"\\E007"}.glyphicon-user:before{content:"\\E008"}.glyphicon-film:before{content:"\\E009"}.glyphicon-th-large:before{content:"\\E010"}.glyphicon-th:before{content:"\\E011"}.glyphicon-th-list:before{content:"\\E012"}.glyphicon-ok:before{content:"\\E013"}.glyphicon-remove:before{content:"\\E014"}.glyphicon-zoom-in:before{content:"\\E015"}.glyphicon-zoom-out:before{content:"\\E016"}.glyphicon-off:before{content:"\\E017"}.glyphicon-signal:before{content:"\\E018"}.glyphicon-cog:before{content:"\\E019"}.glyphicon-trash:before{content:"\\E020"}.glyphicon-home:before{content:"\\E021"}.glyphicon-file:before{content:"\\E022"}.glyphicon-time:before{content:"\\E023"}.glyphicon-road:before{content:"\\E024"}.glyphicon-download-alt:before{content:"\\E025"}.glyphicon-download:before{content:"\\E026"}.glyphicon-upload:before{content:"\\E027"}.glyphicon-inbox:before{content:"\\E028"}.glyphicon-play-circle:before{content:"\\E029"}.glyphicon-repeat:before{content:"\\E030"}.glyphicon-refresh:before{content:"\\E031"}.glyphicon-list-alt:before{content:"\\E032"}.glyphicon-lock:before{content:"\\E033"}.glyphicon-flag:before{content:"\\E034"}.glyphicon-headphones:before{content:"\\E035"}.glyphicon-volume-off:before{content:"\\E036"}.glyphicon-volume-down:before{content:"\\E037"}.glyphicon-volume-up:before{content:"\\E038"}.glyphicon-qrcode:before{content:"\\E039"}.glyphicon-barcode:before{content:"\\E040"}.glyphicon-tag:before{content:"\\E041"}.glyphicon-tags:before{content:"\\E042"}.glyphicon-book:before{content:"\\E043"}.glyphicon-bookmark:before{content:"\\E044"}.glyphicon-print:before{content:"\\E045"}.glyphicon-camera:before{content:"\\E046"}.glyphicon-font:before{content:"\\E047"}.glyphicon-bold:before{content:"\\E048"}.glyphicon-italic:before{content:"\\E049"}.glyphicon-text-height:before{content:"\\E050"}.glyphicon-text-width:before{content:"\\E051"}.glyphicon-align-left:before{content:"\\E052"}.glyphicon-align-center:before{content:"\\E053"}.glyphicon-align-right:before{content:"\\E054"}.glyphicon-align-justify:before{content:"\\E055"}.glyphicon-list:before{content:"\\E056"}.glyphicon-indent-left:before{content:"\\E057"}.glyphicon-indent-right:before{content:"\\E058"}.glyphicon-facetime-video:before{content:"\\E059"}.glyphicon-picture:before{content:"\\E060"}.glyphicon-map-marker:before{content:"\\E062"}.glyphicon-adjust:before{content:"\\E063"}.glyphicon-tint:before{content:"\\E064"}.glyphicon-edit:before{content:"\\E065"}.glyphicon-share:before{content:"\\E066"}.glyphicon-check:before{content:"\\E067"}.glyphicon-move:before{content:"\\E068"}.glyphicon-step-backward:before{content:"\\E069"}.glyphicon-fast-backward:before{content:"\\E070"}.glyphicon-backward:before{content:"\\E071"}.glyphicon-play:before{content:"\\E072"}.glyphicon-pause:before{content:"\\E073"}.glyphicon-stop:before{content:"\\E074"}.glyphicon-forward:before{content:"\\E075"}.glyphicon-fast-forward:before{content:"\\E076"}.glyphicon-step-forward:before{content:"\\E077"}.glyphicon-eject:before{content:"\\E078"}.glyphicon-chevron-left:before{content:"\\E079"}.glyphicon-chevron-right:before{content:"\\E080"}.glyphicon-plus-sign:before{content:"\\E081"}.glyphicon-minus-sign:before{content:"\\E082"}.glyphicon-remove-sign:before{content:"\\E083"}.glyphicon-ok-sign:before{content:"\\E084"}.glyphicon-question-sign:before{content:"\\E085"}.glyphicon-info-sign:before{content:"\\E086"}.glyphicon-screenshot:before{content:"\\E087"}.glyphicon-remove-circle:before{content:"\\E088"}.glyphicon-ok-circle:before{content:"\\E089"}.glyphicon-ban-circle:before{content:"\\E090"}.glyphicon-arrow-left:before{content:"\\E091"}.glyphicon-arrow-right:before{content:"\\E092"}.glyphicon-arrow-up:before{content:"\\E093"}.glyphicon-arrow-down:before{content:"\\E094"}.glyphicon-share-alt:before{content:"\\E095"}.glyphicon-resize-full:before{content:"\\E096"}.glyphicon-resize-small:before{content:"\\E097"}.glyphicon-exclamation-sign:before{content:"\\E101"}.glyphicon-gift:before{content:"\\E102"}.glyphicon-leaf:before{content:"\\E103"}.glyphicon-fire:before{content:"\\E104"}.glyphicon-eye-open:before{content:"\\E105"}.glyphicon-eye-close:before{content:"\\E106"}.glyphicon-warning-sign:before{content:"\\E107"}.glyphicon-plane:before{content:"\\E108"}.glyphicon-calendar:before{content:"\\E109"}.glyphicon-random:before{content:"\\E110"}.glyphicon-comment:before{content:"\\E111"}.glyphicon-magnet:before{content:"\\E112"}.glyphicon-chevron-up:before{content:"\\E113"}.glyphicon-chevron-down:before{content:"\\E114"}.glyphicon-retweet:before{content:"\\E115"}.glyphicon-shopping-cart:before{content:"\\E116"}.glyphicon-folder-close:before{content:"\\E117"}.glyphicon-folder-open:before{content:"\\E118"}.glyphicon-resize-vertical:before{content:"\\E119"}.glyphicon-resize-horizontal:before{content:"\\E120"}.glyphicon-hdd:before{content:"\\E121"}.glyphicon-bullhorn:before{content:"\\E122"}.glyphicon-bell:before{content:"\\E123"}.glyphicon-certificate:before{content:"\\E124"}.glyphicon-thumbs-up:before{content:"\\E125"}.glyphicon-thumbs-down:before{content:"\\E126"}.glyphicon-hand-right:before{content:"\\E127"}.glyphicon-hand-left:before{content:"\\E128"}.glyphicon-hand-up:before{content:"\\E129"}.glyphicon-hand-down:before{content:"\\E130"}.glyphicon-circle-arrow-right:before{content:"\\E131"}.glyphicon-circle-arrow-left:before{content:"\\E132"}.glyphicon-circle-arrow-up:before{content:"\\E133"}.glyphicon-circle-arrow-down:before{content:"\\E134"}.glyphicon-globe:before{content:"\\E135"}.glyphicon-wrench:before{content:"\\E136"}.glyphicon-tasks:before{content:"\\E137"}.glyphicon-filter:before{content:"\\E138"}.glyphicon-briefcase:before{content:"\\E139"}.glyphicon-fullscreen:before{content:"\\E140"}.glyphicon-dashboard:before{content:"\\E141"}.glyphicon-paperclip:before{content:"\\E142"}.glyphicon-heart-empty:before{content:"\\E143"}.glyphicon-link:before{content:"\\E144"}.glyphicon-phone:before{content:"\\E145"}.glyphicon-pushpin:before{content:"\\E146"}.glyphicon-usd:before{content:"\\E148"}.glyphicon-gbp:before{content:"\\E149"}.glyphicon-sort:before{content:"\\E150"}.glyphicon-sort-by-alphabet:before{content:"\\E151"}.glyphicon-sort-by-alphabet-alt:before{content:"\\E152"}.glyphicon-sort-by-order:before{content:"\\E153"}.glyphicon-sort-by-order-alt:before{content:"\\E154"}.glyphicon-sort-by-attributes:before{content:"\\E155"}.glyphicon-sort-by-attributes-alt:before{content:"\\E156"}.glyphicon-unchecked:before{content:"\\E157"}.glyphicon-expand:before{content:"\\E158"}.glyphicon-collapse-down:before{content:"\\E159"}.glyphicon-collapse-up:before{content:"\\E160"}.glyphicon-log-in:before{content:"\\E161"}.glyphicon-flash:before{content:"\\E162"}.glyphicon-log-out:before{content:"\\E163"}.glyphicon-new-window:before{content:"\\E164"}.glyphicon-record:before{content:"\\E165"}.glyphicon-save:before{content:"\\E166"}.glyphicon-open:before{content:"\\E167"}.glyphicon-saved:before{content:"\\E168"}.glyphicon-import:before{content:"\\E169"}.glyphicon-export:before{content:"\\E170"}.glyphicon-send:before{content:"\\E171"}.glyphicon-floppy-disk:before{content:"\\E172"}.glyphicon-floppy-saved:before{content:"\\E173"}.glyphicon-floppy-remove:before{content:"\\E174"}.glyphicon-floppy-save:before{content:"\\E175"}.glyphicon-floppy-open:before{content:"\\E176"}.glyphicon-credit-card:before{content:"\\E177"}.glyphicon-transfer:before{content:"\\E178"}.glyphicon-cutlery:before{content:"\\E179"}.glyphicon-header:before{content:"\\E180"}.glyphicon-compressed:before{content:"\\E181"}.glyphicon-earphone:before{content:"\\E182"}.glyphicon-phone-alt:before{content:"\\E183"}.glyphicon-tower:before{content:"\\E184"}.glyphicon-stats:before{content:"\\E185"}.glyphicon-sd-video:before{content:"\\E186"}.glyphicon-hd-video:before{content:"\\E187"}.glyphicon-subtitles:before{content:"\\E188"}.glyphicon-sound-stereo:before{content:"\\E189"}.glyphicon-sound-dolby:before{content:"\\E190"}.glyphicon-sound-5-1:before{content:"\\E191"}.glyphicon-sound-6-1:before{content:"\\E192"}.glyphicon-sound-7-1:before{content:"\\E193"}.glyphicon-copyright-mark:before{content:"\\E194"}.glyphicon-registration-mark:before{content:"\\E195"}.glyphicon-cloud-download:before{content:"\\E197"}.glyphicon-cloud-upload:before{content:"\\E198"}.glyphicon-tree-conifer:before{content:"\\E199"}.glyphicon-tree-deciduous:before{content:"\\E200"}.glyphicon-cd:before{content:"\\E201"}.glyphicon-save-file:before{content:"\\E202"}.glyphicon-open-file:before{content:"\\E203"}.glyphicon-level-up:before{content:"\\E204"}.glyphicon-copy:before{content:"\\E205"}.glyphicon-paste:before{content:"\\E206"}.glyphicon-alert:before{content:"\\E209"}.glyphicon-equalizer:before{content:"\\E210"}.glyphicon-king:before{content:"\\E211"}.glyphicon-queen:before{content:"\\E212"}.glyphicon-pawn:before{content:"\\E213"}.glyphicon-bishop:before{content:"\\E214"}.glyphicon-knight:before{content:"\\E215"}.glyphicon-baby-formula:before{content:"\\E216"}.glyphicon-tent:before{content:"\\26FA"}.glyphicon-blackboard:before{content:"\\E218"}.glyphicon-bed:before{content:"\\E219"}.glyphicon-apple:before{content:"\\F8FF"}.glyphicon-erase:before{content:"\\E221"}.glyphicon-hourglass:before{content:"\\231B"}.glyphicon-lamp:before{content:"\\E223"}.glyphicon-duplicate:before{content:"\\E224"}.glyphicon-piggy-bank:before{content:"\\E225"}.glyphicon-scissors:before{content:"\\E226"}.glyphicon-bitcoin:before,.glyphicon-btc:before,.glyphicon-xbt:before{content:"\\E227"}.glyphicon-jpy:before,.glyphicon-yen:before{content:"\\A5"}.glyphicon-rub:before,.glyphicon-ruble:before{content:"\\20BD"}.glyphicon-scale:before{content:"\\E230"}.glyphicon-ice-lolly:before{content:"\\E231"}.glyphicon-ice-lolly-tasted:before{content:"\\E232"}.glyphicon-education:before{content:"\\E233"}.glyphicon-option-horizontal:before{content:"\\E234"}.glyphicon-option-vertical:before{content:"\\E235"}.glyphicon-menu-hamburger:before{content:"\\E236"}.glyphicon-modal-window:before{content:"\\E237"}.glyphicon-oil:before{content:"\\E238"}.glyphicon-grain:before{content:"\\E239"}.glyphicon-sunglasses:before{content:"\\E240"}.glyphicon-text-size:before{content:"\\E241"}.glyphicon-text-color:before{content:"\\E242"}.glyphicon-text-background:before{content:"\\E243"}.glyphicon-object-align-top:before{content:"\\E244"}.glyphicon-object-align-bottom:before{content:"\\E245"}.glyphicon-object-align-horizontal:before{content:"\\E246"}.glyphicon-object-align-left:before{content:"\\E247"}.glyphicon-object-align-vertical:before{content:"\\E248"}.glyphicon-object-align-right:before{content:"\\E249"}.glyphicon-triangle-right:before{content:"\\E250"}.glyphicon-triangle-left:before{content:"\\E251"}.glyphicon-triangle-bottom:before{content:"\\E252"}.glyphicon-triangle-top:before{content:"\\E253"}.glyphicon-console:before{content:"\\E254"}.glyphicon-superscript:before{content:"\\E255"}.glyphicon-subscript:before{content:"\\E256"}.glyphicon-menu-left:before{content:"\\E257"}.glyphicon-menu-right:before{content:"\\E258"}.glyphicon-menu-down:before{content:"\\E259"}.glyphicon-menu-up:before{content:"\\E260"}*,:after,:before{-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box}html{font-size:10px;-webkit-tap-highlight-color:transparent}body{font-family:Helvetica Neue,Helvetica,Arial,sans-serif;font-size:14px;line-height:1.42857143;color:#333;background-color:#fff}button,input,select,textarea{font-family:inherit;font-size:inherit;line-height:inherit}a{color:#337ab7;text-decoration:none}a:focus,a:hover{color:#23527c;text-decoration:underline}a:focus{outline:5px auto -webkit-focus-ring-color;outline-offset:-2px}figure{margin:0}img{vertical-align:middle}.carousel-inner>.item>a>img,.carousel-inner>.item>img,.img-responsive,.thumbnail>img,.thumbnail a>img{display:block;max-width:100%;height:auto}.img-rounded{border-radius:6px}.img-thumbnail{display:inline-block;max-width:100%;height:auto;padding:4px;line-height:1.42857143;background-color:#fff;border:1px solid #ddd;border-radius:4px;-webkit-transition:all .2s ease-in-out;-o-transition:all .2s ease-in-out;transition:all .2s ease-in-out}.img-circle{border-radius:50%}hr{margin-top:20px;margin-bottom:20px;border:0;border-top:1px solid #eee}.sr-only{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0,0,0,0);border:0}.sr-only-focusable:active,.sr-only-focusable:focus{position:static;width:auto;height:auto;margin:0;overflow:visible;clip:auto}[role=button]{cursor:pointer}.h1,.h2,.h3,.h4,.h5,.h6,h1,h2,h3,h4,h5,h6{font-family:inherit;font-weight:500;line-height:1.1;color:inherit}.h1 .small,.h1 small,.h2 .small,.h2 small,.h3 .small,.h3 small,.h4 .small,.h4 small,.h5 .small,.h5 small,.h6 .small,.h6 small,h1 .small,h1 small,h2 .small,h2 small,h3 .small,h3 small,h4 .small,h4 small,h5 .small,h5 small,h6 .small,h6 small{font-weight:400;line-height:1;color:#777}.h1,.h2,.h3,h1,h2,h3{margin-top:20px;margin-bottom:10px}.h1 .small,.h1 small,.h2 .small,.h2 small,.h3 .small,.h3 small,h1 .small,h1 small,h2 .small,h2 small,h3 .small,h3 small{font-size:65%}.h4,.h5,.h6,h4,h5,h6{margin-top:10px;margin-bottom:10px}.h4 .small,.h4 small,.h5 .small,.h5 small,.h6 .small,.h6 small,h4 .small,h4 small,h5 .small,h5 small,h6 .small,h6 small{font-size:75%}.h1,h1{font-size:36px}.h2,h2{font-size:30px}.h3,h3{font-size:24px}.h4,h4{font-size:18px}.h5,h5{font-size:14px}.h6,h6{font-size:12px}p{margin:0 0 10px}.lead{margin-bottom:20px;font-size:16px;font-weight:300;line-height:1.4}@media (min-width:768px){.lead{font-size:21px}}.small,small{font-size:85%}.mark,mark{padding:.2em;background-color:#fcf8e3}.text-left{text-align:left}.text-right{text-align:right}.text-center{text-align:center}.text-justify{text-align:justify}.text-nowrap{white-space:nowrap}.text-lowercase{text-transform:lowercase}.text-uppercase{text-transform:uppercase}.text-capitalize{text-transform:capitalize}.text-muted{color:#777}.text-primary{color:#337ab7}a.text-primary:focus,a.text-primary:hover{color:#286090}.text-success{color:#3c763d}a.text-success:focus,a.text-success:hover{color:#2b542c}.text-info{color:#31708f}a.text-info:focus,a.text-info:hover{color:#245269}.text-warning{color:#8a6d3b}a.text-warning:focus,a.text-warning:hover{color:#66512c}.text-danger{color:#a94442}a.text-danger:focus,a.text-danger:hover{color:#843534}.bg-primary{color:#fff;background-color:#337ab7}a.bg-primary:focus,a.bg-primary:hover{background-color:#286090}.bg-success{background-color:#dff0d8}a.bg-success:focus,a.bg-success:hover{background-color:#c1e2b3}.bg-info{background-color:#d9edf7}a.bg-info:focus,a.bg-info:hover{background-color:#afd9ee}.bg-warning{background-color:#fcf8e3}a.bg-warning:focus,a.bg-warning:hover{background-color:#f7ecb5}.bg-danger{background-color:#f2dede}a.bg-danger:focus,a.bg-danger:hover{background-color:#e4b9b9}.page-header{padding-bottom:9px;margin:40px 0 20px;border-bottom:1px solid #eee}ol,ul{margin-top:0;margin-bottom:10px}ol ol,ol ul,ul ol,ul ul{margin-bottom:0}.list-inline,.list-unstyled{padding-left:0;list-style:none}.list-inline{margin-left:-5px}.list-inline>li{display:inline-block;padding-right:5px;padding-left:5px}dl{margin-top:0;margin-bottom:20px}dd,dt{line-height:1.42857143}dt{font-weight:700}dd{margin-left:0}@media (min-width:768px){.dl-horizontal dt{float:left;width:160px;overflow:hidden;clear:left;text-align:right;text-overflow:ellipsis;white-space:nowrap}.dl-horizontal dd{margin-left:180px}}abbr[data-original-title],abbr[title]{cursor:help;border-bottom:1px dotted #777}.initialism{font-size:90%;text-transform:uppercase}blockquote{padding:10px 20px;margin:0 0 20px;font-size:17.5px;border-left:5px solid #eee}blockquote ol:last-child,blockquote p:last-child,blockquote ul:last-child{margin-bottom:0}blockquote .small,blockquote footer,blockquote small{display:block;font-size:80%;line-height:1.42857143;color:#777}blockquote .small:before,blockquote footer:before,blockquote small:before{content:"\\2014   \\A0"}.blockquote-reverse,blockquote.pull-right{padding-right:15px;padding-left:0;text-align:right;border-right:5px solid #eee;border-left:0}.blockquote-reverse .small:before,.blockquote-reverse footer:before,.blockquote-reverse small:before,blockquote.pull-right .small:before,blockquote.pull-right footer:before,blockquote.pull-right small:before{content:""}.blockquote-reverse .small:after,.blockquote-reverse footer:after,.blockquote-reverse small:after,blockquote.pull-right .small:after,blockquote.pull-right footer:after,blockquote.pull-right small:after{content:"\\A0   \\2014"}address{margin-bottom:20px;font-style:normal;line-height:1.42857143}code,kbd,pre,samp{font-family:Menlo,Monaco,Consolas,Courier New,monospace}code{color:#c7254e;background-color:#f9f2f4;border-radius:4px}code,kbd{padding:2px 4px;font-size:90%}kbd{color:#fff;background-color:#333;border-radius:3px;-webkit-box-shadow:inset 0 -1px 0 rgba(0,0,0,.25);box-shadow:inset 0 -1px 0 rgba(0,0,0,.25)}kbd kbd{padding:0;font-size:100%;font-weight:700;-webkit-box-shadow:none;box-shadow:none}pre{display:block;padding:9.5px;margin:0 0 10px;font-size:13px;line-height:1.42857143;color:#333;word-break:break-all;word-wrap:break-word;background-color:#f5f5f5;border:1px solid #ccc;border-radius:4px}pre code{padding:0;font-size:inherit;color:inherit;white-space:pre-wrap;background-color:transparent;border-radius:0}.pre-scrollable{max-height:340px;overflow-y:scroll}.container{padding-right:15px;padding-left:15px;margin-right:auto;margin-left:auto}@media (min-width:768px){.container{width:750px}}@media (min-width:992px){.container{width:970px}}@media (min-width:1200px){.container{width:1170px}}.container-fluid{padding-right:15px;padding-left:15px;margin-right:auto;margin-left:auto}.row{margin-right:-15px;margin-left:-15px}.col-lg-1,.col-lg-2,.col-lg-3,.col-lg-4,.col-lg-5,.col-lg-6,.col-lg-7,.col-lg-8,.col-lg-9,.col-lg-10,.col-lg-11,.col-lg-12,.col-md-1,.col-md-2,.col-md-3,.col-md-4,.col-md-5,.col-md-6,.col-md-7,.col-md-8,.col-md-9,.col-md-10,.col-md-11,.col-md-12,.col-sm-1,.col-sm-2,.col-sm-3,.col-sm-4,.col-sm-5,.col-sm-6,.col-sm-7,.col-sm-8,.col-sm-9,.col-sm-10,.col-sm-11,.col-sm-12,.col-xs-1,.col-xs-2,.col-xs-3,.col-xs-4,.col-xs-5,.col-xs-6,.col-xs-7,.col-xs-8,.col-xs-9,.col-xs-10,.col-xs-11,.col-xs-12{position:relative;min-height:1px;padding-right:15px;padding-left:15px}.col-xs-1,.col-xs-2,.col-xs-3,.col-xs-4,.col-xs-5,.col-xs-6,.col-xs-7,.col-xs-8,.col-xs-9,.col-xs-10,.col-xs-11,.col-xs-12{float:left}.col-xs-12{width:100%}.col-xs-11{width:91.66666667%}.col-xs-10{width:83.33333333%}.col-xs-9{width:75%}.col-xs-8{width:66.66666667%}.col-xs-7{width:58.33333333%}.col-xs-6{width:50%}.col-xs-5{width:41.66666667%}.col-xs-4{width:33.33333333%}.col-xs-3{width:25%}.col-xs-2{width:16.66666667%}.col-xs-1{width:8.33333333%}.col-xs-pull-12{right:100%}.col-xs-pull-11{right:91.66666667%}.col-xs-pull-10{right:83.33333333%}.col-xs-pull-9{right:75%}.col-xs-pull-8{right:66.66666667%}.col-xs-pull-7{right:58.33333333%}.col-xs-pull-6{right:50%}.col-xs-pull-5{right:41.66666667%}.col-xs-pull-4{right:33.33333333%}.col-xs-pull-3{right:25%}.col-xs-pull-2{right:16.66666667%}.col-xs-pull-1{right:8.33333333%}.col-xs-pull-0{right:auto}.col-xs-push-12{left:100%}.col-xs-push-11{left:91.66666667%}.col-xs-push-10{left:83.33333333%}.col-xs-push-9{left:75%}.col-xs-push-8{left:66.66666667%}.col-xs-push-7{left:58.33333333%}.col-xs-push-6{left:50%}.col-xs-push-5{left:41.66666667%}.col-xs-push-4{left:33.33333333%}.col-xs-push-3{left:25%}.col-xs-push-2{left:16.66666667%}.col-xs-push-1{left:8.33333333%}.col-xs-push-0{left:auto}.col-xs-offset-12{margin-left:100%}.col-xs-offset-11{margin-left:91.66666667%}.col-xs-offset-10{margin-left:83.33333333%}.col-xs-offset-9{margin-left:75%}.col-xs-offset-8{margin-left:66.66666667%}.col-xs-offset-7{margin-left:58.33333333%}.col-xs-offset-6{margin-left:50%}.col-xs-offset-5{margin-left:41.66666667%}.col-xs-offset-4{margin-left:33.33333333%}.col-xs-offset-3{margin-left:25%}.col-xs-offset-2{margin-left:16.66666667%}.col-xs-offset-1{margin-left:8.33333333%}.col-xs-offset-0{margin-left:0}@media (min-width:768px){.col-sm-1,.col-sm-2,.col-sm-3,.col-sm-4,.col-sm-5,.col-sm-6,.col-sm-7,.col-sm-8,.col-sm-9,.col-sm-10,.col-sm-11,.col-sm-12{float:left}.col-sm-12{width:100%}.col-sm-11{width:91.66666667%}.col-sm-10{width:83.33333333%}.col-sm-9{width:75%}.col-sm-8{width:66.66666667%}.col-sm-7{width:58.33333333%}.col-sm-6{width:50%}.col-sm-5{width:41.66666667%}.col-sm-4{width:33.33333333%}.col-sm-3{width:25%}.col-sm-2{width:16.66666667%}.col-sm-1{width:8.33333333%}.col-sm-pull-12{right:100%}.col-sm-pull-11{right:91.66666667%}.col-sm-pull-10{right:83.33333333%}.col-sm-pull-9{right:75%}.col-sm-pull-8{right:66.66666667%}.col-sm-pull-7{right:58.33333333%}.col-sm-pull-6{right:50%}.col-sm-pull-5{right:41.66666667%}.col-sm-pull-4{right:33.33333333%}.col-sm-pull-3{right:25%}.col-sm-pull-2{right:16.66666667%}.col-sm-pull-1{right:8.33333333%}.col-sm-pull-0{right:auto}.col-sm-push-12{left:100%}.col-sm-push-11{left:91.66666667%}.col-sm-push-10{left:83.33333333%}.col-sm-push-9{left:75%}.col-sm-push-8{left:66.66666667%}.col-sm-push-7{left:58.33333333%}.col-sm-push-6{left:50%}.col-sm-push-5{left:41.66666667%}.col-sm-push-4{left:33.33333333%}.col-sm-push-3{left:25%}.col-sm-push-2{left:16.66666667%}.col-sm-push-1{left:8.33333333%}.col-sm-push-0{left:auto}.col-sm-offset-12{margin-left:100%}.col-sm-offset-11{margin-left:91.66666667%}.col-sm-offset-10{margin-left:83.33333333%}.col-sm-offset-9{margin-left:75%}.col-sm-offset-8{margin-left:66.66666667%}.col-sm-offset-7{margin-left:58.33333333%}.col-sm-offset-6{margin-left:50%}.col-sm-offset-5{margin-left:41.66666667%}.col-sm-offset-4{margin-left:33.33333333%}.col-sm-offset-3{margin-left:25%}.col-sm-offset-2{margin-left:16.66666667%}.col-sm-offset-1{margin-left:8.33333333%}.col-sm-offset-0{margin-left:0}}@media (min-width:992px){.col-md-1,.col-md-2,.col-md-3,.col-md-4,.col-md-5,.col-md-6,.col-md-7,.col-md-8,.col-md-9,.col-md-10,.col-md-11,.col-md-12{float:left}.col-md-12{width:100%}.col-md-11{width:91.66666667%}.col-md-10{width:83.33333333%}.col-md-9{width:75%}.col-md-8{width:66.66666667%}.col-md-7{width:58.33333333%}.col-md-6{width:50%}.col-md-5{width:41.66666667%}.col-md-4{width:33.33333333%}.col-md-3{width:25%}.col-md-2{width:16.66666667%}.col-md-1{width:8.33333333%}.col-md-pull-12{right:100%}.col-md-pull-11{right:91.66666667%}.col-md-pull-10{right:83.33333333%}.col-md-pull-9{right:75%}.col-md-pull-8{right:66.66666667%}.col-md-pull-7{right:58.33333333%}.col-md-pull-6{right:50%}.col-md-pull-5{right:41.66666667%}.col-md-pull-4{right:33.33333333%}.col-md-pull-3{right:25%}.col-md-pull-2{right:16.66666667%}.col-md-pull-1{right:8.33333333%}.col-md-pull-0{right:auto}.col-md-push-12{left:100%}.col-md-push-11{left:91.66666667%}.col-md-push-10{left:83.33333333%}.col-md-push-9{left:75%}.col-md-push-8{left:66.66666667%}.col-md-push-7{left:58.33333333%}.col-md-push-6{left:50%}.col-md-push-5{left:41.66666667%}.col-md-push-4{left:33.33333333%}.col-md-push-3{left:25%}.col-md-push-2{left:16.66666667%}.col-md-push-1{left:8.33333333%}.col-md-push-0{left:auto}.col-md-offset-12{margin-left:100%}.col-md-offset-11{margin-left:91.66666667%}.col-md-offset-10{margin-left:83.33333333%}.col-md-offset-9{margin-left:75%}.col-md-offset-8{margin-left:66.66666667%}.col-md-offset-7{margin-left:58.33333333%}.col-md-offset-6{margin-left:50%}.col-md-offset-5{margin-left:41.66666667%}.col-md-offset-4{margin-left:33.33333333%}.col-md-offset-3{margin-left:25%}.col-md-offset-2{margin-left:16.66666667%}.col-md-offset-1{margin-left:8.33333333%}.col-md-offset-0{margin-left:0}}@media (min-width:1200px){.col-lg-1,.col-lg-2,.col-lg-3,.col-lg-4,.col-lg-5,.col-lg-6,.col-lg-7,.col-lg-8,.col-lg-9,.col-lg-10,.col-lg-11,.col-lg-12{float:left}.col-lg-12{width:100%}.col-lg-11{width:91.66666667%}.col-lg-10{width:83.33333333%}.col-lg-9{width:75%}.col-lg-8{width:66.66666667%}.col-lg-7{width:58.33333333%}.col-lg-6{width:50%}.col-lg-5{width:41.66666667%}.col-lg-4{width:33.33333333%}.col-lg-3{width:25%}.col-lg-2{width:16.66666667%}.col-lg-1{width:8.33333333%}.col-lg-pull-12{right:100%}.col-lg-pull-11{right:91.66666667%}.col-lg-pull-10{right:83.33333333%}.col-lg-pull-9{right:75%}.col-lg-pull-8{right:66.66666667%}.col-lg-pull-7{right:58.33333333%}.col-lg-pull-6{right:50%}.col-lg-pull-5{right:41.66666667%}.col-lg-pull-4{right:33.33333333%}.col-lg-pull-3{right:25%}.col-lg-pull-2{right:16.66666667%}.col-lg-pull-1{right:8.33333333%}.col-lg-pull-0{right:auto}.col-lg-push-12{left:100%}.col-lg-push-11{left:91.66666667%}.col-lg-push-10{left:83.33333333%}.col-lg-push-9{left:75%}.col-lg-push-8{left:66.66666667%}.col-lg-push-7{left:58.33333333%}.col-lg-push-6{left:50%}.col-lg-push-5{left:41.66666667%}.col-lg-push-4{left:33.33333333%}.col-lg-push-3{left:25%}.col-lg-push-2{left:16.66666667%}.col-lg-push-1{left:8.33333333%}.col-lg-push-0{left:auto}.col-lg-offset-12{margin-left:100%}.col-lg-offset-11{margin-left:91.66666667%}.col-lg-offset-10{margin-left:83.33333333%}.col-lg-offset-9{margin-left:75%}.col-lg-offset-8{margin-left:66.66666667%}.col-lg-offset-7{margin-left:58.33333333%}.col-lg-offset-6{margin-left:50%}.col-lg-offset-5{margin-left:41.66666667%}.col-lg-offset-4{margin-left:33.33333333%}.col-lg-offset-3{margin-left:25%}.col-lg-offset-2{margin-left:16.66666667%}.col-lg-offset-1{margin-left:8.33333333%}.col-lg-offset-0{margin-left:0}}table{background-color:transparent}caption{padding-top:8px;padding-bottom:8px;color:#777}caption,th{text-align:left}.table{width:100%;max-width:100%;margin-bottom:20px}.table>tbody>tr>td,.table>tbody>tr>th,.table>tfoot>tr>td,.table>tfoot>tr>th,.table>thead>tr>td,.table>thead>tr>th{padding:8px;line-height:1.42857143;vertical-align:top;border-top:1px solid #ddd}.table>thead>tr>th{vertical-align:bottom;border-bottom:2px solid #ddd}.table>caption+thead>tr:first-child>td,.table>caption+thead>tr:first-child>th,.table>colgroup+thead>tr:first-child>td,.table>colgroup+thead>tr:first-child>th,.table>thead:first-child>tr:first-child>td,.table>thead:first-child>tr:first-child>th{border-top:0}.table>tbody+tbody{border-top:2px solid #ddd}.table .table{background-color:#fff}.table-condensed>tbody>tr>td,.table-condensed>tbody>tr>th,.table-condensed>tfoot>tr>td,.table-condensed>tfoot>tr>th,.table-condensed>thead>tr>td,.table-condensed>thead>tr>th{padding:5px}.table-bordered,.table-bordered>tbody>tr>td,.table-bordered>tbody>tr>th,.table-bordered>tfoot>tr>td,.table-bordered>tfoot>tr>th,.table-bordered>thead>tr>td,.table-bordered>thead>tr>th{border:1px solid #ddd}.table-bordered>thead>tr>td,.table-bordered>thead>tr>th{border-bottom-width:2px}.table-striped>tbody>tr:nth-of-type(odd){background-color:#f9f9f9}.table-hover>tbody>tr:hover{background-color:#f5f5f5}table col[class*=col-]{position:static;display:table-column;float:none}table td[class*=col-],table th[class*=col-]{position:static;display:table-cell;float:none}.table>tbody>tr.active>td,.table>tbody>tr.active>th,.table>tbody>tr>td.active,.table>tbody>tr>th.active,.table>tfoot>tr.active>td,.table>tfoot>tr.active>th,.table>tfoot>tr>td.active,.table>tfoot>tr>th.active,.table>thead>tr.active>td,.table>thead>tr.active>th,.table>thead>tr>td.active,.table>thead>tr>th.active{background-color:#f5f5f5}.table-hover>tbody>tr.active:hover>td,.table-hover>tbody>tr.active:hover>th,.table-hover>tbody>tr:hover>.active,.table-hover>tbody>tr>td.active:hover,.table-hover>tbody>tr>th.active:hover{background-color:#e8e8e8}.table>tbody>tr.success>td,.table>tbody>tr.success>th,.table>tbody>tr>td.success,.table>tbody>tr>th.success,.table>tfoot>tr.success>td,.table>tfoot>tr.success>th,.table>tfoot>tr>td.success,.table>tfoot>tr>th.success,.table>thead>tr.success>td,.table>thead>tr.success>th,.table>thead>tr>td.success,.table>thead>tr>th.success{background-color:#dff0d8}.table-hover>tbody>tr.success:hover>td,.table-hover>tbody>tr.success:hover>th,.table-hover>tbody>tr:hover>.success,.table-hover>tbody>tr>td.success:hover,.table-hover>tbody>tr>th.success:hover{background-color:#d0e9c6}.table>tbody>tr.info>td,.table>tbody>tr.info>th,.table>tbody>tr>td.info,.table>tbody>tr>th.info,.table>tfoot>tr.info>td,.table>tfoot>tr.info>th,.table>tfoot>tr>td.info,.table>tfoot>tr>th.info,.table>thead>tr.info>td,.table>thead>tr.info>th,.table>thead>tr>td.info,.table>thead>tr>th.info{background-color:#d9edf7}.table-hover>tbody>tr.info:hover>td,.table-hover>tbody>tr.info:hover>th,.table-hover>tbody>tr:hover>.info,.table-hover>tbody>tr>td.info:hover,.table-hover>tbody>tr>th.info:hover{background-color:#c4e3f3}.table>tbody>tr.warning>td,.table>tbody>tr.warning>th,.table>tbody>tr>td.warning,.table>tbody>tr>th.warning,.table>tfoot>tr.warning>td,.table>tfoot>tr.warning>th,.table>tfoot>tr>td.warning,.table>tfoot>tr>th.warning,.table>thead>tr.warning>td,.table>thead>tr.warning>th,.table>thead>tr>td.warning,.table>thead>tr>th.warning{background-color:#fcf8e3}.table-hover>tbody>tr.warning:hover>td,.table-hover>tbody>tr.warning:hover>th,.table-hover>tbody>tr:hover>.warning,.table-hover>tbody>tr>td.warning:hover,.table-hover>tbody>tr>th.warning:hover{background-color:#faf2cc}.table>tbody>tr.danger>td,.table>tbody>tr.danger>th,.table>tbody>tr>td.danger,.table>tbody>tr>th.danger,.table>tfoot>tr.danger>td,.table>tfoot>tr.danger>th,.table>tfoot>tr>td.danger,.table>tfoot>tr>th.danger,.table>thead>tr.danger>td,.table>thead>tr.danger>th,.table>thead>tr>td.danger,.table>thead>tr>th.danger{background-color:#f2dede}.table-hover>tbody>tr.danger:hover>td,.table-hover>tbody>tr.danger:hover>th,.table-hover>tbody>tr:hover>.danger,.table-hover>tbody>tr>td.danger:hover,.table-hover>tbody>tr>th.danger:hover{background-color:#ebcccc}.table-responsive{min-height:.01%;overflow-x:auto}@media screen and (max-width:767px){.table-responsive{width:100%;margin-bottom:15px;overflow-y:hidden;-ms-overflow-style:-ms-autohiding-scrollbar;border:1px solid #ddd}.table-responsive>.table{margin-bottom:0}.table-responsive>.table>tbody>tr>td,.table-responsive>.table>tbody>tr>th,.table-responsive>.table>tfoot>tr>td,.table-responsive>.table>tfoot>tr>th,.table-responsive>.table>thead>tr>td,.table-responsive>.table>thead>tr>th{white-space:nowrap}.table-responsive>.table-bordered{border:0}.table-responsive>.table-bordered>tbody>tr>td:first-child,.table-responsive>.table-bordered>tbody>tr>th:first-child,.table-responsive>.table-bordered>tfoot>tr>td:first-child,.table-responsive>.table-bordered>tfoot>tr>th:first-child,.table-responsive>.table-bordered>thead>tr>td:first-child,.table-responsive>.table-bordered>thead>tr>th:first-child{border-left:0}.table-responsive>.table-bordered>tbody>tr>td:last-child,.table-responsive>.table-bordered>tbody>tr>th:last-child,.table-responsive>.table-bordered>tfoot>tr>td:last-child,.table-responsive>.table-bordered>tfoot>tr>th:last-child,.table-responsive>.table-bordered>thead>tr>td:last-child,.table-responsive>.table-bordered>thead>tr>th:last-child{border-right:0}.table-responsive>.table-bordered>tbody>tr:last-child>td,.table-responsive>.table-bordered>tbody>tr:last-child>th,.table-responsive>.table-bordered>tfoot>tr:last-child>td,.table-responsive>.table-bordered>tfoot>tr:last-child>th{border-bottom:0}}fieldset{min-width:0;margin:0}fieldset,legend{padding:0;border:0}legend{display:block;width:100%;margin-bottom:20px;font-size:21px;line-height:inherit;color:#333;border-bottom:1px solid #e5e5e5}label{display:inline-block;max-width:100%;margin-bottom:5px;font-weight:700}input[type=search]{-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box}input[type=checkbox],input[type=radio]{margin:4px 0 0;margin-top:1px\\9;line-height:normal}input[type=file]{display:block}input[type=range]{display:block;width:100%}select[multiple],select[size]{height:auto}input[type=checkbox]:focus,input[type=file]:focus,input[type=radio]:focus{outline:5px auto -webkit-focus-ring-color;outline-offset:-2px}output{padding-top:7px}.form-control,output{display:block;font-size:14px;line-height:1.42857143;color:#555}.form-control{width:100%;height:34px;padding:6px 12px;background-color:#fff;background-image:none;border:1px solid #ccc;border-radius:4px;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,.075);box-shadow:inset 0 1px 1px rgba(0,0,0,.075);-webkit-transition:border-color .15s ease-in-out,-webkit-box-shadow .15s ease-in-out;-o-transition:border-color ease-in-out .15s,box-shadow ease-in-out .15s;transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out}.form-control:focus{border-color:#66afe9;outline:0;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 8px rgba(102,175,233,.6);box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 8px rgba(102,175,233,.6)}.form-control::-moz-placeholder{color:#999;opacity:1}.form-control:-ms-input-placeholder{color:#999}.form-control::-webkit-input-placeholder{color:#999}.form-control::-ms-expand{background-color:transparent;border:0}.form-control[disabled],.form-control[readonly],fieldset[disabled] .form-control{background-color:#eee;opacity:1}.form-control[disabled],fieldset[disabled] .form-control{cursor:not-allowed}textarea.form-control{height:auto}input[type=search]{-webkit-appearance:none}@media screen and (-webkit-min-device-pixel-ratio:0){input[type=date].form-control,input[type=datetime-local].form-control,input[type=month].form-control,input[type=time].form-control{line-height:34px}.input-group-sm input[type=date],.input-group-sm input[type=datetime-local],.input-group-sm input[type=month],.input-group-sm input[type=time],input[type=date].input-sm,input[type=datetime-local].input-sm,input[type=month].input-sm,input[type=time].input-sm{line-height:30px}.input-group-lg input[type=date],.input-group-lg input[type=datetime-local],.input-group-lg input[type=month],.input-group-lg input[type=time],input[type=date].input-lg,input[type=datetime-local].input-lg,input[type=month].input-lg,input[type=time].input-lg{line-height:46px}}.form-group{margin-bottom:15px}.checkbox,.radio{position:relative;display:block;margin-top:10px;margin-bottom:10px}.checkbox label,.radio label{min-height:20px;padding-left:20px;margin-bottom:0;font-weight:400;cursor:pointer}.checkbox-inline input[type=checkbox],.checkbox input[type=checkbox],.radio-inline input[type=radio],.radio input[type=radio]{position:absolute;margin-top:4px\\9;margin-left:-20px}.checkbox+.checkbox,.radio+.radio{margin-top:-5px}.checkbox-inline,.radio-inline{position:relative;display:inline-block;padding-left:20px;margin-bottom:0;font-weight:400;vertical-align:middle;cursor:pointer}.checkbox-inline+.checkbox-inline,.radio-inline+.radio-inline{margin-top:0;margin-left:10px}.checkbox-inline.disabled,.checkbox.disabled label,.radio-inline.disabled,.radio.disabled label,fieldset[disabled] .checkbox-inline,fieldset[disabled] .checkbox label,fieldset[disabled] .radio-inline,fieldset[disabled] .radio label,fieldset[disabled] input[type=checkbox],fieldset[disabled] input[type=radio],input[type=checkbox].disabled,input[type=checkbox][disabled],input[type=radio].disabled,input[type=radio][disabled]{cursor:not-allowed}.form-control-static{min-height:34px;padding-top:7px;padding-bottom:7px;margin-bottom:0}.form-control-static.input-lg,.form-control-static.input-sm{padding-right:0;padding-left:0}.input-sm{height:30px;padding:5px 10px;font-size:12px;line-height:1.5;border-radius:3px}select.input-sm{height:30px;line-height:30px}select[multiple].input-sm,textarea.input-sm{height:auto}.form-group-sm .form-control{height:30px;padding:5px 10px;font-size:12px;line-height:1.5;border-radius:3px}.form-group-sm select.form-control{height:30px;line-height:30px}.form-group-sm select[multiple].form-control,.form-group-sm textarea.form-control{height:auto}.form-group-sm .form-control-static{height:30px;min-height:32px;padding:6px 10px;font-size:12px;line-height:1.5}.input-lg{height:46px;padding:10px 16px;font-size:18px;line-height:1.3333333;border-radius:6px}select.input-lg{height:46px;line-height:46px}select[multiple].input-lg,textarea.input-lg{height:auto}.form-group-lg .form-control{height:46px;padding:10px 16px;font-size:18px;line-height:1.3333333;border-radius:6px}.form-group-lg select.form-control{height:46px;line-height:46px}.form-group-lg select[multiple].form-control,.form-group-lg textarea.form-control{height:auto}.form-group-lg .form-control-static{height:46px;min-height:38px;padding:11px 16px;font-size:18px;line-height:1.3333333}.has-feedback{position:relative}.has-feedback .form-control{padding-right:42.5px}.form-control-feedback{position:absolute;top:0;right:0;z-index:2;display:block;width:34px;height:34px;line-height:34px;text-align:center;pointer-events:none}.form-group-lg .form-control+.form-control-feedback,.input-group-lg+.form-control-feedback,.input-lg+.form-control-feedback{width:46px;height:46px;line-height:46px}.form-group-sm .form-control+.form-control-feedback,.input-group-sm+.form-control-feedback,.input-sm+.form-control-feedback{width:30px;height:30px;line-height:30px}.has-success .checkbox,.has-success .checkbox-inline,.has-success.checkbox-inline label,.has-success.checkbox label,.has-success .control-label,.has-success .help-block,.has-success .radio,.has-success .radio-inline,.has-success.radio-inline label,.has-success.radio label{color:#3c763d}.has-success .form-control{border-color:#3c763d;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,.075);box-shadow:inset 0 1px 1px rgba(0,0,0,.075)}.has-success .form-control:focus{border-color:#2b542c;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 6px #67b168;box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 6px #67b168}.has-success .input-group-addon{color:#3c763d;background-color:#dff0d8;border-color:#3c763d}.has-success .form-control-feedback{color:#3c763d}.has-warning .checkbox,.has-warning .checkbox-inline,.has-warning.checkbox-inline label,.has-warning.checkbox label,.has-warning .control-label,.has-warning .help-block,.has-warning .radio,.has-warning .radio-inline,.has-warning.radio-inline label,.has-warning.radio label{color:#8a6d3b}.has-warning .form-control{border-color:#8a6d3b;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,.075);box-shadow:inset 0 1px 1px rgba(0,0,0,.075)}.has-warning .form-control:focus{border-color:#66512c;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 6px #c0a16b;box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 6px #c0a16b}.has-warning .input-group-addon{color:#8a6d3b;background-color:#fcf8e3;border-color:#8a6d3b}.has-warning .form-control-feedback{color:#8a6d3b}.has-error .checkbox,.has-error .checkbox-inline,.has-error.checkbox-inline label,.has-error.checkbox label,.has-error .control-label,.has-error .help-block,.has-error .radio,.has-error .radio-inline,.has-error.radio-inline label,.has-error.radio label{color:#a94442}.has-error .form-control{border-color:#a94442;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,.075);box-shadow:inset 0 1px 1px rgba(0,0,0,.075)}.has-error .form-control:focus{border-color:#843534;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 6px #ce8483;box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 6px #ce8483}.has-error .input-group-addon{color:#a94442;background-color:#f2dede;border-color:#a94442}.has-error .form-control-feedback{color:#a94442}.has-feedback label~.form-control-feedback{top:25px}.has-feedback label.sr-only~.form-control-feedback{top:0}.help-block{display:block;margin-top:5px;margin-bottom:10px;color:#737373}@media (min-width:768px){.form-inline .form-group{display:inline-block;margin-bottom:0;vertical-align:middle}.form-inline .form-control{display:inline-block;width:auto;vertical-align:middle}.form-inline .form-control-static{display:inline-block}.form-inline .input-group{display:inline-table;vertical-align:middle}.form-inline .input-group .form-control,.form-inline .input-group .input-group-addon,.form-inline .input-group .input-group-btn{width:auto}.form-inline .input-group>.form-control{width:100%}.form-inline .control-label{margin-bottom:0;vertical-align:middle}.form-inline .checkbox,.form-inline .radio{display:inline-block;margin-top:0;margin-bottom:0;vertical-align:middle}.form-inline .checkbox label,.form-inline .radio label{padding-left:0}.form-inline .checkbox input[type=checkbox],.form-inline .radio input[type=radio]{position:relative;margin-left:0}.form-inline .has-feedback .form-control-feedback{top:0}}.form-horizontal .checkbox,.form-horizontal .checkbox-inline,.form-horizontal .radio,.form-horizontal .radio-inline{padding-top:7px;margin-top:0;margin-bottom:0}.form-horizontal .checkbox,.form-horizontal .radio{min-height:27px}.form-horizontal .form-group{margin-right:-15px;margin-left:-15px}@media (min-width:768px){.form-horizontal .control-label{padding-top:7px;margin-bottom:0;text-align:right}}.form-horizontal .has-feedback .form-control-feedback{right:15px}@media (min-width:768px){.form-horizontal .form-group-lg .control-label{padding-top:11px;font-size:18px}}@media (min-width:768px){.form-horizontal .form-group-sm .control-label{padding-top:6px;font-size:12px}}.btn{display:inline-block;padding:6px 12px;margin-bottom:0;font-size:14px;font-weight:400;line-height:1.42857143;text-align:center;white-space:nowrap;vertical-align:middle;-ms-touch-action:manipulation;touch-action:manipulation;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;background-image:none;border:1px solid transparent;border-radius:4px}.btn.active.focus,.btn.active:focus,.btn.focus,.btn:active.focus,.btn:active:focus,.btn:focus{outline:5px auto -webkit-focus-ring-color;outline-offset:-2px}.btn.focus,.btn:focus,.btn:hover{color:#333;text-decoration:none}.btn.active,.btn:active{background-image:none;outline:0;-webkit-box-shadow:inset 0 3px 5px rgba(0,0,0,.125);box-shadow:inset 0 3px 5px rgba(0,0,0,.125)}.btn.disabled,.btn[disabled],fieldset[disabled] .btn{cursor:not-allowed;filter:alpha(opacity=65);-webkit-box-shadow:none;box-shadow:none;opacity:.65}a.btn.disabled,fieldset[disabled] a.btn{pointer-events:none}.btn-default{color:#333;background-color:#fff;border-color:#ccc}.btn-default.focus,.btn-default:focus{color:#333;background-color:#e6e6e6;border-color:#8c8c8c}.btn-default.active,.btn-default:active,.btn-default:hover,.open>.dropdown-toggle.btn-default{color:#333;background-color:#e6e6e6;border-color:#adadad}.btn-default.active.focus,.btn-default.active:focus,.btn-default.active:hover,.btn-default:active.focus,.btn-default:active:focus,.btn-default:active:hover,.open>.dropdown-toggle.btn-default.focus,.open>.dropdown-toggle.btn-default:focus,.open>.dropdown-toggle.btn-default:hover{color:#333;background-color:#d4d4d4;border-color:#8c8c8c}.btn-default.active,.btn-default:active,.open>.dropdown-toggle.btn-default{background-image:none}.btn-default.disabled.focus,.btn-default.disabled:focus,.btn-default.disabled:hover,.btn-default[disabled].focus,.btn-default[disabled]:focus,.btn-default[disabled]:hover,fieldset[disabled] .btn-default.focus,fieldset[disabled] .btn-default:focus,fieldset[disabled] .btn-default:hover{background-color:#fff;border-color:#ccc}.btn-default .badge{color:#fff;background-color:#333}.btn-primary{color:#fff;background-color:#337ab7;border-color:#2e6da4}.btn-primary.focus,.btn-primary:focus{color:#fff;background-color:#286090;border-color:#122b40}.btn-primary.active,.btn-primary:active,.btn-primary:hover,.open>.dropdown-toggle.btn-primary{color:#fff;background-color:#286090;border-color:#204d74}.btn-primary.active.focus,.btn-primary.active:focus,.btn-primary.active:hover,.btn-primary:active.focus,.btn-primary:active:focus,.btn-primary:active:hover,.open>.dropdown-toggle.btn-primary.focus,.open>.dropdown-toggle.btn-primary:focus,.open>.dropdown-toggle.btn-primary:hover{color:#fff;background-color:#204d74;border-color:#122b40}.btn-primary.active,.btn-primary:active,.open>.dropdown-toggle.btn-primary{background-image:none}.btn-primary.disabled.focus,.btn-primary.disabled:focus,.btn-primary.disabled:hover,.btn-primary[disabled].focus,.btn-primary[disabled]:focus,.btn-primary[disabled]:hover,fieldset[disabled] .btn-primary.focus,fieldset[disabled] .btn-primary:focus,fieldset[disabled] .btn-primary:hover{background-color:#337ab7;border-color:#2e6da4}.btn-primary .badge{color:#337ab7;background-color:#fff}.btn-success{color:#fff;background-color:#5cb85c;border-color:#4cae4c}.btn-success.focus,.btn-success:focus{color:#fff;background-color:#449d44;border-color:#255625}.btn-success.active,.btn-success:active,.btn-success:hover,.open>.dropdown-toggle.btn-success{color:#fff;background-color:#449d44;border-color:#398439}.btn-success.active.focus,.btn-success.active:focus,.btn-success.active:hover,.btn-success:active.focus,.btn-success:active:focus,.btn-success:active:hover,.open>.dropdown-toggle.btn-success.focus,.open>.dropdown-toggle.btn-success:focus,.open>.dropdown-toggle.btn-success:hover{color:#fff;background-color:#398439;border-color:#255625}.btn-success.active,.btn-success:active,.open>.dropdown-toggle.btn-success{background-image:none}.btn-success.disabled.focus,.btn-success.disabled:focus,.btn-success.disabled:hover,.btn-success[disabled].focus,.btn-success[disabled]:focus,.btn-success[disabled]:hover,fieldset[disabled] .btn-success.focus,fieldset[disabled] .btn-success:focus,fieldset[disabled] .btn-success:hover{background-color:#5cb85c;border-color:#4cae4c}.btn-success .badge{color:#5cb85c;background-color:#fff}.btn-info{color:#fff;background-color:#5bc0de;border-color:#46b8da}.btn-info.focus,.btn-info:focus{color:#fff;background-color:#31b0d5;border-color:#1b6d85}.btn-info.active,.btn-info:active,.btn-info:hover,.open>.dropdown-toggle.btn-info{color:#fff;background-color:#31b0d5;border-color:#269abc}.btn-info.active.focus,.btn-info.active:focus,.btn-info.active:hover,.btn-info:active.focus,.btn-info:active:focus,.btn-info:active:hover,.open>.dropdown-toggle.btn-info.focus,.open>.dropdown-toggle.btn-info:focus,.open>.dropdown-toggle.btn-info:hover{color:#fff;background-color:#269abc;border-color:#1b6d85}.btn-info.active,.btn-info:active,.open>.dropdown-toggle.btn-info{background-image:none}.btn-info.disabled.focus,.btn-info.disabled:focus,.btn-info.disabled:hover,.btn-info[disabled].focus,.btn-info[disabled]:focus,.btn-info[disabled]:hover,fieldset[disabled] .btn-info.focus,fieldset[disabled] .btn-info:focus,fieldset[disabled] .btn-info:hover{background-color:#5bc0de;border-color:#46b8da}.btn-info .badge{color:#5bc0de;background-color:#fff}.btn-warning{color:#fff;background-color:#f0ad4e;border-color:#eea236}.btn-warning.focus,.btn-warning:focus{color:#fff;background-color:#ec971f;border-color:#985f0d}.btn-warning.active,.btn-warning:active,.btn-warning:hover,.open>.dropdown-toggle.btn-warning{color:#fff;background-color:#ec971f;border-color:#d58512}.btn-warning.active.focus,.btn-warning.active:focus,.btn-warning.active:hover,.btn-warning:active.focus,.btn-warning:active:focus,.btn-warning:active:hover,.open>.dropdown-toggle.btn-warning.focus,.open>.dropdown-toggle.btn-warning:focus,.open>.dropdown-toggle.btn-warning:hover{color:#fff;background-color:#d58512;border-color:#985f0d}.btn-warning.active,.btn-warning:active,.open>.dropdown-toggle.btn-warning{background-image:none}.btn-warning.disabled.focus,.btn-warning.disabled:focus,.btn-warning.disabled:hover,.btn-warning[disabled].focus,.btn-warning[disabled]:focus,.btn-warning[disabled]:hover,fieldset[disabled] .btn-warning.focus,fieldset[disabled] .btn-warning:focus,fieldset[disabled] .btn-warning:hover{background-color:#f0ad4e;border-color:#eea236}.btn-warning .badge{color:#f0ad4e;background-color:#fff}.btn-danger{color:#fff;background-color:#d9534f;border-color:#d43f3a}.btn-danger.focus,.btn-danger:focus{color:#fff;background-color:#c9302c;border-color:#761c19}.btn-danger.active,.btn-danger:active,.btn-danger:hover,.open>.dropdown-toggle.btn-danger{color:#fff;background-color:#c9302c;border-color:#ac2925}.btn-danger.active.focus,.btn-danger.active:focus,.btn-danger.active:hover,.btn-danger:active.focus,.btn-danger:active:focus,.btn-danger:active:hover,.open>.dropdown-toggle.btn-danger.focus,.open>.dropdown-toggle.btn-danger:focus,.open>.dropdown-toggle.btn-danger:hover{color:#fff;background-color:#ac2925;border-color:#761c19}.btn-danger.active,.btn-danger:active,.open>.dropdown-toggle.btn-danger{background-image:none}.btn-danger.disabled.focus,.btn-danger.disabled:focus,.btn-danger.disabled:hover,.btn-danger[disabled].focus,.btn-danger[disabled]:focus,.btn-danger[disabled]:hover,fieldset[disabled] .btn-danger.focus,fieldset[disabled] .btn-danger:focus,fieldset[disabled] .btn-danger:hover{background-color:#d9534f;border-color:#d43f3a}.btn-danger .badge{color:#d9534f;background-color:#fff}.btn-link{font-weight:400;color:#337ab7;border-radius:0}.btn-link,.btn-link.active,.btn-link:active,.btn-link[disabled],fieldset[disabled] .btn-link{background-color:transparent;-webkit-box-shadow:none;box-shadow:none}.btn-link,.btn-link:active,.btn-link:focus,.btn-link:hover{border-color:transparent}.btn-link:focus,.btn-link:hover{color:#23527c;text-decoration:underline;background-color:transparent}.btn-link[disabled]:focus,.btn-link[disabled]:hover,fieldset[disabled] .btn-link:focus,fieldset[disabled] .btn-link:hover{color:#777;text-decoration:none}.btn-group-lg>.btn,.btn-lg{padding:10px 16px;font-size:18px;line-height:1.3333333;border-radius:6px}.btn-group-sm>.btn,.btn-sm{padding:5px 10px;font-size:12px;line-height:1.5;border-radius:3px}.btn-group-xs>.btn,.btn-xs{padding:1px 5px;font-size:12px;line-height:1.5;border-radius:3px}.btn-block{display:block;width:100%}.btn-block+.btn-block{margin-top:5px}input[type=button].btn-block,input[type=reset].btn-block,input[type=submit].btn-block{width:100%}.fade{opacity:0;-webkit-transition:opacity .15s linear;-o-transition:opacity .15s linear;transition:opacity .15s linear}.fade.in{opacity:1}.collapse{display:none}.collapse.in{display:block}tr.collapse.in{display:table-row}tbody.collapse.in{display:table-row-group}.collapsing{position:relative;height:0;overflow:hidden;-webkit-transition-timing-function:ease;-o-transition-timing-function:ease;transition-timing-function:ease;-webkit-transition-duration:.35s;-o-transition-duration:.35s;transition-duration:.35s;-webkit-transition-property:height,visibility;-o-transition-property:height,visibility;transition-property:height,visibility}.caret{display:inline-block;width:0;height:0;margin-left:2px;vertical-align:middle;border-top:4px dashed;border-top:4px solid\\9;border-right:4px solid transparent;border-left:4px solid transparent}.dropdown,.dropup{position:relative}.dropdown-toggle:focus{outline:0}.dropdown-menu{position:absolute;top:100%;left:0;z-index:1000;display:none;float:left;min-width:160px;padding:5px 0;margin:2px 0 0;font-size:14px;text-align:left;list-style:none;background-color:#fff;-webkit-background-clip:padding-box;background-clip:padding-box;border:1px solid #ccc;border:1px solid rgba(0,0,0,.15);border-radius:4px;-webkit-box-shadow:0 6px 12px rgba(0,0,0,.175);box-shadow:0 6px 12px rgba(0,0,0,.175)}.dropdown-menu.pull-right{right:0;left:auto}.dropdown-menu .divider{height:1px;margin:9px 0;overflow:hidden;background-color:#e5e5e5}.dropdown-menu>li>a{display:block;padding:3px 20px;clear:both;font-weight:400;line-height:1.42857143;color:#333;white-space:nowrap}.dropdown-menu>li>a:focus,.dropdown-menu>li>a:hover{color:#262626;text-decoration:none;background-color:#f5f5f5}.dropdown-menu>.active>a,.dropdown-menu>.active>a:focus,.dropdown-menu>.active>a:hover{color:#fff;text-decoration:none;background-color:#337ab7;outline:0}.dropdown-menu>.disabled>a,.dropdown-menu>.disabled>a:focus,.dropdown-menu>.disabled>a:hover{color:#777}.dropdown-menu>.disabled>a:focus,.dropdown-menu>.disabled>a:hover{text-decoration:none;cursor:not-allowed;background-color:transparent;background-image:none;filter:progid:DXImageTransform.Microsoft.gradient(enabled=false)}.open>.dropdown-menu{display:block}.open>a{outline:0}.dropdown-menu-right{right:0;left:auto}.dropdown-menu-left{right:auto;left:0}.dropdown-header{display:block;padding:3px 20px;font-size:12px;line-height:1.42857143;color:#777;white-space:nowrap}.dropdown-backdrop{position:fixed;top:0;right:0;bottom:0;left:0;z-index:990}.pull-right>.dropdown-menu{right:0;left:auto}.dropup .caret,.navbar-fixed-bottom .dropdown .caret{content:"";border-top:0;border-bottom:4px dashed;border-bottom:4px solid\\9}.dropup .dropdown-menu,.navbar-fixed-bottom .dropdown .dropdown-menu{top:auto;bottom:100%;margin-bottom:2px}@media (min-width:768px){.navbar-right .dropdown-menu{right:0;left:auto}.navbar-right .dropdown-menu-left{right:auto;left:0}}.btn-group,.btn-group-vertical{position:relative;display:inline-block;vertical-align:middle}.btn-group-vertical>.btn,.btn-group>.btn{position:relative;float:left}.btn-group-vertical>.btn.active,.btn-group-vertical>.btn:active,.btn-group-vertical>.btn:focus,.btn-group-vertical>.btn:hover,.btn-group>.btn.active,.btn-group>.btn:active,.btn-group>.btn:focus,.btn-group>.btn:hover{z-index:2}.btn-group .btn+.btn,.btn-group .btn+.btn-group,.btn-group .btn-group+.btn,.btn-group .btn-group+.btn-group{margin-left:-1px}.btn-toolbar{margin-left:-5px}.btn-toolbar .btn,.btn-toolbar .btn-group,.btn-toolbar .input-group{float:left}.btn-toolbar>.btn,.btn-toolbar>.btn-group,.btn-toolbar>.input-group{margin-left:5px}.btn-group>.btn:not(:first-child):not(:last-child):not(.dropdown-toggle){border-radius:0}.btn-group>.btn:first-child{margin-left:0}.btn-group>.btn:first-child:not(:last-child):not(.dropdown-toggle){border-top-right-radius:0;border-bottom-right-radius:0}.btn-group>.btn:last-child:not(:first-child),.btn-group>.dropdown-toggle:not(:first-child){border-top-left-radius:0;border-bottom-left-radius:0}.btn-group>.btn-group{float:left}.btn-group>.btn-group:not(:first-child):not(:last-child)>.btn{border-radius:0}.btn-group>.btn-group:first-child:not(:last-child)>.btn:last-child,.btn-group>.btn-group:first-child:not(:last-child)>.dropdown-toggle{border-top-right-radius:0;border-bottom-right-radius:0}.btn-group>.btn-group:last-child:not(:first-child)>.btn:first-child{border-top-left-radius:0;border-bottom-left-radius:0}.btn-group .dropdown-toggle:active,.btn-group.open .dropdown-toggle{outline:0}.btn-group>.btn+.dropdown-toggle{padding-right:8px;padding-left:8px}.btn-group>.btn-lg+.dropdown-toggle{padding-right:12px;padding-left:12px}.btn-group.open .dropdown-toggle{-webkit-box-shadow:inset 0 3px 5px rgba(0,0,0,.125);box-shadow:inset 0 3px 5px rgba(0,0,0,.125)}.btn-group.open .dropdown-toggle.btn-link{-webkit-box-shadow:none;box-shadow:none}.btn .caret{margin-left:0}.btn-lg .caret{border-width:5px 5px 0;border-bottom-width:0}.dropup .btn-lg .caret{border-width:0 5px 5px}.btn-group-vertical>.btn,.btn-group-vertical>.btn-group,.btn-group-vertical>.btn-group>.btn{display:block;float:none;width:100%;max-width:100%}.btn-group-vertical>.btn-group>.btn{float:none}.btn-group-vertical>.btn+.btn,.btn-group-vertical>.btn+.btn-group,.btn-group-vertical>.btn-group+.btn,.btn-group-vertical>.btn-group+.btn-group{margin-top:-1px;margin-left:0}.btn-group-vertical>.btn:not(:first-child):not(:last-child){border-radius:0}.btn-group-vertical>.btn:first-child:not(:last-child){border-top-left-radius:4px;border-top-right-radius:4px;border-bottom-right-radius:0;border-bottom-left-radius:0}.btn-group-vertical>.btn:last-child:not(:first-child){border-top-left-radius:0;border-top-right-radius:0;border-bottom-right-radius:4px;border-bottom-left-radius:4px}.btn-group-vertical>.btn-group:not(:first-child):not(:last-child)>.btn{border-radius:0}.btn-group-vertical>.btn-group:first-child:not(:last-child)>.btn:last-child,.btn-group-vertical>.btn-group:first-child:not(:last-child)>.dropdown-toggle{border-bottom-right-radius:0;border-bottom-left-radius:0}.btn-group-vertical>.btn-group:last-child:not(:first-child)>.btn:first-child{border-top-left-radius:0;border-top-right-radius:0}.btn-group-justified{display:table;width:100%;table-layout:fixed;border-collapse:separate}.btn-group-justified>.btn,.btn-group-justified>.btn-group{display:table-cell;float:none;width:1%}.btn-group-justified>.btn-group .btn{width:100%}.btn-group-justified>.btn-group .dropdown-menu{left:auto}[data-toggle=buttons]>.btn-group>.btn input[type=checkbox],[data-toggle=buttons]>.btn-group>.btn input[type=radio],[data-toggle=buttons]>.btn input[type=checkbox],[data-toggle=buttons]>.btn input[type=radio]{position:absolute;clip:rect(0,0,0,0);pointer-events:none}.input-group{position:relative;display:table;border-collapse:separate}.input-group[class*=col-]{float:none;padding-right:0;padding-left:0}.input-group .form-control{position:relative;z-index:2;float:left;width:100%;margin-bottom:0}.input-group .form-control:focus{z-index:3}.input-group-lg>.form-control,.input-group-lg>.input-group-addon,.input-group-lg>.input-group-btn>.btn{height:46px;padding:10px 16px;font-size:18px;line-height:1.3333333;border-radius:6px}select.input-group-lg>.form-control,select.input-group-lg>.input-group-addon,select.input-group-lg>.input-group-btn>.btn{height:46px;line-height:46px}select[multiple].input-group-lg>.form-control,select[multiple].input-group-lg>.input-group-addon,select[multiple].input-group-lg>.input-group-btn>.btn,textarea.input-group-lg>.form-control,textarea.input-group-lg>.input-group-addon,textarea.input-group-lg>.input-group-btn>.btn{height:auto}.input-group-sm>.form-control,.input-group-sm>.input-group-addon,.input-group-sm>.input-group-btn>.btn{height:30px;padding:5px 10px;font-size:12px;line-height:1.5;border-radius:3px}select.input-group-sm>.form-control,select.input-group-sm>.input-group-addon,select.input-group-sm>.input-group-btn>.btn{height:30px;line-height:30px}select[multiple].input-group-sm>.form-control,select[multiple].input-group-sm>.input-group-addon,select[multiple].input-group-sm>.input-group-btn>.btn,textarea.input-group-sm>.form-control,textarea.input-group-sm>.input-group-addon,textarea.input-group-sm>.input-group-btn>.btn{height:auto}.input-group-addon,.input-group-btn,.input-group .form-control{display:table-cell}.input-group-addon:not(:first-child):not(:last-child),.input-group-btn:not(:first-child):not(:last-child),.input-group .form-control:not(:first-child):not(:last-child){border-radius:0}.input-group-addon,.input-group-btn{width:1%;white-space:nowrap;vertical-align:middle}.input-group-addon{padding:6px 12px;font-size:14px;font-weight:400;line-height:1;color:#555;text-align:center;background-color:#eee;border:1px solid #ccc;border-radius:4px}.input-group-addon.input-sm{padding:5px 10px;font-size:12px;border-radius:3px}.input-group-addon.input-lg{padding:10px 16px;font-size:18px;border-radius:6px}.input-group-addon input[type=checkbox],.input-group-addon input[type=radio]{margin-top:0}.input-group-addon:first-child,.input-group-btn:first-child>.btn,.input-group-btn:first-child>.btn-group>.btn,.input-group-btn:first-child>.dropdown-toggle,.input-group-btn:last-child>.btn-group:not(:last-child)>.btn,.input-group-btn:last-child>.btn:not(:last-child):not(.dropdown-toggle),.input-group .form-control:first-child{border-top-right-radius:0;border-bottom-right-radius:0}.input-group-addon:first-child{border-right:0}.input-group-addon:last-child,.input-group-btn:first-child>.btn-group:not(:first-child)>.btn,.input-group-btn:first-child>.btn:not(:first-child),.input-group-btn:last-child>.btn,.input-group-btn:last-child>.btn-group>.btn,.input-group-btn:last-child>.dropdown-toggle,.input-group .form-control:last-child{border-top-left-radius:0;border-bottom-left-radius:0}.input-group-addon:last-child{border-left:0}.input-group-btn{font-size:0;white-space:nowrap}.input-group-btn,.input-group-btn>.btn{position:relative}.input-group-btn>.btn+.btn{margin-left:-1px}.input-group-btn>.btn:active,.input-group-btn>.btn:focus,.input-group-btn>.btn:hover{z-index:2}.input-group-btn:first-child>.btn,.input-group-btn:first-child>.btn-group{margin-right:-1px}.input-group-btn:last-child>.btn,.input-group-btn:last-child>.btn-group{z-index:2;margin-left:-1px}.nav{padding-left:0;margin-bottom:0;list-style:none}.nav>li,.nav>li>a{position:relative;display:block}.nav>li>a{padding:10px 15px}.nav>li>a:focus,.nav>li>a:hover{text-decoration:none;background-color:#eee}.nav>li.disabled>a{color:#777}.nav>li.disabled>a:focus,.nav>li.disabled>a:hover{color:#777;text-decoration:none;cursor:not-allowed;background-color:transparent}.nav .open>a,.nav .open>a:focus,.nav .open>a:hover{background-color:#eee;border-color:#337ab7}.nav .nav-divider{height:1px;margin:9px 0;overflow:hidden;background-color:#e5e5e5}.nav>li>a>img{max-width:none}.nav-tabs{border-bottom:1px solid #ddd}.nav-tabs>li{float:left;margin-bottom:-1px}.nav-tabs>li>a{margin-right:2px;line-height:1.42857143;border:1px solid transparent;border-radius:4px 4px 0 0}.nav-tabs>li>a:hover{border-color:#eee #eee #ddd}.nav-tabs>li.active>a,.nav-tabs>li.active>a:focus,.nav-tabs>li.active>a:hover{color:#555;cursor:default;background-color:#fff;border:1px solid #ddd;border-bottom-color:transparent}.nav-tabs.nav-justified{width:100%;border-bottom:0}.nav-tabs.nav-justified>li{float:none}.nav-tabs.nav-justified>li>a{margin-bottom:5px;text-align:center}.nav-tabs.nav-justified>.dropdown .dropdown-menu{top:auto;left:auto}@media (min-width:768px){.nav-tabs.nav-justified>li{display:table-cell;width:1%}.nav-tabs.nav-justified>li>a{margin-bottom:0}}.nav-tabs.nav-justified>li>a{margin-right:0;border-radius:4px}.nav-tabs.nav-justified>.active>a,.nav-tabs.nav-justified>.active>a:focus,.nav-tabs.nav-justified>.active>a:hover{border:1px solid #ddd}@media (min-width:768px){.nav-tabs.nav-justified>li>a{border-bottom:1px solid #ddd;border-radius:4px 4px 0 0}.nav-tabs.nav-justified>.active>a,.nav-tabs.nav-justified>.active>a:focus,.nav-tabs.nav-justified>.active>a:hover{border-bottom-color:#fff}}.nav-pills>li{float:left}.nav-pills>li>a{border-radius:4px}.nav-pills>li+li{margin-left:2px}.nav-pills>li.active>a,.nav-pills>li.active>a:focus,.nav-pills>li.active>a:hover{color:#fff;background-color:#337ab7}.nav-stacked>li{float:none}.nav-stacked>li+li{margin-top:2px;margin-left:0}.nav-justified{width:100%}.nav-justified>li{float:none}.nav-justified>li>a{margin-bottom:5px;text-align:center}.nav-justified>.dropdown .dropdown-menu{top:auto;left:auto}@media (min-width:768px){.nav-justified>li{display:table-cell;width:1%}.nav-justified>li>a{margin-bottom:0}}.nav-tabs-justified{border-bottom:0}.nav-tabs-justified>li>a{margin-right:0;border-radius:4px}.nav-tabs-justified>.active>a,.nav-tabs-justified>.active>a:focus,.nav-tabs-justified>.active>a:hover{border:1px solid #ddd}@media (min-width:768px){.nav-tabs-justified>li>a{border-bottom:1px solid #ddd;border-radius:4px 4px 0 0}.nav-tabs-justified>.active>a,.nav-tabs-justified>.active>a:focus,.nav-tabs-justified>.active>a:hover{border-bottom-color:#fff}}.tab-content>.tab-pane{display:none}.tab-content>.active{display:block}.nav-tabs .dropdown-menu{margin-top:-1px;border-top-left-radius:0;border-top-right-radius:0}.navbar{position:relative;min-height:50px;margin-bottom:20px;border:1px solid transparent}@media (min-width:768px){.navbar{border-radius:4px}}@media (min-width:768px){.navbar-header{float:left}}.navbar-collapse{padding-right:15px;padding-left:15px;overflow-x:visible;-webkit-overflow-scrolling:touch;border-top:1px solid transparent;-webkit-box-shadow:inset 0 1px 0 hsla(0,0%,100%,.1);box-shadow:inset 0 1px 0 hsla(0,0%,100%,.1)}.navbar-collapse.in{overflow-y:auto}@media (min-width:768px){.navbar-collapse{width:auto;border-top:0;-webkit-box-shadow:none;box-shadow:none}.navbar-collapse.collapse{display:block!important;height:auto!important;padding-bottom:0;overflow:visible!important}.navbar-collapse.in{overflow-y:visible}.navbar-fixed-bottom .navbar-collapse,.navbar-fixed-top .navbar-collapse,.navbar-static-top .navbar-collapse{padding-right:0;padding-left:0}}.navbar-fixed-bottom .navbar-collapse,.navbar-fixed-top .navbar-collapse{max-height:340px}@media (max-device-width:480px) and (orientation:landscape){.navbar-fixed-bottom .navbar-collapse,.navbar-fixed-top .navbar-collapse{max-height:200px}}.container-fluid>.navbar-collapse,.container-fluid>.navbar-header,.container>.navbar-collapse,.container>.navbar-header{margin-right:-15px;margin-left:-15px}@media (min-width:768px){.container-fluid>.navbar-collapse,.container-fluid>.navbar-header,.container>.navbar-collapse,.container>.navbar-header{margin-right:0;margin-left:0}}.navbar-static-top{z-index:1000;border-width:0 0 1px}@media (min-width:768px){.navbar-static-top{border-radius:0}}.navbar-fixed-bottom,.navbar-fixed-top{position:fixed;right:0;left:0;z-index:1030}@media (min-width:768px){.navbar-fixed-bottom,.navbar-fixed-top{border-radius:0}}.navbar-fixed-top{top:0;border-width:0 0 1px}.navbar-fixed-bottom{bottom:0;margin-bottom:0;border-width:1px 0 0}.navbar-brand{float:left;height:50px;padding:15px;font-size:18px;line-height:20px}.navbar-brand:focus,.navbar-brand:hover{text-decoration:none}.navbar-brand>img{display:block}@media (min-width:768px){.navbar>.container-fluid .navbar-brand,.navbar>.container .navbar-brand{margin-left:-15px}}.navbar-toggle{position:relative;float:right;padding:9px 10px;margin-top:8px;margin-right:15px;margin-bottom:8px;background-color:transparent;background-image:none;border:1px solid transparent;border-radius:4px}.navbar-toggle:focus{outline:0}.navbar-toggle .icon-bar{display:block;width:22px;height:2px;border-radius:1px}.navbar-toggle .icon-bar+.icon-bar{margin-top:4px}@media (min-width:768px){.navbar-toggle{display:none}}.navbar-nav{margin:7.5px -15px}.navbar-nav>li>a{padding-top:10px;padding-bottom:10px;line-height:20px}@media (max-width:767px){.navbar-nav .open .dropdown-menu{position:static;float:none;width:auto;margin-top:0;background-color:transparent;border:0;-webkit-box-shadow:none;box-shadow:none}.navbar-nav .open .dropdown-menu .dropdown-header,.navbar-nav .open .dropdown-menu>li>a{padding:5px 15px 5px 25px}.navbar-nav .open .dropdown-menu>li>a{line-height:20px}.navbar-nav .open .dropdown-menu>li>a:focus,.navbar-nav .open .dropdown-menu>li>a:hover{background-image:none}}@media (min-width:768px){.navbar-nav{float:left;margin:0}.navbar-nav>li{float:left}.navbar-nav>li>a{padding-top:15px;padding-bottom:15px}}.navbar-form{padding:10px 15px;margin:8px -15px;border-top:1px solid transparent;border-bottom:1px solid transparent;-webkit-box-shadow:inset 0 1px 0 hsla(0,0%,100%,.1),0 1px 0 hsla(0,0%,100%,.1);box-shadow:inset 0 1px 0 hsla(0,0%,100%,.1),0 1px 0 hsla(0,0%,100%,.1)}@media (min-width:768px){.navbar-form .form-group{display:inline-block;margin-bottom:0;vertical-align:middle}.navbar-form .form-control{display:inline-block;width:auto;vertical-align:middle}.navbar-form .form-control-static{display:inline-block}.navbar-form .input-group{display:inline-table;vertical-align:middle}.navbar-form .input-group .form-control,.navbar-form .input-group .input-group-addon,.navbar-form .input-group .input-group-btn{width:auto}.navbar-form .input-group>.form-control{width:100%}.navbar-form .control-label{margin-bottom:0;vertical-align:middle}.navbar-form .checkbox,.navbar-form .radio{display:inline-block;margin-top:0;margin-bottom:0;vertical-align:middle}.navbar-form .checkbox label,.navbar-form .radio label{padding-left:0}.navbar-form .checkbox input[type=checkbox],.navbar-form .radio input[type=radio]{position:relative;margin-left:0}.navbar-form .has-feedback .form-control-feedback{top:0}}@media (max-width:767px){.navbar-form .form-group{margin-bottom:5px}.navbar-form .form-group:last-child{margin-bottom:0}}@media (min-width:768px){.navbar-form{width:auto;padding-top:0;padding-bottom:0;margin-right:0;margin-left:0;border:0;-webkit-box-shadow:none;box-shadow:none}}.navbar-nav>li>.dropdown-menu{margin-top:0;border-top-left-radius:0;border-top-right-radius:0}.navbar-fixed-bottom .navbar-nav>li>.dropdown-menu{margin-bottom:0;border-top-left-radius:4px;border-top-right-radius:4px;border-bottom-right-radius:0;border-bottom-left-radius:0}.navbar-btn{margin-top:8px;margin-bottom:8px}.navbar-btn.btn-sm{margin-top:10px;margin-bottom:10px}.navbar-btn.btn-xs{margin-top:14px;margin-bottom:14px}.navbar-text{margin-top:15px;margin-bottom:15px}@media (min-width:768px){.navbar-text{float:left;margin-right:15px;margin-left:15px}}@media (min-width:768px){.navbar-left{float:left!important}.navbar-right{float:right!important;margin-right:-15px}.navbar-right~.navbar-right{margin-right:0}}.navbar-default{background-color:#f8f8f8;border-color:#e7e7e7}.navbar-default .navbar-brand{color:#777}.navbar-default .navbar-brand:focus,.navbar-default .navbar-brand:hover{color:#5e5e5e;background-color:transparent}.navbar-default .navbar-nav>li>a,.navbar-default .navbar-text{color:#777}.navbar-default .navbar-nav>li>a:focus,.navbar-default .navbar-nav>li>a:hover{color:#333;background-color:transparent}.navbar-default .navbar-nav>.active>a,.navbar-default .navbar-nav>.active>a:focus,.navbar-default .navbar-nav>.active>a:hover{color:#555;background-color:#e7e7e7}.navbar-default .navbar-nav>.disabled>a,.navbar-default .navbar-nav>.disabled>a:focus,.navbar-default .navbar-nav>.disabled>a:hover{color:#ccc;background-color:transparent}.navbar-default .navbar-toggle{border-color:#ddd}.navbar-default .navbar-toggle:focus,.navbar-default .navbar-toggle:hover{background-color:#ddd}.navbar-default .navbar-toggle .icon-bar{background-color:#888}.navbar-default .navbar-collapse,.navbar-default .navbar-form{border-color:#e7e7e7}.navbar-default .navbar-nav>.open>a,.navbar-default .navbar-nav>.open>a:focus,.navbar-default .navbar-nav>.open>a:hover{color:#555;background-color:#e7e7e7}@media (max-width:767px){.navbar-default .navbar-nav .open .dropdown-menu>li>a{color:#777}.navbar-default .navbar-nav .open .dropdown-menu>li>a:focus,.navbar-default .navbar-nav .open .dropdown-menu>li>a:hover{color:#333;background-color:transparent}.navbar-default .navbar-nav .open .dropdown-menu>.active>a,.navbar-default .navbar-nav .open .dropdown-menu>.active>a:focus,.navbar-default .navbar-nav .open .dropdown-menu>.active>a:hover{color:#555;background-color:#e7e7e7}.navbar-default .navbar-nav .open .dropdown-menu>.disabled>a,.navbar-default .navbar-nav .open .dropdown-menu>.disabled>a:focus,.navbar-default .navbar-nav .open .dropdown-menu>.disabled>a:hover{color:#ccc;background-color:transparent}}.navbar-default .navbar-link{color:#777}.navbar-default .navbar-link:hover{color:#333}.navbar-default .btn-link{color:#777}.navbar-default .btn-link:focus,.navbar-default .btn-link:hover{color:#333}.navbar-default .btn-link[disabled]:focus,.navbar-default .btn-link[disabled]:hover,fieldset[disabled] .navbar-default .btn-link:focus,fieldset[disabled] .navbar-default .btn-link:hover{color:#ccc}.navbar-inverse{background-color:#222;border-color:#080808}.navbar-inverse .navbar-brand{color:#9d9d9d}.navbar-inverse .navbar-brand:focus,.navbar-inverse .navbar-brand:hover{color:#fff;background-color:transparent}.navbar-inverse .navbar-nav>li>a,.navbar-inverse .navbar-text{color:#9d9d9d}.navbar-inverse .navbar-nav>li>a:focus,.navbar-inverse .navbar-nav>li>a:hover{color:#fff;background-color:transparent}.navbar-inverse .navbar-nav>.active>a,.navbar-inverse .navbar-nav>.active>a:focus,.navbar-inverse .navbar-nav>.active>a:hover{color:#fff;background-color:#080808}.navbar-inverse .navbar-nav>.disabled>a,.navbar-inverse .navbar-nav>.disabled>a:focus,.navbar-inverse .navbar-nav>.disabled>a:hover{color:#444;background-color:transparent}.navbar-inverse .navbar-toggle{border-color:#333}.navbar-inverse .navbar-toggle:focus,.navbar-inverse .navbar-toggle:hover{background-color:#333}.navbar-inverse .navbar-toggle .icon-bar{background-color:#fff}.navbar-inverse .navbar-collapse,.navbar-inverse .navbar-form{border-color:#101010}.navbar-inverse .navbar-nav>.open>a,.navbar-inverse .navbar-nav>.open>a:focus,.navbar-inverse .navbar-nav>.open>a:hover{color:#fff;background-color:#080808}@media (max-width:767px){.navbar-inverse .navbar-nav .open .dropdown-menu>.dropdown-header{border-color:#080808}.navbar-inverse .navbar-nav .open .dropdown-menu .divider{background-color:#080808}.navbar-inverse .navbar-nav .open .dropdown-menu>li>a{color:#9d9d9d}.navbar-inverse .navbar-nav .open .dropdown-menu>li>a:focus,.navbar-inverse .navbar-nav .open .dropdown-menu>li>a:hover{color:#fff;background-color:transparent}.navbar-inverse .navbar-nav .open .dropdown-menu>.active>a,.navbar-inverse .navbar-nav .open .dropdown-menu>.active>a:focus,.navbar-inverse .navbar-nav .open .dropdown-menu>.active>a:hover{color:#fff;background-color:#080808}.navbar-inverse .navbar-nav .open .dropdown-menu>.disabled>a,.navbar-inverse .navbar-nav .open .dropdown-menu>.disabled>a:focus,.navbar-inverse .navbar-nav .open .dropdown-menu>.disabled>a:hover{color:#444;background-color:transparent}}.navbar-inverse .navbar-link{color:#9d9d9d}.navbar-inverse .navbar-link:hover{color:#fff}.navbar-inverse .btn-link{color:#9d9d9d}.navbar-inverse .btn-link:focus,.navbar-inverse .btn-link:hover{color:#fff}.navbar-inverse .btn-link[disabled]:focus,.navbar-inverse .btn-link[disabled]:hover,fieldset[disabled] .navbar-inverse .btn-link:focus,fieldset[disabled] .navbar-inverse .btn-link:hover{color:#444}.breadcrumb{padding:8px 15px;margin-bottom:20px;list-style:none;background-color:#f5f5f5;border-radius:4px}.breadcrumb>li{display:inline-block}.breadcrumb>li+li:before{padding:0 5px;color:#ccc;content:"/\\A0"}.breadcrumb>.active{color:#777}.pagination{display:inline-block;padding-left:0;margin:20px 0;border-radius:4px}.pagination>li{display:inline}.pagination>li>a,.pagination>li>span{position:relative;float:left;padding:6px 12px;margin-left:-1px;line-height:1.42857143;color:#337ab7;text-decoration:none;background-color:#fff;border:1px solid #ddd}.pagination>li:first-child>a,.pagination>li:first-child>span{margin-left:0;border-top-left-radius:4px;border-bottom-left-radius:4px}.pagination>li:last-child>a,.pagination>li:last-child>span{border-top-right-radius:4px;border-bottom-right-radius:4px}.pagination>li>a:focus,.pagination>li>a:hover,.pagination>li>span:focus,.pagination>li>span:hover{z-index:2;color:#23527c;background-color:#eee;border-color:#ddd}.pagination>.active>a,.pagination>.active>a:focus,.pagination>.active>a:hover,.pagination>.active>span,.pagination>.active>span:focus,.pagination>.active>span:hover{z-index:3;color:#fff;cursor:default;background-color:#337ab7;border-color:#337ab7}.pagination>.disabled>a,.pagination>.disabled>a:focus,.pagination>.disabled>a:hover,.pagination>.disabled>span,.pagination>.disabled>span:focus,.pagination>.disabled>span:hover{color:#777;cursor:not-allowed;background-color:#fff;border-color:#ddd}.pagination-lg>li>a,.pagination-lg>li>span{padding:10px 16px;font-size:18px;line-height:1.3333333}.pagination-lg>li:first-child>a,.pagination-lg>li:first-child>span{border-top-left-radius:6px;border-bottom-left-radius:6px}.pagination-lg>li:last-child>a,.pagination-lg>li:last-child>span{border-top-right-radius:6px;border-bottom-right-radius:6px}.pagination-sm>li>a,.pagination-sm>li>span{padding:5px 10px;font-size:12px;line-height:1.5}.pagination-sm>li:first-child>a,.pagination-sm>li:first-child>span{border-top-left-radius:3px;border-bottom-left-radius:3px}.pagination-sm>li:last-child>a,.pagination-sm>li:last-child>span{border-top-right-radius:3px;border-bottom-right-radius:3px}.pager{padding-left:0;margin:20px 0;text-align:center;list-style:none}.pager li{display:inline}.pager li>a,.pager li>span{display:inline-block;padding:5px 14px;background-color:#fff;border:1px solid #ddd;border-radius:15px}.pager li>a:focus,.pager li>a:hover{text-decoration:none;background-color:#eee}.pager .next>a,.pager .next>span{float:right}.pager .previous>a,.pager .previous>span{float:left}.pager .disabled>a,.pager .disabled>a:focus,.pager .disabled>a:hover,.pager .disabled>span{color:#777;cursor:not-allowed;background-color:#fff}.label{display:inline;padding:.2em .6em .3em;font-size:75%;font-weight:700;line-height:1;color:#fff;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em}a.label:focus,a.label:hover{color:#fff;text-decoration:none;cursor:pointer}.label:empty{display:none}.btn .label{position:relative;top:-1px}.label-default{background-color:#777}.label-default[href]:focus,.label-default[href]:hover{background-color:#5e5e5e}.label-primary{background-color:#337ab7}.label-primary[href]:focus,.label-primary[href]:hover{background-color:#286090}.label-success{background-color:#5cb85c}.label-success[href]:focus,.label-success[href]:hover{background-color:#449d44}.label-info{background-color:#5bc0de}.label-info[href]:focus,.label-info[href]:hover{background-color:#31b0d5}.label-warning{background-color:#f0ad4e}.label-warning[href]:focus,.label-warning[href]:hover{background-color:#ec971f}.label-danger{background-color:#d9534f}.label-danger[href]:focus,.label-danger[href]:hover{background-color:#c9302c}.badge{display:inline-block;min-width:10px;padding:3px 7px;font-size:12px;font-weight:700;line-height:1;color:#fff;text-align:center;white-space:nowrap;vertical-align:middle;background-color:#777;border-radius:10px}.badge:empty{display:none}.btn .badge{position:relative;top:-1px}.btn-group-xs>.btn .badge,.btn-xs .badge{top:0;padding:1px 5px}a.badge:focus,a.badge:hover{color:#fff;text-decoration:none;cursor:pointer}.list-group-item.active>.badge,.nav-pills>.active>a>.badge{color:#337ab7;background-color:#fff}.list-group-item>.badge{float:right}.list-group-item>.badge+.badge{margin-right:5px}.nav-pills>li>a>.badge{margin-left:3px}.jumbotron{padding-top:30px;padding-bottom:30px;margin-bottom:30px;background-color:#eee}.jumbotron,.jumbotron .h1,.jumbotron h1{color:inherit}.jumbotron p{margin-bottom:15px;font-size:21px;font-weight:200}.jumbotron>hr{border-top-color:#d5d5d5}.container-fluid .jumbotron,.container .jumbotron{padding-right:15px;padding-left:15px;border-radius:6px}.jumbotron .container{max-width:100%}@media screen and (min-width:768px){.jumbotron{padding-top:48px;padding-bottom:48px}.container-fluid .jumbotron,.container .jumbotron{padding-right:60px;padding-left:60px}.jumbotron .h1,.jumbotron h1{font-size:63px}}.thumbnail{display:block;padding:4px;margin-bottom:20px;line-height:1.42857143;background-color:#fff;border:1px solid #ddd;border-radius:4px;-webkit-transition:border .2s ease-in-out;-o-transition:border .2s ease-in-out;transition:border .2s ease-in-out}.thumbnail>img,.thumbnail a>img{margin-right:auto;margin-left:auto}a.thumbnail.active,a.thumbnail:focus,a.thumbnail:hover{border-color:#337ab7}.thumbnail .caption{padding:9px;color:#333}.alert{padding:15px;margin-bottom:20px;border:1px solid transparent;border-radius:4px}.alert h4{margin-top:0;color:inherit}.alert .alert-link{font-weight:700}.alert>p,.alert>ul{margin-bottom:0}.alert>p+p{margin-top:5px}.alert-dismissable,.alert-dismissible{padding-right:35px}.alert-dismissable .close,.alert-dismissible .close{position:relative;top:-2px;right:-21px;color:inherit}.alert-success{color:#3c763d;background-color:#dff0d8;border-color:#d6e9c6}.alert-success hr{border-top-color:#c9e2b3}.alert-success .alert-link{color:#2b542c}.alert-info{color:#31708f;background-color:#d9edf7;border-color:#bce8f1}.alert-info hr{border-top-color:#a6e1ec}.alert-info .alert-link{color:#245269}.alert-warning{color:#8a6d3b;background-color:#fcf8e3;border-color:#faebcc}.alert-warning hr{border-top-color:#f7e1b5}.alert-warning .alert-link{color:#66512c}.alert-danger{color:#a94442;background-color:#f2dede;border-color:#ebccd1}.alert-danger hr{border-top-color:#e4b9c0}.alert-danger .alert-link{color:#843534}@-webkit-keyframes progress-bar-stripes{0%{background-position:40px 0}to{background-position:0 0}}@-o-keyframes progress-bar-stripes{0%{background-position:40px 0}to{background-position:0 0}}@keyframes progress-bar-stripes{0%{background-position:40px 0}to{background-position:0 0}}.progress{height:20px;margin-bottom:20px;overflow:hidden;background-color:#f5f5f5;border-radius:4px;-webkit-box-shadow:inset 0 1px 2px rgba(0,0,0,.1);box-shadow:inset 0 1px 2px rgba(0,0,0,.1)}.progress-bar{float:left;width:0;height:100%;font-size:12px;line-height:20px;color:#fff;text-align:center;background-color:#337ab7;-webkit-box-shadow:inset 0 -1px 0 rgba(0,0,0,.15);box-shadow:inset 0 -1px 0 rgba(0,0,0,.15);-webkit-transition:width .6s ease;-o-transition:width .6s ease;transition:width .6s ease}.progress-bar-striped,.progress-striped .progress-bar{background-image:-webkit-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent);background-image:-o-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 25%,transparent 50%,hsla(0,0%,100%,.15) 50%,hsla(0,0%,100%,.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent);-webkit-background-size:40px 40px;background-size:40px 40px}.progress-bar.active,.progress.active .progress-bar{-webkit-animation:progress-bar-stripes 2s linear infinite;-o-animation:progress-bar-stripes 2s linear infinite;animation:progress-bar-stripes 2s linear infinite}.progress-bar-success{background-color:#5cb85c}.progress-striped .progress-bar-success{background-image:-webkit-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent);background-image:-o-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 25%,transparent 50%,hsla(0,0%,100%,.15) 50%,hsla(0,0%,100%,.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent)}.progress-bar-info{background-color:#5bc0de}.progress-striped .progress-bar-info{background-image:-webkit-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent);background-image:-o-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 25%,transparent 50%,hsla(0,0%,100%,.15) 50%,hsla(0,0%,100%,.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent)}.progress-bar-warning{background-color:#f0ad4e}.progress-striped .progress-bar-warning{background-image:-webkit-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent);background-image:-o-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 25%,transparent 50%,hsla(0,0%,100%,.15) 50%,hsla(0,0%,100%,.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent)}.progress-bar-danger{background-color:#d9534f}.progress-striped .progress-bar-danger{background-image:-webkit-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent);background-image:-o-linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 25%,transparent 50%,hsla(0,0%,100%,.15) 50%,hsla(0,0%,100%,.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,hsla(0,0%,100%,.15) 25%,transparent 0,transparent 50%,hsla(0,0%,100%,.15) 0,hsla(0,0%,100%,.15) 75%,transparent 0,transparent)}.media{margin-top:15px}.media:first-child{margin-top:0}.media,.media-body{overflow:hidden;zoom:1}.media-body{width:10000px}.media-object{display:block}.media-object.img-thumbnail{max-width:none}.media-right,.media>.pull-right{padding-left:10px}.media-left,.media>.pull-left{padding-right:10px}.media-body,.media-left,.media-right{display:table-cell;vertical-align:top}.media-middle{vertical-align:middle}.media-bottom{vertical-align:bottom}.media-heading{margin-top:0;margin-bottom:5px}.media-list{padding-left:0;list-style:none}.list-group{padding-left:0;margin-bottom:20px}.list-group-item{position:relative;display:block;padding:10px 15px;margin-bottom:-1px;background-color:#fff;border:1px solid #ddd}.list-group-item:first-child{border-top-left-radius:4px;border-top-right-radius:4px}.list-group-item:last-child{margin-bottom:0;border-bottom-right-radius:4px;border-bottom-left-radius:4px}a.list-group-item,button.list-group-item{color:#555}a.list-group-item .list-group-item-heading,button.list-group-item .list-group-item-heading{color:#333}a.list-group-item:focus,a.list-group-item:hover,button.list-group-item:focus,button.list-group-item:hover{color:#555;text-decoration:none;background-color:#f5f5f5}button.list-group-item{width:100%;text-align:left}.list-group-item.disabled,.list-group-item.disabled:focus,.list-group-item.disabled:hover{color:#777;cursor:not-allowed;background-color:#eee}.list-group-item.disabled .list-group-item-heading,.list-group-item.disabled:focus .list-group-item-heading,.list-group-item.disabled:hover .list-group-item-heading{color:inherit}.list-group-item.disabled .list-group-item-text,.list-group-item.disabled:focus .list-group-item-text,.list-group-item.disabled:hover .list-group-item-text{color:#777}.list-group-item.active,.list-group-item.active:focus,.list-group-item.active:hover{z-index:2;color:#fff;background-color:#337ab7;border-color:#337ab7}.list-group-item.active .list-group-item-heading,.list-group-item.active .list-group-item-heading>.small,.list-group-item.active .list-group-item-heading>small,.list-group-item.active:focus .list-group-item-heading,.list-group-item.active:focus .list-group-item-heading>.small,.list-group-item.active:focus .list-group-item-heading>small,.list-group-item.active:hover .list-group-item-heading,.list-group-item.active:hover .list-group-item-heading>.small,.list-group-item.active:hover .list-group-item-heading>small{color:inherit}.list-group-item.active .list-group-item-text,.list-group-item.active:focus .list-group-item-text,.list-group-item.active:hover .list-group-item-text{color:#c7ddef}.list-group-item-success{color:#3c763d;background-color:#dff0d8}a.list-group-item-success,button.list-group-item-success{color:#3c763d}a.list-group-item-success .list-group-item-heading,button.list-group-item-success .list-group-item-heading{color:inherit}a.list-group-item-success:focus,a.list-group-item-success:hover,button.list-group-item-success:focus,button.list-group-item-success:hover{color:#3c763d;background-color:#d0e9c6}a.list-group-item-success.active,a.list-group-item-success.active:focus,a.list-group-item-success.active:hover,button.list-group-item-success.active,button.list-group-item-success.active:focus,button.list-group-item-success.active:hover{color:#fff;background-color:#3c763d;border-color:#3c763d}.list-group-item-info{color:#31708f;background-color:#d9edf7}a.list-group-item-info,button.list-group-item-info{color:#31708f}a.list-group-item-info .list-group-item-heading,button.list-group-item-info .list-group-item-heading{color:inherit}a.list-group-item-info:focus,a.list-group-item-info:hover,button.list-group-item-info:focus,button.list-group-item-info:hover{color:#31708f;background-color:#c4e3f3}a.list-group-item-info.active,a.list-group-item-info.active:focus,a.list-group-item-info.active:hover,button.list-group-item-info.active,button.list-group-item-info.active:focus,button.list-group-item-info.active:hover{color:#fff;background-color:#31708f;border-color:#31708f}.list-group-item-warning{color:#8a6d3b;background-color:#fcf8e3}a.list-group-item-warning,button.list-group-item-warning{color:#8a6d3b}a.list-group-item-warning .list-group-item-heading,button.list-group-item-warning .list-group-item-heading{color:inherit}a.list-group-item-warning:focus,a.list-group-item-warning:hover,button.list-group-item-warning:focus,button.list-group-item-warning:hover{color:#8a6d3b;background-color:#faf2cc}a.list-group-item-warning.active,a.list-group-item-warning.active:focus,a.list-group-item-warning.active:hover,button.list-group-item-warning.active,button.list-group-item-warning.active:focus,button.list-group-item-warning.active:hover{color:#fff;background-color:#8a6d3b;border-color:#8a6d3b}.list-group-item-danger{color:#a94442;background-color:#f2dede}a.list-group-item-danger,button.list-group-item-danger{color:#a94442}a.list-group-item-danger .list-group-item-heading,button.list-group-item-danger .list-group-item-heading{color:inherit}a.list-group-item-danger:focus,a.list-group-item-danger:hover,button.list-group-item-danger:focus,button.list-group-item-danger:hover{color:#a94442;background-color:#ebcccc}a.list-group-item-danger.active,a.list-group-item-danger.active:focus,a.list-group-item-danger.active:hover,button.list-group-item-danger.active,button.list-group-item-danger.active:focus,button.list-group-item-danger.active:hover{color:#fff;background-color:#a94442;border-color:#a94442}.list-group-item-heading{margin-top:0;margin-bottom:5px}.list-group-item-text{margin-bottom:0;line-height:1.3}.panel{margin-bottom:20px;background-color:#fff;border:1px solid transparent;border-radius:4px;-webkit-box-shadow:0 1px 1px rgba(0,0,0,.05);box-shadow:0 1px 1px rgba(0,0,0,.05)}.panel-body{padding:15px}.panel-heading{padding:10px 15px;border-bottom:1px solid transparent;border-top-left-radius:3px;border-top-right-radius:3px}.panel-heading>.dropdown .dropdown-toggle,.panel-title{color:inherit}.panel-title{margin-top:0;margin-bottom:0;font-size:16px}.panel-title>.small,.panel-title>.small>a,.panel-title>a,.panel-title>small,.panel-title>small>a{color:inherit}.panel-footer{padding:10px 15px;background-color:#f5f5f5;border-top:1px solid #ddd;border-bottom-right-radius:3px;border-bottom-left-radius:3px}.panel>.list-group,.panel>.panel-collapse>.list-group{margin-bottom:0}.panel>.list-group .list-group-item,.panel>.panel-collapse>.list-group .list-group-item{border-width:1px 0;border-radius:0}.panel>.list-group:first-child .list-group-item:first-child,.panel>.panel-collapse>.list-group:first-child .list-group-item:first-child{border-top:0;border-top-left-radius:3px;border-top-right-radius:3px}.panel>.list-group:last-child .list-group-item:last-child,.panel>.panel-collapse>.list-group:last-child .list-group-item:last-child{border-bottom:0;border-bottom-right-radius:3px;border-bottom-left-radius:3px}.panel>.panel-heading+.panel-collapse>.list-group .list-group-item:first-child{border-top-left-radius:0;border-top-right-radius:0}.list-group+.panel-footer,.panel-heading+.list-group .list-group-item:first-child{border-top-width:0}.panel>.panel-collapse>.table,.panel>.table,.panel>.table-responsive>.table{margin-bottom:0}.panel>.panel-collapse>.table caption,.panel>.table-responsive>.table caption,.panel>.table caption{padding-right:15px;padding-left:15px}.panel>.table-responsive:first-child>.table:first-child,.panel>.table-responsive:first-child>.table:first-child>tbody:first-child>tr:first-child,.panel>.table-responsive:first-child>.table:first-child>thead:first-child>tr:first-child,.panel>.table:first-child,.panel>.table:first-child>tbody:first-child>tr:first-child,.panel>.table:first-child>thead:first-child>tr:first-child{border-top-left-radius:3px;border-top-right-radius:3px}.panel>.table-responsive:first-child>.table:first-child>tbody:first-child>tr:first-child td:first-child,.panel>.table-responsive:first-child>.table:first-child>tbody:first-child>tr:first-child th:first-child,.panel>.table-responsive:first-child>.table:first-child>thead:first-child>tr:first-child td:first-child,.panel>.table-responsive:first-child>.table:first-child>thead:first-child>tr:first-child th:first-child,.panel>.table:first-child>tbody:first-child>tr:first-child td:first-child,.panel>.table:first-child>tbody:first-child>tr:first-child th:first-child,.panel>.table:first-child>thead:first-child>tr:first-child td:first-child,.panel>.table:first-child>thead:first-child>tr:first-child th:first-child{border-top-left-radius:3px}.panel>.table-responsive:first-child>.table:first-child>tbody:first-child>tr:first-child td:last-child,.panel>.table-responsive:first-child>.table:first-child>tbody:first-child>tr:first-child th:last-child,.panel>.table-responsive:first-child>.table:first-child>thead:first-child>tr:first-child td:last-child,.panel>.table-responsive:first-child>.table:first-child>thead:first-child>tr:first-child th:last-child,.panel>.table:first-child>tbody:first-child>tr:first-child td:last-child,.panel>.table:first-child>tbody:first-child>tr:first-child th:last-child,.panel>.table:first-child>thead:first-child>tr:first-child td:last-child,.panel>.table:first-child>thead:first-child>tr:first-child th:last-child{border-top-right-radius:3px}.panel>.table-responsive:last-child>.table:last-child,.panel>.table-responsive:last-child>.table:last-child>tbody:last-child>tr:last-child,.panel>.table-responsive:last-child>.table:last-child>tfoot:last-child>tr:last-child,.panel>.table:last-child,.panel>.table:last-child>tbody:last-child>tr:last-child,.panel>.table:last-child>tfoot:last-child>tr:last-child{border-bottom-right-radius:3px;border-bottom-left-radius:3px}.panel>.table-responsive:last-child>.table:last-child>tbody:last-child>tr:last-child td:first-child,.panel>.table-responsive:last-child>.table:last-child>tbody:last-child>tr:last-child th:first-child,.panel>.table-responsive:last-child>.table:last-child>tfoot:last-child>tr:last-child td:first-child,.panel>.table-responsive:last-child>.table:last-child>tfoot:last-child>tr:last-child th:first-child,.panel>.table:last-child>tbody:last-child>tr:last-child td:first-child,.panel>.table:last-child>tbody:last-child>tr:last-child th:first-child,.panel>.table:last-child>tfoot:last-child>tr:last-child td:first-child,.panel>.table:last-child>tfoot:last-child>tr:last-child th:first-child{border-bottom-left-radius:3px}.panel>.table-responsive:last-child>.table:last-child>tbody:last-child>tr:last-child td:last-child,.panel>.table-responsive:last-child>.table:last-child>tbody:last-child>tr:last-child th:last-child,.panel>.table-responsive:last-child>.table:last-child>tfoot:last-child>tr:last-child td:last-child,.panel>.table-responsive:last-child>.table:last-child>tfoot:last-child>tr:last-child th:last-child,.panel>.table:last-child>tbody:last-child>tr:last-child td:last-child,.panel>.table:last-child>tbody:last-child>tr:last-child th:last-child,.panel>.table:last-child>tfoot:last-child>tr:last-child td:last-child,.panel>.table:last-child>tfoot:last-child>tr:last-child th:last-child{border-bottom-right-radius:3px}.panel>.panel-body+.table,.panel>.panel-body+.table-responsive,.panel>.table+.panel-body,.panel>.table-responsive+.panel-body{border-top:1px solid #ddd}.panel>.table>tbody:first-child>tr:first-child td,.panel>.table>tbody:first-child>tr:first-child th{border-top:0}.panel>.table-bordered,.panel>.table-responsive>.table-bordered{border:0}.panel>.table-bordered>tbody>tr>td:first-child,.panel>.table-bordered>tbody>tr>th:first-child,.panel>.table-bordered>tfoot>tr>td:first-child,.panel>.table-bordered>tfoot>tr>th:first-child,.panel>.table-bordered>thead>tr>td:first-child,.panel>.table-bordered>thead>tr>th:first-child,.panel>.table-responsive>.table-bordered>tbody>tr>td:first-child,.panel>.table-responsive>.table-bordered>tbody>tr>th:first-child,.panel>.table-responsive>.table-bordered>tfoot>tr>td:first-child,.panel>.table-responsive>.table-bordered>tfoot>tr>th:first-child,.panel>.table-responsive>.table-bordered>thead>tr>td:first-child,.panel>.table-responsive>.table-bordered>thead>tr>th:first-child{border-left:0}.panel>.table-bordered>tbody>tr>td:last-child,.panel>.table-bordered>tbody>tr>th:last-child,.panel>.table-bordered>tfoot>tr>td:last-child,.panel>.table-bordered>tfoot>tr>th:last-child,.panel>.table-bordered>thead>tr>td:last-child,.panel>.table-bordered>thead>tr>th:last-child,.panel>.table-responsive>.table-bordered>tbody>tr>td:last-child,.panel>.table-responsive>.table-bordered>tbody>tr>th:last-child,.panel>.table-responsive>.table-bordered>tfoot>tr>td:last-child,.panel>.table-responsive>.table-bordered>tfoot>tr>th:last-child,.panel>.table-responsive>.table-bordered>thead>tr>td:last-child,.panel>.table-responsive>.table-bordered>thead>tr>th:last-child{border-right:0}.panel>.table-bordered>tbody>tr:first-child>td,.panel>.table-bordered>tbody>tr:first-child>th,.panel>.table-bordered>tbody>tr:last-child>td,.panel>.table-bordered>tbody>tr:last-child>th,.panel>.table-bordered>tfoot>tr:last-child>td,.panel>.table-bordered>tfoot>tr:last-child>th,.panel>.table-bordered>thead>tr:first-child>td,.panel>.table-bordered>thead>tr:first-child>th,.panel>.table-responsive>.table-bordered>tbody>tr:first-child>td,.panel>.table-responsive>.table-bordered>tbody>tr:first-child>th,.panel>.table-responsive>.table-bordered>tbody>tr:last-child>td,.panel>.table-responsive>.table-bordered>tbody>tr:last-child>th,.panel>.table-responsive>.table-bordered>tfoot>tr:last-child>td,.panel>.table-responsive>.table-bordered>tfoot>tr:last-child>th,.panel>.table-responsive>.table-bordered>thead>tr:first-child>td,.panel>.table-responsive>.table-bordered>thead>tr:first-child>th{border-bottom:0}.panel>.table-responsive{margin-bottom:0;border:0}.panel-group{margin-bottom:20px}.panel-group .panel{margin-bottom:0;border-radius:4px}.panel-group .panel+.panel{margin-top:5px}.panel-group .panel-heading{border-bottom:0}.panel-group .panel-heading+.panel-collapse>.list-group,.panel-group .panel-heading+.panel-collapse>.panel-body{border-top:1px solid #ddd}.panel-group .panel-footer{border-top:0}.panel-group .panel-footer+.panel-collapse .panel-body{border-bottom:1px solid #ddd}.panel-default{border-color:#ddd}.panel-default>.panel-heading{color:#333;background-color:#f5f5f5;border-color:#ddd}.panel-default>.panel-heading+.panel-collapse>.panel-body{border-top-color:#ddd}.panel-default>.panel-heading .badge{color:#f5f5f5;background-color:#333}.panel-default>.panel-footer+.panel-collapse>.panel-body{border-bottom-color:#ddd}.panel-primary{border-color:#337ab7}.panel-primary>.panel-heading{color:#fff;background-color:#337ab7;border-color:#337ab7}.panel-primary>.panel-heading+.panel-collapse>.panel-body{border-top-color:#337ab7}.panel-primary>.panel-heading .badge{color:#337ab7;background-color:#fff}.panel-primary>.panel-footer+.panel-collapse>.panel-body{border-bottom-color:#337ab7}.panel-success{border-color:#d6e9c6}.panel-success>.panel-heading{color:#3c763d;background-color:#dff0d8;border-color:#d6e9c6}.panel-success>.panel-heading+.panel-collapse>.panel-body{border-top-color:#d6e9c6}.panel-success>.panel-heading .badge{color:#dff0d8;background-color:#3c763d}.panel-success>.panel-footer+.panel-collapse>.panel-body{border-bottom-color:#d6e9c6}.panel-info{border-color:#bce8f1}.panel-info>.panel-heading{color:#31708f;background-color:#d9edf7;border-color:#bce8f1}.panel-info>.panel-heading+.panel-collapse>.panel-body{border-top-color:#bce8f1}.panel-info>.panel-heading .badge{color:#d9edf7;background-color:#31708f}.panel-info>.panel-footer+.panel-collapse>.panel-body{border-bottom-color:#bce8f1}.panel-warning{border-color:#faebcc}.panel-warning>.panel-heading{color:#8a6d3b;background-color:#fcf8e3;border-color:#faebcc}.panel-warning>.panel-heading+.panel-collapse>.panel-body{border-top-color:#faebcc}.panel-warning>.panel-heading .badge{color:#fcf8e3;background-color:#8a6d3b}.panel-warning>.panel-footer+.panel-collapse>.panel-body{border-bottom-color:#faebcc}.panel-danger{border-color:#ebccd1}.panel-danger>.panel-heading{color:#a94442;background-color:#f2dede;border-color:#ebccd1}.panel-danger>.panel-heading+.panel-collapse>.panel-body{border-top-color:#ebccd1}.panel-danger>.panel-heading .badge{color:#f2dede;background-color:#a94442}.panel-danger>.panel-footer+.panel-collapse>.panel-body{border-bottom-color:#ebccd1}.embed-responsive{position:relative;display:block;height:0;padding:0;overflow:hidden}.embed-responsive .embed-responsive-item,.embed-responsive embed,.embed-responsive iframe,.embed-responsive object,.embed-responsive video{position:absolute;top:0;bottom:0;left:0;width:100%;height:100%;border:0}.embed-responsive-16by9{padding-bottom:56.25%}.embed-responsive-4by3{padding-bottom:75%}.well{min-height:20px;padding:19px;margin-bottom:20px;background-color:#f5f5f5;border:1px solid #e3e3e3;border-radius:4px;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,.05);box-shadow:inset 0 1px 1px rgba(0,0,0,.05)}.well blockquote{border-color:#ddd;border-color:rgba(0,0,0,.15)}.well-lg{padding:24px;border-radius:6px}.well-sm{padding:9px;border-radius:3px}.close{float:right;font-size:21px;font-weight:700;line-height:1;color:#000;text-shadow:0 1px 0 #fff;filter:alpha(opacity=20);opacity:.2}.close:focus,.close:hover{color:#000;text-decoration:none;cursor:pointer;filter:alpha(opacity=50);opacity:.5}button.close{-webkit-appearance:none;padding:0;cursor:pointer;background:0 0;border:0}.modal,.modal-open{overflow:hidden}.modal{position:fixed;top:0;right:0;bottom:0;left:0;z-index:1050;display:none;-webkit-overflow-scrolling:touch;outline:0}.modal.fade .modal-dialog{-webkit-transition:-webkit-transform .3s ease-out;-o-transition:-o-transform .3s ease-out;transition:transform .3s ease-out;-webkit-transform:translateY(-25%);-ms-transform:translateY(-25%);-o-transform:translateY(-25%);transform:translateY(-25%)}.modal.in .modal-dialog{-webkit-transform:translate(0);-ms-transform:translate(0);-o-transform:translate(0);transform:translate(0)}.modal-open .modal{overflow-x:hidden;overflow-y:auto}.modal-dialog{position:relative;width:auto;margin:10px}.modal-content{position:relative;background-color:#fff;-webkit-background-clip:padding-box;background-clip:padding-box;border:1px solid #999;border:1px solid rgba(0,0,0,.2);border-radius:6px;outline:0;-webkit-box-shadow:0 3px 9px rgba(0,0,0,.5);box-shadow:0 3px 9px rgba(0,0,0,.5)}.modal-backdrop{position:fixed;top:0;right:0;bottom:0;left:0;z-index:1040;background-color:#000}.modal-backdrop.fade{filter:alpha(opacity=0);opacity:0}.modal-backdrop.in{filter:alpha(opacity=50);opacity:.5}.modal-header{padding:15px;border-bottom:1px solid #e5e5e5}.modal-header .close{margin-top:-2px}.modal-title{margin:0;line-height:1.42857143}.modal-body{position:relative;padding:15px}.modal-footer{padding:15px;text-align:right;border-top:1px solid #e5e5e5}.modal-footer .btn+.btn{margin-bottom:0;margin-left:5px}.modal-footer .btn-group .btn+.btn{margin-left:-1px}.modal-footer .btn-block+.btn-block{margin-left:0}.modal-scrollbar-measure{position:absolute;top:-9999px;width:50px;height:50px;overflow:scroll}@media (min-width:768px){.modal-dialog{width:600px;margin:30px auto}.modal-content{-webkit-box-shadow:0 5px 15px rgba(0,0,0,.5);box-shadow:0 5px 15px rgba(0,0,0,.5)}.modal-sm{width:300px}}@media (min-width:992px){.modal-lg{width:900px}}.tooltip{position:absolute;z-index:1070;display:block;font-family:Helvetica Neue,Helvetica,Arial,sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:1.42857143;text-align:left;text-align:start;text-decoration:none;text-shadow:none;text-transform:none;letter-spacing:normal;word-break:normal;word-spacing:normal;word-wrap:normal;white-space:normal;filter:alpha(opacity=0);opacity:0;line-break:auto}.tooltip.in{filter:alpha(opacity=90);opacity:.9}.tooltip.top{padding:5px 0;margin-top:-3px}.tooltip.right{padding:0 5px;margin-left:3px}.tooltip.bottom{padding:5px 0;margin-top:3px}.tooltip.left{padding:0 5px;margin-left:-3px}.tooltip-inner{max-width:200px;padding:3px 8px;color:#fff;text-align:center;background-color:#000;border-radius:4px}.tooltip-arrow{position:absolute;width:0;height:0;border-color:transparent;border-style:solid}.tooltip.top .tooltip-arrow{bottom:0;left:50%;margin-left:-5px;border-width:5px 5px 0;border-top-color:#000}.tooltip.top-left .tooltip-arrow{right:5px}.tooltip.top-left .tooltip-arrow,.tooltip.top-right .tooltip-arrow{bottom:0;margin-bottom:-5px;border-width:5px 5px 0;border-top-color:#000}.tooltip.top-right .tooltip-arrow{left:5px}.tooltip.right .tooltip-arrow{top:50%;left:0;margin-top:-5px;border-width:5px 5px 5px 0;border-right-color:#000}.tooltip.left .tooltip-arrow{top:50%;right:0;margin-top:-5px;border-width:5px 0 5px 5px;border-left-color:#000}.tooltip.bottom .tooltip-arrow{top:0;left:50%;margin-left:-5px;border-width:0 5px 5px;border-bottom-color:#000}.tooltip.bottom-left .tooltip-arrow{top:0;right:5px;margin-top:-5px;border-width:0 5px 5px;border-bottom-color:#000}.tooltip.bottom-right .tooltip-arrow{top:0;left:5px;margin-top:-5px;border-width:0 5px 5px;border-bottom-color:#000}.popover{position:absolute;top:0;left:0;z-index:1060;display:none;max-width:276px;padding:1px;font-family:Helvetica Neue,Helvetica,Arial,sans-serif;font-size:14px;font-style:normal;font-weight:400;line-height:1.42857143;text-align:left;text-align:start;text-decoration:none;text-shadow:none;text-transform:none;letter-spacing:normal;word-break:normal;word-spacing:normal;word-wrap:normal;white-space:normal;background-color:#fff;-webkit-background-clip:padding-box;background-clip:padding-box;border:1px solid #ccc;border:1px solid rgba(0,0,0,.2);border-radius:6px;-webkit-box-shadow:0 5px 10px rgba(0,0,0,.2);box-shadow:0 5px 10px rgba(0,0,0,.2);line-break:auto}.popover.top{margin-top:-10px}.popover.right{margin-left:10px}.popover.bottom{margin-top:10px}.popover.left{margin-left:-10px}.popover-title{padding:8px 14px;margin:0;font-size:14px;background-color:#f7f7f7;border-bottom:1px solid #ebebeb;border-radius:5px 5px 0 0}.popover-content{padding:9px 14px}.popover>.arrow,.popover>.arrow:after{position:absolute;display:block;width:0;height:0;border-color:transparent;border-style:solid}.popover>.arrow{border-width:11px}.popover>.arrow:after{content:"";border-width:10px}.popover.top>.arrow{bottom:-11px;left:50%;margin-left:-11px;border-top-color:#999;border-top-color:rgba(0,0,0,.25);border-bottom-width:0}.popover.top>.arrow:after{bottom:1px;margin-left:-10px;content:" ";border-top-color:#fff;border-bottom-width:0}.popover.right>.arrow{top:50%;left:-11px;margin-top:-11px;border-right-color:#999;border-right-color:rgba(0,0,0,.25);border-left-width:0}.popover.right>.arrow:after{bottom:-10px;left:1px;content:" ";border-right-color:#fff;border-left-width:0}.popover.bottom>.arrow{top:-11px;left:50%;margin-left:-11px;border-top-width:0;border-bottom-color:#999;border-bottom-color:rgba(0,0,0,.25)}.popover.bottom>.arrow:after{top:1px;margin-left:-10px;content:" ";border-top-width:0;border-bottom-color:#fff}.popover.left>.arrow{top:50%;right:-11px;margin-top:-11px;border-right-width:0;border-left-color:#999;border-left-color:rgba(0,0,0,.25)}.popover.left>.arrow:after{right:1px;bottom:-10px;content:" ";border-right-width:0;border-left-color:#fff}.carousel,.carousel-inner{position:relative}.carousel-inner{width:100%;overflow:hidden}.carousel-inner>.item{position:relative;display:none;-webkit-transition:left .6s ease-in-out;-o-transition:.6s ease-in-out left;transition:left .6s ease-in-out}.carousel-inner>.item>a>img,.carousel-inner>.item>img{line-height:1}@media (-webkit-transform-3d),(transform-3d){.carousel-inner>.item{-webkit-transition:-webkit-transform .6s ease-in-out;-o-transition:-o-transform .6s ease-in-out;transition:transform .6s ease-in-out;-webkit-backface-visibility:hidden;backface-visibility:hidden;-webkit-perspective:1000px;perspective:1000px}.carousel-inner>.item.active.right,.carousel-inner>.item.next{left:0;-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}.carousel-inner>.item.active.left,.carousel-inner>.item.prev{left:0;-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}.carousel-inner>.item.active,.carousel-inner>.item.next.left,.carousel-inner>.item.prev.right{left:0;-webkit-transform:translateZ(0);transform:translateZ(0)}}.carousel-inner>.active,.carousel-inner>.next,.carousel-inner>.prev{display:block}.carousel-inner>.active{left:0}.carousel-inner>.next,.carousel-inner>.prev{position:absolute;top:0;width:100%}.carousel-inner>.next{left:100%}.carousel-inner>.prev{left:-100%}.carousel-inner>.next.left,.carousel-inner>.prev.right{left:0}.carousel-inner>.active.left{left:-100%}.carousel-inner>.active.right{left:100%}.carousel-control{position:absolute;top:0;bottom:0;left:0;width:15%;font-size:20px;color:#fff;text-align:center;text-shadow:0 1px 2px rgba(0,0,0,.6);background-color:transparent;filter:alpha(opacity=50);opacity:.5}.carousel-control.left{background-image:-webkit-linear-gradient(left,rgba(0,0,0,.5),rgba(0,0,0,.0001));background-image:-o-linear-gradient(left,rgba(0,0,0,.5) 0,rgba(0,0,0,.0001) 100%);background-image:-webkit-gradient(linear,left top,right top,from(rgba(0,0,0,.5)),to(rgba(0,0,0,.0001)));background-image:linear-gradient(90deg,rgba(0,0,0,.5) 0,rgba(0,0,0,.0001));filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#80000000",endColorstr="#00000000",GradientType=1);background-repeat:repeat-x}.carousel-control.right{right:0;left:auto;background-image:-webkit-linear-gradient(left,rgba(0,0,0,.0001),rgba(0,0,0,.5));background-image:-o-linear-gradient(left,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-image:-webkit-gradient(linear,left top,right top,from(rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(90deg,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5));filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#00000000",endColorstr="#80000000",GradientType=1);background-repeat:repeat-x}.carousel-control:focus,.carousel-control:hover{color:#fff;text-decoration:none;filter:alpha(opacity=90);outline:0;opacity:.9}.carousel-control .glyphicon-chevron-left,.carousel-control .glyphicon-chevron-right,.carousel-control .icon-next,.carousel-control .icon-prev{position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-10px}.carousel-control .glyphicon-chevron-left,.carousel-control .icon-prev{left:50%;margin-left:-10px}.carousel-control .glyphicon-chevron-right,.carousel-control .icon-next{right:50%;margin-right:-10px}.carousel-control .icon-next,.carousel-control .icon-prev{width:20px;height:20px;font-family:serif;line-height:1}.carousel-control .icon-prev:before{content:"\\2039"}.carousel-control .icon-next:before{content:"\\203A"}.carousel-indicators{position:absolute;bottom:10px;left:50%;z-index:15;width:60%;padding-left:0;margin-left:-30%;text-align:center;list-style:none}.carousel-indicators li{display:inline-block;width:10px;height:10px;margin:1px;text-indent:-999px;cursor:pointer;background-color:#000\\9;background-color:transparent;border:1px solid #fff;border-radius:10px}.carousel-indicators .active{width:12px;height:12px;margin:0;background-color:#fff}.carousel-caption{position:absolute;right:15%;bottom:20px;left:15%;z-index:10;padding-top:20px;padding-bottom:20px;color:#fff;text-align:center;text-shadow:0 1px 2px rgba(0,0,0,.6)}.carousel-caption .btn{text-shadow:none}@media screen and (min-width:768px){.carousel-control .glyphicon-chevron-left,.carousel-control .glyphicon-chevron-right,.carousel-control .icon-next,.carousel-control .icon-prev{width:30px;height:30px;margin-top:-10px;font-size:30px}.carousel-control .glyphicon-chevron-left,.carousel-control .icon-prev{margin-left:-10px}.carousel-control .glyphicon-chevron-right,.carousel-control .icon-next{margin-right:-10px}.carousel-caption{right:20%;left:20%;padding-bottom:30px}.carousel-indicators{bottom:20px}}.btn-group-vertical>.btn-group:after,.btn-group-vertical>.btn-group:before,.btn-toolbar:after,.btn-toolbar:before,.clearfix:after,.clearfix:before,.container-fluid:after,.container-fluid:before,.container:after,.container:before,.dl-horizontal dd:after,.dl-horizontal dd:before,.form-horizontal .form-group:after,.form-horizontal .form-group:before,.modal-footer:after,.modal-footer:before,.modal-header:after,.modal-header:before,.nav:after,.nav:before,.navbar-collapse:after,.navbar-collapse:before,.navbar-header:after,.navbar-header:before,.navbar:after,.navbar:before,.pager:after,.pager:before,.panel-body:after,.panel-body:before,.row:after,.row:before{display:table;content:" "}.btn-group-vertical>.btn-group:after,.btn-toolbar:after,.clearfix:after,.container-fluid:after,.container:after,.dl-horizontal dd:after,.form-horizontal .form-group:after,.modal-footer:after,.modal-header:after,.nav:after,.navbar-collapse:after,.navbar-header:after,.navbar:after,.pager:after,.panel-body:after,.row:after{clear:both}.center-block{display:block;margin-right:auto;margin-left:auto}.pull-right{float:right!important}.pull-left{float:left!important}.hide{display:none!important}.show{display:block!important}.invisible{visibility:hidden}.text-hide{font:0/0 a;color:transparent;text-shadow:none;background-color:transparent;border:0}.hidden{display:none!important}.affix{position:fixed}@-ms-viewport{width:device-width}.visible-lg,.visible-lg-block,.visible-lg-inline,.visible-lg-inline-block,.visible-md,.visible-md-block,.visible-md-inline,.visible-md-inline-block,.visible-sm,.visible-sm-block,.visible-sm-inline,.visible-sm-inline-block,.visible-xs,.visible-xs-block,.visible-xs-inline,.visible-xs-inline-block{display:none!important}@media (max-width:767px){.visible-xs{display:block!important}table.visible-xs{display:table!important}tr.visible-xs{display:table-row!important}td.visible-xs,th.visible-xs{display:table-cell!important}}@media (max-width:767px){.visible-xs-block{display:block!important}}@media (max-width:767px){.visible-xs-inline{display:inline!important}}@media (max-width:767px){.visible-xs-inline-block{display:inline-block!important}}@media (min-width:768px) and (max-width:991px){.visible-sm{display:block!important}table.visible-sm{display:table!important}tr.visible-sm{display:table-row!important}td.visible-sm,th.visible-sm{display:table-cell!important}}@media (min-width:768px) and (max-width:991px){.visible-sm-block{display:block!important}}@media (min-width:768px) and (max-width:991px){.visible-sm-inline{display:inline!important}}@media (min-width:768px) and (max-width:991px){.visible-sm-inline-block{display:inline-block!important}}@media (min-width:992px) and (max-width:1199px){.visible-md{display:block!important}table.visible-md{display:table!important}tr.visible-md{display:table-row!important}td.visible-md,th.visible-md{display:table-cell!important}}@media (min-width:992px) and (max-width:1199px){.visible-md-block{display:block!important}}@media (min-width:992px) and (max-width:1199px){.visible-md-inline{display:inline!important}}@media (min-width:992px) and (max-width:1199px){.visible-md-inline-block{display:inline-block!important}}@media (min-width:1200px){.visible-lg{display:block!important}table.visible-lg{display:table!important}tr.visible-lg{display:table-row!important}td.visible-lg,th.visible-lg{display:table-cell!important}}@media (min-width:1200px){.visible-lg-block{display:block!important}}@media (min-width:1200px){.visible-lg-inline{display:inline!important}}@media (min-width:1200px){.visible-lg-inline-block{display:inline-block!important}}@media (max-width:767px){.hidden-xs{display:none!important}}@media (min-width:768px) and (max-width:991px){.hidden-sm{display:none!important}}@media (min-width:992px) and (max-width:1199px){.hidden-md{display:none!important}}@media (min-width:1200px){.hidden-lg{display:none!important}}.visible-print{display:none!important}@media print{.visible-print{display:block!important}table.visible-print{display:table!important}tr.visible-print{display:table-row!important}td.visible-print,th.visible-print{display:table-cell!important}}.visible-print-block{display:none!important}@media print{.visible-print-block{display:block!important}}.visible-print-inline{display:none!important}@media print{.visible-print-inline{display:inline!important}}.visible-print-inline-block{display:none!important}@media print{.visible-print-inline-block{display:inline-block!important}}@media print{.hidden-print{display:none!important}}',""]);
},function(t,e,n){e=t.exports=n(39)(),e.push([t.id,"table.dataTable{width:100%;margin:0 auto;clear:both;border-collapse:separate;border-spacing:0}table.dataTable tfoot th,table.dataTable thead th{font-weight:700}table.dataTable thead td,table.dataTable thead th{padding:10px 18px;border-bottom:1px solid #111}table.dataTable thead td:active,table.dataTable thead th:active{outline:none}table.dataTable tfoot td,table.dataTable tfoot th{padding:10px 18px 6px;border-top:1px solid #111}table.dataTable thead .sorting,table.dataTable thead .sorting_asc,table.dataTable thead .sorting_desc{cursor:pointer;*cursor:hand}table.dataTable thead .sorting,table.dataTable thead .sorting_asc,table.dataTable thead .sorting_asc_disabled,table.dataTable thead .sorting_desc,table.dataTable thead .sorting_desc_disabled{background-repeat:no-repeat;background-position:100%}table.dataTable thead .sorting{background-image:url("+n(308)+")}table.dataTable thead .sorting_asc{background-image:url("+n(306)+")}table.dataTable thead .sorting_desc{background-image:url("+n(309)+")}table.dataTable thead .sorting_asc_disabled{background-image:url("+n(307)+")}table.dataTable thead .sorting_desc_disabled{background-image:url("+n(310)+')}table.dataTable tbody tr{background-color:#fff}table.dataTable tbody tr.selected{background-color:#b0bed9}table.dataTable tbody td,table.dataTable tbody th{padding:8px 10px}table.dataTable.display tbody td,table.dataTable.display tbody th,table.dataTable.row-border tbody td,table.dataTable.row-border tbody th{border-top:1px solid #ddd}table.dataTable.display tbody tr:first-child td,table.dataTable.display tbody tr:first-child th,table.dataTable.row-border tbody tr:first-child td,table.dataTable.row-border tbody tr:first-child th{border-top:none}table.dataTable.cell-border tbody td,table.dataTable.cell-border tbody th{border-top:1px solid #ddd;border-right:1px solid #ddd}table.dataTable.cell-border tbody tr td:first-child,table.dataTable.cell-border tbody tr th:first-child{border-left:1px solid #ddd}table.dataTable.cell-border tbody tr:first-child td,table.dataTable.cell-border tbody tr:first-child th{border-top:none}table.dataTable.display tbody tr.odd,table.dataTable.stripe tbody tr.odd{background-color:#f9f9f9}table.dataTable.display tbody tr.odd.selected,table.dataTable.stripe tbody tr.odd.selected{background-color:#acbad4}table.dataTable.display tbody tr:hover,table.dataTable.hover tbody tr:hover{background-color:#f6f6f6}table.dataTable.display tbody tr:hover.selected,table.dataTable.hover tbody tr:hover.selected{background-color:#aab7d1}table.dataTable.display tbody tr>.sorting_1,table.dataTable.display tbody tr>.sorting_2,table.dataTable.display tbody tr>.sorting_3,table.dataTable.order-column tbody tr>.sorting_1,table.dataTable.order-column tbody tr>.sorting_2,table.dataTable.order-column tbody tr>.sorting_3{background-color:#fafafa}table.dataTable.display tbody tr.selected>.sorting_1,table.dataTable.display tbody tr.selected>.sorting_2,table.dataTable.display tbody tr.selected>.sorting_3,table.dataTable.order-column tbody tr.selected>.sorting_1,table.dataTable.order-column tbody tr.selected>.sorting_2,table.dataTable.order-column tbody tr.selected>.sorting_3{background-color:#acbad5}table.dataTable.display tbody tr.odd>.sorting_1,table.dataTable.order-column.stripe tbody tr.odd>.sorting_1{background-color:#f1f1f1}table.dataTable.display tbody tr.odd>.sorting_2,table.dataTable.order-column.stripe tbody tr.odd>.sorting_2{background-color:#f3f3f3}table.dataTable.display tbody tr.odd>.sorting_3,table.dataTable.order-column.stripe tbody tr.odd>.sorting_3{background-color:#f5f5f5}table.dataTable.display tbody tr.odd.selected>.sorting_1,table.dataTable.order-column.stripe tbody tr.odd.selected>.sorting_1{background-color:#a6b4cd}table.dataTable.display tbody tr.odd.selected>.sorting_2,table.dataTable.order-column.stripe tbody tr.odd.selected>.sorting_2{background-color:#a8b5cf}table.dataTable.display tbody tr.odd.selected>.sorting_3,table.dataTable.order-column.stripe tbody tr.odd.selected>.sorting_3{background-color:#a9b7d1}table.dataTable.display tbody tr.even>.sorting_1,table.dataTable.order-column.stripe tbody tr.even>.sorting_1{background-color:#fafafa}table.dataTable.display tbody tr.even>.sorting_2,table.dataTable.order-column.stripe tbody tr.even>.sorting_2{background-color:#fcfcfc}table.dataTable.display tbody tr.even>.sorting_3,table.dataTable.order-column.stripe tbody tr.even>.sorting_3{background-color:#fefefe}table.dataTable.display tbody tr.even.selected>.sorting_1,table.dataTable.order-column.stripe tbody tr.even.selected>.sorting_1{background-color:#acbad5}table.dataTable.display tbody tr.even.selected>.sorting_2,table.dataTable.order-column.stripe tbody tr.even.selected>.sorting_2{background-color:#aebcd6}table.dataTable.display tbody tr.even.selected>.sorting_3,table.dataTable.order-column.stripe tbody tr.even.selected>.sorting_3{background-color:#afbdd8}table.dataTable.display tbody tr:hover>.sorting_1,table.dataTable.order-column.hover tbody tr:hover>.sorting_1{background-color:#eaeaea}table.dataTable.display tbody tr:hover>.sorting_2,table.dataTable.order-column.hover tbody tr:hover>.sorting_2{background-color:#ececec}table.dataTable.display tbody tr:hover>.sorting_3,table.dataTable.order-column.hover tbody tr:hover>.sorting_3{background-color:#efefef}table.dataTable.display tbody tr:hover.selected>.sorting_1,table.dataTable.order-column.hover tbody tr:hover.selected>.sorting_1{background-color:#a2aec7}table.dataTable.display tbody tr:hover.selected>.sorting_2,table.dataTable.order-column.hover tbody tr:hover.selected>.sorting_2{background-color:#a3b0c9}table.dataTable.display tbody tr:hover.selected>.sorting_3,table.dataTable.order-column.hover tbody tr:hover.selected>.sorting_3{background-color:#a5b2cb}table.dataTable.no-footer{border-bottom:1px solid #111}table.dataTable.nowrap td,table.dataTable.nowrap th{white-space:nowrap}table.dataTable.compact thead td,table.dataTable.compact thead th{padding:4px 17px 4px 4px}table.dataTable.compact tbody td,table.dataTable.compact tbody th,table.dataTable.compact tfoot td,table.dataTable.compact tfoot th{padding:4px}table.dataTable td.dt-left,table.dataTable th.dt-left{text-align:left}table.dataTable td.dataTables_empty,table.dataTable td.dt-center,table.dataTable th.dt-center{text-align:center}table.dataTable td.dt-right,table.dataTable th.dt-right{text-align:right}table.dataTable td.dt-justify,table.dataTable th.dt-justify{text-align:justify}table.dataTable td.dt-nowrap,table.dataTable th.dt-nowrap{white-space:nowrap}table.dataTable tfoot td.dt-head-left,table.dataTable tfoot th.dt-head-left,table.dataTable thead td.dt-head-left,table.dataTable thead th.dt-head-left{text-align:left}table.dataTable tfoot td.dt-head-center,table.dataTable tfoot th.dt-head-center,table.dataTable thead td.dt-head-center,table.dataTable thead th.dt-head-center{text-align:center}table.dataTable tfoot td.dt-head-right,table.dataTable tfoot th.dt-head-right,table.dataTable thead td.dt-head-right,table.dataTable thead th.dt-head-right{text-align:right}table.dataTable tfoot td.dt-head-justify,table.dataTable tfoot th.dt-head-justify,table.dataTable thead td.dt-head-justify,table.dataTable thead th.dt-head-justify{text-align:justify}table.dataTable tfoot td.dt-head-nowrap,table.dataTable tfoot th.dt-head-nowrap,table.dataTable thead td.dt-head-nowrap,table.dataTable thead th.dt-head-nowrap{white-space:nowrap}table.dataTable tbody td.dt-body-left,table.dataTable tbody th.dt-body-left{text-align:left}table.dataTable tbody td.dt-body-center,table.dataTable tbody th.dt-body-center{text-align:center}table.dataTable tbody td.dt-body-right,table.dataTable tbody th.dt-body-right{text-align:right}table.dataTable tbody td.dt-body-justify,table.dataTable tbody th.dt-body-justify{text-align:justify}table.dataTable tbody td.dt-body-nowrap,table.dataTable tbody th.dt-body-nowrap{white-space:nowrap}table.dataTable,table.dataTable td,table.dataTable th{-webkit-box-sizing:content-box;box-sizing:content-box}.dataTables_wrapper{position:relative;clear:both;zoom:1}.dataTables_wrapper .dataTables_length{float:left}.dataTables_wrapper .dataTables_filter{float:right;text-align:right}.dataTables_wrapper .dataTables_filter input{margin-left:.5em}.dataTables_wrapper .dataTables_info{clear:both;float:left;padding-top:.755em}.dataTables_wrapper .dataTables_paginate{float:right;text-align:right;padding-top:.25em}.dataTables_wrapper .dataTables_paginate .paginate_button{box-sizing:border-box;display:inline-block;min-width:1.5em;padding:.5em 1em;margin-left:2px;text-align:center;text-decoration:none!important;cursor:pointer;*cursor:hand;color:#333!important;border:1px solid transparent;border-radius:2px}.dataTables_wrapper .dataTables_paginate .paginate_button.current,.dataTables_wrapper .dataTables_paginate .paginate_button.current:hover{color:#333!important;border:1px solid #979797;background-color:#fff;background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#fff),color-stop(100%,#dcdcdc));background:-webkit-linear-gradient(top,#fff,#dcdcdc);background:-moz-linear-gradient(top,#fff 0,#dcdcdc 100%);background:-ms-linear-gradient(top,#fff 0,#dcdcdc 100%);background:-o-linear-gradient(top,#fff 0,#dcdcdc 100%);background:linear-gradient(180deg,#fff 0,#dcdcdc)}.dataTables_wrapper .dataTables_paginate .paginate_button.disabled,.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:active,.dataTables_wrapper .dataTables_paginate .paginate_button.disabled:hover{cursor:default;color:#666!important;border:1px solid transparent;background:transparent;box-shadow:none}.dataTables_wrapper .dataTables_paginate .paginate_button:hover{color:#fff!important;border:1px solid #111;background-color:#585858;background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#585858),color-stop(100%,#111));background:-webkit-linear-gradient(top,#585858,#111);background:-moz-linear-gradient(top,#585858 0,#111 100%);background:-ms-linear-gradient(top,#585858 0,#111 100%);background:-o-linear-gradient(top,#585858 0,#111 100%);background:linear-gradient(180deg,#585858 0,#111)}.dataTables_wrapper .dataTables_paginate .paginate_button:active{outline:none;background-color:#2b2b2b;background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#2b2b2b),color-stop(100%,#0c0c0c));background:-webkit-linear-gradient(top,#2b2b2b,#0c0c0c);background:-moz-linear-gradient(top,#2b2b2b 0,#0c0c0c 100%);background:-ms-linear-gradient(top,#2b2b2b 0,#0c0c0c 100%);background:-o-linear-gradient(top,#2b2b2b 0,#0c0c0c 100%);background:linear-gradient(180deg,#2b2b2b 0,#0c0c0c);box-shadow:inset 0 0 3px #111}.dataTables_wrapper .dataTables_paginate .ellipsis{padding:0 1em}.dataTables_wrapper .dataTables_processing{position:absolute;top:50%;left:50%;width:100%;height:40px;margin-left:-50%;margin-top:-25px;padding-top:20px;text-align:center;font-size:1.2em;background-color:#fff;background:-webkit-gradient(linear,left top,right top,color-stop(0,hsla(0,0%,100%,0)),color-stop(25%,hsla(0,0%,100%,.9)),color-stop(75%,hsla(0,0%,100%,.9)),color-stop(100%,hsla(0,0%,100%,0)));background:-webkit-linear-gradient(left,hsla(0,0%,100%,0),hsla(0,0%,100%,.9) 25%,hsla(0,0%,100%,.9) 75%,hsla(0,0%,100%,0));background:-moz-linear-gradient(left,hsla(0,0%,100%,0) 0,hsla(0,0%,100%,.9) 25%,hsla(0,0%,100%,.9) 75%,hsla(0,0%,100%,0) 100%);background:-ms-linear-gradient(left,hsla(0,0%,100%,0) 0,hsla(0,0%,100%,.9) 25%,hsla(0,0%,100%,.9) 75%,hsla(0,0%,100%,0) 100%);background:-o-linear-gradient(left,hsla(0,0%,100%,0) 0,hsla(0,0%,100%,.9) 25%,hsla(0,0%,100%,.9) 75%,hsla(0,0%,100%,0) 100%);background:linear-gradient(90deg,hsla(0,0%,100%,0) 0,hsla(0,0%,100%,.9) 25%,hsla(0,0%,100%,.9) 75%,hsla(0,0%,100%,0))}.dataTables_wrapper .dataTables_filter,.dataTables_wrapper .dataTables_info,.dataTables_wrapper .dataTables_length,.dataTables_wrapper .dataTables_paginate,.dataTables_wrapper .dataTables_processing{color:#333}.dataTables_wrapper .dataTables_scroll{clear:both}.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody{*margin-top:-1px;-webkit-overflow-scrolling:touch}.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody td,.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody th{vertical-align:middle}.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody td>div.dataTables_sizing,.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody th>div.dataTables_sizing{height:0;overflow:hidden;margin:0!important;padding:0!important}.dataTables_wrapper.no-footer .dataTables_scrollBody{border-bottom:1px solid #111}.dataTables_wrapper.no-footer div.dataTables_scrollBody table,.dataTables_wrapper.no-footer div.dataTables_scrollHead table{border-bottom:none}.dataTables_wrapper:after{visibility:hidden;display:block;content:"";clear:both;height:0}@media screen and (max-width:767px){.dataTables_wrapper .dataTables_info,.dataTables_wrapper .dataTables_paginate{float:none;text-align:center}.dataTables_wrapper .dataTables_paginate{margin-top:.5em}}@media screen and (max-width:640px){.dataTables_wrapper .dataTables_filter,.dataTables_wrapper .dataTables_length{float:none;text-align:center}.dataTables_wrapper .dataTables_filter{margin-top:.5em}}',""])},function(t,e,n){e=t.exports=n(39)(),e.push([t.id,".mg-active-datapoint{fill:#000;font-size:.9rem;font-weight:400;opacity:.8}.mg-area1-color{fill:#00f}.mg-area2-color{fill:#05b378}.mg-area3-color{fill:#db4437}.mg-area4-color{fill:#f8b128}.mg-area5-color{fill:#5c5c5c}text.mg-barplot-group-label{font-weight:900}.mg-barplot rect.mg-bar{shape-rendering:auto}.mg-barplot rect.mg-bar.default-bar{fill:#b6b6fc}.mg-barplot rect.mg-bar.default-active{fill:#9e9efc}.mg-barplot .mg-bar-prediction{fill:#5b5b5b}.mg-barplot .mg-bar-baseline{stroke:#5b5b5b;stroke-width:2}.mg-bar-target-element{font-size:11px;padding-left:5px;padding-right:5px;font-weight:300}.mg-baselines line{opacity:1;shape-rendering:auto;stroke:#b3b2b2;stroke-width:1px}.mg-baselines text{fill:#000;font-size:.9rem;opacity:.6;stroke:none}.mg-baselines-small text{font-size:.6rem}.mg-category-guides line{stroke:#b3b2b2}.mg-header{cursor:default;font-size:1.2rem}.mg-header .mg-chart-description,.mg-header .mg-warning{fill:#ccc;font-family:FontAwesome;font-size:1.2rem}.mg-points circle{opacity:.65}.mg-popover{font-size:.95rem}.mg-popover-content{cursor:auto;line-height:17px}.mg-data-table{margin-top:30px}.mg-data-table thead tr th{border-bottom:1px solid #a9a9a9;cursor:default;font-size:1.1rem;font-weight:400;padding:5px 5px 8px;text-align:right}.mg-data-table thead tr th .fa{color:#ccc;padding-left:4px}.mg-data-table thead tr th .popover{font-size:1rem;font-weight:400}.mg-data-table .secondary-title{color:#a9a9a9}.mg-data-table tbody tr td{margin:2px;padding:5px;vertical-align:top}.mg-data-table tbody tr td.table-text{opacity:.8;padding-left:30px}.mg-x-axis line.mg-extended-xax-ticks,.mg-y-axis line.mg-extended-yax-ticks{opacity:.4}.mg-histogram .axis line,.mg-histogram .axis path{fill:none;opacity:.7;shape-rendering:auto;stroke:#ccc}tspan.hist-symbol{fill:#9e9efc}.mg-histogram .mg-bar rect{fill:#b6b6fc;shape-rendering:auto}.mg-histogram .mg-bar rect.active{fill:#9e9efc}.mg-least-squares-line{stroke:red;stroke-width:1px}.mg-lowess-line{fill:none;stroke:red}.mg-line1-color{stroke:#4040e8}.mg-hover-line1-color{fill:#4040e8}.mg-line2-color{stroke:#05b378}.mg-hover-line2-color{fill:#05b378}.mg-line3-color{stroke:#db4437}.mg-hover-line3-color{fill:#db4437}.mg-line4-color{stroke:#f8b128}.mg-hover-line4-color{fill:#f8b128}.mg-line5-color{stroke:#5c5c5c}.mg-hover-line5-color{fill:#5c5c5c}.mg-line-legend text{font-size:.9rem;font-weight:300;stroke:none}.mg-line1-legend-color{color:#4040e8;fill:#4040e8}.mg-line2-legend-color{color:#05b378;fill:#05b378}.mg-line3-legend-color{color:#db4437;fill:#db4437}.mg-line4-legend-color{color:#f8b128;fill:#f8b128}.mg-line5-legend-color{color:#5c5c5c;fill:#5c5c5c}.mg-main-area-solid svg .mg-main-area{fill:#ccf;opacity:1}.mg-markers line{opacity:1;shape-rendering:auto;stroke:#b3b2b2;stroke-width:1px}.mg-markers text{fill:#000;font-size:.8rem;opacity:.6}.mg-missing-text{opacity:.9}.mg-missing-background{stroke:blue;fill:none;stroke-dasharray:10,5;stroke-opacity:.05;stroke-width:2}.mg-missing .mg-main-line{opacity:.1}.mg-missing .mg-main-area{opacity:.03}path.mg-main-area{opacity:.2;stroke:none}path.mg-confidence-band{fill:#ccc;opacity:.4;stroke:none}path.mg-main-line{fill:none;opacity:.8;stroke-width:1.1px}.mg-points circle{fill-opacity:.4;stroke-opacity:1}circle.mg-points-mono,tspan.mg-points-mono{fill:#00f;stroke:#00f}.mg-points circle.selected{fill-opacity:1;stroke-opacity:1}.mg-voronoi path{fill:none;pointer-events:all;stroke:none;stroke-opacity:.1}.mg-x-rug-mono,.mg-y-rug-mono{stroke:#000}.mg-x-axis line,.mg-y-axis line{opacity:1;shape-rendering:auto;stroke:#b3b2b2;stroke-width:1px}.mg-histogram .axis text,.mg-x-axis text,.mg-y-axis text{fill:#000;font-size:.9rem;opacity:.6}.mg-axis .label,.mg-x-axis .label,.mg-y-axis .label{font-size:.8rem;text-transform:uppercase;font-weight:400}.mg-active-datapoint-small,.mg-x-axis-small text,.mg-y-axis-small text{font-size:.6rem}.mg-x-axis-small .label,.mg-y-axis-small .label{font-size:.65rem}.mg-year-marker text{fill:#000;font-size:.7rem;opacity:.6}.mg-year-marker line{opacity:1;shape-rendering:auto;stroke:#b3b2b2;stroke-width:1px}.mg-year-marker-small text{font-size:.6rem}",""])},function(t,e,n){e=t.exports=n(39)(),e.push([t.id,".nvd3 .nv-axis line,.nvd3 .nv-axis path{fill:none;shape-rendering:crispEdges}.nv-brush .extent,.nvd3 .background path,.nvd3 .nv-axis line,.nvd3 .nv-axis path{shape-rendering:crispEdges}.nv-distx,.nv-disty,.nv-noninteractive,.nvd3 .nv-axis,.nvd3.nv-pie .nv-label,.nvd3.nv-sparklineplus g.nv-hoverValue{pointer-events:none}.nvd3 .nv-axis{opacity:1}.nvd3 .nv-axis.nv-disabled,.nvd3 .nv-controlsWrap .nv-legend .nv-check-box .nv-check{opacity:0}.nvd3 .nv-axis path{stroke:#000;stroke-opacity:.75}.nvd3 .nv-axis path.domain{stroke-opacity:.75}.nvd3 .nv-axis.nv-x path.domain{stroke-opacity:0}.nvd3 .nv-axis line{stroke:#e5e5e5}.nvd3 .nv-axis .zero line,.nvd3 .nv-axis line.zero{stroke-opacity:.75}.nvd3 .nv-axis .nv-axisMaxMin text{font-weight:700}.nvd3 .x2 .nv-axis .nv-axisMaxMin text,.nvd3 .x3 .nv-axis .nv-axisMaxMin text,.nvd3 .x .nv-axis .nv-axisMaxMin text{text-anchor:middle}.nvd3 .nv-bars rect{fill-opacity:.75;transition:fill-opacity .25s linear}.nvd3 .nv-bars rect.hover{fill-opacity:1}.nvd3 .nv-bars .hover rect{fill:#add8e6}.nvd3 .nv-bars text{fill:transparent}.nvd3 .nv-bars .hover text{fill:#000}.nvd3 .nv-discretebar .nv-groups rect,.nvd3 .nv-multibar .nv-groups rect,.nvd3 .nv-multibarHorizontal .nv-groups rect{stroke-opacity:0;transition:fill-opacity .25s linear}.with-transitions .nv-candlestickBar .nv-ticks .nv-tick,.with-transitions .nvd3 .nv-groups .nv-point{transition:stroke-width .25s linear,stroke-opacity .25s linear}.nvd3 .nv-candlestickBar .nv-ticks rect:hover,.nvd3 .nv-discretebar .nv-groups rect:hover,.nvd3 .nv-multibar .nv-groups rect:hover,.nvd3 .nv-multibarHorizontal .nv-groups rect:hover{fill-opacity:1}.nvd3 .nv-discretebar .nv-groups text,.nvd3 .nv-multibarHorizontal .nv-groups text{font-weight:700;fill:#000;stroke:transparent}.nvd3 .nv-boxplot circle{fill-opacity:.5}.nvd3 .nv-boxplot circle:hover,.nvd3 .nv-boxplot rect:hover{fill-opacity:1}.nvd3 line.nv-boxplot-median{stroke:#000}.nv-boxplot-tick:hover{stroke-width:2.5px}.nvd3.nv-bullet{font:10px sans-serif}.nvd3.nv-bullet .nv-measure{fill-opacity:.8}.nvd3.nv-bullet .nv-measure:hover{fill-opacity:1}.nvd3.nv-bullet .nv-marker{stroke:#000;stroke-width:2px}.nvd3.nv-bullet .nv-markerTriangle{stroke:#000;fill:#fff;stroke-width:1.5px}.nvd3.nv-bullet .nv-markerLine{stroke:#000;stroke-width:1.5px}.nvd3.nv-bullet .nv-tick line{stroke:#666;stroke-width:.5px}.nvd3.nv-bullet .nv-range.nv-s0{fill:#eee}.nvd3.nv-bullet .nv-range.nv-s1{fill:#ddd}.nvd3.nv-bullet .nv-range.nv-s2{fill:#ccc}.nvd3.nv-bullet .nv-title{font-size:14px;font-weight:700}.nvd3.nv-bullet .nv-subtitle{fill:#999}.nvd3.nv-bullet .nv-range{fill:#bababa;fill-opacity:.4}.nvd3.nv-bullet .nv-range:hover{fill-opacity:.7}.nvd3.nv-candlestickBar .nv-ticks .nv-tick{stroke-width:1px}.nvd3.nv-candlestickBar .nv-ticks .nv-tick.hover{stroke-width:2px}.nvd3.nv-candlestickBar .nv-ticks .nv-tick.positive rect{stroke:#2ca02c;fill:#2ca02c}.nvd3.nv-candlestickBar .nv-ticks .nv-tick.negative rect{stroke:#d62728;fill:#d62728}.nvd3.nv-candlestickBar .nv-ticks line{stroke:#333}.nv-force-node{stroke:#fff;stroke-width:1.5px}.nv-force-link{stroke:#999;stroke-opacity:.6}.nv-force-node text{stroke-width:0}.nvd3 .nv-check-box .nv-box{fill-opacity:0;stroke-width:2}.nvd3 .nv-check-box .nv-check{fill-opacity:0;stroke-width:4}.nvd3 .nv-series.nv-disabled .nv-check-box .nv-check{fill-opacity:0;stroke-opacity:0}.nvd3.nv-linePlusBar .nv-bar rect{fill-opacity:.75}.nvd3.nv-linePlusBar .nv-bar rect:hover{fill-opacity:1}.nvd3 .nv-groups path.nv-line{fill:none}.nvd3 .nv-groups path.nv-area{stroke:none}.nvd3.nv-line .nvd3.nv-scatter .nv-groups .nv-point{fill-opacity:0;stroke-opacity:0}.nvd3.nv-scatter.nv-single-point .nv-groups .nv-point{fill-opacity:.5!important;stroke-opacity:.5!important}.nvd3 .nv-groups .nv-point.hover,.nvd3.nv-scatter .nv-groups .nv-point.hover{stroke-width:7px;fill-opacity:.95!important;stroke-opacity:.95!important}.nvd3 .nv-point-paths path{stroke:#aaa;stroke-opacity:0;fill:#eee;fill-opacity:0}.nvd3 .nv-indexLine{cursor:ew-resize}svg.nvd3-svg{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;display:block;width:100%;height:100%}.nvtooltip.with-3d-shadow,.with-3d-shadow .nvtooltip{box-shadow:0 5px 10px rgba(0,0,0,.2);border-radius:5px}.nvd3 text{font:400 12px Arial,sans-serif}.nvd3 .title{font:700 14px Arial,sans-serif}.nvd3 .nv-background{fill:#fff;fill-opacity:0}.nvd3.nv-noData{font-size:18px;font-weight:700}.nv-brush .extent{fill-opacity:.125}.nv-brush .resize path{fill:#eee;stroke:#666}.nvd3 .nv-legend .nv-series{cursor:pointer}.nvd3 .nv-legend .nv-disabled circle{fill-opacity:0}.nvd3 .nv-brush .extent{fill-opacity:0!important}.nvd3 .nv-brushBackground rect{stroke:#000;stroke-width:.4;fill:#fff;fill-opacity:.7}@media print{.nvd3 text{stroke-width:0;fill-opacity:1}}.nvd3.nv-ohlcBar .nv-ticks .nv-tick{stroke-width:1px}.nvd3.nv-ohlcBar .nv-ticks .nv-tick.hover{stroke-width:2px}.nvd3.nv-ohlcBar .nv-ticks .nv-tick.positive{stroke:#2ca02c}.nvd3.nv-ohlcBar .nv-ticks .nv-tick.negative{stroke:#d62728}.nvd3 .background path{fill:none;stroke:#eee;stroke-opacity:.4}.nvd3 .foreground path{fill:none;stroke-opacity:.7}.nvd3 .nv-parallelCoordinates-brush .extent{fill:#fff;fill-opacity:.6;stroke:gray;shape-rendering:crispEdges}.nvd3 .nv-parallelCoordinates .hover{fill-opacity:1;stroke-width:3px}.nvd3 .missingValuesline line{fill:none;stroke:#000;stroke-width:1;stroke-opacity:1;stroke-dasharray:5,5}.nvd3.nv-pie .nv-pie-title{font-size:24px;fill:rgba(19,196,249,.59)}.nvd3.nv-pie .nv-slice text{stroke:#000;stroke-width:0}.nvd3.nv-pie path{transition:fill-opacity .25s linear,stroke-width .25s linear,stroke-opacity .25s linear;stroke:#fff;stroke-width:1px;stroke-opacity:1;fill-opacity:.7}.nvd3.nv-pie .hover path{fill-opacity:1}.nvd3.nv-pie .nv-label rect{fill-opacity:0;stroke-opacity:0}.nvd3 .nv-groups .nv-point.hover{stroke-width:20px;stroke-opacity:.5}.nvd3 .nv-scatter .nv-point.hover{fill-opacity:1}.nvd3.nv-sparkline path{fill:none}.nvd3.nv-sparklineplus .nv-hoverValue line{stroke:#333;stroke-width:1.5px}.nvd3.nv-sparklineplus,.nvd3.nv-sparklineplus g{pointer-events:all}.nvd3 .nv-interactiveGuideLine,.nvtooltip{pointer-events:none}.nvd3 .nv-hoverArea{fill-opacity:0;stroke-opacity:0}.nvd3.nv-sparklineplus .nv-xValue,.nvd3.nv-sparklineplus .nv-yValue{stroke-width:0;font-size:.9em;font-weight:400}.nvd3.nv-sparklineplus .nv-yValue{stroke:#f66}.nvd3.nv-sparklineplus .nv-maxValue{stroke:#2ca02c;fill:#2ca02c}.nvd3.nv-sparklineplus .nv-minValue{stroke:#d62728;fill:#d62728}.nvd3.nv-sparklineplus .nv-currentValue{font-weight:700;font-size:1.1em}.nvtooltip h3,.nvtooltip table td.key{font-weight:400}.nvd3.nv-stackedarea path.nv-area{fill-opacity:.7;stroke-opacity:0;transition:fill-opacity .25s linear,stroke-opacity .25s linear}.nvd3.nv-stackedarea path.nv-area.hover{fill-opacity:.9}.nvd3.nv-stackedarea .nv-groups .nv-point{stroke-opacity:0;fill-opacity:0}.nvtooltip{position:absolute;color:#000;padding:1px;z-index:10000;display:block;font-family:Arial,sans-serif;font-size:13px;text-align:left;white-space:nowrap;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;background:hsla(0,0%,100%,.8);border:1px solid rgba(0,0,0,.5);border-radius:4px}.nvtooltip h3,.nvtooltip p{margin:0;text-align:center}.nvtooltip.with-transitions,.with-transitions .nvtooltip{transition:opacity 50ms linear;transition-delay:.2s}.nvtooltip.x-nvtooltip,.nvtooltip.y-nvtooltip{padding:8px}.nvtooltip h3{padding:4px 14px;line-height:18px;background-color:hsla(0,0%,97%,.75);color:#000;border-bottom:1px solid #ebebeb;border-radius:5px 5px 0 0}.nvtooltip p{padding:5px 14px}.nvtooltip span{display:inline-block;margin:2px 0}.nvtooltip table{margin:6px;border-spacing:0}.nvtooltip table td{padding:2px 9px 2px 0;vertical-align:middle}.nvtooltip table td.key.total{font-weight:700}.nvtooltip table td.value{text-align:right;font-weight:700}.nvtooltip table td.percent{color:#a9a9a9}.nvtooltip table tr.highlight td{padding:1px 9px 1px 0;border-bottom-style:solid;border-bottom-width:1px;border-top-style:solid;border-top-width:1px}.nvtooltip table td.legend-color-guide div{vertical-align:middle;width:12px;height:12px;border:1px solid #999}.nvtooltip .footer{padding:3px;text-align:center}.nvtooltip-pending-removal{pointer-events:none;display:none}.nvd3 line.nv-guideline{stroke:#ccc}",""])},function(t,e,n){e=t.exports=n(39)(),e.push([t.id,".Select,.Select-control{position:relative}.Select,.Select div,.Select input,.Select span{-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box}.Select.is-disabled>.Select-control{background-color:#f9f9f9}.Select.is-disabled>.Select-control:hover{box-shadow:none}.Select.is-disabled .Select-arrow-zone{cursor:default;pointer-events:none;opacity:.35}.Select-control{background-color:#fff;border-radius:4px;border:1px solid #ccc;color:#333;cursor:default;display:table;border-spacing:0;border-collapse:separate;height:36px;outline:0;overflow:hidden;width:100%}.is-searchable.is-focused:not(.is-open)>.Select-control,.is-searchable.is-open>.Select-control{cursor:text}.Select-control:hover{box-shadow:0 1px 0 rgba(0,0,0,.06)}.Select-control .Select-input:focus{outline:0}.is-open>.Select-control{border-bottom-right-radius:0;border-bottom-left-radius:0;background:#fff;border-color:#b3b3b3 #ccc #d9d9d9}.is-open>.Select-control>.Select-arrow{border-color:transparent transparent #999;border-width:0 5px 5px}.is-focused:not(.is-open)>.Select-control{border-color:#007eff;box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 0 3px rgba(0,126,255,.1)}.Select--single>.Select-control .Select-value,.Select-placeholder{bottom:0;color:#aaa;left:0;line-height:34px;padding-left:10px;padding-right:10px;position:absolute;right:0;top:0;max-width:100%;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.has-value.is-pseudo-focused.Select--single>.Select-control .Select-value .Select-value-label,.has-value.Select--single>.Select-control .Select-value .Select-value-label{color:#333}.has-value.is-pseudo-focused.Select--single>.Select-control .Select-value a.Select-value-label,.has-value.Select--single>.Select-control .Select-value a.Select-value-label{cursor:pointer;text-decoration:none}.has-value.is-pseudo-focused.Select--single>.Select-control .Select-value a.Select-value-label:focus,.has-value.is-pseudo-focused.Select--single>.Select-control .Select-value a.Select-value-label:hover,.has-value.Select--single>.Select-control .Select-value a.Select-value-label:focus,.has-value.Select--single>.Select-control .Select-value a.Select-value-label:hover{color:#007eff;outline:0;text-decoration:underline}.Select-input{height:34px;padding-left:10px;padding-right:10px;vertical-align:middle}.Select-input>input{width:100%;background:none;border:0;box-shadow:none;cursor:default;display:inline-block;font-family:inherit;font-size:inherit;margin:0;outline:0;line-height:14px;padding:8px 0 12px;-webkit-appearance:none}.Select-loading,.Select-loading-zone{width:16px;position:relative;vertical-align:middle}.is-focused .Select-input>input{cursor:text}.has-value.is-pseudo-focused .Select-input{opacity:0}.Select-control:not(.is-searchable)>.Select-input{outline:0}.Select-loading-zone{cursor:pointer;display:table-cell;text-align:center}.Select-loading{-webkit-animation:Select-animation-spin .4s infinite linear;-o-animation:Select-animation-spin .4s infinite linear;animation:Select-animation-spin .4s infinite linear;height:16px;box-sizing:border-box;border-radius:50%;border:2px solid #ccc;border-right-color:#333;display:inline-block}.Select-clear-zone{-webkit-animation:Select-animation-fadeIn .2s;-o-animation:Select-animation-fadeIn .2s;animation:Select-animation-fadeIn .2s;color:#999;cursor:pointer;display:table-cell;position:relative;text-align:center;vertical-align:middle;width:17px}.Select-clear-zone:hover{color:#d0021b}.Select-clear{display:inline-block;font-size:18px;line-height:1}.Select--multi .Select-clear-zone{width:17px}.Select-arrow-zone{cursor:pointer;display:table-cell;position:relative;text-align:center;vertical-align:middle;width:25px;padding-right:5px}.Select--multi .Select-multi-value-wrapper,.Select-arrow{display:inline-block}.Select-arrow{border-color:#999 transparent transparent;border-style:solid;border-width:5px 5px 2.5px;height:0;width:0}.is-open .Select-arrow,.Select-arrow-zone:hover>.Select-arrow{border-top-color:#666}.Select .Select-aria-only{display:inline-block;height:1px;width:1px;margin:-1px;clip:rect(0,0,0,0);overflow:hidden}.Select-noresults,.Select-option{box-sizing:border-box;display:block;padding:8px 10px}@-webkit-keyframes Select-animation-fadeIn{0%{opacity:0}to{opacity:1}}@keyframes Select-animation-fadeIn{0%{opacity:0}to{opacity:1}}.Select-menu-outer{border-bottom-right-radius:4px;border-bottom-left-radius:4px;background-color:#fff;border:1px solid #ccc;border-top-color:#e6e6e6;box-shadow:0 1px 0 rgba(0,0,0,.06);box-sizing:border-box;margin-top:-1px;max-height:200px;position:absolute;top:100%;width:100%;z-index:1;-webkit-overflow-scrolling:touch}.Select-menu{max-height:198px;overflow-y:auto}.Select-option{background-color:#fff;color:#666;cursor:pointer}.Select-option:last-child{border-bottom-right-radius:4px;border-bottom-left-radius:4px}.Select-option.is-selected{background-color:#f5faff;background-color:rgba(0,126,255,.04);color:#333}.Select-option.is-focused{background-color:#ebf5ff;background-color:rgba(0,126,255,.08);color:#333}.Select-option.is-disabled{color:#ccc;cursor:default}.Select-noresults{color:#999;cursor:default}.Select--multi .Select-input{vertical-align:middle;margin-left:10px;padding:0}.Select--multi.has-value .Select-input{margin-left:5px}.Select--multi .Select-value{background-color:#ebf5ff;background-color:rgba(0,126,255,.08);border-radius:2px;border:1px solid #c2e0ff;border:1px solid rgba(0,126,255,.24);color:#007eff;display:inline-block;font-size:.9em;line-height:1.4;margin-left:5px;margin-top:5px;vertical-align:top}.Select--multi .Select-value-icon,.Select--multi .Select-value-label{display:inline-block;vertical-align:middle}.Select--multi .Select-value-label{border-bottom-right-radius:2px;border-top-right-radius:2px;cursor:default;padding:2px 5px}.Select--multi a.Select-value-label{color:#007eff;cursor:pointer;text-decoration:none}.Select--multi a.Select-value-label:hover{text-decoration:underline}.Select--multi .Select-value-icon{cursor:pointer;border-bottom-left-radius:2px;border-top-left-radius:2px;border-right:1px solid #c2e0ff;border-right:1px solid rgba(0,126,255,.24);padding:1px 5px 3px}.Select--multi .Select-value-icon:focus,.Select--multi .Select-value-icon:hover{background-color:#d8eafd;background-color:rgba(0,113,230,.08);color:#0071e6}.Select--multi .Select-value-icon:active{background-color:#c2e0ff;background-color:rgba(0,126,255,.24)}.Select--multi.is-disabled .Select-value{background-color:#fcfcfc;border:1px solid #e3e3e3;color:#333}.Select--multi.is-disabled .Select-value-icon{cursor:not-allowed;border-right:1px solid #e3e3e3}.Select--multi.is-disabled .Select-value-icon:active,.Select--multi.is-disabled .Select-value-icon:focus,.Select--multi.is-disabled .Select-value-icon:hover{background-color:#fcfcfc}@keyframes Select-animation-spin{to{transform:rotate(1turn)}}@-webkit-keyframes Select-animation-spin{to{-webkit-transform:rotate(1turn)}}",""]);
},function(t,e,n){"use strict";var r=n(112);t.exports=function(t,e){t.classList?t.classList.add(e):r(t)||(t.className=t.className+" "+e)}},function(t,e,n){"use strict";t.exports={addClass:n(204),removeClass:n(206),hasClass:n(112)}},function(t,e){"use strict";t.exports=function(t,e){t.classList?t.classList.remove(e):t.className=t.className.replace(new RegExp("(^|\\s)"+e+"(?:\\s|$)","g"),"$1").replace(/\s+/g," ").replace(/^\s*|\s*$/g,"")}},function(t,e,n){"use strict";var r=n(32),o=n(211);t.exports=function(t,e){return function(n){var i=n.currentTarget,a=n.target,s=o(i,t);s.some(function(t){return r(t,a)})&&e.call(this,n)}}},function(t,e,n){"use strict";var r=n(74),o=n(113),i=n(207);t.exports={on:r,off:o,filter:i}},function(t,e,n){"use strict";function r(t){return t.nodeName&&t.nodeName.toLowerCase()}function o(t){for(var e=(0,s.default)(t),n=t&&t.offsetParent;n&&"html"!==r(t)&&"static"===(0,u.default)(n,"position");)n=n.offsetParent;return n||e.documentElement}var i=n(47);e.__esModule=!0,e.default=o;var a=n(31),s=i.interopRequireDefault(a),l=n(46),u=i.interopRequireDefault(l);t.exports=e.default},function(t,e,n){"use strict";function r(t){return t.nodeName&&t.nodeName.toLowerCase()}function o(t,e){var n,o={top:0,left:0};return"fixed"===(0,g.default)(t,"position")?n=t.getBoundingClientRect():(e=e||(0,u.default)(t),n=(0,s.default)(t),"html"!==r(e)&&(o=(0,s.default)(e)),o.top+=parseInt((0,g.default)(e,"borderTopWidth"),10)-(0,f.default)(e)||0,o.left+=parseInt((0,g.default)(e,"borderLeftWidth"),10)-(0,p.default)(e)||0),i._extends({},n,{top:n.top-o.top-(parseInt((0,g.default)(t,"marginTop"),10)||0),left:n.left-o.left-(parseInt((0,g.default)(t,"marginLeft"),10)||0)})}var i=n(47);e.__esModule=!0,e.default=o;var a=n(114),s=i.interopRequireDefault(a),l=n(209),u=i.interopRequireDefault(l),c=n(115),f=i.interopRequireDefault(c),d=n(212),p=i.interopRequireDefault(d),h=n(46),g=i.interopRequireDefault(h);t.exports=e.default},function(t,e){"use strict";var n=/^[\w-]*$/,r=Function.prototype.bind.call(Function.prototype.call,[].slice);t.exports=function(t,e){var o,i="#"===e[0],a="."===e[0],s=i||a?e.slice(1):e,l=n.test(s);return l?i?(t=t.getElementById?t:document,(o=t.getElementById(s))?[o]:[]):r(t.getElementsByClassName&&a?t.getElementsByClassName(s):t.getElementsByTagName(e)):r(t.querySelectorAll(e))}},function(t,e,n){"use strict";var r=n(45);t.exports=function(t,e){var n=r(t);return void 0===e?n?"pageXOffset"in n?n.pageXOffset:n.document.documentElement.scrollLeft:t.scrollLeft:void(n?n.scrollTo(e,"pageYOffset"in n?n.pageYOffset:n.document.documentElement.scrollTop):t.scrollLeft=e)}},function(t,e,n){"use strict";var r=n(47),o=n(116),i=r.interopRequireDefault(o),a=/^(top|right|bottom|left)$/,s=/^([+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|))(?!px)[a-z%]+$/i;t.exports=function(t){if(!t)throw new TypeError("No Element passed to `getComputedStyle()`");var e=t.ownerDocument;return"defaultView"in e?e.defaultView.opener?t.ownerDocument.defaultView.getComputedStyle(t,null):window.getComputedStyle(t,null):{getPropertyValue:function(e){var n=t.style;e=(0,i.default)(e),"float"==e&&(e="styleFloat");var r=t.currentStyle[e]||null;if(null==r&&n&&n[e]&&(r=n[e]),s.test(r)&&!a.test(e)){var o=n.left,l=t.runtimeStyle,u=l&&l.left;u&&(l.left=t.currentStyle.left),n.left="fontSize"===e?"1em":r,r=n.pixelLeft+"px",n.left=o,u&&(l.left=u)}return r}}}},function(t,e){"use strict";t.exports=function(t,e){return"removeProperty"in t.style?t.style.removeProperty(e):t.style.removeAttribute(e)}},function(t,e,n){"use strict";function r(){var t,e="",n={O:"otransitionend",Moz:"transitionend",Webkit:"webkitTransitionEnd",ms:"MSTransitionEnd"},r=document.createElement("div");for(var o in n)if(u.call(n,o)&&void 0!==r.style[o+"TransitionProperty"]){e="-"+o.toLowerCase()+"-",t=n[o];break}return t||void 0===r.style.transitionProperty||(t="transitionend"),{end:t,prefix:e}}var o,i,a,s,l=n(25),u=Object.prototype.hasOwnProperty,c="transform",f={};l&&(f=r(),c=f.prefix+c,a=f.prefix+"transition-property",i=f.prefix+"transition-duration",s=f.prefix+"transition-delay",o=f.prefix+"transition-timing-function"),t.exports={transform:c,end:f.end,property:a,timing:o,delay:s,duration:i}},function(t,e){"use strict";var n=/-(.)/g;t.exports=function(t){return t.replace(n,function(t,e){return e.toUpperCase()})}},function(t,e){"use strict";var n=/([A-Z])/g;t.exports=function(t){return t.replace(n,"-$1").toLowerCase()}},function(t,e,n){"use strict";var r=n(217),o=/^ms-/;t.exports=function(t){return r(t).replace(o,"-ms-")}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(1),p=r(d),h=n(134),g=r(h),v=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){return p.default.createElement(g.default,(0,i.default)({},this.props,{accordion:!0}),this.props.children)},e}(p.default.Component);e.default=v,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(26),i=r(o),a=n(5),s=r(a),l=n(7),u=r(l),c=n(2),f=r(c),d=n(4),p=r(d),h=n(3),g=r(h),v=n(6),m=r(v),y=n(1),b=r(y),x=n(8),_=n(12),w={onDismiss:b.default.PropTypes.func,closeLabel:b.default.PropTypes.string},T={closeLabel:"Close alert"},C=function(t){function e(){return(0,f.default)(this,e),(0,p.default)(this,t.apply(this,arguments))}return(0,g.default)(e,t),e.prototype.renderDismissButton=function(t){return b.default.createElement("button",{type:"button",className:"close",onClick:t,"aria-hidden":"true",tabIndex:"-1"},b.default.createElement("span",null,"×"))},e.prototype.renderSrOnlyDismissButton=function(t,e){return b.default.createElement("button",{type:"button",className:"close sr-only",onClick:t},e)},e.prototype.render=function(){var t,e=this.props,n=e.onDismiss,r=e.closeLabel,o=e.className,i=e.children,a=(0,u.default)(e,["onDismiss","closeLabel","className","children"]),l=(0,x.splitBsProps)(a),c=l[0],f=l[1],d=!!n,p=(0,s.default)({},(0,x.getClassSet)(c),(t={},t[(0,x.prefix)(c,"dismissable")]=d,t));return b.default.createElement("div",(0,s.default)({},f,{role:"alert",className:(0,m.default)(o,p)}),d&&this.renderDismissButton(n),i,d&&this.renderSrOnlyDismissButton(n,r))},e}(b.default.Component);C.propTypes=w,C.defaultProps=T,e.default=(0,x.bsStyles)((0,i.default)(_.State),_.State.INFO,(0,x.bsClass)("alert",C)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b={pullRight:m.default.PropTypes.bool},x={pullRight:!1},_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.hasContent=function(t){var e=!1;return m.default.Children.forEach(t,function(t){e||(t||0===t)&&(e=!0)}),e},e.prototype.render=function(){var t=this.props,e=t.pullRight,n=t.className,r=t.children,o=(0,s.default)(t,["pullRight","className","children"]),a=(0,y.splitBsProps)(o),l=a[0],u=a[1],c=(0,i.default)({},(0,y.getClassSet)(l),{"pull-right":e,hidden:!this.hasContent(r)});return m.default.createElement("span",(0,i.default)({},u,{className:(0,g.default)(n,c)}),r)},e}(m.default.Component);_.propTypes=b,_.defaultProps=x,e.default=(0,y.bsClass)("badge",_),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(119),b=r(y),x=n(8),_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,x.splitBsProps)(n),o=r[0],a=r[1],l=(0,x.getClassSet)(o);return m.default.createElement("ol",(0,i.default)({},a,{role:"navigation","aria-label":"breadcrumbs",className:(0,g.default)(e,l)}))},e}(m.default.Component);_.Item=b.default,e.default=(0,x.bsClass)("breadcrumb",_),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(40),b=r(y),x=n(8),_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,x.splitBsProps)(n),o=r[0],a=r[1],l=(0,x.getClassSet)(o);return m.default.createElement("div",(0,i.default)({},a,{role:"toolbar",className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,x.bsClass)("btn-toolbar",(0,x.bsSizes)(b.default.SIZES,_)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(225),b=r(y),x=n(121),_=r(x),w=n(78),T=r(w),C=n(18),k=r(C),E=n(8),P=n(13),S=r(P),M={slide:m.default.PropTypes.bool,indicators:m.default.PropTypes.bool,interval:m.default.PropTypes.number,controls:m.default.PropTypes.bool,pauseOnHover:m.default.PropTypes.bool,wrap:m.default.PropTypes.bool,onSelect:m.default.PropTypes.func,onSlideEnd:m.default.PropTypes.func,activeIndex:m.default.PropTypes.number,defaultActiveIndex:m.default.PropTypes.number,direction:m.default.PropTypes.oneOf(["prev","next"]),prevIcon:m.default.PropTypes.node,prevLabel:m.default.PropTypes.string,nextIcon:m.default.PropTypes.node,nextLabel:m.default.PropTypes.string},N={slide:!0,interval:5e3,pauseOnHover:!0,wrap:!0,indicators:!0,controls:!0,prevIcon:m.default.createElement(T.default,{glyph:"chevron-left"}),prevLabel:"Previous",nextIcon:m.default.createElement(T.default,{glyph:"chevron-right"}),nextLabel:"Next"},A=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));o.handleMouseOver=o.handleMouseOver.bind(o),o.handleMouseOut=o.handleMouseOut.bind(o),o.handlePrev=o.handlePrev.bind(o),o.handleNext=o.handleNext.bind(o),o.handleItemAnimateOutEnd=o.handleItemAnimateOutEnd.bind(o);var i=n.defaultActiveIndex;return o.state={activeIndex:null!=i?i:0,previousActiveIndex:null,direction:null},o.isUnmounted=!1,o}return(0,p.default)(e,t),e.prototype.componentWillReceiveProps=function(t){var e=this.getActiveIndex();null!=t.activeIndex&&t.activeIndex!==e&&(clearTimeout(this.timeout),this.setState({previousActiveIndex:e,direction:null!=t.direction?t.direction:this.getDirection(e,t.activeIndex)}))},e.prototype.componentDidMount=function(){this.waitForNext()},e.prototype.componentWillUnmount=function(){clearTimeout(this.timeout),this.isUnmounted=!0},e.prototype.handleMouseOver=function(){this.props.pauseOnHover&&this.pause()},e.prototype.handleMouseOut=function(){this.isPaused&&this.play()},e.prototype.handlePrev=function(t){var e=this.getActiveIndex()-1;if(e<0){if(!this.props.wrap)return;e=S.default.count(this.props.children)-1}this.select(e,t,"prev")},e.prototype.handleNext=function(t){var e=this.getActiveIndex()+1,n=S.default.count(this.props.children);if(e>n-1){if(!this.props.wrap)return;e=0}this.select(e,t,"next")},e.prototype.handleItemAnimateOutEnd=function(){var t=this;this.setState({previousActiveIndex:null,direction:null},function(){t.waitForNext(),t.props.onSlideEnd&&t.props.onSlideEnd()})},e.prototype.getActiveIndex=function(){var t=this.props.activeIndex;return null!=t?t:this.state.activeIndex},e.prototype.getDirection=function(t,e){return t===e?null:t>e?"prev":"next"},e.prototype.select=function(t,e,n){if(clearTimeout(this.timeout),!this.isUnmounted){var r=this.getActiveIndex();n=n||this.getDirection(r,t);var o=this.props.onSelect;if(o&&(o.length>1?(e?(e.persist(),e.direction=n):e={direction:n},o(t,e)):o(t)),null==this.props.activeIndex&&t!==r){if(null!=this.state.previousActiveIndex)return;this.setState({activeIndex:t,previousActiveIndex:r,direction:n})}}},e.prototype.waitForNext=function(){var t=this.props,e=t.slide,n=t.interval,r=t.activeIndex;!this.isPaused&&e&&n&&null==r&&(this.timeout=setTimeout(this.handleNext,n))},e.prototype.pause=function(){this.isPaused=!0,clearTimeout(this.timeout)},e.prototype.play=function(){this.isPaused=!1,this.waitForNext()},e.prototype.renderIndicators=function(t,e,n){var r=this,o=[];return S.default.forEach(t,function(t,n){o.push(m.default.createElement("li",{key:n,className:n===e?"active":null,onClick:function(t){return r.select(n,t)}})," ")}),m.default.createElement("ol",{className:(0,E.prefix)(n,"indicators")},o)},e.prototype.renderControls=function(t){var e=t.wrap,n=t.children,r=t.activeIndex,o=t.prevIcon,i=t.nextIcon,a=t.bsProps,s=t.prevLabel,l=t.nextLabel,u=(0,E.prefix)(a,"control"),c=S.default.count(n);return[(e||0!==r)&&m.default.createElement(k.default,{key:"prev",className:(0,g.default)(u,"left"),onClick:this.handlePrev},o,s&&m.default.createElement("span",{className:"sr-only"},s)),(e||r!==c-1)&&m.default.createElement(k.default,{key:"next",className:(0,g.default)(u,"right"),onClick:this.handleNext},i,l&&m.default.createElement("span",{className:"sr-only"},l))]},e.prototype.render=function(){var t=this,e=this.props,n=e.slide,r=e.indicators,o=e.controls,a=e.wrap,l=e.prevIcon,u=e.prevLabel,c=e.nextIcon,f=e.nextLabel,d=e.className,p=e.children,h=(0,s.default)(e,["slide","indicators","controls","wrap","prevIcon","prevLabel","nextIcon","nextLabel","className","children"]),y=this.state,b=y.previousActiveIndex,x=y.direction,_=(0,E.splitBsPropsAndOmit)(h,["interval","pauseOnHover","onSelect","onSlideEnd","activeIndex","defaultActiveIndex","direction"]),w=_[0],T=_[1],C=this.getActiveIndex(),k=(0,i.default)({},(0,E.getClassSet)(w),{slide:n});return m.default.createElement("div",(0,i.default)({},T,{className:(0,g.default)(d,k),onMouseOver:this.handleMouseOver,onMouseOut:this.handleMouseOut}),r&&this.renderIndicators(p,C,w),m.default.createElement("div",{className:(0,E.prefix)(w,"inner")},S.default.map(p,function(e,r){var o=r===C,i=n&&r===b;return(0,v.cloneElement)(e,{active:o,index:r,animateOut:i,animateIn:o&&null!=b&&n,direction:x,onAnimateOutEnd:i?t.handleItemAnimateOutEnd:null})})),o&&this.renderControls({wrap:a,children:p,activeIndex:C,prevIcon:l,prevLabel:u,nextIcon:c,nextLabel:f,bsProps:w}))},e}(m.default.Component);A.propTypes=M,A.defaultProps=N,A.Caption=b.default,A.Item=_.default,e.default=(0,E.bsClass)("carousel",A),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("carousel-caption",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(15),b=(r(y),n(8)),x={inline:m.default.PropTypes.bool,disabled:m.default.PropTypes.bool,validationState:m.default.PropTypes.oneOf(["success","warning","error",null]),inputRef:m.default.PropTypes.func},_={inline:!1,disabled:!1},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.inline,n=t.disabled,r=t.validationState,o=t.inputRef,a=t.className,l=t.style,u=t.children,c=(0,s.default)(t,["inline","disabled","validationState","inputRef","className","style","children"]),f=(0,b.splitBsProps)(c),d=f[0],p=f[1],h=m.default.createElement("input",(0,i.default)({},p,{ref:o,type:"checkbox",disabled:n}));if(e){var v,y=(v={},v[(0,b.prefix)(d,"inline")]=!0,v.disabled=n,v);return m.default.createElement("label",{className:(0,g.default)(a,y),style:l},h,u)}var x=(0,i.default)({},(0,b.getClassSet)(d),{disabled:n});return r&&(x["has-"+r]=!0),m.default.createElement("div",{className:(0,g.default)(a,x),style:l},m.default.createElement("label",null,h,u))},e}(m.default.Component);w.propTypes=x,w.defaultProps=_,e.default=(0,b.bsClass)("checkbox",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_=n(136),w=r(_),T=n(12),C={componentClass:b.default,visibleXsBlock:m.default.PropTypes.bool,visibleSmBlock:m.default.PropTypes.bool,visibleMdBlock:m.default.PropTypes.bool,visibleLgBlock:m.default.PropTypes.bool},k={componentClass:"div"},E=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return T.DEVICE_SIZES.forEach(function(t){var e="visible"+(0,w.default)(t)+"Block";l[e]&&(u["visible-"+t+"-block"]=!0),delete l[e]}),m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);E.propTypes=C,E.defaultProps=k,e.default=(0,x.bsClass)("clearfix",E),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_=n(12),w={componentClass:b.default,xs:m.default.PropTypes.number,sm:m.default.PropTypes.number,md:m.default.PropTypes.number,lg:m.default.PropTypes.number,xsHidden:m.default.PropTypes.bool,smHidden:m.default.PropTypes.bool,mdHidden:m.default.PropTypes.bool,lgHidden:m.default.PropTypes.bool,xsOffset:m.default.PropTypes.number,smOffset:m.default.PropTypes.number,mdOffset:m.default.PropTypes.number,lgOffset:m.default.PropTypes.number,xsPush:m.default.PropTypes.number,smPush:m.default.PropTypes.number,mdPush:m.default.PropTypes.number,lgPush:m.default.PropTypes.number,xsPull:m.default.PropTypes.number,smPull:m.default.PropTypes.number,mdPull:m.default.PropTypes.number,lgPull:m.default.PropTypes.number},T={componentClass:"div"},C=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=[];return _.DEVICE_SIZES.forEach(function(t){function e(e,n){var r=""+t+e,o=l[r];null!=o&&u.push((0,x.prefix)(a,""+t+n+"-"+o)),delete l[r]}e("",""),e("Offset","-offset"),e("Push","-push"),e("Pull","-pull");var n=t+"Hidden";l[n]&&u.push("hidden-"+t),delete l[n]}),m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);C.propTypes=w,C.defaultProps=T,e.default=(0,x.bsClass)("col",C),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(15),b=(r(y),n(8)),x={htmlFor:m.default.PropTypes.string,srOnly:m.default.PropTypes.bool},_={srOnly:!1},w={$bs_formGroup:m.default.PropTypes.object},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.context.$bs_formGroup,e=t&&t.controlId,n=this.props,r=n.htmlFor,o=void 0===r?e:r,a=n.srOnly,l=n.className,u=(0,s.default)(n,["htmlFor","srOnly","className"]),c=(0,b.splitBsProps)(u),f=c[0],d=c[1],p=(0,i.default)({},(0,b.getClassSet)(f),{"sr-only":a});return m.default.createElement("label",(0,i.default)({},d,{htmlFor:o,className:(0,g.default)(l,p)}))},e}(m.default.Component);T.propTypes=x,T.defaultProps=_,T.contextTypes=w,e.default=(0,b.bsClass)("control-label",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(7),i=r(o),a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(5),p=r(d),h=n(1),g=r(h),v=n(48),m=r(v),y=n(50),b=r(y),x=(0,p.default)({},m.default.propTypes,{bsStyle:g.default.PropTypes.string,bsSize:g.default.PropTypes.string,title:g.default.PropTypes.node.isRequired,noCaret:g.default.PropTypes.bool,children:g.default.PropTypes.node}),_=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.bsSize,n=t.bsStyle,r=t.title,o=t.children,a=(0,i.default)(t,["bsSize","bsStyle","title","children"]),s=(0,b.default)(a,m.default.ControlledComponent),l=s[0],u=s[1];return g.default.createElement(m.default,(0,p.default)({},l,{bsSize:e,bsStyle:n}),g.default.createElement(m.default.Toggle,(0,p.default)({},u,{bsSize:e,bsStyle:n}),r),g.default.createElement(m.default.Menu,null,o))},e}(g.default.Component);_.propTypes=x,e.default=_,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(151),u=r(l),c=n(2),f=r(c),d=n(4),p=r(d),h=n(3),g=r(h),v=n(6),m=r(v),y=n(76),b=r(y),x=n(1),_=r(x),w=n(11),T=r(w),C=n(138),k=r(C),E=n(8),P=n(10),S=r(P),M=n(13),N=r(M),A={open:_.default.PropTypes.bool,pullRight:_.default.PropTypes.bool,onClose:_.default.PropTypes.func,labelledBy:_.default.PropTypes.oneOfType([_.default.PropTypes.string,_.default.PropTypes.number]),onSelect:_.default.PropTypes.func,rootCloseEvent:_.default.PropTypes.oneOf(["click","mousedown"])},O={bsRole:"menu",pullRight:!1},D=function(t){function e(n){(0,f.default)(this,e);var r=(0,p.default)(this,t.call(this,n));return r.handleKeyDown=r.handleKeyDown.bind(r),r}return(0,g.default)(e,t),e.prototype.handleKeyDown=function(t){switch(t.keyCode){case b.default.codes.down:this.focusNext(),t.preventDefault();break;case b.default.codes.up:this.focusPrevious(),t.preventDefault();break;case b.default.codes.esc:case b.default.codes.tab:this.props.onClose(t)}},e.prototype.getItemsAndActiveIndex=function(){var t=this.getFocusableMenuItems(),e=t.indexOf(document.activeElement);return{items:t,activeIndex:e}},e.prototype.getFocusableMenuItems=function(){var t=T.default.findDOMNode(this);return t?(0,u.default)(t.querySelectorAll('[tabIndex="-1"]')):[]},e.prototype.focusNext=function(){var t=this.getItemsAndActiveIndex(),e=t.items,n=t.activeIndex;if(0!==e.length){var r=n===e.length-1?0:n+1;e[r].focus()}},e.prototype.focusPrevious=function(){var t=this.getItemsAndActiveIndex(),e=t.items,n=t.activeIndex;if(0!==e.length){var r=0===n?e.length-1:n-1;e[r].focus()}},e.prototype.render=function(){var t,e=this,n=this.props,r=n.open,o=n.pullRight,a=n.onClose,l=n.labelledBy,u=n.onSelect,c=n.className,f=n.rootCloseEvent,d=n.children,p=(0,s.default)(n,["open","pullRight","onClose","labelledBy","onSelect","className","rootCloseEvent","children"]),h=(0,E.splitBsProps)(p),g=h[0],v=h[1],y=(0,i.default)({},(0,E.getClassSet)(g),(t={},t[(0,E.prefix)(g,"right")]=o,t));return _.default.createElement(k.default,{disabled:!r,onRootClose:a,event:f},_.default.createElement("ul",(0,i.default)({},v,{role:"menu",className:(0,m.default)(c,y),"aria-labelledby":l}),N.default.map(d,function(t){return _.default.cloneElement(t,{onKeyDown:(0,S.default)(t.props.onKeyDown,e.handleKeyDown),onSelect:(0,S.default)(t.props.onSelect,u)})})))},e}(_.default.Component);D.propTypes=A,D.defaultProps=O,e.default=(0,E.bsClass)("dropdown-menu",D),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={horizontal:m.default.PropTypes.bool,inline:m.default.PropTypes.bool,componentClass:b.default},w={horizontal:!1,inline:!1,componentClass:"form"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.horizontal,n=t.inline,r=t.componentClass,o=t.className,a=(0,s.default)(t,["horizontal","inline","componentClass","className"]),l=(0,x.splitBsProps)(a),u=l[0],c=l[1],f=[];return e&&f.push((0,x.prefix)(u,"horizontal")),n&&f.push((0,x.prefix)(u,"inline")),m.default.createElement(r,(0,i.default)({},c,{className:(0,g.default)(o,f)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("form",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(15),_=(r(x),n(234)),w=r(_),T=n(235),C=r(T),k=n(8),E={componentClass:b.default,type:m.default.PropTypes.string,id:m.default.PropTypes.string,inputRef:m.default.PropTypes.func},P={componentClass:"input"},S={$bs_formGroup:m.default.PropTypes.object},M=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.context.$bs_formGroup,e=t&&t.controlId,n=this.props,r=n.componentClass,o=n.type,a=n.id,l=void 0===a?e:a,u=n.inputRef,c=n.className,f=(0,s.default)(n,["componentClass","type","id","inputRef","className"]),d=(0,k.splitBsProps)(f),p=d[0],h=d[1],v=void 0;return"file"!==o&&(v=(0,k.getClassSet)(p)),m.default.createElement(r,(0,i.default)({},h,{type:o,id:l,ref:u,className:(0,g.default)(c,v)}))},e}(m.default.Component);M.propTypes=E,M.defaultProps=P,M.contextTypes=S,M.Feedback=w.default,M.Static=C.default,e.default=(0,k.bsClass)("form-control",M),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(7),i=r(o),a=n(5),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(78),b=r(y),x=n(8),_={bsRole:"feedback"},w={$bs_formGroup:m.default.PropTypes.object},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.getGlyph=function(t){switch(t){case"success":return"ok";case"warning":return"warning-sign";case"error":return"remove";default:return null}},e.prototype.renderDefaultFeedback=function(t,e,n,r){var o=this.getGlyph(t&&t.validationState);return o?m.default.createElement(b.default,(0,s.default)({},r,{glyph:o,className:(0,g.default)(e,n)})):null},e.prototype.render=function(){var t=this.props,e=t.className,n=t.children,r=(0,i.default)(t,["className","children"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);if(!n)return this.renderDefaultFeedback(this.context.$bs_formGroup,e,u,l);var c=m.default.Children.only(n);return m.default.cloneElement(c,(0,s.default)({},l,{className:(0,g.default)(c.props.className,e,u)}))},e}(m.default.Component);T.defaultProps=_,T.contextTypes=w,e.default=(0,x.bsClass)("form-control-feedback",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={componentClass:b.default},w={componentClass:"p"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("form-control-static",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=n(12),x=n(13),_=r(x),w={controlId:m.default.PropTypes.string,validationState:m.default.PropTypes.oneOf(["success","warning","error",null])},T={$bs_formGroup:m.default.PropTypes.object.isRequired},C=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.getChildContext=function(){var t=this.props,e=t.controlId,n=t.validationState;return{$bs_formGroup:{controlId:e,validationState:n}}},e.prototype.hasFeedback=function(t){var e=this;return _.default.some(t,function(t){return"feedback"===t.props.bsRole||t.props.children&&e.hasFeedback(t.props.children)})},e.prototype.render=function(){var t=this.props,e=t.validationState,n=t.className,r=t.children,o=(0,s.default)(t,["validationState","className","children"]),a=(0,y.splitBsPropsAndOmit)(o,["controlId"]),l=a[0],u=a[1],c=(0,i.default)({},(0,y.getClassSet)(l),{"has-feedback":this.hasFeedback(r)});return e&&(c["has-"+e]=!0),m.default.createElement("div",(0,i.default)({},u,{className:(0,g.default)(n,c)}),r)},e}(m.default.Component);C.propTypes=w,C.childContextTypes=T,e.default=(0,y.bsClass)("form-group",(0,y.bsSizes)([b.Size.LARGE,b.Size.SMALL],C)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("span",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("help-block",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b={responsive:m.default.PropTypes.bool,rounded:m.default.PropTypes.bool,circle:m.default.PropTypes.bool,thumbnail:m.default.PropTypes.bool},x={responsive:!1,rounded:!1,circle:!1,thumbnail:!1},_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.responsive,r=e.rounded,o=e.circle,a=e.thumbnail,l=e.className,u=(0,s.default)(e,["responsive","rounded","circle","thumbnail","className"]),c=(0,y.splitBsProps)(u),f=c[0],d=c[1],p=(t={},t[(0,y.prefix)(f,"responsive")]=n,t[(0,y.prefix)(f,"rounded")]=r,t[(0,y.prefix)(f,"circle")]=o,t[(0,y.prefix)(f,"thumbnail")]=a,t);return m.default.createElement("img",(0,i.default)({},d,{className:(0,g.default)(l,p)}))},e}(m.default.Component);_.propTypes=b,_.defaultProps=x,e.default=(0,y.bsClass)("img",_),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(240),b=r(y),x=n(241),_=r(x),w=n(8),T=n(12),C=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,
s.default)(t,["className"]),r=(0,w.splitBsProps)(n),o=r[0],a=r[1],l=(0,w.getClassSet)(o);return m.default.createElement("span",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);C.Addon=b.default,C.Button=_.default,e.default=(0,w.bsClass)("input-group",(0,w.bsSizes)([T.Size.LARGE,T.Size.SMALL],C)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("span",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("input-group-addon",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("span",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("input-group-btn",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(1),g=r(h),v=n(6),m=r(v),y=n(9),b=r(y),x=n(8),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return g.default.createElement(e,(0,i.default)({},l,{className:(0,m.default)(n,u)}))},e}(g.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("jumbotron",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(26),i=r(o),a=n(5),s=r(a),l=n(7),u=r(l),c=n(2),f=r(c),d=n(4),p=r(d),h=n(3),g=r(h),v=n(6),m=r(v),y=n(1),b=r(y),x=n(8),_=n(12),w=function(t){function e(){return(0,f.default)(this,e),(0,p.default)(this,t.apply(this,arguments))}return(0,g.default)(e,t),e.prototype.hasContent=function(t){var e=!1;return b.default.Children.forEach(t,function(t){e||(t||0===t)&&(e=!0)}),e},e.prototype.render=function(){var t=this.props,e=t.className,n=t.children,r=(0,u.default)(t,["className","children"]),o=(0,x.splitBsProps)(r),i=o[0],a=o[1],l=(0,s.default)({},(0,x.getClassSet)(i),{hidden:!this.hasContent(n)});return b.default.createElement("span",(0,s.default)({},a,{className:(0,m.default)(e,l)}),n)},e}(b.default.Component);e.default=(0,x.bsClass)("label",(0,x.bsStyles)([].concat((0,i.default)(_.State),[_.Style.DEFAULT,_.Style.PRIMARY]),_.Style.DEFAULT,w)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){return t?k.default.some(t,function(t){return t.type!==w.default||t.props.href||t.props.onClick})?"div":"ul":"div"}e.__esModule=!0;var i=n(5),a=r(i),s=n(7),l=r(s),u=n(2),c=r(u),f=n(4),d=r(f),p=n(3),h=r(p),g=n(6),v=r(g),m=n(1),y=r(m),b=n(9),x=r(b),_=n(124),w=r(_),T=n(8),C=n(13),k=r(C),E={componentClass:x.default},P=function(t){function e(){return(0,c.default)(this,e),(0,d.default)(this,t.apply(this,arguments))}return(0,h.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.children,n=t.componentClass,r=void 0===n?o(e):n,i=t.className,s=(0,l.default)(t,["children","componentClass","className"]),u=(0,T.splitBsProps)(s),c=u[0],f=u[1],d=(0,T.getClassSet)(c),p="ul"===r&&k.default.every(e,function(t){return t.type===w.default});return y.default.createElement(r,(0,a.default)({},f,{className:(0,v.default)(i,d)}),p?k.default.map(e,function(t){return(0,m.cloneElement)(t,{listItem:!0})}):e)},e}(y.default.Component);P.propTypes=E,e.default=(0,T.bsClass)("list-group",P),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("media-body",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={componentClass:b.default},w={componentClass:"h4"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("media-heading",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(79),b=r(y),x=n(8),_={align:m.default.PropTypes.oneOf(["top","middle","bottom"])},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.align,n=t.className,r=(0,s.default)(t,["align","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return e&&(u[(0,x.prefix)(b.default.defaultProps,e)]=!0),m.default.createElement("div",(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);w.propTypes=_,e.default=(0,x.bsClass)("media-left",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("ul",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("media-list",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("li",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("media",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(79),b=r(y),x=n(8),_={align:m.default.PropTypes.oneOf(["top","middle","bottom"])},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.align,n=t.className,r=(0,s.default)(t,["align","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return e&&(u[(0,x.prefix)(b.default.defaultProps,e)]=!0),m.default.createElement("div",(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);w.propTypes=_,e.default=(0,x.bsClass)("media-right",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(51),b=r(y),x=n(18),_=r(x),w=n(8),T=n(10),C=r(T),k={active:m.default.PropTypes.bool,disabled:m.default.PropTypes.bool,divider:(0,b.default)(m.default.PropTypes.bool,function(t){var e=t.divider,n=t.children;return e&&n?new Error("Children will not be rendered for dividers"):null}),eventKey:m.default.PropTypes.any,header:m.default.PropTypes.bool,href:m.default.PropTypes.string,onClick:m.default.PropTypes.func,onSelect:m.default.PropTypes.func},E={divider:!1,disabled:!1,header:!1},P=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o}return(0,p.default)(e,t),e.prototype.handleClick=function(t){var e=this.props,n=e.href,r=e.disabled,o=e.onSelect,i=e.eventKey;n&&!r||t.preventDefault(),r||o&&o(i,t)},e.prototype.render=function(){var t=this.props,e=t.active,n=t.disabled,r=t.divider,o=t.header,a=t.onClick,l=t.className,u=t.style,c=(0,s.default)(t,["active","disabled","divider","header","onClick","className","style"]),f=(0,w.splitBsPropsAndOmit)(c,["eventKey","onSelect"]),d=f[0],p=f[1];return r?(p.children=void 0,m.default.createElement("li",(0,i.default)({},p,{role:"separator",className:(0,g.default)(l,"divider"),style:u}))):o?m.default.createElement("li",(0,i.default)({},p,{role:"heading",className:(0,g.default)(l,(0,w.prefix)(d,"header")),style:u})):m.default.createElement("li",{role:"presentation",className:(0,g.default)(l,{active:e,disabled:n}),style:u},m.default.createElement(_.default,(0,i.default)({},p,{role:"menuitem",tabIndex:"-1",onClick:(0,C.default)(a,this.handleClick)})))},e}(m.default.Component);P.propTypes=k,P.defaultProps=E,e.default=(0,w.bsClass)("dropdown",P),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(7),i=r(o),a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(5),p=r(d),h=n(6),g=r(h),v=n(208),m=r(v),y=n(31),b=r(y),x=n(25),_=r(x),w=n(117),T=r(w),C=n(1),k=r(C),E=n(11),P=r(E),S=n(284),M=r(S),N=n(141),A=r(N),O=n(9),D=r(O),I=n(49),R=r(I),L=n(125),F=r(L),j=n(253),B=r(j),U=n(126),H=r(U),z=n(127),W=r(z),q=n(128),V=r(q),K=n(8),Y=n(10),G=r(Y),X=n(50),$=r(X),Z=n(12),J=(0,p.default)({},M.default.propTypes,B.default.propTypes,{backdrop:k.default.PropTypes.oneOf(["static",!0,!1]),keyboard:k.default.PropTypes.bool,animation:k.default.PropTypes.bool,dialogComponentClass:D.default,autoFocus:k.default.PropTypes.bool,enforceFocus:k.default.PropTypes.bool,show:k.default.PropTypes.bool,onHide:k.default.PropTypes.func,onEnter:k.default.PropTypes.func,onEntering:k.default.PropTypes.func,onEntered:k.default.PropTypes.func,onExit:k.default.PropTypes.func,onExiting:k.default.PropTypes.func,onExited:k.default.PropTypes.func,container:M.default.propTypes.container}),Q=(0,p.default)({},M.default.defaultProps,{animation:!0,dialogComponentClass:B.default}),tt={$bs_modal:k.default.PropTypes.shape({onHide:k.default.PropTypes.func})},et=function(t){function e(n,r){(0,s.default)(this,e);var o=(0,u.default)(this,t.call(this,n,r));return o.handleEntering=o.handleEntering.bind(o),o.handleExited=o.handleExited.bind(o),o.handleWindowResize=o.handleWindowResize.bind(o),o.handleDialogClick=o.handleDialogClick.bind(o),o.state={style:{}},o}return(0,f.default)(e,t),e.prototype.getChildContext=function(){return{$bs_modal:{onHide:this.props.onHide}}},e.prototype.componentWillUnmount=function(){this.handleExited()},e.prototype.handleEntering=function(){m.default.on(window,"resize",this.handleWindowResize),this.updateStyle()},e.prototype.handleExited=function(){m.default.off(window,"resize",this.handleWindowResize)},e.prototype.handleWindowResize=function(){this.updateStyle()},e.prototype.handleDialogClick=function(t){t.target===t.currentTarget&&this.props.onHide()},e.prototype.updateStyle=function(){if(_.default){var t=this._modal.getDialogElement(),e=t.scrollHeight,n=(0,b.default)(t),r=(0,A.default)(P.default.findDOMNode(this.props.container||n.body)),o=e>n.documentElement.clientHeight;this.setState({style:{paddingRight:r&&!o?(0,T.default)():void 0,paddingLeft:!r&&o?(0,T.default)():void 0}})}},e.prototype.render=function(){var t=this,n=this.props,r=n.backdrop,o=n.animation,a=n.show,s=n.dialogComponentClass,l=n.className,u=n.style,c=n.children,f=n.onEntering,d=n.onExited,h=(0,i.default)(n,["backdrop","animation","show","dialogComponentClass","className","style","children","onEntering","onExited"]),v=(0,$.default)(h,M.default),m=v[0],y=v[1],b=a&&!o&&"in";return k.default.createElement(M.default,(0,p.default)({},m,{ref:function(e){t._modal=e},show:a,onEntering:(0,G.default)(f,this.handleEntering),onExited:(0,G.default)(d,this.handleExited),backdrop:r,backdropClassName:(0,g.default)((0,K.prefix)(h,"backdrop"),b),containerClassName:(0,K.prefix)(h,"open"),transition:o?R.default:void 0,dialogTransitionTimeout:e.TRANSITION_DURATION,backdropTransitionTimeout:e.BACKDROP_TRANSITION_DURATION}),k.default.createElement(s,(0,p.default)({},y,{style:(0,p.default)({},this.state.style,u),className:(0,g.default)(l,b),onClick:r===!0?this.handleDialogClick:null}),c))},e}(k.default.Component);et.propTypes=J,et.defaultProps=Q,et.childContextTypes=tt,et.Body=F.default,et.Header=W.default,et.Title=V.default,et.Footer=H.default,et.Dialog=B.default,et.TRANSITION_DURATION=300,et.BACKDROP_TRANSITION_DURATION=150,e.default=(0,K.bsClass)("modal",(0,K.bsSizes)([Z.Size.LARGE,Z.Size.SMALL],et)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=n(12),x={dialogClassName:m.default.PropTypes.string},_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.dialogClassName,r=e.className,o=e.style,a=e.children,l=(0,s.default)(e,["dialogClassName","className","style","children"]),u=(0,y.splitBsProps)(l),c=u[0],f=u[1],d=(0,y.prefix)(c),p=(0,i.default)({display:"block"},o),h=(0,i.default)({},(0,y.getClassSet)(c),(t={},t[d]=!1,t[(0,y.prefix)(c,"dialog")]=!0,t));return m.default.createElement("div",(0,i.default)({},f,{tabIndex:"-1",role:"dialog",style:p,className:(0,g.default)(r,d)}),m.default.createElement("div",{className:(0,g.default)(n,h)},m.default.createElement("div",{className:(0,y.prefix)(c,"content"),role:"document"},a)))},e}(m.default.Component);_.propTypes=x,e.default=(0,y.bsClass)("modal",(0,y.bsSizes)([b.Size.LARGE,b.Size.SMALL],_)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(7),i=r(o),a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(5),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(48),b=r(y),x=n(50),_=r(x),w=n(13),T=r(w),C=(0,p.default)({},b.default.propTypes,{title:m.default.PropTypes.node.isRequired,noCaret:m.default.PropTypes.bool,active:m.default.PropTypes.bool,children:m.default.PropTypes.node}),k=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.isActive=function(t,e,n){var r=t.props,o=this;return!!(r.active||null!=e&&r.eventKey===e||n&&r.href===n)||!!T.default.some(r.children,function(t){return o.isActive(t,e,n)})||r.active},e.prototype.render=function(){var t=this,e=this.props,n=e.title,r=e.activeKey,o=e.activeHref,a=e.className,s=e.style,l=e.children,u=(0,i.default)(e,["title","activeKey","activeHref","className","style","children"]),c=this.isActive(this,r,o);delete u.active,delete u.eventKey;var f=(0,_.default)(u,b.default.ControlledComponent),d=f[0],h=f[1];return m.default.createElement(b.default,(0,p.default)({},d,{componentClass:"li",className:(0,g.default)(a,{active:c}),style:s}),m.default.createElement(b.default.Toggle,(0,p.default)({},h,{useAnchor:!0}),n),m.default.createElement(b.default.Menu,null,T.default.map(l,function(e){return m.default.cloneElement(e,{active:t.isActive(e,r,o)})})))},e}(m.default.Component);k.propTypes=C,e.default=k,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r=function(t,n){var r=n.$bs_navbar,o=void 0===r?{bsClass:"navbar"}:r,i=t.componentClass,s=t.className,u=t.pullRight,c=t.pullLeft,f=(0,l.default)(t,["componentClass","className","pullRight","pullLeft"]);return y.default.createElement(i,(0,a.default)({},f,{className:(0,v.default)(s,(0,D.prefix)(o,e),u&&(0,D.prefix)(o,"right"),c&&(0,D.prefix)(o,"left"))}))};return r.displayName=n,r.propTypes={componentClass:x.default,pullRight:y.default.PropTypes.bool,pullLeft:y.default.PropTypes.bool},r.defaultProps={componentClass:t,pullRight:!1,pullLeft:!1},r.contextTypes={$bs_navbar:m.PropTypes.shape({bsClass:m.PropTypes.string})},r}e.__esModule=!0;var i=n(5),a=r(i),s=n(7),l=r(s),u=n(2),c=r(u),f=n(4),d=r(f),p=n(3),h=r(p),g=n(6),v=r(g),m=n(1),y=r(m),b=n(9),x=r(b),_=n(55),w=r(_),T=n(123),C=r(T),k=n(131),E=r(k),P=n(256),S=r(P),M=n(257),N=r(M),A=n(258),O=r(A),D=n(8),I=n(12),R=n(10),L=r(R),F={fixedTop:y.default.PropTypes.bool,fixedBottom:y.default.PropTypes.bool,staticTop:y.default.PropTypes.bool,inverse:y.default.PropTypes.bool,fluid:y.default.PropTypes.bool,componentClass:x.default,onToggle:y.default.PropTypes.func,onSelect:y.default.PropTypes.func,collapseOnSelect:y.default.PropTypes.bool,expanded:y.default.PropTypes.bool,role:y.default.PropTypes.string},j={componentClass:"nav",fixedTop:!1,fixedBottom:!1,staticTop:!1,inverse:!1,fluid:!1,collapseOnSelect:!1},B={$bs_navbar:m.PropTypes.shape({bsClass:m.PropTypes.string,expanded:m.PropTypes.bool,onToggle:m.PropTypes.func.isRequired,onSelect:m.PropTypes.func})},U=function(t){function e(n,r){(0,c.default)(this,e);var o=(0,d.default)(this,t.call(this,n,r));return o.handleToggle=o.handleToggle.bind(o),o.handleCollapse=o.handleCollapse.bind(o),o}return(0,h.default)(e,t),e.prototype.getChildContext=function(){var t=this.props,e=t.bsClass,n=t.expanded,r=t.onSelect,o=t.collapseOnSelect;return{$bs_navbar:{bsClass:e,expanded:n,onToggle:this.handleToggle,onSelect:(0,L.default)(r,o?this.handleCollapse:null)}}},e.prototype.handleCollapse=function(){var t=this.props,e=t.onToggle,n=t.expanded;n&&e(!1)},e.prototype.handleToggle=function(){var t=this.props,e=t.onToggle,n=t.expanded;e(!n)},e.prototype.render=function(){var t,e=this.props,n=e.componentClass,r=e.fixedTop,o=e.fixedBottom,i=e.staticTop,s=e.inverse,u=e.fluid,c=e.className,f=e.children,d=(0,l.default)(e,["componentClass","fixedTop","fixedBottom","staticTop","inverse","fluid","className","children"]),p=(0,D.splitBsPropsAndOmit)(d,["expanded","onToggle","onSelect","collapseOnSelect"]),h=p[0],g=p[1];void 0===g.role&&"nav"!==n&&(g.role="navigation"),s&&(h.bsStyle=I.Style.INVERSE);var m=(0,a.default)({},(0,D.getClassSet)(h),(t={},t[(0,D.prefix)(h,"fixed-top")]=r,t[(0,D.prefix)(h,"fixed-bottom")]=o,t[(0,D.prefix)(h,"static-top")]=i,t));return y.default.createElement(n,(0,a.default)({},g,{className:(0,v.default)(c,m)}),y.default.createElement(C.default,{fluid:u},f))},e}(y.default.Component);U.propTypes=F,U.defaultProps=j,U.childContextTypes=B,(0,D.bsClass)("navbar",U);var H=(0,w.default)(U,{expanded:"onToggle"});H.Brand=E.default,H.Header=N.default,H.Toggle=O.default,H.Collapse=S.default,H.Form=o("div","form","NavbarForm"),H.Text=o("p","text","NavbarText"),H.Link=o("a","link","NavbarLink"),e.default=(0,D.bsStyles)([I.Style.DEFAULT,I.Style.INVERSE],I.Style.DEFAULT,H),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(1),g=r(h),v=n(77),m=r(v),y=n(8),b={$bs_navbar:h.PropTypes.shape({bsClass:h.PropTypes.string,expanded:h.PropTypes.bool})},x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.children,n=(0,s.default)(t,["children"]),r=this.context.$bs_navbar||{bsClass:"navbar"},o=(0,y.prefix)(r,"collapse");return g.default.createElement(m.default,(0,i.default)({in:r.expanded},n),g.default.createElement("div",{className:o},e))},e}(g.default.Component);x.contextTypes=b,e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b={$bs_navbar:m.default.PropTypes.shape({bsClass:m.default.PropTypes.string})},x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=this.context.$bs_navbar||{bsClass:"navbar"},o=(0,y.prefix)(r,"header");return m.default.createElement("div",(0,i.default)({},n,{className:(0,g.default)(e,o)}))},e}(m.default.Component);x.contextTypes=b,e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=n(10),x=r(b),_={onClick:v.PropTypes.func,children:v.PropTypes.node},w={$bs_navbar:v.PropTypes.shape({bsClass:v.PropTypes.string,expanded:v.PropTypes.bool,onToggle:v.PropTypes.func.isRequired})},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.onClick,n=t.className,r=t.children,o=(0,s.default)(t,["onClick","className","children"]),a=this.context.$bs_navbar||{bsClass:"navbar"},l=(0,i.default)({type:"button"},o,{onClick:(0,x.default)(e,a.onToggle),className:(0,g.default)(n,(0,y.prefix)(a,"toggle"),!a.expanded&&"collapsed")});return r?m.default.createElement("button",l,r):m.default.createElement("button",l,m.default.createElement("span",{className:"sr-only"},"Toggle navigation"),m.default.createElement("span",{className:"icon-bar"}),m.default.createElement("span",{className:"icon-bar"}),m.default.createElement("span",{className:"icon-bar"}))},e}(m.default.Component);T.propTypes=_,T.contextTypes=w,e.default=T,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){return Array.isArray(e)?e.indexOf(t)>=0:t===e}e.__esModule=!0;var i=n(7),a=r(i),s=n(2),l=r(s),u=n(4),c=r(u),f=n(3),d=r(f),p=n(5),h=r(p),g=n(32),v=r(g),m=n(1),y=r(m),b=n(11),x=r(b),_=n(15),w=(r(_),n(132)),T=r(w),C=n(10),k=r(C),E=y.default.PropTypes.oneOf(["click","hover","focus"]),P=(0,h.default)({},T.default.propTypes,{trigger:y.default.PropTypes.oneOfType([E,y.default.PropTypes.arrayOf(E)]),delay:y.default.PropTypes.number,delayShow:y.default.PropTypes.number,delayHide:y.default.PropTypes.number,defaultOverlayShown:y.default.PropTypes.bool,overlay:y.default.PropTypes.node.isRequired,onBlur:y.default.PropTypes.func,onClick:y.default.PropTypes.func,onFocus:y.default.PropTypes.func,onMouseOut:y.default.PropTypes.func,onMouseOver:y.default.PropTypes.func,target:y.default.PropTypes.oneOf([null]),onHide:y.default.PropTypes.oneOf([null]),show:y.default.PropTypes.oneOf([null])}),S={defaultOverlayShown:!1,trigger:["hover","focus"]},M=function(t){function e(n,r){(0,l.default)(this,e);var o=(0,c.default)(this,t.call(this,n,r));return o.handleToggle=o.handleToggle.bind(o),o.handleDelayedShow=o.handleDelayedShow.bind(o),o.handleDelayedHide=o.handleDelayedHide.bind(o),o.handleHide=o.handleHide.bind(o),o.handleMouseOver=function(t){return o.handleMouseOverOut(o.handleDelayedShow,t)},o.handleMouseOut=function(t){return o.handleMouseOverOut(o.handleDelayedHide,t)},o._mountNode=null,o.state={show:n.defaultOverlayShown},o}return(0,d.default)(e,t),e.prototype.componentDidMount=function(){this._mountNode=document.createElement("div"),this.renderOverlay()},e.prototype.componentDidUpdate=function(){this.renderOverlay()},e.prototype.componentWillUnmount=function(){x.default.unmountComponentAtNode(this._mountNode),this._mountNode=null,clearTimeout(this._hoverShowDelay),clearTimeout(this._hoverHideDelay)},e.prototype.handleToggle=function(){this.state.show?this.hide():this.show()},e.prototype.handleDelayedShow=function(){var t=this;if(null!=this._hoverHideDelay)return clearTimeout(this._hoverHideDelay),void(this._hoverHideDelay=null);if(!this.state.show&&null==this._hoverShowDelay){var e=null!=this.props.delayShow?this.props.delayShow:this.props.delay;return e?void(this._hoverShowDelay=setTimeout(function(){t._hoverShowDelay=null,t.show()},e)):void this.show()}},e.prototype.handleDelayedHide=function(){var t=this;if(null!=this._hoverShowDelay)return clearTimeout(this._hoverShowDelay),void(this._hoverShowDelay=null);if(this.state.show&&null==this._hoverHideDelay){var e=null!=this.props.delayHide?this.props.delayHide:this.props.delay;return e?void(this._hoverHideDelay=setTimeout(function(){t._hoverHideDelay=null,t.hide()},e)):void this.hide()}},e.prototype.handleMouseOverOut=function(t,e){var n=e.currentTarget,r=e.relatedTarget||e.nativeEvent.toElement;r&&(r===n||(0,v.default)(n,r))||t(e)},e.prototype.handleHide=function(){this.hide()},e.prototype.show=function(){this.setState({show:!0})},e.prototype.hide=function(){this.setState({show:!1})},e.prototype.makeOverlay=function(t,e){return y.default.createElement(T.default,(0,h.default)({},e,{show:this.state.show,onHide:this.handleHide,target:this}),t)},e.prototype.renderOverlay=function(){x.default.unstable_renderSubtreeIntoContainer(this,this._overlay,this._mountNode)},e.prototype.render=function(){var t=this.props,e=t.trigger,n=t.overlay,r=t.children,i=t.onBlur,s=t.onClick,l=t.onFocus,u=t.onMouseOut,c=t.onMouseOver,f=(0,a.default)(t,["trigger","overlay","children","onBlur","onClick","onFocus","onMouseOut","onMouseOver"]);delete f.delay,delete f.delayShow,delete f.delayHide,delete f.defaultOverlayShown;var d=y.default.Children.only(r),p=d.props,h={"aria-describedby":n.props.id};return h.onClick=(0,k.default)(p.onClick,s),o("click",e)&&(h.onClick=(0,k.default)(h.onClick,this.handleToggle)),o("hover",e)&&(h.onMouseOver=(0,k.default)(p.onMouseOver,c,this.handleMouseOver),h.onMouseOut=(0,k.default)(p.onMouseOut,u,this.handleMouseOut)),o("focus",e)&&(h.onFocus=(0,k.default)(p.onFocus,l,this.handleDelayedShow),h.onBlur=(0,k.default)(p.onBlur,i,this.handleDelayedHide)),this._overlay=this.makeOverlay(n,f),(0,m.cloneElement)(d,h)},e}(y.default.Component);M.propTypes=P,M.defaultProps=S,e.default=M,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=t.children,r=(0,s.default)(t,["className","children"]),o=(0,y.splitBsProps)(r),a=o[0],l=o[1],u=(0,y.getClassSet)(a);return m.default.createElement("div",(0,i.default)({},l,{className:(0,g.default)(e,u)}),m.default.createElement("h1",null,n))},e}(m.default.Component);e.default=(0,y.bsClass)("page-header",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(133),i=r(o),a=n(281),s=r(a);e.default=s.default.wrapper(i.default,"`<PageItem>`","`<Pager.Item>`"),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(133),b=r(y),x=n(8),_=n(10),w=r(_),T=n(13),C=r(T),k={onSelect:m.default.PropTypes.func},E=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.onSelect,n=t.className,r=t.children,o=(0,s.default)(t,["onSelect","className","children"]),a=(0,x.splitBsProps)(o),l=a[0],u=a[1],c=(0,x.getClassSet)(l);return m.default.createElement("ul",(0,i.default)({},u,{className:(0,g.default)(n,c)}),C.default.map(r,function(t){return(0,v.cloneElement)(t,{onSelect:(0,w.default)(t.props.onSelect,e)})}))},e}(m.default.Component);E.propTypes=k,E.Item=b.default,e.default=(0,x.bsClass)("pager",E),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(7),i=r(o),a=n(5),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(264),_=r(x),w=n(8),T={activePage:m.default.PropTypes.number,items:m.default.PropTypes.number,maxButtons:m.default.PropTypes.number,boundaryLinks:m.default.PropTypes.bool,ellipsis:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),first:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),last:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),prev:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),next:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),onSelect:m.default.PropTypes.func,buttonComponentClass:b.default},C={activePage:1,items:1,maxButtons:0,first:!1,last:!1,prev:!1,next:!1,ellipsis:!0,boundaryLinks:!1},k=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.renderPageButtons=function(t,e,n,r,o,i){var a=[],l=void 0,u=void 0,c=void 0;if(n){var f=t-parseInt(n/2,10);l=Math.max(f,1),c=e>=l+n,c?u=l+n-1:(u=e,l=e-n+1,l<1&&(l=1))}else l=1,u=e;for(var d=l;d<=u;d++)a.push(m.default.createElement(_.default,(0,s.default)({},i,{key:d,eventKey:d,active:d===t}),d));return r&&o&&1!==l&&(a.unshift(m.default.createElement(_.default,{key:"ellipsisFirst",disabled:!0,componentClass:i.componentClass},m.default.createElement("span",{"aria-label":"More"},o===!0?"…":o))),a.unshift(m.default.createElement(_.default,(0,s.default)({},i,{key:1,eventKey:1,active:!1}),"1"))),n&&c&&o&&(a.push(m.default.createElement(_.default,{key:"ellipsis",disabled:!0,componentClass:i.componentClass},m.default.createElement("span",{"aria-label":"More"},o===!0?"…":o))),r&&u!==e&&a.push(m.default.createElement(_.default,(0,s.default)({},i,{key:e,eventKey:e,active:!1}),e))),a},e.prototype.render=function(){var t=this.props,e=t.activePage,n=t.items,r=t.maxButtons,o=t.boundaryLinks,a=t.ellipsis,l=t.first,u=t.last,c=t.prev,f=t.next,d=t.onSelect,p=t.buttonComponentClass,h=t.className,v=(0,i.default)(t,["activePage","items","maxButtons","boundaryLinks","ellipsis","first","last","prev","next","onSelect","buttonComponentClass","className"]),y=(0,
w.splitBsProps)(v),b=y[0],x=y[1],T=(0,w.getClassSet)(b),C={onSelect:d,componentClass:p};return m.default.createElement("ul",(0,s.default)({},x,{className:(0,g.default)(h,T)}),l&&m.default.createElement(_.default,(0,s.default)({},C,{eventKey:1,disabled:1===e}),m.default.createElement("span",{"aria-label":"First"},l===!0?"«":l)),c&&m.default.createElement(_.default,(0,s.default)({},C,{eventKey:e-1,disabled:1===e}),m.default.createElement("span",{"aria-label":"Previous"},c===!0?"‹":c)),this.renderPageButtons(e,n,r,o,a,C),f&&m.default.createElement(_.default,(0,s.default)({},C,{eventKey:e+1,disabled:e>=n}),m.default.createElement("span",{"aria-label":"Next"},f===!0?"›":f)),u&&m.default.createElement(_.default,(0,s.default)({},C,{eventKey:n,disabled:e>=n}),m.default.createElement("span",{"aria-label":"Last"},u===!0?"»":u)))},e}(m.default.Component);k.propTypes=T,k.defaultProps=C,e.default=(0,w.bsClass)("pagination",k),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(18),_=r(x),w=n(10),T=r(w),C={componentClass:b.default,className:m.default.PropTypes.string,eventKey:m.default.PropTypes.any,onSelect:m.default.PropTypes.func,disabled:m.default.PropTypes.bool,active:m.default.PropTypes.bool,onClick:m.default.PropTypes.func},k={componentClass:_.default,active:!1,disabled:!1},E=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o}return(0,p.default)(e,t),e.prototype.handleClick=function(t){var e=this.props,n=e.disabled,r=e.onSelect,o=e.eventKey;n||r&&r(o,t)},e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.active,r=t.disabled,o=t.onClick,a=t.className,l=t.style,u=(0,s.default)(t,["componentClass","active","disabled","onClick","className","style"]);return e===_.default&&delete u.eventKey,delete u.onSelect,m.default.createElement("li",{className:(0,g.default)(a,{active:n,disabled:r}),style:l},m.default.createElement(e,(0,i.default)({},u,{disabled:r,onClick:(0,T.default)(o,this.handleClick)})))},e}(m.default.Component);E.propTypes=C,E.defaultProps=k,e.default=E,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(26),i=r(o),a=n(7),s=r(a),l=n(5),u=r(l),c=n(2),f=r(c),d=n(4),p=r(d),h=n(3),g=r(h),v=n(6),m=r(v),y=n(1),b=r(y),x=n(77),_=r(x),w=n(8),T=n(12),C={collapsible:b.default.PropTypes.bool,onSelect:b.default.PropTypes.func,header:b.default.PropTypes.node,id:b.default.PropTypes.oneOfType([b.default.PropTypes.string,b.default.PropTypes.number]),footer:b.default.PropTypes.node,defaultExpanded:b.default.PropTypes.bool,expanded:b.default.PropTypes.bool,eventKey:b.default.PropTypes.any,headerRole:b.default.PropTypes.string,panelRole:b.default.PropTypes.string,onEnter:b.default.PropTypes.func,onEntering:b.default.PropTypes.func,onEntered:b.default.PropTypes.func,onExit:b.default.PropTypes.func,onExiting:b.default.PropTypes.func,onExited:b.default.PropTypes.func},k={defaultExpanded:!1},E=function(t){function e(n,r){(0,f.default)(this,e);var o=(0,p.default)(this,t.call(this,n,r));return o.handleClickTitle=o.handleClickTitle.bind(o),o.state={expanded:o.props.defaultExpanded},o}return(0,g.default)(e,t),e.prototype.handleClickTitle=function(t){t.persist(),t.selected=!0,this.props.onSelect?this.props.onSelect(this.props.eventKey,t):t.preventDefault(),t.selected&&this.setState({expanded:!this.state.expanded})},e.prototype.renderHeader=function(t,e,n,r,o,i){var a=(0,w.prefix)(i,"title");return t?b.default.isValidElement(e)?(0,y.cloneElement)(e,{className:(0,m.default)(e.props.className,a),children:this.renderAnchor(e.props.children,n,r,o)}):b.default.createElement("h4",{role:"presentation",className:a},this.renderAnchor(e,n,r,o)):b.default.isValidElement(e)?(0,y.cloneElement)(e,{className:(0,m.default)(e.props.className,a)}):e},e.prototype.renderAnchor=function(t,e,n,r){return b.default.createElement("a",{role:n,href:e&&"#"+e,onClick:this.handleClickTitle,"aria-controls":e,"aria-expanded":r,"aria-selected":r,className:r?null:"collapsed"},t)},e.prototype.renderCollapsibleBody=function(t,e,n,r,o,i){return b.default.createElement(_.default,(0,u.default)({in:e},i),b.default.createElement("div",{id:t,role:n,className:(0,w.prefix)(o,"collapse"),"aria-hidden":!e},this.renderBody(r,o)))},e.prototype.renderBody=function(t,e){function n(){o.length&&(r.push(b.default.createElement("div",{key:r.length,className:i},o)),o=[])}var r=[],o=[],i=(0,w.prefix)(e,"body");return b.default.Children.toArray(t).forEach(function(t){return b.default.isValidElement(t)&&t.props.fill?(n(),void r.push((0,y.cloneElement)(t,{fill:void 0}))):void o.push(t)}),n(),r},e.prototype.render=function(){var t=this.props,e=t.collapsible,n=t.header,r=t.id,o=t.footer,i=t.expanded,a=t.headerRole,l=t.panelRole,c=t.className,f=t.children,d=t.onEnter,p=t.onEntering,h=t.onEntered,g=t.onExit,v=t.onExiting,y=t.onExited,x=(0,s.default)(t,["collapsible","header","id","footer","expanded","headerRole","panelRole","className","children","onEnter","onEntering","onEntered","onExit","onExiting","onExited"]),_=(0,w.splitBsPropsAndOmit)(x,["defaultExpanded","eventKey","onSelect"]),T=_[0],C=_[1],k=null!=i?i:this.state.expanded,E=(0,w.getClassSet)(T);return b.default.createElement("div",(0,u.default)({},C,{className:(0,m.default)(c,E),id:e?null:r}),n&&b.default.createElement("div",{className:(0,w.prefix)(T,"heading")},this.renderHeader(e,n,r,a,k,T)),e?this.renderCollapsibleBody(r,k,l,f,T,{onEnter:d,onEntering:p,onEntered:h,onExit:g,onExiting:v,onExited:y}):this.renderBody(f,T),o&&b.default.createElement("div",{className:(0,w.prefix)(T,"footer")},o))},e}(b.default.Component);E.propTypes=C,E.defaultProps=k,e.default=(0,w.bsClass)("panel",(0,w.bsStyles)([].concat((0,i.default)(T.State),[T.Style.DEFAULT,T.Style.PRIMARY]),T.Style.DEFAULT,E)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(52),b=r(y),x=n(8),_={id:(0,b.default)(m.default.PropTypes.oneOfType([m.default.PropTypes.string,m.default.PropTypes.number])),placement:m.default.PropTypes.oneOf(["top","right","bottom","left"]),positionTop:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),positionLeft:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),arrowOffsetTop:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),arrowOffsetLeft:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),title:m.default.PropTypes.node},w={placement:"right"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.placement,r=e.positionTop,o=e.positionLeft,a=e.arrowOffsetTop,l=e.arrowOffsetLeft,u=e.title,c=e.className,f=e.style,d=e.children,p=(0,s.default)(e,["placement","positionTop","positionLeft","arrowOffsetTop","arrowOffsetLeft","title","className","style","children"]),h=(0,x.splitBsProps)(p),v=h[0],y=h[1],b=(0,i.default)({},(0,x.getClassSet)(v),(t={},t[n]=!0,t)),_=(0,i.default)({display:"block",top:r,left:o},f),w={top:a,left:l};return m.default.createElement("div",(0,i.default)({},y,{role:"tooltip",className:(0,g.default)(c,b),style:_}),m.default.createElement("div",{className:"arrow",style:w}),u&&m.default.createElement("h3",{className:(0,x.prefix)(v,"title")},u),m.default.createElement("div",{className:(0,x.prefix)(v,"content")},d))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("popover",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r=t[e];if(!r)return null;var o=null;return _.default.Children.forEach(r,function(t){if(!o&&t.type!==M){var e=_.default.isValidElement(t)?t.type.displayName||t.type.name||t.type:t;o=new Error("Children of "+n+" can contain only ProgressBar "+("components. Found "+e+"."))}}),o}function i(t,e,n){var r=(t-e)/(n-e)*100;return Math.round(r*E)/E}e.__esModule=!0;var a=n(26),s=r(a),l=n(5),u=r(l),c=n(7),f=r(c),d=n(2),p=r(d),h=n(4),g=r(h),v=n(3),m=r(v),y=n(6),b=r(y),x=n(1),_=r(x),w=n(8),T=n(12),C=n(13),k=r(C),E=1e3,P={min:x.PropTypes.number,now:x.PropTypes.number,max:x.PropTypes.number,label:x.PropTypes.node,srOnly:x.PropTypes.bool,striped:x.PropTypes.bool,active:x.PropTypes.bool,children:o,isChild:x.PropTypes.bool},S={min:0,max:100,active:!1,isChild:!1,srOnly:!1,striped:!1},M=function(t){function e(){return(0,p.default)(this,e),(0,g.default)(this,t.apply(this,arguments))}return(0,m.default)(e,t),e.prototype.renderProgressBar=function(t){var e,n=t.min,r=t.now,o=t.max,a=t.label,s=t.srOnly,l=t.striped,c=t.active,d=t.className,p=t.style,h=(0,f.default)(t,["min","now","max","label","srOnly","striped","active","className","style"]),g=(0,w.splitBsProps)(h),v=g[0],m=g[1],y=(0,u.default)({},(0,w.getClassSet)(v),(e={active:c},e[(0,w.prefix)(v,"striped")]=c||l,e));return _.default.createElement("div",(0,u.default)({},m,{role:"progressbar",className:(0,b.default)(d,y),style:(0,u.default)({width:i(r,n,o)+"%"},p),"aria-valuenow":r,"aria-valuemin":n,"aria-valuemax":o}),s?_.default.createElement("span",{className:"sr-only"},a):a)},e.prototype.render=function(){var t=this.props,e=t.isChild,n=(0,f.default)(t,["isChild"]);if(e)return this.renderProgressBar(n);var r=n.min,o=n.now,i=n.max,a=n.label,s=n.srOnly,l=n.striped,c=n.active,d=n.bsClass,p=n.bsStyle,h=n.className,g=n.children,v=(0,f.default)(n,["min","now","max","label","srOnly","striped","active","bsClass","bsStyle","className","children"]);return _.default.createElement("div",(0,u.default)({},v,{className:(0,b.default)(h,"progress")}),g?k.default.map(g,function(t){return(0,x.cloneElement)(t,{isChild:!0})}):this.renderProgressBar({min:r,now:o,max:i,label:a,srOnly:s,striped:l,active:c,bsClass:d,bsStyle:p}))},e}(_.default.Component);M.propTypes=P,M.defaultProps=S,e.default=(0,w.bsClass)("progress-bar",(0,w.bsStyles)((0,s.default)(T.State),M)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(15),b=(r(y),n(8)),x={inline:m.default.PropTypes.bool,disabled:m.default.PropTypes.bool,validationState:m.default.PropTypes.oneOf(["success","warning","error",null]),inputRef:m.default.PropTypes.func},_={inline:!1,disabled:!1},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.inline,n=t.disabled,r=t.validationState,o=t.inputRef,a=t.className,l=t.style,u=t.children,c=(0,s.default)(t,["inline","disabled","validationState","inputRef","className","style","children"]),f=(0,b.splitBsProps)(c),d=f[0],p=f[1],h=m.default.createElement("input",(0,i.default)({},p,{ref:o,type:"radio",disabled:n}));if(e){var v,y=(v={},v[(0,b.prefix)(d,"inline")]=!0,v.disabled=n,v);return m.default.createElement("label",{className:(0,g.default)(a,y),style:l},h,u)}var x=(0,i.default)({},(0,b.getClassSet)(d),{disabled:n});return r&&(x["has-"+r]=!0),m.default.createElement("div",{className:(0,g.default)(a,x),style:l},m.default.createElement("label",null,h,u))},e}(m.default.Component);w.propTypes=x,w.defaultProps=_,e.default=(0,b.bsClass)("radio",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(15),b=(r(y),n(8)),x={children:v.PropTypes.element.isRequired,a16by9:v.PropTypes.bool,a4by3:v.PropTypes.bool},_={a16by9:!1,a4by3:!1},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.a16by9,r=e.a4by3,o=e.className,a=e.children,l=(0,s.default)(e,["a16by9","a4by3","className","children"]),u=(0,b.splitBsProps)(l),c=u[0],f=u[1],d=(0,i.default)({},(0,b.getClassSet)(c),(t={},t[(0,b.prefix)(c,"16by9")]=n,t[(0,b.prefix)(c,"4by3")]=r,t));return m.default.createElement("div",{className:(0,g.default)(d)},(0,v.cloneElement)(a,(0,i.default)({},f,{className:(0,g.default)(o,(0,b.prefix)(c,"item"))})))},e}(m.default.Component);w.propTypes=x,w.defaultProps=_,e.default=(0,b.bsClass)("embed-responsive",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(9),b=r(y),x=n(8),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("row",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(7),i=r(o),a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(5),p=r(d),h=n(1),g=r(h),v=n(40),m=r(v),y=n(48),b=r(y),x=n(272),_=r(x),w=n(50),T=r(w),C=(0,p.default)({},b.default.propTypes,{bsStyle:g.default.PropTypes.string,bsSize:g.default.PropTypes.string,href:g.default.PropTypes.string,onClick:g.default.PropTypes.func,title:g.default.PropTypes.node.isRequired,toggleLabel:g.default.PropTypes.string,children:g.default.PropTypes.node}),k=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.bsSize,n=t.bsStyle,r=t.title,o=t.toggleLabel,a=t.children,s=(0,i.default)(t,["bsSize","bsStyle","title","toggleLabel","children"]),l=(0,T.default)(s,b.default.ControlledComponent),u=l[0],c=l[1];return g.default.createElement(b.default,(0,p.default)({},u,{bsSize:e,bsStyle:n}),g.default.createElement(m.default,(0,p.default)({},c,{disabled:s.disabled,bsSize:e,bsStyle:n}),r),g.default.createElement(_.default,{"aria-label":o||r,bsSize:e,bsStyle:n}),g.default.createElement(b.default.Menu,null,a))},e}(g.default.Component);k.propTypes=C,k.Toggle=_.default,e.default=k,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(1),p=r(d),h=n(122),g=r(h),v=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){return p.default.createElement(g.default,(0,i.default)({},this.props,{useAnchor:!1,noCaret:!1}))},e}(p.default.Component);v.defaultProps=g.default.defaultProps,e.default=v,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(2),i=r(o),a=n(4),s=r(a),l=n(3),u=r(l),c=n(5),f=r(c),d=n(1),p=r(d),h=n(80),g=r(h),v=n(81),m=r(v),y=n(135),b=r(y),x=(0,f.default)({},b.default.propTypes,{disabled:p.default.PropTypes.bool,title:p.default.PropTypes.node,tabClassName:p.default.PropTypes.string}),_=function(t){function e(){return(0,i.default)(this,e),(0,s.default)(this,t.apply(this,arguments))}return(0,u.default)(e,t),e.prototype.render=function(){var t=(0,f.default)({},this.props);return delete t.title,delete t.disabled,delete t.tabClassName,p.default.createElement(b.default,t)},e}(p.default.Component);_.propTypes=x,_.Container=g.default,_.Content=m.default,_.Pane=b.default,e.default=_,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b={striped:m.default.PropTypes.bool,bordered:m.default.PropTypes.bool,condensed:m.default.PropTypes.bool,hover:m.default.PropTypes.bool,responsive:m.default.PropTypes.bool},x={bordered:!1,condensed:!1,hover:!1,responsive:!1,striped:!1},_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.striped,r=e.bordered,o=e.condensed,a=e.hover,l=e.responsive,u=e.className,c=(0,s.default)(e,["striped","bordered","condensed","hover","responsive","className"]),f=(0,y.splitBsProps)(c),d=f[0],p=f[1],h=(0,i.default)({},(0,y.getClassSet)(d),(t={},t[(0,y.prefix)(d,"striped")]=n,t[(0,y.prefix)(d,"bordered")]=r,t[(0,y.prefix)(d,"condensed")]=o,t[(0,y.prefix)(d,"hover")]=a,t)),v=m.default.createElement("table",(0,i.default)({},p,{className:(0,g.default)(u,h)}));return l?m.default.createElement("div",{className:(0,y.prefix)(d,"responsive")},v):v},e}(m.default.Component);_.propTypes=b,_.defaultProps=x,e.default=(0,y.bsClass)("table",_),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){var e=void 0;return A.default.forEach(t,function(t){null==e&&(e=t.props.eventKey)}),e}e.__esModule=!0;var i=n(5),a=r(i),s=n(7),l=r(s),u=n(2),c=r(u),f=n(4),d=r(f),p=n(3),h=r(p),g=n(1),v=r(g),m=n(52),y=r(m),b=n(55),x=r(b),_=n(129),w=r(_),T=n(130),C=r(T),k=n(80),E=r(k),P=n(81),S=r(P),M=n(8),N=n(13),A=r(N),O=E.default.ControlledComponent,D={activeKey:v.default.PropTypes.any,bsStyle:v.default.PropTypes.oneOf(["tabs","pills"]),animation:v.default.PropTypes.bool,id:(0,y.default)(v.default.PropTypes.oneOfType([v.default.PropTypes.string,v.default.PropTypes.number])),onSelect:v.default.PropTypes.func,unmountOnExit:v.default.PropTypes.bool},I={bsStyle:"tabs",animation:!0,unmountOnExit:!1},R=function(t){function e(){return(0,c.default)(this,e),(0,d.default)(this,t.apply(this,arguments))}return(0,h.default)(e,t),e.prototype.renderTab=function(t){var e=t.props,n=e.title,r=e.eventKey,o=e.disabled,i=e.tabClassName;return null==n?null:v.default.createElement(C.default,{eventKey:r,disabled:o,className:i},n)},e.prototype.render=function(){var t=this.props,e=t.id,n=t.onSelect,r=t.animation,i=t.unmountOnExit,s=t.bsClass,u=t.className,c=t.style,f=t.children,d=t.activeKey,p=void 0===d?o(f):d,h=(0,l.default)(t,["id","onSelect","animation","unmountOnExit","bsClass","className","style","children","activeKey"]);return v.default.createElement(O,{id:e,activeKey:p,onSelect:n,className:u,style:c},v.default.createElement("div",null,v.default.createElement(w.default,(0,a.default)({},h,{role:"tablist"}),A.default.map(f,this.renderTab)),v.default.createElement(S.default,{bsClass:s,animation:r,unmountOnExit:i},f)))},e}(v.default.Component);R.propTypes=D,R.defaultProps=I,(0,M.bsClass)("tab",R),e.default=(0,x.default)(R,{activeKey:"onSelect"}),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(18),b=r(y),x=n(8),_={src:m.default.PropTypes.string,alt:m.default.PropTypes.string,href:m.default.PropTypes.string},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.src,n=t.alt,r=t.className,o=t.children,a=(0,s.default)(t,["src","alt","className","children"]),l=(0,x.splitBsProps)(a),u=l[0],c=l[1],f=c.href?b.default:"div",d=(0,x.getClassSet)(u);return m.default.createElement(f,(0,i.default)({},c,{className:(0,g.default)(r,d)}),m.default.createElement("img",{src:e,alt:n}),o&&m.default.createElement("div",{className:"caption"},o))},e}(m.default.Component);w.propTypes=_,e.default=(0,x.bsClass)("thumbnail",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(52),b=r(y),x=n(8),_={id:(0,b.default)(m.default.PropTypes.oneOfType([m.default.PropTypes.string,m.default.PropTypes.number])),placement:m.default.PropTypes.oneOf(["top","right","bottom","left"]),positionTop:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),positionLeft:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),arrowOffsetTop:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),arrowOffsetLeft:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string])},w={placement:"right"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.placement,r=e.positionTop,o=e.positionLeft,a=e.arrowOffsetTop,l=e.arrowOffsetLeft,u=e.className,c=e.style,f=e.children,d=(0,s.default)(e,["placement","positionTop","positionLeft","arrowOffsetTop","arrowOffsetLeft","className","style","children"]),p=(0,x.splitBsProps)(d),h=p[0],v=p[1],y=(0,i.default)({},(0,x.getClassSet)(h),(t={},t[n]=!0,t)),b=(0,i.default)({top:r,left:o},c),_={top:a,left:l};return m.default.createElement("div",(0,i.default)({},v,{role:"tooltip",className:(0,g.default)(u,y),style:b}),m.default.createElement("div",{className:(0,x.prefix)(h,"arrow"),style:_}),m.default.createElement("div",{className:(0,x.prefix)(h,"inner")},f))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("tooltip",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(5),i=r(o),a=n(7),s=r(a),l=n(2),u=r(l),c=n(4),f=r(c),d=n(3),p=r(d),h=n(6),g=r(h),v=n(1),m=r(v),y=n(8),b=n(12),x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("div",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("well",(0,y.bsSizes)([b.Size.LARGE,b.Size.SMALL],x)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(){for(var t=arguments.length,e=Array(t),n=0;n<t;n++)e[n]=arguments[n];return(0,s.default)(function(t,n,r){var o=void 0;return e.every(function(e){return!!u.default.some(t.children,function(t){return t.props.bsRole===e})||(o=e,!1)}),o?new Error("(children) "+r+" - Missing a required child with bsRole: "+(o+". "+r+" must have at least one child of each of ")+("the following bsRoles: "+e.join(", "))):null})}function i(){for(var t=arguments.length,e=Array(t),n=0;n<t;n++)e[n]=arguments[n];return(0,s.default)(function(t,n,r){var o=void 0;return e.every(function(e){var n=u.default.filter(t.children,function(t){return t.props.bsRole===e});return!(n.length>1&&(o=e,1))}),o?new Error("(children) "+r+" - Duplicate children detected of bsRole: "+(o+". Only one child each allowed with the following ")+("bsRoles: "+e.join(", "))):null})}e.__esModule=!0,e.requiredRoles=o,e.exclusiveRoles=i;var a=n(53),s=r(a),l=n(13),u=r(l)},function(t,e){"use strict";function n(){var t=document.createElement("div"),e=t.style;"AnimationEvent"in window||delete a.animationend.animation,"TransitionEvent"in window||delete a.transitionend.transition;for(var n in a){var r=a[n];for(var o in r)if(o in e){s.push(r[o]);break}}}function r(t,e,n){t.addEventListener(e,n,!1)}function o(t,e,n){t.removeEventListener(e,n,!1)}e.__esModule=!0;var i=!("undefined"==typeof window||!window.document||!window.document.createElement),a={transitionend:{transition:"transitionend",WebkitTransition:"webkitTransitionEnd",MozTransition:"mozTransitionEnd",OTransition:"oTransitionEnd",msTransition:"MSTransitionEnd"},animationend:{animation:"animationend",WebkitAnimation:"webkitAnimationEnd",MozAnimation:"mozAnimationEnd",OAnimation:"oAnimationEnd",msAnimation:"MSAnimationEnd"}},s=[];i&&n();var l={addEndEventListener:function(t,e){return 0===s.length?void window.setTimeout(e,0):void s.forEach(function(n){r(t,n,e)})},removeEndEventListener:function(t,e){0!==s.length&&s.forEach(function(n){o(t,n,e)})}};e.default=l,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r=void 0;"object"===("undefined"==typeof t?"undefined":(0,p.default)(t))?r=t.message:(r=t+" is deprecated. Use "+e+" instead.",n&&(r+="\nYou can read more about it at "+n)),g[r]||(g[r]=!0)}function i(){g={}}e.__esModule=!0;var a=n(2),s=r(a),l=n(4),u=r(l),c=n(3),f=r(c),d=n(58),p=r(d);e._resetWarned=i;var h=n(15),g=(r(h),{});o.wrapper=function(t){for(var e=arguments.length,n=Array(e>1?e-1:0),r=1;r<e;r++)n[r-1]=arguments[r];return function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.componentWillMount=function(){if(o.apply(void 0,n),t.prototype.componentWillMount){for(var e,r=arguments.length,i=Array(r),a=0;a<r;a++)i[a]=arguments[a];(e=t.prototype.componentWillMount).call.apply(e,[this].concat(i))}},e}(t)},e.default=o},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){if(t&&t.__esModule)return t;var e={};if(null!=t)for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n]);return e.default=t,e}e.__esModule=!0,e.ValidComponentChildren=e.createChainedFunction=e.bootstrapUtils=void 0;var i=n(8),a=o(i),s=n(10),l=r(s),u=n(13),c=r(u);e.bootstrapUtils=a,e.createChainedFunction=l.default,e.ValidComponentChildren=c.default},function(t,e,n){"use strict";var r=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},o=n(1),i={position:"absolute",top:0,left:0,visibility:"hidden",height:0,overflow:"scroll",whiteSpace:"pre"},a=o.createClass({displayName:"AutosizeInput",propTypes:{className:o.PropTypes.string,defaultValue:o.PropTypes.any,inputClassName:o.PropTypes.string,inputStyle:o.PropTypes.object,minWidth:o.PropTypes.oneOfType([o.PropTypes.number,o.PropTypes.string]),onChange:o.PropTypes.func,placeholder:o.PropTypes.string,placeholderIsMinWidth:o.PropTypes.bool,style:o.PropTypes.object,value:o.PropTypes.any},getDefaultProps:function(){return{minWidth:1}},getInitialState:function(){return{inputWidth:this.props.minWidth}},componentDidMount:function(){this.copyInputStyles(),this.updateInputWidth()},componentDidUpdate:function(){this.updateInputWidth()},copyInputStyles:function(){if(this.isMounted()&&window.getComputedStyle){var t=window.getComputedStyle(this.refs.input);if(t){var e=this.refs.sizer;if(e.style.fontSize=t.fontSize,e.style.fontFamily=t.fontFamily,e.style.fontWeight=t.fontWeight,e.style.fontStyle=t.fontStyle,e.style.letterSpacing=t.letterSpacing,this.props.placeholder){var n=this.refs.placeholderSizer;n.style.fontSize=t.fontSize,n.style.fontFamily=t.fontFamily,n.style.fontWeight=t.fontWeight,n.style.fontStyle=t.fontStyle,n.style.letterSpacing=t.letterSpacing}}}},updateInputWidth:function(){if(this.isMounted()&&"undefined"!=typeof this.refs.sizer.scrollWidth){var t=void 0;t=this.props.placeholder&&(!this.props.value||this.props.value&&this.props.placeholderIsMinWidth)?Math.max(this.refs.sizer.scrollWidth,this.refs.placeholderSizer.scrollWidth)+2:this.refs.sizer.scrollWidth+2,t<this.props.minWidth&&(t=this.props.minWidth),t!==this.state.inputWidth&&this.setState({inputWidth:t})}},getInput:function(){return this.refs.input},focus:function(){this.refs.input.focus()},blur:function(){this.refs.input.blur()},select:function(){this.refs.input.select()},render:function(){var t=this.props.defaultValue||this.props.value||"",e=this.props.style||{};e.display||(e.display="inline-block");var n=r({},this.props.inputStyle);n.width=this.state.inputWidth+"px",n.boxSizing="content-box";var a=r({},this.props);return a.className=this.props.inputClassName,a.style=n,delete a.inputClassName,delete a.inputStyle,delete a.minWidth,delete a.placeholderIsMinWidth,o.createElement("div",{className:this.props.className,style:e},o.createElement("input",r({},a,{ref:"input"})),o.createElement("div",{ref:"sizer",style:i},t),this.props.placeholder?o.createElement("div",{ref:"placeholderSizer",style:i},this.props.placeholder):null)}});t.exports=a},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0});var o=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},i=n(1),a=r(i),s=n(15),l=r(s),u=n(83),c=r(u),f=n(9),d=r(f),p=n(137),h=r(p),g=n(285),v=r(g),m=n(41),y=r(m),b=n(140),x=r(b),_=n(288),w=r(_),T=n(25),C=r(T),k=n(111),E=r(k),P=n(32),S=r(P),M=n(82),N=r(M),A=new v.default,O=a.default.createClass({displayName:"Modal",propTypes:o({},h.default.propTypes,{show:a.default.PropTypes.bool,container:a.default.PropTypes.oneOfType([c.default,a.default.PropTypes.func]),onShow:a.default.PropTypes.func,onHide:a.default.PropTypes.func,backdrop:a.default.PropTypes.oneOfType([a.default.PropTypes.bool,a.default.PropTypes.oneOf(["static"])]),renderBackdrop:a.default.PropTypes.func,onEscapeKeyUp:a.default.PropTypes.func,onBackdropClick:a.default.PropTypes.func,backdropStyle:a.default.PropTypes.object,backdropClassName:a.default.PropTypes.string,containerClassName:a.default.PropTypes.string,keyboard:a.default.PropTypes.bool,transition:d.default,dialogTransitionTimeout:a.default.PropTypes.number,backdropTransitionTimeout:a.default.PropTypes.number,autoFocus:a.default.PropTypes.bool,enforceFocus:a.default.PropTypes.bool,onEnter:a.default.PropTypes.func,onEntering:a.default.PropTypes.func,onEntered:a.default.PropTypes.func,onExit:a.default.PropTypes.func,onExiting:a.default.PropTypes.func,onExited:a.default.PropTypes.func,manager:a.default.PropTypes.object.isRequired}),getDefaultProps:function(){var t=function(){};return{show:!1,backdrop:!0,keyboard:!0,autoFocus:!0,enforceFocus:!0,onHide:t,manager:A,renderBackdrop:function(t){return a.default.createElement("div",t)}}},getInitialState:function(){return{exited:!this.props.show}},render:function(){var t=this.props,e=t.show,n=t.container,r=t.children,o=t.transition,s=t.backdrop,l=t.dialogTransitionTimeout,u=t.className,c=t.style,f=t.onExit,d=t.onExiting,p=t.onEnter,g=t.onEntering,v=t.onEntered,m=a.default.Children.only(r),y=e||o&&!this.state.exited;if(!y)return null;var b=m.props,x=b.role,_=b.tabIndex;return void 0!==x&&void 0!==_||(m=(0,i.cloneElement)(m,{role:void 0===x?"document":x,tabIndex:null==_?"-1":_})),o&&(m=a.default.createElement(o,{transitionAppear:!0,unmountOnExit:!0,in:e,timeout:l,onExit:f,onExiting:d,onExited:this.handleHidden,onEnter:p,onEntering:g,onEntered:v},m)),a.default.createElement(h.default,{ref:this.setMountNode,container:n},a.default.createElement("div",{ref:"modal",role:x||"dialog",style:c,className:u},s&&this.renderBackdrop(),m))},renderBackdrop:function t(){var e=this,n=this.props,r=n.backdropStyle,o=n.backdropClassName,t=n.renderBackdrop,i=n.transition,s=n.backdropTransitionTimeout,l=function(t){return e.backdrop=t},u=a.default.createElement("div",{ref:l,style:this.props.backdropStyle,className:this.props.backdropClassName,onClick:this.handleBackdropClick});return i&&(u=a.default.createElement(i,{transitionAppear:!0,in:this.props.show,
timeout:s},t({ref:l,style:r,className:o,onClick:this.handleBackdropClick}))),u},componentWillReceiveProps:function(t){t.show?this.setState({exited:!1}):t.transition||this.setState({exited:!0})},componentWillUpdate:function(t){!this.props.show&&t.show&&this.checkForFocus()},componentDidMount:function(){this.props.show&&this.onShow()},componentDidUpdate:function(t){var e=this.props.transition;!t.show||this.props.show||e?!t.show&&this.props.show&&this.onShow():this.onHide()},componentWillUnmount:function(){var t=this.props,e=t.show,n=t.transition;(e||n&&!this.state.exited)&&this.onHide()},onShow:function(){var t=(0,y.default)(this),e=(0,N.default)(this.props.container,t.body);this.props.manager.add(this,e,this.props.containerClassName),this._onDocumentKeyupListener=(0,x.default)(t,"keyup",this.handleDocumentKeyUp),this._onFocusinListener=(0,w.default)(this.enforceFocus),this.focus(),this.props.onShow&&this.props.onShow()},onHide:function(){this.props.manager.remove(this),this._onDocumentKeyupListener.remove(),this._onFocusinListener.remove(),this.restoreLastFocus()},setMountNode:function(t){this.mountNode=t?t.getMountNode():t},handleHidden:function(){if(this.setState({exited:!0}),this.onHide(),this.props.onExited){var t;(t=this.props).onExited.apply(t,arguments)}},handleBackdropClick:function(t){t.target===t.currentTarget&&(this.props.onBackdropClick&&this.props.onBackdropClick(t),this.props.backdrop===!0&&this.props.onHide())},handleDocumentKeyUp:function(t){this.props.keyboard&&27===t.keyCode&&this.isTopModal()&&(this.props.onEscapeKeyUp&&this.props.onEscapeKeyUp(t),this.props.onHide())},checkForFocus:function(){C.default&&(this.lastFocus=(0,E.default)())},focus:function(){var t=this.props.autoFocus,e=this.getDialogElement(),n=(0,E.default)((0,y.default)(this)),r=n&&(0,S.default)(e,n);e&&t&&!r&&(this.lastFocus=n,e.hasAttribute("tabIndex")||(e.setAttribute("tabIndex",-1),(0,l.default)(!1,'The modal content node does not accept focus. For the benefit of assistive technologies, the tabIndex of the node is being set to "-1".')),e.focus())},restoreLastFocus:function(){this.lastFocus&&this.lastFocus.focus&&(this.lastFocus.focus(),this.lastFocus=null)},enforceFocus:function t(){var t=this.props.enforceFocus;if(t&&this.isMounted()&&this.isTopModal()){var e=(0,E.default)((0,y.default)(this)),n=this.getDialogElement();n&&n!==e&&!(0,S.default)(n,e)&&n.focus()}},getDialogElement:function(){var t=this.refs.modal;return t&&t.lastChild},isTopModal:function(){return this.props.manager.isTopModal(this)}});O.Manager=v.default,e.default=O,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){var n=-1;return t.some(function(t,r){if(e(t,r))return n=r,!0}),n}function a(t,e){return i(t,function(t){return t.modals.indexOf(e)!==-1})}function s(t,e){var n={overflow:"hidden"};t.style={overflow:e.style.overflow,paddingRight:e.style.paddingRight},t.overflowing&&(n.paddingRight=parseInt((0,f.default)(e,"paddingRight")||0,10)+(0,g.default)()+"px"),(0,f.default)(e,n)}function l(t,e){var n=t.style;Object.keys(n).forEach(function(t){return e.style[t]=n[t]})}Object.defineProperty(e,"__esModule",{value:!0});var u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),c=n(46),f=r(c),d=n(205),p=r(d),h=n(117),g=r(h),v=n(141),m=r(v),y=n(290),b=function(){function t(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},n=e.hideSiblingNodes,r=void 0===n||n,i=e.handleContainerOverflow,a=void 0===i||i;o(this,t),this.hideSiblingNodes=r,this.handleContainerOverflow=a,this.modals=[],this.containers=[],this.data=[]}return u(t,[{key:"add",value:function(t,e,n){var r=this.modals.indexOf(t),o=this.containers.indexOf(e);if(r!==-1)return r;if(r=this.modals.length,this.modals.push(t),this.hideSiblingNodes&&(0,y.hideSiblings)(e,t.mountNode),o!==-1)return this.data[o].modals.push(t),r;var i={modals:[t],classes:n?n.split(/\s+/):[],overflowing:(0,m.default)(e)};return this.handleContainerOverflow&&s(i,e),i.classes.forEach(p.default.addClass.bind(null,e)),this.containers.push(e),this.data.push(i),r}},{key:"remove",value:function(t){var e=this.modals.indexOf(t);if(e!==-1){var n=a(this.data,t),r=this.data[n],o=this.containers[n];r.modals.splice(r.modals.indexOf(t),1),this.modals.splice(e,1),0===r.modals.length?(r.classes.forEach(p.default.removeClass.bind(null,o)),this.handleContainerOverflow&&l(r,o),this.hideSiblingNodes&&(0,y.showSiblings)(o,t.mountNode),this.containers.splice(n,1),this.data.splice(n,1)):this.hideSiblingNodes&&(0,y.ariaHidden)(!1,r.modals[r.modals.length-1].mountNode)}}},{key:"isTopModal",value:function(t){return!!this.modals.length&&this.modals[this.modals.length-1]===t}}]),t}();e.default=b,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}function i(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function a(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0});var l=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),c=n(1),f=r(c),d=n(137),p=r(d),h=n(287),g=r(h),v=n(138),m=r(v),y=n(9),b=r(y),x=function(t){function e(t,n){i(this,e);var r=a(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t,n));return r.state={exited:!t.show},r.onHiddenListener=r.handleHidden.bind(r),r}return s(e,t),u(e,[{key:"componentWillReceiveProps",value:function(t){t.show?this.setState({exited:!1}):t.transition||this.setState({exited:!0})}},{key:"render",value:function(){var t=this.props,e=t.container,n=t.containerPadding,r=t.target,i=t.placement,a=t.shouldUpdatePosition,s=t.rootClose,l=t.children,u=t.transition,c=o(t,["container","containerPadding","target","placement","shouldUpdatePosition","rootClose","children","transition"]),d=c.show||u&&!this.state.exited;if(!d)return null;var h=l;if(h=f.default.createElement(g.default,{container:e,containerPadding:n,target:r,placement:i,shouldUpdatePosition:a},h),u){var v=c.onExit,y=c.onExiting,b=c.onEnter,x=c.onEntering,_=c.onEntered;h=f.default.createElement(u,{in:c.show,transitionAppear:!0,onExit:v,onExiting:y,onExited:this.onHiddenListener,onEnter:b,onEntering:x,onEntered:_},h)}return s&&(h=f.default.createElement(m.default,{onRootClose:c.onHide},h)),f.default.createElement(p.default,{container:e},h)}},{key:"handleHidden",value:function(){if(this.setState({exited:!0}),this.props.onExited){var t;(t=this.props).onExited.apply(t,arguments)}}}]),e}(f.default.Component);x.propTypes=l({},p.default.propTypes,g.default.propTypes,{show:f.default.PropTypes.bool,rootClose:f.default.PropTypes.bool,onHide:function(t){var e=f.default.PropTypes.func;t.rootClose&&(e=e.isRequired);for(var n=arguments.length,r=Array(n>1?n-1:0),o=1;o<n;o++)r[o-1]=arguments[o];return e.apply(void 0,[t].concat(r))},transition:b.default,onEnter:f.default.PropTypes.func,onEntering:f.default.PropTypes.func,onEntered:f.default.PropTypes.func,onExit:f.default.PropTypes.func,onExiting:f.default.PropTypes.func,onExited:f.default.PropTypes.func}),e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}function i(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function a(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0});var l=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),c=n(6),f=r(c),d=n(1),p=r(d),h=n(11),g=r(h),v=n(83),m=r(v),y=n(289),b=r(y),x=n(82),_=r(x),w=n(41),T=r(w),C=function(t){function e(t,n){i(this,e);var r=a(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t,n));return r.state={positionLeft:0,positionTop:0,arrowOffsetLeft:null,arrowOffsetTop:null},r._needsFlush=!1,r._lastTarget=null,r}return s(e,t),u(e,[{key:"componentDidMount",value:function(){this.updatePosition(this.getTarget())}},{key:"componentWillReceiveProps",value:function(){this._needsFlush=!0}},{key:"componentDidUpdate",value:function(t){this._needsFlush&&(this._needsFlush=!1,this.maybeUpdatePosition(this.props.placement!==t.placement))}},{key:"render",value:function(){var t=this.props,e=t.children,n=t.className,r=o(t,["children","className"]),i=this.state,a=i.positionLeft,s=i.positionTop,u=o(i,["positionLeft","positionTop"]);delete r.target,delete r.container,delete r.containerPadding,delete r.shouldUpdatePosition;var c=p.default.Children.only(e);return(0,d.cloneElement)(c,l({},r,u,{positionLeft:a,positionTop:s,className:(0,f.default)(n,c.props.className),style:l({},c.props.style,{left:a,top:s})}))}},{key:"getTarget",value:function(){var t=this.props.target,e="function"==typeof t?t():t;return e&&g.default.findDOMNode(e)||null}},{key:"maybeUpdatePosition",value:function(t){var e=this.getTarget();(this.props.shouldUpdatePosition||e!==this._lastTarget||t)&&this.updatePosition(e)}},{key:"updatePosition",value:function(t){if(this._lastTarget=t,!t)return void this.setState({positionLeft:0,positionTop:0,arrowOffsetLeft:null,arrowOffsetTop:null});var e=g.default.findDOMNode(this),n=(0,_.default)(this.props.container,(0,T.default)(this).body);this.setState((0,b.default)(this.props.placement,e,t,n,this.props.containerPadding))}}]),e}(p.default.Component);C.propTypes={target:p.default.PropTypes.oneOfType([m.default,p.default.PropTypes.func]),container:p.default.PropTypes.oneOfType([m.default,p.default.PropTypes.func]),containerPadding:p.default.PropTypes.number,placement:p.default.PropTypes.oneOf(["top","right","bottom","left"]),shouldUpdatePosition:p.default.PropTypes.bool},C.displayName="Position",C.defaultProps={containerPadding:0,placement:"right",shouldUpdatePosition:!1},e.default=C,t.exports=e.default},function(t,e){"use strict";function n(t){var e=!document.addEventListener,n=void 0;return e?(document.attachEvent("onfocusin",t),n=function(){return document.detachEvent("onfocusin",t)}):(document.addEventListener("focus",t,!0),n=function(){return document.removeEventListener("focus",t,!0)}),{remove:n}}Object.defineProperty(e,"__esModule",{value:!0}),e.default=n,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){var e=void 0,n=void 0,r=void 0;if("BODY"===t.tagName)e=window.innerWidth,n=window.innerHeight,r=(0,p.default)((0,g.default)(t).documentElement)||(0,p.default)(t);else{var o=(0,u.default)(t);e=o.width,n=o.height,r=(0,p.default)(t)}return{width:e,height:n,scroll:r}}function i(t,e,n,r){var i=o(n),a=i.scroll,s=i.height,l=t-r-a,u=t+r-a+e;return l<0?-l:u>s?s-u:0}function a(t,e,n,r){var i=o(n),a=i.width,s=t-r,l=t+r+e;return s<0?-s:l>a?a-l:0}function s(t,e,n,r,o){var s="BODY"===r.tagName?(0,u.default)(n):(0,f.default)(n,r),l=(0,u.default)(e),c=l.height,d=l.width,p=void 0,h=void 0,g=void 0,v=void 0;if("left"===t||"right"===t){h=s.top+(s.height-c)/2,p="left"===t?s.left-d:s.left+s.width;var m=i(h,c,r,o);h+=m,v=50*(1-2*m/c)+"%",g=void 0}else{if("top"!==t&&"bottom"!==t)throw new Error('calcOverlayPosition(): No such placement of "'+t+'" found.');p=s.left+(s.width-d)/2,h="top"===t?s.top-c:s.top+s.height;var y=a(p,d,r,o);p+=y,g=50*(1-2*y/d)+"%",v=void 0}return{positionLeft:p,positionTop:h,arrowOffsetLeft:g,arrowOffsetTop:v}}Object.defineProperty(e,"__esModule",{value:!0}),e.default=s;var l=n(114),u=r(l),c=n(210),f=r(c),d=n(115),p=r(d),h=n(41),g=r(h);t.exports=e.default},function(t,e){"use strict";function n(t,e){e&&(t?e.setAttribute("aria-hidden","true"):e.removeAttribute("aria-hidden"))}function r(t,e){s(t,e,function(t){return n(!0,t)})}function o(t,e){s(t,e,function(t){return n(!1,t)})}Object.defineProperty(e,"__esModule",{value:!0}),e.ariaHidden=n,e.hideSiblings=r,e.showSiblings=o;var i=["template","script","style"],a=function(t){var e=t.nodeType,n=t.tagName;return 1===e&&i.indexOf(n.toLowerCase())===-1},s=function(t,e,n){e=[].concat(e),[].forEach.call(t.children,function(t){e.indexOf(t)===-1&&a(t)&&n(t)})}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}function i(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}function s(t){return d.default.createElement(h.default,t)}Object.defineProperty(e,"__esModule",{value:!0});var l=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),c=function(t,e,n){for(var r=!0;r;){var o=t,i=e,a=n;r=!1,null===o&&(o=Function.prototype);var s=Object.getOwnPropertyDescriptor(o,i);if(void 0!==s){if("value"in s)return s.value;var l=s.get;if(void 0===l)return;return l.call(a)}var u=Object.getPrototypeOf(o);if(null===u)return;t=u,e=i,n=a,r=!0,s=u=void 0}},f=n(1),d=r(f),p=n(54),h=r(p),g=n(144),v=r(g),m={autoload:d.default.PropTypes.bool.isRequired,cache:d.default.PropTypes.any,children:d.default.PropTypes.func.isRequired,ignoreAccents:d.default.PropTypes.bool,ignoreCase:d.default.PropTypes.bool,loadingPlaceholder:f.PropTypes.string.isRequired,loadOptions:d.default.PropTypes.func.isRequired,options:f.PropTypes.array.isRequired,placeholder:d.default.PropTypes.oneOfType([d.default.PropTypes.string,d.default.PropTypes.node]),searchPromptText:d.default.PropTypes.oneOfType([d.default.PropTypes.string,d.default.PropTypes.node])},y={autoload:!0,cache:{},children:s,ignoreAccents:!0,ignoreCase:!0,loadingPlaceholder:"Loading...",options:[],searchPromptText:"Type to search"},b=function(t){function e(t,n){i(this,e),c(Object.getPrototypeOf(e.prototype),"constructor",this).call(this,t,n),this.state={isLoading:!1,options:t.options},this._onInputChange=this._onInputChange.bind(this)}return a(e,t),u(e,[{key:"componentDidMount",value:function(){var t=this.props.autoload;t&&this.loadOptions("")}},{key:"componentWillUpdate",value:function(t,e){var n=this,r=["options"];r.forEach(function(e){n.props[e]!==t[e]&&n.setState(o({},e,t[e]))})}},{key:"loadOptions",value:function t(e){var n=this,r=this.props,o=r.cache,t=r.loadOptions;if(o&&o.hasOwnProperty(e))return void this.setState({options:o[e]});var i=function t(r,i){if(t===n._callback){n._callback=null;var a=i&&i.options||[];o&&(o[e]=a),n.setState({isLoading:!1,options:a})}};this._callback=i;var a=t(e,i);return a&&a.then(function(t){return i(null,t)},function(t){return i(t)}),this._callback&&!this.state.isLoading&&this.setState({isLoading:!0}),e}},{key:"_onInputChange",value:function(t){var e=this.props,n=e.ignoreAccents,r=e.ignoreCase;return n&&(t=(0,v.default)(t)),r&&(t=t.toLowerCase()),this.loadOptions(t)}},{key:"render",value:function(){var t=this.props,e=t.children,n=t.loadingPlaceholder,r=t.placeholder,o=t.searchPromptText,i=this.state,a=i.isLoading,s=i.options,u={noResultsText:a?n:o,placeholder:a?n:r,options:a?[]:s};return e(l({},this.props,u,{isLoading:a,onInputChange:this._onInputChange}))}}]),e}(f.Component);e.default=b,b.propTypes=m,b.defaultProps=y,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}var o=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},i=n(1),a=r(i),s=n(54),l=r(s),u=a.default.createClass({displayName:"AsyncCreatableSelect",render:function(){var t=this;return a.default.createElement(l.default.Async,this.props,function(e){return a.default.createElement(l.default.Creatable,t.props,function(t){return a.default.createElement(l.default,o({},e,t,{onInputChange:function(n){return t.onInputChange(n),e.onInputChange(n)}}))})})}});t.exports=u},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}function i(t){return p.default.createElement(g.default,t)}function a(t){var e=t.option,n=t.options,r=t.labelKey,o=t.valueKey;return 0===n.filter(function(t){return t[r]===e[r]||t[o]===e[o]}).length}function s(t){var e=t.label;return!!e}function l(t){var e=t.label,n=t.labelKey,r=t.valueKey,o={};return o[r]=e,o[n]=e,o.className="Select-create-option-placeholder",o}function u(t){return'Create option "'+t+'"'}function c(t){var e=t.keyCode;switch(e){case 9:case 13:case 188:return!0}return!1}var f=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},d=n(1),p=r(d),h=n(54),g=r(h),v=n(142),m=r(v),y=n(143),b=r(y),x=p.default.createClass({displayName:"CreatableSelect",propTypes:{children:p.default.PropTypes.func,filterOptions:p.default.PropTypes.any,isOptionUnique:p.default.PropTypes.func,isValidNewOption:p.default.PropTypes.func,menuRenderer:p.default.PropTypes.any,newOptionCreator:p.default.PropTypes.func,options:p.default.PropTypes.array,promptTextCreator:p.default.PropTypes.func,shouldKeyDownEventCreateNewOption:p.default.PropTypes.func},statics:{isOptionUnique:a,isValidNewOption:s,newOptionCreator:l,promptTextCreator:u,shouldKeyDownEventCreateNewOption:c},getDefaultProps:function(){return{filterOptions:m.default,isOptionUnique:a,isValidNewOption:s,menuRenderer:b.default,newOptionCreator:l,promptTextCreator:u,shouldKeyDownEventCreateNewOption:c}},createNewOption:function(){var t=this.props,e=t.isValidNewOption,n=t.newOptionCreator,r=t.options,o=void 0===r?[]:r;if(t.shouldKeyDownEventCreateNewOption,e({label:this.inputValue})){var i=n({label:this.inputValue,labelKey:this.labelKey,valueKey:this.valueKey}),a=this.isOptionUnique({option:i});a&&(o.unshift(i),this.select.selectValue(i))}},filterOptions:function t(){var e=this.props,t=e.filterOptions,n=e.isValidNewOption,r=(e.options,e.promptTextCreator),o=arguments[2]||[],i=t.apply(void 0,arguments)||[];if(n({label:this.inputValue})){var a=this.props.newOptionCreator,s=a({label:this.inputValue,labelKey:this.labelKey,valueKey:this.valueKey}),l=this.isOptionUnique({option:s,options:o.concat(i)});if(l){var u=r(this.inputValue);this._createPlaceholderOption=a({label:u,labelKey:this.labelKey,valueKey:this.valueKey}),i.unshift(this._createPlaceholderOption)}}return i},isOptionUnique:function t(e){var n=e.option,r=e.options,t=this.props.isOptionUnique;return r=r||this.select.filterOptions(),t({labelKey:this.labelKey,option:n,options:r,valueKey:this.valueKey})},menuRenderer:function t(e){var t=this.props.menuRenderer;return t(f({},e,{onSelect:this.onOptionSelect}))},onInputChange:function(t){this.inputValue=t},onInputKeyDown:function(t){var e=this.props.shouldKeyDownEventCreateNewOption,n=this.select.getFocusedOption();n&&n===this._createPlaceholderOption&&e({keyCode:t.keyCode})&&(this.createNewOption(),t.preventDefault())},onOptionSelect:function(t,e){t===this._createPlaceholderOption?this.createNewOption():this.select.selectValue(t)},render:function(){var t=this,e=this.props,n=e.children,r=void 0===n?i:n,a=(e.newOptionCreator,e.shouldKeyDownEventCreateNewOption,o(e,["children","newOptionCreator","shouldKeyDownEventCreateNewOption"])),s=f({},a,{allowCreate:!0,filterOptions:this.filterOptions,menuRenderer:this.menuRenderer,onInputChange:this.onInputChange,onInputKeyDown:this.onInputKeyDown,ref:function(e){t.select=e,e&&(t.labelKey=e.props.labelKey,t.valueKey=e.props.valueKey)}});return r(s)}});t.exports=x},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}var o=n(1),i=r(o),a=n(6),s=r(a),l=i.default.createClass({displayName:"Option",propTypes:{children:i.default.PropTypes.node,className:i.default.PropTypes.string,instancePrefix:i.default.PropTypes.string.isRequired,isDisabled:i.default.PropTypes.bool,isFocused:i.default.PropTypes.bool,isSelected:i.default.PropTypes.bool,onFocus:i.default.PropTypes.func,onSelect:i.default.PropTypes.func,onUnfocus:i.default.PropTypes.func,option:i.default.PropTypes.object.isRequired,optionIndex:i.default.PropTypes.number},blockEvent:function(t){t.preventDefault(),t.stopPropagation(),"A"===t.target.tagName&&"href"in t.target&&(t.target.target?window.open(t.target.href,t.target.target):window.location.href=t.target.href)},handleMouseDown:function(t){t.preventDefault(),t.stopPropagation(),this.props.onSelect(this.props.option,t)},handleMouseEnter:function(t){this.onFocus(t)},handleMouseMove:function(t){this.onFocus(t)},handleTouchEnd:function(t){this.dragging||this.handleMouseDown(t)},handleTouchMove:function(t){this.dragging=!0},handleTouchStart:function(t){this.dragging=!1},onFocus:function(t){this.props.isFocused||this.props.onFocus(this.props.option,t)},render:function(){var t=this.props,e=t.option,n=t.instancePrefix,r=t.optionIndex,o=(0,s.default)(this.props.className,e.className);return e.disabled?i.default.createElement("div",{className:o,onMouseDown:this.blockEvent,onClick:this.blockEvent},this.props.children):i.default.createElement("div",{className:o,style:e.style,role:"option",onMouseDown:this.handleMouseDown,onMouseEnter:this.handleMouseEnter,onMouseMove:this.handleMouseMove,onTouchStart:this.handleTouchStart,onTouchMove:this.handleTouchMove,onTouchEnd:this.handleTouchEnd,id:n+"-option-"+r,title:e.title},this.props.children)}});t.exports=l},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}var o=n(1),i=r(o),a=n(6),s=r(a),l=i.default.createClass({displayName:"Value",propTypes:{children:i.default.PropTypes.node,disabled:i.default.PropTypes.bool,id:i.default.PropTypes.string,onClick:i.default.PropTypes.func,onRemove:i.default.PropTypes.func,value:i.default.PropTypes.object.isRequired},handleMouseDown:function(t){if("mousedown"!==t.type||0===t.button)return this.props.onClick?(t.stopPropagation(),void this.props.onClick(this.props.value,t)):void(this.props.value.href&&t.stopPropagation())},onRemove:function(t){t.preventDefault(),t.stopPropagation(),this.props.onRemove(this.props.value)},handleTouchEndRemove:function(t){this.dragging||this.onRemove(t)},handleTouchMove:function(t){this.dragging=!0},handleTouchStart:function(t){this.dragging=!1},renderRemoveIcon:function(){if(!this.props.disabled&&this.props.onRemove)return i.default.createElement("span",{className:"Select-value-icon","aria-hidden":"true",onMouseDown:this.onRemove,onTouchEnd:this.handleTouchEndRemove,onTouchStart:this.handleTouchStart,onTouchMove:this.handleTouchMove},"×")},renderLabel:function(){var t="Select-value-label";return this.props.onClick||this.props.value.href?i.default.createElement("a",{className:t,href:this.props.value.href,target:this.props.value.target,onMouseDown:this.handleMouseDown,onTouchEnd:this.handleMouseDown},this.props.children):i.default.createElement("span",{className:t,role:"option","aria-selected":"true",id:this.props.id},this.props.children)},render:function(){return i.default.createElement("div",{className:(0,s.default)("Select-value",this.props.value.className),style:this.props.value.style,title:this.props.value.title},this.renderRemoveIcon(),this.renderLabel())}});t.exports=l},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){var e=t.onMouseDown;return a.default.createElement("span",{className:"Select-arrow",onMouseDown:e})}Object.defineProperty(e,"__esModule",{value:!0}),e.default=o;var i=n(1),a=r(i);t.exports=e.default},function(t,e,n){var r=n(199);"string"==typeof r&&(r=[[t.id,r,""]]),n(42)(r,{}),r.locals&&(t.exports=r.locals)},function(t,e,n){var r=n(200);"string"==typeof r&&(r=[[t.id,r,""]]),n(42)(r,{}),r.locals&&(t.exports=r.locals)},function(t,e,n){var r=n(201);"string"==typeof r&&(r=[[t.id,r,""]]),n(42)(r,{}),r.locals&&(t.exports=r.locals)},function(t,e,n){var r=n(202);"string"==typeof r&&(r=[[t.id,r,""]]),n(42)(r,{}),r.locals&&(t.exports=r.locals)},function(t,e,n){var r=n(203);"string"==typeof r&&(r=[[t.id,r,""]]),n(42)(r,{}),r.locals&&(t.exports=r.locals)},function(t,e,n){"use strict";function r(t){if(t&&t.__esModule)return t;var e={};if(null!=t)for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n]);return e.default=t,e}function o(t){return t&&t.__esModule?t:{default:t}}function i(t,e){function n(r,o){function i(t,n){var r=d.getLinkName(t),i=this.props[o[t]];r&&s(this.props,r)&&!i&&(i=this.props[r].requestChange);for(var a=arguments.length,l=Array(a>2?a-2:0),u=2;u<a;u++)l[u-2]=arguments[u];e(this,t,i,n,l)}function s(t,e){return void 0!==t[e]}function u(t){var e={};return d.each(t,function(t,n){y.indexOf(n)===-1&&(e[n]=t)}),e}var f,p=arguments.length<=2||void 0===arguments[2]?[]:arguments[2],h=r.displayName||r.name||"Component",g=d.getType(r).propTypes,v=d.isReactComponent(r),m=Object.keys(o),y=["valueLink","checkedLink"].concat(m.map(d.defaultKey));f=d.uncontrolledPropTypes(o,g,h),(0,c.default)(v||!p.length,"[uncontrollable] stateless function components cannot pass through methods because they have no associated instances. Check component: "+h+", attempting to pass through methods: "+p.join(", ")),p=d.transform(p,function(t,e){t[e]=function(){var t;return(t=this.refs.inner)[e].apply(t,arguments)}},{});var b=l.default.createClass(a({displayName:"Uncontrolled("+h+")",mixins:t,propTypes:f},p,{componentWillMount:function(){var t=this,e=this.props;this._values={},m.forEach(function(n){t._values[n]=e[d.defaultKey(n)]})},componentWillReceiveProps:function(t){var e=this,n=this.props;m.forEach(function(r){void 0===d.getValue(t,r)&&void 0!==d.getValue(n,r)&&(e._values[r]=t[d.defaultKey(r)])})},getControlledInstance:function(){return this.refs.inner},render:function(){var t=this,e={},n=u(this.props);return d.each(o,function(n,r){var o=d.getLinkName(r),a=t.props[r];o&&!s(t.props,r)&&s(t.props,o)&&(a=t.props[o].value),e[r]=void 0!==a?a:t._values[r],e[n]=i.bind(t,r)}),e=a({},n,e,{ref:v?"inner":null}),l.default.createElement(r,e)}}));return b.ControlledComponent=r,b.deferControlTo=function(t){var e=arguments.length<=1||void 0===arguments[1]?{}:arguments[1],r=arguments[2];return n(t,a({},o,e),r)},b}return n}e.__esModule=!0;var a=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t};e.default=i;var s=n(1),l=o(s),u=n(75),c=o(u),f=n(303),d=r(f);t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r={};return r}function i(t){return y[0]>=15||0===y[0]&&y[1]>=13?t:t.type}function a(t,e){var n=l(e);return n&&!s(t,e)&&s(t,n)?t[n].value:t[e]}function s(t,e){return void 0!==t[e]}function l(t){return"value"===t?"valueLink":"checked"===t?"checkedLink":null}function u(t){return"default"+t.charAt(0).toUpperCase()+t.substr(1)}function c(t,e,n){return function(){for(var r=arguments.length,o=Array(r),i=0;i<r;i++)o[i]=arguments[i];e&&e.call.apply(e,[t].concat(o)),n&&n.call.apply(n,[t].concat(o))}}function f(t,e,n){return d(t,e.bind(null,n=n||(Array.isArray(t)?[]:{}))),n}function d(t,e,n){if(Array.isArray(t))return t.forEach(e,n);for(var r in t)p(t,r)&&e.call(n,t[r],r,t)}function p(t,e){return!!t&&Object.prototype.hasOwnProperty.call(t,e)}function h(t){return!!(t&&t.prototype&&t.prototype.isReactComponent)}e.__esModule=!0,e.version=void 0,e.uncontrolledPropTypes=o,e.getType=i,e.getValue=a,e.getLinkName=l,e.defaultKey=u,e.chain=c,e.transform=f,e.each=d,e.has=p,e.isReactComponent=h;var g=n(1),v=r(g),m=n(75),y=(r(m),e.version=v.default.version.split(".").map(parseFloat))},function(t,e,n){t.exports=n.p+"e18bbf611f2a2e43afc071aa2f4e1512.ttf"},function(t,e,n){t.exports=n.p+"89889688147bd7575d6327160d64e760.svg"},function(t,e){t.exports="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABMAAAATCAYAAAByUDbMAAAAZ0lEQVQ4y2NgGLKgquEuFxBPAGI2ahhWCsS/gDibUoO0gPgxEP8H4ttArEyuQYxAPBdqEAxPBImTY5gjEL9DM+wTENuQahAvEO9DMwiGdwAxOymGJQLxTyD+jgWDxCMZRsEoGAVoAADeemwtPcZI2wAAAABJRU5ErkJggg=="},function(t,e){t.exports="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABMAAAATCAQAAADYWf5HAAAAW0lEQVQoz2NgoCm4w3Vnwh02wspK7/y6k01Ikdadx3f+37l9RxmfIsY7c4GKQHDiHUbcyhzvvIMq+3THBpci3jv7oIpAcMcdduzKEu/8vPMdDn/eiWQYBYMKAAC3ykIEuYQJUgAAAABJRU5ErkJggg=="},function(t,e){t.exports="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABMAAAATCAQAAADYWf5HAAAAkElEQVQoz7XQMQ5AQBCF4dWQSJxC5wwax1Cq1e7BAdxD5SL+Tq/QCM1oNiJidwox0355mXnG/DrEtIQ6azioNZQxI0ykPhTQIwhCR+BmBYtlK7kLJYwWCcJA9M4qdrZrd8pPjZWPtOqdRQy320YSV17OatFC4euts6z39GYMKRPCTKY9UnPQ6P+GtMRfGtPnBCiqhAeJPmkqAAAAAElFTkSuQmCC"},function(t,e){t.exports="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABMAAAATCAYAAAByUDbMAAAAZUlEQVQ4y2NgGAWjYBSggaqGu5FA/BOIv2PBIPFEUgxjB+IdQPwfC94HxLykus4GiD+hGfQOiB3J8SojEE9EM2wuSJzcsFMG4ttQgx4DsRalkZENxL+AuJQaMcsGxBOAmGvopk8AVz1sLZgg0bsAAAAASUVORK5CYII="},function(t,e){t.exports="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABMAAAATCAQAAADYWf5HAAAAWUlEQVQoz2NgGAWDCtyJvPPzznc4/HknEbsy9js77vyHw313eHGZZ3PnE1TRuzuOuK1lvDMRqmzuHUZ87lO+cxuo6PEdLUIeyb7z604pYf+y3Zlwh4u2YQoAc7ZCBHH4jigAAAAASUVORK5CYII="},function(t,e,n){t.exports=n.p+"fa2772327f55d8198301fdb8bcfc8158.woff"},function(t,e,n){t.exports=n.p+"448c34a56d699c29117adc64c43affeb.woff2"}])})}).call(e,n(169),n(170),n(171),n(173),n(175))},function(t,e,n){var r,o;/*!
	 * jQuery JavaScript Library v3.1.1
	 * https://jquery.com/
	 *
	 * Includes Sizzle.js
	 * https://sizzlejs.com/
	 *
	 * Copyright jQuery Foundation and other contributors
	 * Released under the MIT license
	 * https://jquery.org/license
	 *
	 * Date: 2016-09-22T22:30Z
	 */
!function(e,n){"use strict";"object"==typeof t&&"object"==typeof t.exports?t.exports=e.document?n(e,!0):function(t){if(!t.document)throw new Error("jQuery requires a window with a document");return n(t)}:n(e)}("undefined"!=typeof window?window:this,function(n,i){"use strict";function a(t,e){e=e||it;var n=e.createElement("script");n.text=t,e.head.appendChild(n).parentNode.removeChild(n)}function s(t){var e=!!t&&"length"in t&&t.length,n=yt.type(t);return"function"!==n&&!yt.isWindow(t)&&("array"===n||0===e||"number"==typeof e&&e>0&&e-1 in t)}function l(t,e,n){return yt.isFunction(e)?yt.grep(t,function(t,r){return!!e.call(t,r,t)!==n}):e.nodeType?yt.grep(t,function(t){return t===e!==n}):"string"!=typeof e?yt.grep(t,function(t){return ct.call(e,t)>-1!==n}):St.test(e)?yt.filter(e,t,n):(e=yt.filter(e,t),yt.grep(t,function(t){return ct.call(e,t)>-1!==n&&1===t.nodeType}))}function u(t,e){for(;(t=t[e])&&1!==t.nodeType;);return t}function c(t){var e={};return yt.each(t.match(It)||[],function(t,n){e[n]=!0}),e}function f(t){return t}function d(t){throw t}function p(t,e,n){var r;try{t&&yt.isFunction(r=t.promise)?r.call(t).done(e).fail(n):t&&yt.isFunction(r=t.then)?r.call(t,e,n):e.call(void 0,t)}catch(t){n.call(void 0,t)}}function h(){it.removeEventListener("DOMContentLoaded",h),n.removeEventListener("load",h),yt.ready()}function g(){this.expando=yt.expando+g.uid++}function v(t){return"true"===t||"false"!==t&&("null"===t?null:t===+t+""?+t:Ht.test(t)?JSON.parse(t):t)}function m(t,e,n){var r;if(void 0===n&&1===t.nodeType)if(r="data-"+e.replace(zt,"-$&").toLowerCase(),n=t.getAttribute(r),"string"==typeof n){try{n=v(n)}catch(t){}Ut.set(t,e,n)}else n=void 0;return n}function y(t,e,n,r){var o,i=1,a=20,s=r?function(){return r.cur()}:function(){return yt.css(t,e,"")},l=s(),u=n&&n[3]||(yt.cssNumber[e]?"":"px"),c=(yt.cssNumber[e]||"px"!==u&&+l)&&qt.exec(yt.css(t,e));if(c&&c[3]!==u){u=u||c[3],n=n||[],c=+l||1;do i=i||".5",c/=i,yt.style(t,e,c+u);while(i!==(i=s()/l)&&1!==i&&--a)}return n&&(c=+c||+l||0,o=n[1]?c+(n[1]+1)*n[2]:+n[2],r&&(r.unit=u,r.start=c,r.end=o)),o}function b(t){var e,n=t.ownerDocument,r=t.nodeName,o=Gt[r];return o?o:(e=n.body.appendChild(n.createElement(r)),o=yt.css(e,"display"),e.parentNode.removeChild(e),"none"===o&&(o="block"),Gt[r]=o,o)}function x(t,e){for(var n,r,o=[],i=0,a=t.length;i<a;i++)r=t[i],r.style&&(n=r.style.display,e?("none"===n&&(o[i]=Bt.get(r,"display")||null,o[i]||(r.style.display="")),""===r.style.display&&Kt(r)&&(o[i]=b(r))):"none"!==n&&(o[i]="none",Bt.set(r,"display",n)));for(i=0;i<a;i++)null!=o[i]&&(t[i].style.display=o[i]);return t}function _(t,e){var n;return n="undefined"!=typeof t.getElementsByTagName?t.getElementsByTagName(e||"*"):"undefined"!=typeof t.querySelectorAll?t.querySelectorAll(e||"*"):[],void 0===e||e&&yt.nodeName(t,e)?yt.merge([t],n):n}function w(t,e){for(var n=0,r=t.length;n<r;n++)Bt.set(t[n],"globalEval",!e||Bt.get(e[n],"globalEval"))}function T(t,e,n,r,o){for(var i,a,s,l,u,c,f=e.createDocumentFragment(),d=[],p=0,h=t.length;p<h;p++)if(i=t[p],i||0===i)if("object"===yt.type(i))yt.merge(d,i.nodeType?[i]:i);else if(Qt.test(i)){for(a=a||f.appendChild(e.createElement("div")),s=($t.exec(i)||["",""])[1].toLowerCase(),l=Jt[s]||Jt._default,a.innerHTML=l[1]+yt.htmlPrefilter(i)+l[2],c=l[0];c--;)a=a.lastChild;yt.merge(d,a.childNodes),a=f.firstChild,a.textContent=""}else d.push(e.createTextNode(i));for(f.textContent="",p=0;i=d[p++];)if(r&&yt.inArray(i,r)>-1)o&&o.push(i);else if(u=yt.contains(i.ownerDocument,i),a=_(f.appendChild(i),"script"),u&&w(a),n)for(c=0;i=a[c++];)Zt.test(i.type||"")&&n.push(i);return f}function C(){return!0}function k(){return!1}function E(){try{return it.activeElement}catch(t){}}function P(t,e,n,r,o,i){var a,s;if("object"==typeof e){"string"!=typeof n&&(r=r||n,n=void 0);for(s in e)P(t,s,n,r,e[s],i);return t}if(null==r&&null==o?(o=n,r=n=void 0):null==o&&("string"==typeof n?(o=r,r=void 0):(o=r,r=n,n=void 0)),o===!1)o=k;else if(!o)return t;return 1===i&&(a=o,o=function(t){return yt().off(t),a.apply(this,arguments)},o.guid=a.guid||(a.guid=yt.guid++)),t.each(function(){yt.event.add(this,e,o,r,n)})}function S(t,e){return yt.nodeName(t,"table")&&yt.nodeName(11!==e.nodeType?e:e.firstChild,"tr")?t.getElementsByTagName("tbody")[0]||t:t}function M(t){return t.type=(null!==t.getAttribute("type"))+"/"+t.type,t}function N(t){var e=se.exec(t.type);return e?t.type=e[1]:t.removeAttribute("type"),t}function A(t,e){var n,r,o,i,a,s,l,u;if(1===e.nodeType){if(Bt.hasData(t)&&(i=Bt.access(t),a=Bt.set(e,i),u=i.events)){delete a.handle,a.events={};for(o in u)for(n=0,r=u[o].length;n<r;n++)yt.event.add(e,o,u[o][n])}Ut.hasData(t)&&(s=Ut.access(t),l=yt.extend({},s),Ut.set(e,l))}}function O(t,e){var n=e.nodeName.toLowerCase();"input"===n&&Xt.test(t.type)?e.checked=t.checked:"input"!==n&&"textarea"!==n||(e.defaultValue=t.defaultValue)}function D(t,e,n,r){e=lt.apply([],e);var o,i,s,l,u,c,f=0,d=t.length,p=d-1,h=e[0],g=yt.isFunction(h);if(g||d>1&&"string"==typeof h&&!vt.checkClone&&ae.test(h))return t.each(function(o){var i=t.eq(o);g&&(e[0]=h.call(this,o,i.html())),D(i,e,n,r)});if(d&&(o=T(e,t[0].ownerDocument,!1,t,r),i=o.firstChild,1===o.childNodes.length&&(o=i),i||r)){for(s=yt.map(_(o,"script"),M),l=s.length;f<d;f++)u=o,f!==p&&(u=yt.clone(u,!0,!0),l&&yt.merge(s,_(u,"script"))),n.call(t[f],u,f);if(l)for(c=s[s.length-1].ownerDocument,yt.map(s,N),f=0;f<l;f++)u=s[f],Zt.test(u.type||"")&&!Bt.access(u,"globalEval")&&yt.contains(c,u)&&(u.src?yt._evalUrl&&yt._evalUrl(u.src):a(u.textContent.replace(le,""),c))}return t}function I(t,e,n){for(var r,o=e?yt.filter(e,t):t,i=0;null!=(r=o[i]);i++)n||1!==r.nodeType||yt.cleanData(_(r)),r.parentNode&&(n&&yt.contains(r.ownerDocument,r)&&w(_(r,"script")),r.parentNode.removeChild(r));return t}function R(t,e,n){var r,o,i,a,s=t.style;return n=n||fe(t),n&&(a=n.getPropertyValue(e)||n[e],""!==a||yt.contains(t.ownerDocument,t)||(a=yt.style(t,e)),!vt.pixelMarginRight()&&ce.test(a)&&ue.test(e)&&(r=s.width,o=s.minWidth,i=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=r,s.minWidth=o,s.maxWidth=i)),void 0!==a?a+"":a}function L(t,e){return{get:function(){return t()?void delete this.get:(this.get=e).apply(this,arguments)}}}function F(t){if(t in ve)return t;for(var e=t[0].toUpperCase()+t.slice(1),n=ge.length;n--;)if(t=ge[n]+e,t in ve)return t}function j(t,e,n){var r=qt.exec(e);return r?Math.max(0,r[2]-(n||0))+(r[3]||"px"):e}function B(t,e,n,r,o){var i,a=0;for(i=n===(r?"border":"content")?4:"width"===e?1:0;i<4;i+=2)"margin"===n&&(a+=yt.css(t,n+Vt[i],!0,o)),r?("content"===n&&(a-=yt.css(t,"padding"+Vt[i],!0,o)),"margin"!==n&&(a-=yt.css(t,"border"+Vt[i]+"Width",!0,o))):(a+=yt.css(t,"padding"+Vt[i],!0,o),"padding"!==n&&(a+=yt.css(t,"border"+Vt[i]+"Width",!0,o)));return a}function U(t,e,n){var r,o=!0,i=fe(t),a="border-box"===yt.css(t,"boxSizing",!1,i);if(t.getClientRects().length&&(r=t.getBoundingClientRect()[e]),r<=0||null==r){if(r=R(t,e,i),(r<0||null==r)&&(r=t.style[e]),ce.test(r))return r;o=a&&(vt.boxSizingReliable()||r===t.style[e]),r=parseFloat(r)||0}return r+B(t,e,n||(a?"border":"content"),o,i)+"px"}function H(t,e,n,r,o){return new H.prototype.init(t,e,n,r,o)}function z(){ye&&(n.requestAnimationFrame(z),yt.fx.tick())}function W(){return n.setTimeout(function(){me=void 0}),me=yt.now()}function q(t,e){var n,r=0,o={height:t};for(e=e?1:0;r<4;r+=2-e)n=Vt[r],o["margin"+n]=o["padding"+n]=t;return e&&(o.opacity=o.width=t),o}function V(t,e,n){for(var r,o=(G.tweeners[e]||[]).concat(G.tweeners["*"]),i=0,a=o.length;i<a;i++)if(r=o[i].call(n,e,t))return r}function K(t,e,n){var r,o,i,a,s,l,u,c,f="width"in e||"height"in e,d=this,p={},h=t.style,g=t.nodeType&&Kt(t),v=Bt.get(t,"fxshow");n.queue||(a=yt._queueHooks(t,"fx"),null==a.unqueued&&(a.unqueued=0,s=a.empty.fire,a.empty.fire=function(){a.unqueued||s()}),a.unqueued++,d.always(function(){d.always(function(){a.unqueued--,yt.queue(t,"fx").length||a.empty.fire()})}));for(r in e)if(o=e[r],be.test(o)){if(delete e[r],i=i||"toggle"===o,o===(g?"hide":"show")){if("show"!==o||!v||void 0===v[r])continue;g=!0}p[r]=v&&v[r]||yt.style(t,r)}if(l=!yt.isEmptyObject(e),l||!yt.isEmptyObject(p)){f&&1===t.nodeType&&(n.overflow=[h.overflow,h.overflowX,h.overflowY],u=v&&v.display,null==u&&(u=Bt.get(t,"display")),c=yt.css(t,"display"),"none"===c&&(u?c=u:(x([t],!0),u=t.style.display||u,c=yt.css(t,"display"),x([t]))),("inline"===c||"inline-block"===c&&null!=u)&&"none"===yt.css(t,"float")&&(l||(d.done(function(){h.display=u}),null==u&&(c=h.display,u="none"===c?"":c)),h.display="inline-block")),n.overflow&&(h.overflow="hidden",d.always(function(){h.overflow=n.overflow[0],h.overflowX=n.overflow[1],h.overflowY=n.overflow[2]})),l=!1;for(r in p)l||(v?"hidden"in v&&(g=v.hidden):v=Bt.access(t,"fxshow",{display:u}),i&&(v.hidden=!g),g&&x([t],!0),d.done(function(){g||x([t]),Bt.remove(t,"fxshow");for(r in p)yt.style(t,r,p[r])})),l=V(g?v[r]:0,r,d),r in v||(v[r]=l.start,g&&(l.end=l.start,l.start=0))}}function Y(t,e){var n,r,o,i,a;for(n in t)if(r=yt.camelCase(n),o=e[r],i=t[n],yt.isArray(i)&&(o=i[1],i=t[n]=i[0]),n!==r&&(t[r]=i,delete t[n]),a=yt.cssHooks[r],a&&"expand"in a){i=a.expand(i),delete t[r];for(n in i)n in t||(t[n]=i[n],e[n]=o)}else e[r]=o}function G(t,e,n){var r,o,i=0,a=G.prefilters.length,s=yt.Deferred().always(function(){delete l.elem}),l=function(){if(o)return!1;for(var e=me||W(),n=Math.max(0,u.startTime+u.duration-e),r=n/u.duration||0,i=1-r,a=0,l=u.tweens.length;a<l;a++)u.tweens[a].run(i);return s.notifyWith(t,[u,i,n]),i<1&&l?n:(s.resolveWith(t,[u]),!1)},u=s.promise({elem:t,props:yt.extend({},e),opts:yt.extend(!0,{specialEasing:{},easing:yt.easing._default},n),originalProperties:e,originalOptions:n,startTime:me||W(),duration:n.duration,tweens:[],createTween:function(e,n){var r=yt.Tween(t,u.opts,e,n,u.opts.specialEasing[e]||u.opts.easing);return u.tweens.push(r),r},stop:function(e){var n=0,r=e?u.tweens.length:0;if(o)return this;for(o=!0;n<r;n++)u.tweens[n].run(1);return e?(s.notifyWith(t,[u,1,0]),s.resolveWith(t,[u,e])):s.rejectWith(t,[u,e]),this}}),c=u.props;for(Y(c,u.opts.specialEasing);i<a;i++)if(r=G.prefilters[i].call(u,t,c,u.opts))return yt.isFunction(r.stop)&&(yt._queueHooks(u.elem,u.opts.queue).stop=yt.proxy(r.stop,r)),r;return yt.map(c,V,u),yt.isFunction(u.opts.start)&&u.opts.start.call(t,u),yt.fx.timer(yt.extend(l,{elem:t,anim:u,queue:u.opts.queue})),u.progress(u.opts.progress).done(u.opts.done,u.opts.complete).fail(u.opts.fail).always(u.opts.always)}function X(t){var e=t.match(It)||[];return e.join(" ")}function $(t){return t.getAttribute&&t.getAttribute("class")||""}function Z(t,e,n,r){var o;if(yt.isArray(e))yt.each(e,function(e,o){n||Ne.test(t)?r(t,o):Z(t+"["+("object"==typeof o&&null!=o?e:"")+"]",o,n,r)});else if(n||"object"!==yt.type(e))r(t,e);else for(o in e)Z(t+"["+o+"]",e[o],n,r)}function J(t){return function(e,n){"string"!=typeof e&&(n=e,e="*");var r,o=0,i=e.toLowerCase().match(It)||[];if(yt.isFunction(n))for(;r=i[o++];)"+"===r[0]?(r=r.slice(1)||"*",(t[r]=t[r]||[]).unshift(n)):(t[r]=t[r]||[]).push(n)}}function Q(t,e,n,r){function o(s){var l;return i[s]=!0,yt.each(t[s]||[],function(t,s){var u=s(e,n,r);return"string"!=typeof u||a||i[u]?a?!(l=u):void 0:(e.dataTypes.unshift(u),o(u),!1)}),l}var i={},a=t===ze;return o(e.dataTypes[0])||!i["*"]&&o("*")}function tt(t,e){var n,r,o=yt.ajaxSettings.flatOptions||{};for(n in e)void 0!==e[n]&&((o[n]?t:r||(r={}))[n]=e[n]);return r&&yt.extend(!0,t,r),t}function et(t,e,n){for(var r,o,i,a,s=t.contents,l=t.dataTypes;"*"===l[0];)l.shift(),void 0===r&&(r=t.mimeType||e.getResponseHeader("Content-Type"));if(r)for(o in s)if(s[o]&&s[o].test(r)){l.unshift(o);break}if(l[0]in n)i=l[0];else{for(o in n){if(!l[0]||t.converters[o+" "+l[0]]){i=o;break}a||(a=o)}i=i||a}if(i)return i!==l[0]&&l.unshift(i),n[i]}function nt(t,e,n,r){var o,i,a,s,l,u={},c=t.dataTypes.slice();if(c[1])for(a in t.converters)u[a.toLowerCase()]=t.converters[a];for(i=c.shift();i;)if(t.responseFields[i]&&(n[t.responseFields[i]]=e),!l&&r&&t.dataFilter&&(e=t.dataFilter(e,t.dataType)),l=i,i=c.shift())if("*"===i)i=l;else if("*"!==l&&l!==i){if(a=u[l+" "+i]||u["* "+i],!a)for(o in u)if(s=o.split(" "),s[1]===i&&(a=u[l+" "+s[0]]||u["* "+s[0]])){a===!0?a=u[o]:u[o]!==!0&&(i=s[0],c.unshift(s[1]));break}if(a!==!0)if(a&&t.throws)e=a(e);else try{e=a(e)}catch(t){return{state:"parsererror",error:a?t:"No conversion from "+l+" to "+i}}}return{state:"success",data:e}}function rt(t){return yt.isWindow(t)?t:9===t.nodeType&&t.defaultView}var ot=[],it=n.document,at=Object.getPrototypeOf,st=ot.slice,lt=ot.concat,ut=ot.push,ct=ot.indexOf,ft={},dt=ft.toString,pt=ft.hasOwnProperty,ht=pt.toString,gt=ht.call(Object),vt={},mt="3.1.1",yt=function(t,e){return new yt.fn.init(t,e)},bt=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,xt=/^-ms-/,_t=/-([a-z])/g,wt=function(t,e){return e.toUpperCase()};yt.fn=yt.prototype={jquery:mt,constructor:yt,length:0,toArray:function(){return st.call(this)},get:function(t){return null==t?st.call(this):t<0?this[t+this.length]:this[t]},pushStack:function(t){var e=yt.merge(this.constructor(),t);return e.prevObject=this,e},each:function(t){return yt.each(this,t)},map:function(t){return this.pushStack(yt.map(this,function(e,n){return t.call(e,n,e)}))},slice:function(){return this.pushStack(st.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(t){var e=this.length,n=+t+(t<0?e:0);return this.pushStack(n>=0&&n<e?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:ut,sort:ot.sort,splice:ot.splice},yt.extend=yt.fn.extend=function(){var t,e,n,r,o,i,a=arguments[0]||{},s=1,l=arguments.length,u=!1;for("boolean"==typeof a&&(u=a,a=arguments[s]||{},s++),"object"==typeof a||yt.isFunction(a)||(a={}),s===l&&(a=this,s--);s<l;s++)if(null!=(t=arguments[s]))for(e in t)n=a[e],r=t[e],a!==r&&(u&&r&&(yt.isPlainObject(r)||(o=yt.isArray(r)))?(o?(o=!1,i=n&&yt.isArray(n)?n:[]):i=n&&yt.isPlainObject(n)?n:{},a[e]=yt.extend(u,i,r)):void 0!==r&&(a[e]=r));return a},yt.extend({expando:"jQuery"+(mt+Math.random()).replace(/\D/g,""),isReady:!0,error:function(t){throw new Error(t)},noop:function(){},isFunction:function(t){return"function"===yt.type(t)},isArray:Array.isArray,isWindow:function(t){return null!=t&&t===t.window},isNumeric:function(t){var e=yt.type(t);return("number"===e||"string"===e)&&!isNaN(t-parseFloat(t))},isPlainObject:function(t){var e,n;return!(!t||"[object Object]"!==dt.call(t))&&(!(e=at(t))||(n=pt.call(e,"constructor")&&e.constructor,"function"==typeof n&&ht.call(n)===gt))},isEmptyObject:function(t){var e;for(e in t)return!1;return!0},type:function(t){return null==t?t+"":"object"==typeof t||"function"==typeof t?ft[dt.call(t)]||"object":typeof t},globalEval:function(t){a(t)},camelCase:function(t){return t.replace(xt,"ms-").replace(_t,wt)},nodeName:function(t,e){return t.nodeName&&t.nodeName.toLowerCase()===e.toLowerCase()},each:function(t,e){var n,r=0;if(s(t))for(n=t.length;r<n&&e.call(t[r],r,t[r])!==!1;r++);else for(r in t)if(e.call(t[r],r,t[r])===!1)break;return t},trim:function(t){return null==t?"":(t+"").replace(bt,"")},makeArray:function(t,e){var n=e||[];return null!=t&&(s(Object(t))?yt.merge(n,"string"==typeof t?[t]:t):ut.call(n,t)),n},inArray:function(t,e,n){return null==e?-1:ct.call(e,t,n)},merge:function(t,e){for(var n=+e.length,r=0,o=t.length;r<n;r++)t[o++]=e[r];return t.length=o,t},grep:function(t,e,n){for(var r,o=[],i=0,a=t.length,s=!n;i<a;i++)r=!e(t[i],i),r!==s&&o.push(t[i]);return o},map:function(t,e,n){var r,o,i=0,a=[];if(s(t))for(r=t.length;i<r;i++)o=e(t[i],i,n),null!=o&&a.push(o);else for(i in t)o=e(t[i],i,n),null!=o&&a.push(o);return lt.apply([],a)},guid:1,proxy:function(t,e){var n,r,o;if("string"==typeof e&&(n=t[e],e=t,t=n),yt.isFunction(t))return r=st.call(arguments,2),o=function(){return t.apply(e||this,r.concat(st.call(arguments)))},o.guid=t.guid=t.guid||yt.guid++,o},now:Date.now,support:vt}),"function"==typeof Symbol&&(yt.fn[Symbol.iterator]=ot[Symbol.iterator]),yt.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(t,e){ft["[object "+e+"]"]=e.toLowerCase()});var Tt=/*!
	 * Sizzle CSS Selector Engine v2.3.3
	 * https://sizzlejs.com/
	 *
	 * Copyright jQuery Foundation and other contributors
	 * Released under the MIT license
	 * http://jquery.org/license
	 *
	 * Date: 2016-08-08
	 */
function(t){function e(t,e,n,r){var o,i,a,s,l,u,c,d=e&&e.ownerDocument,h=e?e.nodeType:9;if(n=n||[],"string"!=typeof t||!t||1!==h&&9!==h&&11!==h)return n;if(!r&&((e?e.ownerDocument||e:H)!==D&&O(e),e=e||D,R)){if(11!==h&&(l=mt.exec(t)))if(o=l[1]){if(9===h){if(!(a=e.getElementById(o)))return n;if(a.id===o)return n.push(a),n}else if(d&&(a=d.getElementById(o))&&B(e,a)&&a.id===o)return n.push(a),n}else{if(l[2])return J.apply(n,e.getElementsByTagName(t)),n;if((o=l[3])&&w.getElementsByClassName&&e.getElementsByClassName)return J.apply(n,e.getElementsByClassName(o)),n}if(w.qsa&&!K[t+" "]&&(!L||!L.test(t))){if(1!==h)d=e,c=t;else if("object"!==e.nodeName.toLowerCase()){for((s=e.getAttribute("id"))?s=s.replace(_t,wt):e.setAttribute("id",s=U),u=E(t),i=u.length;i--;)u[i]="#"+s+" "+p(u[i]);c=u.join(","),d=yt.test(t)&&f(e.parentNode)||e}if(c)try{return J.apply(n,d.querySelectorAll(c)),n}catch(t){}finally{s===U&&e.removeAttribute("id")}}}return S(t.replace(st,"$1"),e,n,r)}function n(){function t(n,r){return e.push(n+" ")>T.cacheLength&&delete t[e.shift()],t[n+" "]=r}var e=[];return t}function r(t){return t[U]=!0,t}function o(t){var e=D.createElement("fieldset");try{return!!t(e)}catch(t){return!1}finally{e.parentNode&&e.parentNode.removeChild(e),e=null}}function i(t,e){for(var n=t.split("|"),r=n.length;r--;)T.attrHandle[n[r]]=e}function a(t,e){var n=e&&t,r=n&&1===t.nodeType&&1===e.nodeType&&t.sourceIndex-e.sourceIndex;if(r)return r;if(n)for(;n=n.nextSibling;)if(n===e)return-1;return t?1:-1}function s(t){return function(e){var n=e.nodeName.toLowerCase();return"input"===n&&e.type===t}}function l(t){return function(e){var n=e.nodeName.toLowerCase();return("input"===n||"button"===n)&&e.type===t}}function u(t){return function(e){return"form"in e?e.parentNode&&e.disabled===!1?"label"in e?"label"in e.parentNode?e.parentNode.disabled===t:e.disabled===t:e.isDisabled===t||e.isDisabled!==!t&&Ct(e)===t:e.disabled===t:"label"in e&&e.disabled===t}}function c(t){return r(function(e){return e=+e,r(function(n,r){for(var o,i=t([],n.length,e),a=i.length;a--;)n[o=i[a]]&&(n[o]=!(r[o]=n[o]))})})}function f(t){return t&&"undefined"!=typeof t.getElementsByTagName&&t}function d(){}function p(t){for(var e=0,n=t.length,r="";e<n;e++)r+=t[e].value;return r}function h(t,e,n){var r=e.dir,o=e.next,i=o||r,a=n&&"parentNode"===i,s=W++;return e.first?function(e,n,o){for(;e=e[r];)if(1===e.nodeType||a)return t(e,n,o);return!1}:function(e,n,l){var u,c,f,d=[z,s];if(l){for(;e=e[r];)if((1===e.nodeType||a)&&t(e,n,l))return!0}else for(;e=e[r];)if(1===e.nodeType||a)if(f=e[U]||(e[U]={}),c=f[e.uniqueID]||(f[e.uniqueID]={}),o&&o===e.nodeName.toLowerCase())e=e[r]||e;else{if((u=c[i])&&u[0]===z&&u[1]===s)return d[2]=u[2];if(c[i]=d,d[2]=t(e,n,l))return!0}return!1}}function g(t){return t.length>1?function(e,n,r){for(var o=t.length;o--;)if(!t[o](e,n,r))return!1;return!0}:t[0]}function v(t,n,r){for(var o=0,i=n.length;o<i;o++)e(t,n[o],r);return r}function m(t,e,n,r,o){for(var i,a=[],s=0,l=t.length,u=null!=e;s<l;s++)(i=t[s])&&(n&&!n(i,r,o)||(a.push(i),u&&e.push(s)));return a}function y(t,e,n,o,i,a){return o&&!o[U]&&(o=y(o)),i&&!i[U]&&(i=y(i,a)),r(function(r,a,s,l){var u,c,f,d=[],p=[],h=a.length,g=r||v(e||"*",s.nodeType?[s]:s,[]),y=!t||!r&&e?g:m(g,d,t,s,l),b=n?i||(r?t:h||o)?[]:a:y;if(n&&n(y,b,s,l),o)for(u=m(b,p),o(u,[],s,l),c=u.length;c--;)(f=u[c])&&(b[p[c]]=!(y[p[c]]=f));if(r){if(i||t){if(i){for(u=[],c=b.length;c--;)(f=b[c])&&u.push(y[c]=f);i(null,b=[],u,l)}for(c=b.length;c--;)(f=b[c])&&(u=i?tt(r,f):d[c])>-1&&(r[u]=!(a[u]=f))}}else b=m(b===a?b.splice(h,b.length):b),i?i(null,a,b,l):J.apply(a,b)})}function b(t){for(var e,n,r,o=t.length,i=T.relative[t[0].type],a=i||T.relative[" "],s=i?1:0,l=h(function(t){return t===e},a,!0),u=h(function(t){return tt(e,t)>-1},a,!0),c=[function(t,n,r){var o=!i&&(r||n!==M)||((e=n).nodeType?l(t,n,r):u(t,n,r));return e=null,o}];s<o;s++)if(n=T.relative[t[s].type])c=[h(g(c),n)];else{if(n=T.filter[t[s].type].apply(null,t[s].matches),n[U]){for(r=++s;r<o&&!T.relative[t[r].type];r++);return y(s>1&&g(c),s>1&&p(t.slice(0,s-1).concat({value:" "===t[s-2].type?"*":""})).replace(st,"$1"),n,s<r&&b(t.slice(s,r)),r<o&&b(t=t.slice(r)),r<o&&p(t))}c.push(n)}return g(c)}function x(t,n){var o=n.length>0,i=t.length>0,a=function(r,a,s,l,u){var c,f,d,p=0,h="0",g=r&&[],v=[],y=M,b=r||i&&T.find.TAG("*",u),x=z+=null==y?1:Math.random()||.1,_=b.length;for(u&&(M=a===D||a||u);h!==_&&null!=(c=b[h]);h++){if(i&&c){for(f=0,a||c.ownerDocument===D||(O(c),s=!R);d=t[f++];)if(d(c,a||D,s)){l.push(c);break}u&&(z=x)}o&&((c=!d&&c)&&p--,r&&g.push(c))}if(p+=h,o&&h!==p){for(f=0;d=n[f++];)d(g,v,a,s);if(r){if(p>0)for(;h--;)g[h]||v[h]||(v[h]=$.call(l));v=m(v)}J.apply(l,v),u&&!r&&v.length>0&&p+n.length>1&&e.uniqueSort(l)}return u&&(z=x,M=y),g};return o?r(a):a}var _,w,T,C,k,E,P,S,M,N,A,O,D,I,R,L,F,j,B,U="sizzle"+1*new Date,H=t.document,z=0,W=0,q=n(),V=n(),K=n(),Y=function(t,e){return t===e&&(A=!0),0},G={}.hasOwnProperty,X=[],$=X.pop,Z=X.push,J=X.push,Q=X.slice,tt=function(t,e){for(var n=0,r=t.length;n<r;n++)if(t[n]===e)return n;return-1},et="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",nt="[\\x20\\t\\r\\n\\f]",rt="(?:\\\\.|[\\w-]|[^\0-\\xa0])+",ot="\\["+nt+"*("+rt+")(?:"+nt+"*([*^$|!~]?=)"+nt+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+rt+"))|)"+nt+"*\\]",it=":("+rt+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+ot+")*)|.*)\\)|)",at=new RegExp(nt+"+","g"),st=new RegExp("^"+nt+"+|((?:^|[^\\\\])(?:\\\\.)*)"+nt+"+$","g"),lt=new RegExp("^"+nt+"*,"+nt+"*"),ut=new RegExp("^"+nt+"*([>+~]|"+nt+")"+nt+"*"),ct=new RegExp("="+nt+"*([^\\]'\"]*?)"+nt+"*\\]","g"),ft=new RegExp(it),dt=new RegExp("^"+rt+"$"),pt={ID:new RegExp("^#("+rt+")"),CLASS:new RegExp("^\\.("+rt+")"),TAG:new RegExp("^("+rt+"|[*])"),ATTR:new RegExp("^"+ot),PSEUDO:new RegExp("^"+it),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+nt+"*(even|odd|(([+-]|)(\\d*)n|)"+nt+"*(?:([+-]|)"+nt+"*(\\d+)|))"+nt+"*\\)|)","i"),bool:new RegExp("^(?:"+et+")$","i"),needsContext:new RegExp("^"+nt+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+nt+"*((?:-\\d)?\\d*)"+nt+"*\\)|)(?=[^-]|$)","i")},ht=/^(?:input|select|textarea|button)$/i,gt=/^h\d$/i,vt=/^[^{]+\{\s*\[native \w/,mt=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,yt=/[+~]/,bt=new RegExp("\\\\([\\da-f]{1,6}"+nt+"?|("+nt+")|.)","ig"),xt=function(t,e,n){var r="0x"+e-65536;return r!==r||n?e:r<0?String.fromCharCode(r+65536):String.fromCharCode(r>>10|55296,1023&r|56320)},_t=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,wt=function(t,e){return e?"\0"===t?"�":t.slice(0,-1)+"\\"+t.charCodeAt(t.length-1).toString(16)+" ":"\\"+t},Tt=function(){O()},Ct=h(function(t){return t.disabled===!0&&("form"in t||"label"in t)},{dir:"parentNode",next:"legend"});try{J.apply(X=Q.call(H.childNodes),H.childNodes),X[H.childNodes.length].nodeType}catch(t){J={apply:X.length?function(t,e){Z.apply(t,Q.call(e))}:function(t,e){for(var n=t.length,r=0;t[n++]=e[r++];);t.length=n-1}}}w=e.support={},k=e.isXML=function(t){var e=t&&(t.ownerDocument||t).documentElement;return!!e&&"HTML"!==e.nodeName},O=e.setDocument=function(t){var e,n,r=t?t.ownerDocument||t:H;return r!==D&&9===r.nodeType&&r.documentElement?(D=r,I=D.documentElement,R=!k(D),H!==D&&(n=D.defaultView)&&n.top!==n&&(n.addEventListener?n.addEventListener("unload",Tt,!1):n.attachEvent&&n.attachEvent("onunload",Tt)),w.attributes=o(function(t){return t.className="i",!t.getAttribute("className")}),w.getElementsByTagName=o(function(t){return t.appendChild(D.createComment("")),!t.getElementsByTagName("*").length}),w.getElementsByClassName=vt.test(D.getElementsByClassName),w.getById=o(function(t){return I.appendChild(t).id=U,!D.getElementsByName||!D.getElementsByName(U).length}),w.getById?(T.filter.ID=function(t){var e=t.replace(bt,xt);return function(t){return t.getAttribute("id")===e}},T.find.ID=function(t,e){if("undefined"!=typeof e.getElementById&&R){var n=e.getElementById(t);return n?[n]:[]}}):(T.filter.ID=function(t){var e=t.replace(bt,xt);return function(t){var n="undefined"!=typeof t.getAttributeNode&&t.getAttributeNode("id");return n&&n.value===e}},T.find.ID=function(t,e){if("undefined"!=typeof e.getElementById&&R){var n,r,o,i=e.getElementById(t);if(i){if(n=i.getAttributeNode("id"),n&&n.value===t)return[i];for(o=e.getElementsByName(t),r=0;i=o[r++];)if(n=i.getAttributeNode("id"),n&&n.value===t)return[i]}return[]}}),T.find.TAG=w.getElementsByTagName?function(t,e){return"undefined"!=typeof e.getElementsByTagName?e.getElementsByTagName(t):w.qsa?e.querySelectorAll(t):void 0}:function(t,e){var n,r=[],o=0,i=e.getElementsByTagName(t);if("*"===t){for(;n=i[o++];)1===n.nodeType&&r.push(n);return r}return i},T.find.CLASS=w.getElementsByClassName&&function(t,e){if("undefined"!=typeof e.getElementsByClassName&&R)return e.getElementsByClassName(t)},F=[],L=[],(w.qsa=vt.test(D.querySelectorAll))&&(o(function(t){I.appendChild(t).innerHTML="<a id='"+U+"'></a><select id='"+U+"-\r\\' msallowcapture=''><option selected=''></option></select>",t.querySelectorAll("[msallowcapture^='']").length&&L.push("[*^$]="+nt+"*(?:''|\"\")"),t.querySelectorAll("[selected]").length||L.push("\\["+nt+"*(?:value|"+et+")"),t.querySelectorAll("[id~="+U+"-]").length||L.push("~="),t.querySelectorAll(":checked").length||L.push(":checked"),t.querySelectorAll("a#"+U+"+*").length||L.push(".#.+[+~]")}),o(function(t){t.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var e=D.createElement("input");e.setAttribute("type","hidden"),t.appendChild(e).setAttribute("name","D"),t.querySelectorAll("[name=d]").length&&L.push("name"+nt+"*[*^$|!~]?="),2!==t.querySelectorAll(":enabled").length&&L.push(":enabled",":disabled"),I.appendChild(t).disabled=!0,2!==t.querySelectorAll(":disabled").length&&L.push(":enabled",":disabled"),t.querySelectorAll("*,:x"),L.push(",.*:")})),(w.matchesSelector=vt.test(j=I.matches||I.webkitMatchesSelector||I.mozMatchesSelector||I.oMatchesSelector||I.msMatchesSelector))&&o(function(t){w.disconnectedMatch=j.call(t,"*"),j.call(t,"[s!='']:x"),F.push("!=",it)}),L=L.length&&new RegExp(L.join("|")),F=F.length&&new RegExp(F.join("|")),e=vt.test(I.compareDocumentPosition),B=e||vt.test(I.contains)?function(t,e){var n=9===t.nodeType?t.documentElement:t,r=e&&e.parentNode;return t===r||!(!r||1!==r.nodeType||!(n.contains?n.contains(r):t.compareDocumentPosition&&16&t.compareDocumentPosition(r)))}:function(t,e){if(e)for(;e=e.parentNode;)if(e===t)return!0;return!1},Y=e?function(t,e){if(t===e)return A=!0,0;var n=!t.compareDocumentPosition-!e.compareDocumentPosition;return n?n:(n=(t.ownerDocument||t)===(e.ownerDocument||e)?t.compareDocumentPosition(e):1,1&n||!w.sortDetached&&e.compareDocumentPosition(t)===n?t===D||t.ownerDocument===H&&B(H,t)?-1:e===D||e.ownerDocument===H&&B(H,e)?1:N?tt(N,t)-tt(N,e):0:4&n?-1:1)}:function(t,e){if(t===e)return A=!0,0;var n,r=0,o=t.parentNode,i=e.parentNode,s=[t],l=[e];if(!o||!i)return t===D?-1:e===D?1:o?-1:i?1:N?tt(N,t)-tt(N,e):0;if(o===i)return a(t,e);for(n=t;n=n.parentNode;)s.unshift(n);for(n=e;n=n.parentNode;)l.unshift(n);for(;s[r]===l[r];)r++;return r?a(s[r],l[r]):s[r]===H?-1:l[r]===H?1:0},D):D},e.matches=function(t,n){return e(t,null,null,n)},e.matchesSelector=function(t,n){if((t.ownerDocument||t)!==D&&O(t),n=n.replace(ct,"='$1']"),w.matchesSelector&&R&&!K[n+" "]&&(!F||!F.test(n))&&(!L||!L.test(n)))try{var r=j.call(t,n);if(r||w.disconnectedMatch||t.document&&11!==t.document.nodeType)return r}catch(t){}return e(n,D,null,[t]).length>0},e.contains=function(t,e){return(t.ownerDocument||t)!==D&&O(t),B(t,e)},e.attr=function(t,e){(t.ownerDocument||t)!==D&&O(t);var n=T.attrHandle[e.toLowerCase()],r=n&&G.call(T.attrHandle,e.toLowerCase())?n(t,e,!R):void 0;return void 0!==r?r:w.attributes||!R?t.getAttribute(e):(r=t.getAttributeNode(e))&&r.specified?r.value:null},e.escape=function(t){return(t+"").replace(_t,wt)},e.error=function(t){throw new Error("Syntax error, unrecognized expression: "+t)},e.uniqueSort=function(t){var e,n=[],r=0,o=0;if(A=!w.detectDuplicates,N=!w.sortStable&&t.slice(0),t.sort(Y),A){for(;e=t[o++];)e===t[o]&&(r=n.push(o));for(;r--;)t.splice(n[r],1)}return N=null,t},C=e.getText=function(t){var e,n="",r=0,o=t.nodeType;if(o){if(1===o||9===o||11===o){if("string"==typeof t.textContent)return t.textContent;for(t=t.firstChild;t;t=t.nextSibling)n+=C(t)}else if(3===o||4===o)return t.nodeValue}else for(;e=t[r++];)n+=C(e);return n},T=e.selectors={cacheLength:50,createPseudo:r,match:pt,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(t){return t[1]=t[1].replace(bt,xt),t[3]=(t[3]||t[4]||t[5]||"").replace(bt,xt),"~="===t[2]&&(t[3]=" "+t[3]+" "),t.slice(0,4)},CHILD:function(t){return t[1]=t[1].toLowerCase(),"nth"===t[1].slice(0,3)?(t[3]||e.error(t[0]),t[4]=+(t[4]?t[5]+(t[6]||1):2*("even"===t[3]||"odd"===t[3])),t[5]=+(t[7]+t[8]||"odd"===t[3])):t[3]&&e.error(t[0]),t},PSEUDO:function(t){var e,n=!t[6]&&t[2];return pt.CHILD.test(t[0])?null:(t[3]?t[2]=t[4]||t[5]||"":n&&ft.test(n)&&(e=E(n,!0))&&(e=n.indexOf(")",n.length-e)-n.length)&&(t[0]=t[0].slice(0,e),t[2]=n.slice(0,e)),t.slice(0,3))}},filter:{TAG:function(t){var e=t.replace(bt,xt).toLowerCase();return"*"===t?function(){return!0}:function(t){return t.nodeName&&t.nodeName.toLowerCase()===e}},CLASS:function(t){var e=q[t+" "];return e||(e=new RegExp("(^|"+nt+")"+t+"("+nt+"|$)"))&&q(t,function(t){return e.test("string"==typeof t.className&&t.className||"undefined"!=typeof t.getAttribute&&t.getAttribute("class")||"")})},ATTR:function(t,n,r){return function(o){var i=e.attr(o,t);return null==i?"!="===n:!n||(i+="","="===n?i===r:"!="===n?i!==r:"^="===n?r&&0===i.indexOf(r):"*="===n?r&&i.indexOf(r)>-1:"$="===n?r&&i.slice(-r.length)===r:"~="===n?(" "+i.replace(at," ")+" ").indexOf(r)>-1:"|="===n&&(i===r||i.slice(0,r.length+1)===r+"-"))}},CHILD:function(t,e,n,r,o){var i="nth"!==t.slice(0,3),a="last"!==t.slice(-4),s="of-type"===e;return 1===r&&0===o?function(t){return!!t.parentNode}:function(e,n,l){var u,c,f,d,p,h,g=i!==a?"nextSibling":"previousSibling",v=e.parentNode,m=s&&e.nodeName.toLowerCase(),y=!l&&!s,b=!1;if(v){if(i){for(;g;){for(d=e;d=d[g];)if(s?d.nodeName.toLowerCase()===m:1===d.nodeType)return!1;h=g="only"===t&&!h&&"nextSibling"}return!0}if(h=[a?v.firstChild:v.lastChild],a&&y){for(d=v,f=d[U]||(d[U]={}),c=f[d.uniqueID]||(f[d.uniqueID]={}),u=c[t]||[],p=u[0]===z&&u[1],b=p&&u[2],d=p&&v.childNodes[p];d=++p&&d&&d[g]||(b=p=0)||h.pop();)if(1===d.nodeType&&++b&&d===e){c[t]=[z,p,b];break}}else if(y&&(d=e,f=d[U]||(d[U]={}),c=f[d.uniqueID]||(f[d.uniqueID]={}),u=c[t]||[],p=u[0]===z&&u[1],b=p),b===!1)for(;(d=++p&&d&&d[g]||(b=p=0)||h.pop())&&((s?d.nodeName.toLowerCase()!==m:1!==d.nodeType)||!++b||(y&&(f=d[U]||(d[U]={}),c=f[d.uniqueID]||(f[d.uniqueID]={}),c[t]=[z,b]),d!==e)););return b-=o,b===r||b%r===0&&b/r>=0}}},PSEUDO:function(t,n){var o,i=T.pseudos[t]||T.setFilters[t.toLowerCase()]||e.error("unsupported pseudo: "+t);return i[U]?i(n):i.length>1?(o=[t,t,"",n],T.setFilters.hasOwnProperty(t.toLowerCase())?r(function(t,e){for(var r,o=i(t,n),a=o.length;a--;)r=tt(t,o[a]),t[r]=!(e[r]=o[a])}):function(t){return i(t,0,o)}):i}},pseudos:{not:r(function(t){var e=[],n=[],o=P(t.replace(st,"$1"));return o[U]?r(function(t,e,n,r){for(var i,a=o(t,null,r,[]),s=t.length;s--;)(i=a[s])&&(t[s]=!(e[s]=i))}):function(t,r,i){return e[0]=t,o(e,null,i,n),e[0]=null,!n.pop()}}),has:r(function(t){return function(n){return e(t,n).length>0}}),contains:r(function(t){return t=t.replace(bt,xt),function(e){return(e.textContent||e.innerText||C(e)).indexOf(t)>-1}}),lang:r(function(t){return dt.test(t||"")||e.error("unsupported lang: "+t),t=t.replace(bt,xt).toLowerCase(),function(e){var n;do if(n=R?e.lang:e.getAttribute("xml:lang")||e.getAttribute("lang"))return n=n.toLowerCase(),n===t||0===n.indexOf(t+"-");while((e=e.parentNode)&&1===e.nodeType);return!1}}),target:function(e){var n=t.location&&t.location.hash;return n&&n.slice(1)===e.id},root:function(t){return t===I},focus:function(t){return t===D.activeElement&&(!D.hasFocus||D.hasFocus())&&!!(t.type||t.href||~t.tabIndex)},enabled:u(!1),disabled:u(!0),checked:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&!!t.checked||"option"===e&&!!t.selected},selected:function(t){return t.parentNode&&t.parentNode.selectedIndex,t.selected===!0},empty:function(t){for(t=t.firstChild;t;t=t.nextSibling)if(t.nodeType<6)return!1;return!0},parent:function(t){return!T.pseudos.empty(t)},header:function(t){return gt.test(t.nodeName)},input:function(t){return ht.test(t.nodeName)},button:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&"button"===t.type||"button"===e},text:function(t){var e;return"input"===t.nodeName.toLowerCase()&&"text"===t.type&&(null==(e=t.getAttribute("type"))||"text"===e.toLowerCase())},first:c(function(){return[0]}),last:c(function(t,e){return[e-1]}),eq:c(function(t,e,n){return[n<0?n+e:n]}),even:c(function(t,e){for(var n=0;n<e;n+=2)t.push(n);return t}),odd:c(function(t,e){for(var n=1;n<e;n+=2)t.push(n);return t}),lt:c(function(t,e,n){for(var r=n<0?n+e:n;--r>=0;)t.push(r);return t}),gt:c(function(t,e,n){for(var r=n<0?n+e:n;++r<e;)t.push(r);return t})}},T.pseudos.nth=T.pseudos.eq;for(_ in{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})T.pseudos[_]=s(_);for(_ in{submit:!0,reset:!0})T.pseudos[_]=l(_);return d.prototype=T.filters=T.pseudos,T.setFilters=new d,E=e.tokenize=function(t,n){var r,o,i,a,s,l,u,c=V[t+" "];if(c)return n?0:c.slice(0);for(s=t,l=[],u=T.preFilter;s;){r&&!(o=lt.exec(s))||(o&&(s=s.slice(o[0].length)||s),l.push(i=[])),r=!1,(o=ut.exec(s))&&(r=o.shift(),i.push({value:r,type:o[0].replace(st," ")}),s=s.slice(r.length));for(a in T.filter)!(o=pt[a].exec(s))||u[a]&&!(o=u[a](o))||(r=o.shift(),i.push({value:r,type:a,matches:o}),s=s.slice(r.length));if(!r)break}return n?s.length:s?e.error(t):V(t,l).slice(0)},P=e.compile=function(t,e){var n,r=[],o=[],i=K[t+" "];if(!i){for(e||(e=E(t)),n=e.length;n--;)i=b(e[n]),i[U]?r.push(i):o.push(i);i=K(t,x(o,r)),i.selector=t}return i},S=e.select=function(t,e,n,r){var o,i,a,s,l,u="function"==typeof t&&t,c=!r&&E(t=u.selector||t);if(n=n||[],1===c.length){if(i=c[0]=c[0].slice(0),i.length>2&&"ID"===(a=i[0]).type&&9===e.nodeType&&R&&T.relative[i[1].type]){if(e=(T.find.ID(a.matches[0].replace(bt,xt),e)||[])[0],!e)return n;u&&(e=e.parentNode),t=t.slice(i.shift().value.length)}for(o=pt.needsContext.test(t)?0:i.length;o--&&(a=i[o],!T.relative[s=a.type]);)if((l=T.find[s])&&(r=l(a.matches[0].replace(bt,xt),yt.test(i[0].type)&&f(e.parentNode)||e))){if(i.splice(o,1),t=r.length&&p(i),!t)return J.apply(n,r),n;break}}return(u||P(t,c))(r,e,!R,n,!e||yt.test(t)&&f(e.parentNode)||e),n},w.sortStable=U.split("").sort(Y).join("")===U,w.detectDuplicates=!!A,O(),w.sortDetached=o(function(t){return 1&t.compareDocumentPosition(D.createElement("fieldset"))}),o(function(t){return t.innerHTML="<a href='#'></a>","#"===t.firstChild.getAttribute("href")})||i("type|href|height|width",function(t,e,n){if(!n)return t.getAttribute(e,"type"===e.toLowerCase()?1:2)}),w.attributes&&o(function(t){return t.innerHTML="<input/>",t.firstChild.setAttribute("value",""),""===t.firstChild.getAttribute("value")})||i("value",function(t,e,n){if(!n&&"input"===t.nodeName.toLowerCase())return t.defaultValue}),o(function(t){return null==t.getAttribute("disabled")})||i(et,function(t,e,n){var r;if(!n)return t[e]===!0?e.toLowerCase():(r=t.getAttributeNode(e))&&r.specified?r.value:null}),e}(n);yt.find=Tt,yt.expr=Tt.selectors,yt.expr[":"]=yt.expr.pseudos,yt.uniqueSort=yt.unique=Tt.uniqueSort,yt.text=Tt.getText,yt.isXMLDoc=Tt.isXML,yt.contains=Tt.contains,yt.escapeSelector=Tt.escape;var Ct=function(t,e,n){for(var r=[],o=void 0!==n;(t=t[e])&&9!==t.nodeType;)if(1===t.nodeType){if(o&&yt(t).is(n))break;r.push(t)}return r},kt=function(t,e){for(var n=[];t;t=t.nextSibling)1===t.nodeType&&t!==e&&n.push(t);return n},Et=yt.expr.match.needsContext,Pt=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i,St=/^.[^:#\[\.,]*$/;yt.filter=function(t,e,n){var r=e[0];return n&&(t=":not("+t+")"),1===e.length&&1===r.nodeType?yt.find.matchesSelector(r,t)?[r]:[]:yt.find.matches(t,yt.grep(e,function(t){return 1===t.nodeType}))},yt.fn.extend({find:function(t){var e,n,r=this.length,o=this;if("string"!=typeof t)return this.pushStack(yt(t).filter(function(){for(e=0;e<r;e++)if(yt.contains(o[e],this))return!0}));for(n=this.pushStack([]),e=0;e<r;e++)yt.find(t,o[e],n);return r>1?yt.uniqueSort(n):n},filter:function(t){return this.pushStack(l(this,t||[],!1))},not:function(t){return this.pushStack(l(this,t||[],!0))},is:function(t){return!!l(this,"string"==typeof t&&Et.test(t)?yt(t):t||[],!1).length}});var Mt,Nt=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/,At=yt.fn.init=function(t,e,n){var r,o;if(!t)return this;if(n=n||Mt,"string"==typeof t){if(r="<"===t[0]&&">"===t[t.length-1]&&t.length>=3?[null,t,null]:Nt.exec(t),!r||!r[1]&&e)return!e||e.jquery?(e||n).find(t):this.constructor(e).find(t);if(r[1]){if(e=e instanceof yt?e[0]:e,yt.merge(this,yt.parseHTML(r[1],e&&e.nodeType?e.ownerDocument||e:it,!0)),Pt.test(r[1])&&yt.isPlainObject(e))for(r in e)yt.isFunction(this[r])?this[r](e[r]):this.attr(r,e[r]);return this}return o=it.getElementById(r[2]),o&&(this[0]=o,this.length=1),this}return t.nodeType?(this[0]=t,this.length=1,this):yt.isFunction(t)?void 0!==n.ready?n.ready(t):t(yt):yt.makeArray(t,this)};At.prototype=yt.fn,Mt=yt(it);var Ot=/^(?:parents|prev(?:Until|All))/,Dt={children:!0,contents:!0,next:!0,prev:!0};yt.fn.extend({has:function(t){var e=yt(t,this),n=e.length;return this.filter(function(){for(var t=0;t<n;t++)if(yt.contains(this,e[t]))return!0})},closest:function(t,e){var n,r=0,o=this.length,i=[],a="string"!=typeof t&&yt(t);if(!Et.test(t))for(;r<o;r++)for(n=this[r];n&&n!==e;n=n.parentNode)if(n.nodeType<11&&(a?a.index(n)>-1:1===n.nodeType&&yt.find.matchesSelector(n,t))){i.push(n);break}return this.pushStack(i.length>1?yt.uniqueSort(i):i)},index:function(t){return t?"string"==typeof t?ct.call(yt(t),this[0]):ct.call(this,t.jquery?t[0]:t):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(t,e){return this.pushStack(yt.uniqueSort(yt.merge(this.get(),yt(t,e))))},addBack:function(t){return this.add(null==t?this.prevObject:this.prevObject.filter(t))}}),yt.each({parent:function(t){var e=t.parentNode;return e&&11!==e.nodeType?e:null},parents:function(t){return Ct(t,"parentNode")},parentsUntil:function(t,e,n){return Ct(t,"parentNode",n)},next:function(t){return u(t,"nextSibling")},prev:function(t){return u(t,"previousSibling")},nextAll:function(t){return Ct(t,"nextSibling")},prevAll:function(t){return Ct(t,"previousSibling")},nextUntil:function(t,e,n){return Ct(t,"nextSibling",n)},prevUntil:function(t,e,n){return Ct(t,"previousSibling",n)},siblings:function(t){return kt((t.parentNode||{}).firstChild,t)},children:function(t){return kt(t.firstChild)},contents:function(t){return t.contentDocument||yt.merge([],t.childNodes)}},function(t,e){yt.fn[t]=function(n,r){var o=yt.map(this,e,n);return"Until"!==t.slice(-5)&&(r=n),r&&"string"==typeof r&&(o=yt.filter(r,o)),this.length>1&&(Dt[t]||yt.uniqueSort(o),Ot.test(t)&&o.reverse()),this.pushStack(o)}});var It=/[^\x20\t\r\n\f]+/g;yt.Callbacks=function(t){t="string"==typeof t?c(t):yt.extend({},t);var e,n,r,o,i=[],a=[],s=-1,l=function(){for(o=t.once,r=e=!0;a.length;s=-1)for(n=a.shift();++s<i.length;)i[s].apply(n[0],n[1])===!1&&t.stopOnFalse&&(s=i.length,n=!1);t.memory||(n=!1),e=!1,o&&(i=n?[]:"")},u={add:function(){return i&&(n&&!e&&(s=i.length-1,a.push(n)),function e(n){yt.each(n,function(n,r){yt.isFunction(r)?t.unique&&u.has(r)||i.push(r):r&&r.length&&"string"!==yt.type(r)&&e(r)})}(arguments),n&&!e&&l()),this},remove:function(){return yt.each(arguments,function(t,e){for(var n;(n=yt.inArray(e,i,n))>-1;)i.splice(n,1),n<=s&&s--}),this},has:function(t){return t?yt.inArray(t,i)>-1:i.length>0},empty:function(){return i&&(i=[]),this},disable:function(){return o=a=[],i=n="",this},disabled:function(){return!i},lock:function(){return o=a=[],n||e||(i=n=""),this},locked:function(){return!!o},fireWith:function(t,n){return o||(n=n||[],n=[t,n.slice?n.slice():n],a.push(n),e||l()),this},fire:function(){return u.fireWith(this,arguments),this},fired:function(){return!!r}};return u},yt.extend({Deferred:function(t){var e=[["notify","progress",yt.Callbacks("memory"),yt.Callbacks("memory"),2],["resolve","done",yt.Callbacks("once memory"),yt.Callbacks("once memory"),0,"resolved"],["reject","fail",yt.Callbacks("once memory"),yt.Callbacks("once memory"),1,"rejected"]],r="pending",o={state:function(){return r},always:function(){return i.done(arguments).fail(arguments),this},catch:function(t){return o.then(null,t)},pipe:function(){var t=arguments;return yt.Deferred(function(n){yt.each(e,function(e,r){var o=yt.isFunction(t[r[4]])&&t[r[4]];i[r[1]](function(){var t=o&&o.apply(this,arguments);t&&yt.isFunction(t.promise)?t.promise().progress(n.notify).done(n.resolve).fail(n.reject):n[r[0]+"With"](this,o?[t]:arguments)})}),t=null}).promise()},then:function(t,r,o){function i(t,e,r,o){return function(){var s=this,l=arguments,u=function(){var n,u;if(!(t<a)){if(n=r.apply(s,l),n===e.promise())throw new TypeError("Thenable self-resolution");u=n&&("object"==typeof n||"function"==typeof n)&&n.then,yt.isFunction(u)?o?u.call(n,i(a,e,f,o),i(a,e,d,o)):(a++,u.call(n,i(a,e,f,o),i(a,e,d,o),i(a,e,f,e.notifyWith))):(r!==f&&(s=void 0,l=[n]),(o||e.resolveWith)(s,l))}},c=o?u:function(){try{u()}catch(n){yt.Deferred.exceptionHook&&yt.Deferred.exceptionHook(n,c.stackTrace),t+1>=a&&(r!==d&&(s=void 0,l=[n]),e.rejectWith(s,l))}};t?c():(yt.Deferred.getStackHook&&(c.stackTrace=yt.Deferred.getStackHook()),n.setTimeout(c))}}var a=0;return yt.Deferred(function(n){e[0][3].add(i(0,n,yt.isFunction(o)?o:f,n.notifyWith)),e[1][3].add(i(0,n,yt.isFunction(t)?t:f)),e[2][3].add(i(0,n,yt.isFunction(r)?r:d))}).promise()},promise:function(t){return null!=t?yt.extend(t,o):o}},i={};return yt.each(e,function(t,n){var a=n[2],s=n[5];o[n[1]]=a.add,s&&a.add(function(){r=s},e[3-t][2].disable,e[0][2].lock),a.add(n[3].fire),i[n[0]]=function(){return i[n[0]+"With"](this===i?void 0:this,arguments),this},i[n[0]+"With"]=a.fireWith}),o.promise(i),t&&t.call(i,i),i},when:function(t){var e=arguments.length,n=e,r=Array(n),o=st.call(arguments),i=yt.Deferred(),a=function(t){return function(n){r[t]=this,o[t]=arguments.length>1?st.call(arguments):n,--e||i.resolveWith(r,o)}};if(e<=1&&(p(t,i.done(a(n)).resolve,i.reject),"pending"===i.state()||yt.isFunction(o[n]&&o[n].then)))return i.then();for(;n--;)p(o[n],a(n),i.reject);return i.promise()}});var Rt=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;yt.Deferred.exceptionHook=function(t,e){n.console&&n.console.warn&&t&&Rt.test(t.name)&&n.console.warn("jQuery.Deferred exception: "+t.message,t.stack,e)},yt.readyException=function(t){n.setTimeout(function(){throw t})};var Lt=yt.Deferred();yt.fn.ready=function(t){return Lt.then(t).catch(function(t){yt.readyException(t)}),this},yt.extend({isReady:!1,readyWait:1,holdReady:function(t){t?yt.readyWait++:yt.ready(!0)},ready:function(t){(t===!0?--yt.readyWait:yt.isReady)||(yt.isReady=!0,t!==!0&&--yt.readyWait>0||Lt.resolveWith(it,[yt]))}}),yt.ready.then=Lt.then,"complete"===it.readyState||"loading"!==it.readyState&&!it.documentElement.doScroll?n.setTimeout(yt.ready):(it.addEventListener("DOMContentLoaded",h),n.addEventListener("load",h));var Ft=function(t,e,n,r,o,i,a){var s=0,l=t.length,u=null==n;if("object"===yt.type(n)){o=!0;for(s in n)Ft(t,e,s,n[s],!0,i,a)}else if(void 0!==r&&(o=!0,yt.isFunction(r)||(a=!0),u&&(a?(e.call(t,r),e=null):(u=e,e=function(t,e,n){return u.call(yt(t),n)})),e))for(;s<l;s++)e(t[s],n,a?r:r.call(t[s],s,e(t[s],n)));return o?t:u?e.call(t):l?e(t[0],n):i},jt=function(t){return 1===t.nodeType||9===t.nodeType||!+t.nodeType};g.uid=1,g.prototype={cache:function(t){var e=t[this.expando];return e||(e={},jt(t)&&(t.nodeType?t[this.expando]=e:Object.defineProperty(t,this.expando,{value:e,configurable:!0}))),e},set:function(t,e,n){var r,o=this.cache(t);if("string"==typeof e)o[yt.camelCase(e)]=n;else for(r in e)o[yt.camelCase(r)]=e[r];return o},get:function(t,e){return void 0===e?this.cache(t):t[this.expando]&&t[this.expando][yt.camelCase(e)]},access:function(t,e,n){return void 0===e||e&&"string"==typeof e&&void 0===n?this.get(t,e):(this.set(t,e,n),void 0!==n?n:e)},remove:function(t,e){var n,r=t[this.expando];if(void 0!==r){if(void 0!==e){yt.isArray(e)?e=e.map(yt.camelCase):(e=yt.camelCase(e),e=e in r?[e]:e.match(It)||[]),n=e.length;for(;n--;)delete r[e[n]]}(void 0===e||yt.isEmptyObject(r))&&(t.nodeType?t[this.expando]=void 0:delete t[this.expando])}},hasData:function(t){var e=t[this.expando];return void 0!==e&&!yt.isEmptyObject(e)}};var Bt=new g,Ut=new g,Ht=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,zt=/[A-Z]/g;yt.extend({hasData:function(t){return Ut.hasData(t)||Bt.hasData(t)},data:function(t,e,n){return Ut.access(t,e,n)},removeData:function(t,e){Ut.remove(t,e)},_data:function(t,e,n){return Bt.access(t,e,n)},_removeData:function(t,e){Bt.remove(t,e)}}),yt.fn.extend({data:function(t,e){var n,r,o,i=this[0],a=i&&i.attributes;if(void 0===t){if(this.length&&(o=Ut.get(i),1===i.nodeType&&!Bt.get(i,"hasDataAttrs"))){for(n=a.length;n--;)a[n]&&(r=a[n].name,0===r.indexOf("data-")&&(r=yt.camelCase(r.slice(5)),m(i,r,o[r])));Bt.set(i,"hasDataAttrs",!0)}return o}return"object"==typeof t?this.each(function(){Ut.set(this,t)}):Ft(this,function(e){var n;if(i&&void 0===e){if(n=Ut.get(i,t),void 0!==n)return n;if(n=m(i,t),void 0!==n)return n}else this.each(function(){Ut.set(this,t,e)})},null,e,arguments.length>1,null,!0)},removeData:function(t){return this.each(function(){Ut.remove(this,t)})}}),yt.extend({queue:function(t,e,n){var r;if(t)return e=(e||"fx")+"queue",r=Bt.get(t,e),n&&(!r||yt.isArray(n)?r=Bt.access(t,e,yt.makeArray(n)):r.push(n)),r||[]},dequeue:function(t,e){e=e||"fx";var n=yt.queue(t,e),r=n.length,o=n.shift(),i=yt._queueHooks(t,e),a=function(){yt.dequeue(t,e)};"inprogress"===o&&(o=n.shift(),r--),o&&("fx"===e&&n.unshift("inprogress"),delete i.stop,o.call(t,a,i)),!r&&i&&i.empty.fire()},_queueHooks:function(t,e){var n=e+"queueHooks";return Bt.get(t,n)||Bt.access(t,n,{empty:yt.Callbacks("once memory").add(function(){Bt.remove(t,[e+"queue",n])})})}}),yt.fn.extend({queue:function(t,e){var n=2;return"string"!=typeof t&&(e=t,t="fx",n--),arguments.length<n?yt.queue(this[0],t):void 0===e?this:this.each(function(){var n=yt.queue(this,t,e);yt._queueHooks(this,t),"fx"===t&&"inprogress"!==n[0]&&yt.dequeue(this,t)})},dequeue:function(t){return this.each(function(){yt.dequeue(this,t)})},clearQueue:function(t){return this.queue(t||"fx",[])},promise:function(t,e){var n,r=1,o=yt.Deferred(),i=this,a=this.length,s=function(){--r||o.resolveWith(i,[i])};for("string"!=typeof t&&(e=t,t=void 0),t=t||"fx";a--;)n=Bt.get(i[a],t+"queueHooks"),n&&n.empty&&(r++,n.empty.add(s));return s(),o.promise(e)}});var Wt=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,qt=new RegExp("^(?:([+-])=|)("+Wt+")([a-z%]*)$","i"),Vt=["Top","Right","Bottom","Left"],Kt=function(t,e){return t=e||t,"none"===t.style.display||""===t.style.display&&yt.contains(t.ownerDocument,t)&&"none"===yt.css(t,"display")},Yt=function(t,e,n,r){var o,i,a={};for(i in e)a[i]=t.style[i],t.style[i]=e[i];o=n.apply(t,r||[]);for(i in e)t.style[i]=a[i];return o},Gt={};yt.fn.extend({show:function(){return x(this,!0)},hide:function(){return x(this)},toggle:function(t){return"boolean"==typeof t?t?this.show():this.hide():this.each(function(){Kt(this)?yt(this).show():yt(this).hide()})}});var Xt=/^(?:checkbox|radio)$/i,$t=/<([a-z][^\/\0>\x20\t\r\n\f]+)/i,Zt=/^$|\/(?:java|ecma)script/i,Jt={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};Jt.optgroup=Jt.option,Jt.tbody=Jt.tfoot=Jt.colgroup=Jt.caption=Jt.thead,Jt.th=Jt.td;
var Qt=/<|&#?\w+;/;!function(){var t=it.createDocumentFragment(),e=t.appendChild(it.createElement("div")),n=it.createElement("input");n.setAttribute("type","radio"),n.setAttribute("checked","checked"),n.setAttribute("name","t"),e.appendChild(n),vt.checkClone=e.cloneNode(!0).cloneNode(!0).lastChild.checked,e.innerHTML="<textarea>x</textarea>",vt.noCloneChecked=!!e.cloneNode(!0).lastChild.defaultValue}();var te=it.documentElement,ee=/^key/,ne=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,re=/^([^.]*)(?:\.(.+)|)/;yt.event={global:{},add:function(t,e,n,r,o){var i,a,s,l,u,c,f,d,p,h,g,v=Bt.get(t);if(v)for(n.handler&&(i=n,n=i.handler,o=i.selector),o&&yt.find.matchesSelector(te,o),n.guid||(n.guid=yt.guid++),(l=v.events)||(l=v.events={}),(a=v.handle)||(a=v.handle=function(e){return"undefined"!=typeof yt&&yt.event.triggered!==e.type?yt.event.dispatch.apply(t,arguments):void 0}),e=(e||"").match(It)||[""],u=e.length;u--;)s=re.exec(e[u])||[],p=g=s[1],h=(s[2]||"").split(".").sort(),p&&(f=yt.event.special[p]||{},p=(o?f.delegateType:f.bindType)||p,f=yt.event.special[p]||{},c=yt.extend({type:p,origType:g,data:r,handler:n,guid:n.guid,selector:o,needsContext:o&&yt.expr.match.needsContext.test(o),namespace:h.join(".")},i),(d=l[p])||(d=l[p]=[],d.delegateCount=0,f.setup&&f.setup.call(t,r,h,a)!==!1||t.addEventListener&&t.addEventListener(p,a)),f.add&&(f.add.call(t,c),c.handler.guid||(c.handler.guid=n.guid)),o?d.splice(d.delegateCount++,0,c):d.push(c),yt.event.global[p]=!0)},remove:function(t,e,n,r,o){var i,a,s,l,u,c,f,d,p,h,g,v=Bt.hasData(t)&&Bt.get(t);if(v&&(l=v.events)){for(e=(e||"").match(It)||[""],u=e.length;u--;)if(s=re.exec(e[u])||[],p=g=s[1],h=(s[2]||"").split(".").sort(),p){for(f=yt.event.special[p]||{},p=(r?f.delegateType:f.bindType)||p,d=l[p]||[],s=s[2]&&new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=i=d.length;i--;)c=d[i],!o&&g!==c.origType||n&&n.guid!==c.guid||s&&!s.test(c.namespace)||r&&r!==c.selector&&("**"!==r||!c.selector)||(d.splice(i,1),c.selector&&d.delegateCount--,f.remove&&f.remove.call(t,c));a&&!d.length&&(f.teardown&&f.teardown.call(t,h,v.handle)!==!1||yt.removeEvent(t,p,v.handle),delete l[p])}else for(p in l)yt.event.remove(t,p+e[u],n,r,!0);yt.isEmptyObject(l)&&Bt.remove(t,"handle events")}},dispatch:function(t){var e,n,r,o,i,a,s=yt.event.fix(t),l=new Array(arguments.length),u=(Bt.get(this,"events")||{})[s.type]||[],c=yt.event.special[s.type]||{};for(l[0]=s,e=1;e<arguments.length;e++)l[e]=arguments[e];if(s.delegateTarget=this,!c.preDispatch||c.preDispatch.call(this,s)!==!1){for(a=yt.event.handlers.call(this,s,u),e=0;(o=a[e++])&&!s.isPropagationStopped();)for(s.currentTarget=o.elem,n=0;(i=o.handlers[n++])&&!s.isImmediatePropagationStopped();)s.rnamespace&&!s.rnamespace.test(i.namespace)||(s.handleObj=i,s.data=i.data,r=((yt.event.special[i.origType]||{}).handle||i.handler).apply(o.elem,l),void 0!==r&&(s.result=r)===!1&&(s.preventDefault(),s.stopPropagation()));return c.postDispatch&&c.postDispatch.call(this,s),s.result}},handlers:function(t,e){var n,r,o,i,a,s=[],l=e.delegateCount,u=t.target;if(l&&u.nodeType&&!("click"===t.type&&t.button>=1))for(;u!==this;u=u.parentNode||this)if(1===u.nodeType&&("click"!==t.type||u.disabled!==!0)){for(i=[],a={},n=0;n<l;n++)r=e[n],o=r.selector+" ",void 0===a[o]&&(a[o]=r.needsContext?yt(o,this).index(u)>-1:yt.find(o,this,null,[u]).length),a[o]&&i.push(r);i.length&&s.push({elem:u,handlers:i})}return u=this,l<e.length&&s.push({elem:u,handlers:e.slice(l)}),s},addProp:function(t,e){Object.defineProperty(yt.Event.prototype,t,{enumerable:!0,configurable:!0,get:yt.isFunction(e)?function(){if(this.originalEvent)return e(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[t]},set:function(e){Object.defineProperty(this,t,{enumerable:!0,configurable:!0,writable:!0,value:e})}})},fix:function(t){return t[yt.expando]?t:new yt.Event(t)},special:{load:{noBubble:!0},focus:{trigger:function(){if(this!==E()&&this.focus)return this.focus(),!1},delegateType:"focusin"},blur:{trigger:function(){if(this===E()&&this.blur)return this.blur(),!1},delegateType:"focusout"},click:{trigger:function(){if("checkbox"===this.type&&this.click&&yt.nodeName(this,"input"))return this.click(),!1},_default:function(t){return yt.nodeName(t.target,"a")}},beforeunload:{postDispatch:function(t){void 0!==t.result&&t.originalEvent&&(t.originalEvent.returnValue=t.result)}}}},yt.removeEvent=function(t,e,n){t.removeEventListener&&t.removeEventListener(e,n)},yt.Event=function(t,e){return this instanceof yt.Event?(t&&t.type?(this.originalEvent=t,this.type=t.type,this.isDefaultPrevented=t.defaultPrevented||void 0===t.defaultPrevented&&t.returnValue===!1?C:k,this.target=t.target&&3===t.target.nodeType?t.target.parentNode:t.target,this.currentTarget=t.currentTarget,this.relatedTarget=t.relatedTarget):this.type=t,e&&yt.extend(this,e),this.timeStamp=t&&t.timeStamp||yt.now(),void(this[yt.expando]=!0)):new yt.Event(t,e)},yt.Event.prototype={constructor:yt.Event,isDefaultPrevented:k,isPropagationStopped:k,isImmediatePropagationStopped:k,isSimulated:!1,preventDefault:function(){var t=this.originalEvent;this.isDefaultPrevented=C,t&&!this.isSimulated&&t.preventDefault()},stopPropagation:function(){var t=this.originalEvent;this.isPropagationStopped=C,t&&!this.isSimulated&&t.stopPropagation()},stopImmediatePropagation:function(){var t=this.originalEvent;this.isImmediatePropagationStopped=C,t&&!this.isSimulated&&t.stopImmediatePropagation(),this.stopPropagation()}},yt.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,char:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:function(t){var e=t.button;return null==t.which&&ee.test(t.type)?null!=t.charCode?t.charCode:t.keyCode:!t.which&&void 0!==e&&ne.test(t.type)?1&e?1:2&e?3:4&e?2:0:t.which}},yt.event.addProp),yt.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(t,e){yt.event.special[t]={delegateType:e,bindType:e,handle:function(t){var n,r=this,o=t.relatedTarget,i=t.handleObj;return o&&(o===r||yt.contains(r,o))||(t.type=i.origType,n=i.handler.apply(this,arguments),t.type=e),n}}}),yt.fn.extend({on:function(t,e,n,r){return P(this,t,e,n,r)},one:function(t,e,n,r){return P(this,t,e,n,r,1)},off:function(t,e,n){var r,o;if(t&&t.preventDefault&&t.handleObj)return r=t.handleObj,yt(t.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof t){for(o in t)this.off(o,e,t[o]);return this}return e!==!1&&"function"!=typeof e||(n=e,e=void 0),n===!1&&(n=k),this.each(function(){yt.event.remove(this,t,n,e)})}});var oe=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([a-z][^\/\0>\x20\t\r\n\f]*)[^>]*)\/>/gi,ie=/<script|<style|<link/i,ae=/checked\s*(?:[^=]|=\s*.checked.)/i,se=/^true\/(.*)/,le=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;yt.extend({htmlPrefilter:function(t){return t.replace(oe,"<$1></$2>")},clone:function(t,e,n){var r,o,i,a,s=t.cloneNode(!0),l=yt.contains(t.ownerDocument,t);if(!(vt.noCloneChecked||1!==t.nodeType&&11!==t.nodeType||yt.isXMLDoc(t)))for(a=_(s),i=_(t),r=0,o=i.length;r<o;r++)O(i[r],a[r]);if(e)if(n)for(i=i||_(t),a=a||_(s),r=0,o=i.length;r<o;r++)A(i[r],a[r]);else A(t,s);return a=_(s,"script"),a.length>0&&w(a,!l&&_(t,"script")),s},cleanData:function(t){for(var e,n,r,o=yt.event.special,i=0;void 0!==(n=t[i]);i++)if(jt(n)){if(e=n[Bt.expando]){if(e.events)for(r in e.events)o[r]?yt.event.remove(n,r):yt.removeEvent(n,r,e.handle);n[Bt.expando]=void 0}n[Ut.expando]&&(n[Ut.expando]=void 0)}}}),yt.fn.extend({detach:function(t){return I(this,t,!0)},remove:function(t){return I(this,t)},text:function(t){return Ft(this,function(t){return void 0===t?yt.text(this):this.empty().each(function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=t)})},null,t,arguments.length)},append:function(){return D(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=S(this,t);e.appendChild(t)}})},prepend:function(){return D(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=S(this,t);e.insertBefore(t,e.firstChild)}})},before:function(){return D(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this)})},after:function(){return D(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this.nextSibling)})},empty:function(){for(var t,e=0;null!=(t=this[e]);e++)1===t.nodeType&&(yt.cleanData(_(t,!1)),t.textContent="");return this},clone:function(t,e){return t=null!=t&&t,e=null==e?t:e,this.map(function(){return yt.clone(this,t,e)})},html:function(t){return Ft(this,function(t){var e=this[0]||{},n=0,r=this.length;if(void 0===t&&1===e.nodeType)return e.innerHTML;if("string"==typeof t&&!ie.test(t)&&!Jt[($t.exec(t)||["",""])[1].toLowerCase()]){t=yt.htmlPrefilter(t);try{for(;n<r;n++)e=this[n]||{},1===e.nodeType&&(yt.cleanData(_(e,!1)),e.innerHTML=t);e=0}catch(t){}}e&&this.empty().append(t)},null,t,arguments.length)},replaceWith:function(){var t=[];return D(this,arguments,function(e){var n=this.parentNode;yt.inArray(this,t)<0&&(yt.cleanData(_(this)),n&&n.replaceChild(e,this))},t)}}),yt.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(t,e){yt.fn[t]=function(t){for(var n,r=[],o=yt(t),i=o.length-1,a=0;a<=i;a++)n=a===i?this:this.clone(!0),yt(o[a])[e](n),ut.apply(r,n.get());return this.pushStack(r)}});var ue=/^margin/,ce=new RegExp("^("+Wt+")(?!px)[a-z%]+$","i"),fe=function(t){var e=t.ownerDocument.defaultView;return e&&e.opener||(e=n),e.getComputedStyle(t)};!function(){function t(){if(s){s.style.cssText="box-sizing:border-box;position:relative;display:block;margin:auto;border:1px;padding:1px;top:1%;width:50%",s.innerHTML="",te.appendChild(a);var t=n.getComputedStyle(s);e="1%"!==t.top,i="2px"===t.marginLeft,r="4px"===t.width,s.style.marginRight="50%",o="4px"===t.marginRight,te.removeChild(a),s=null}}var e,r,o,i,a=it.createElement("div"),s=it.createElement("div");s.style&&(s.style.backgroundClip="content-box",s.cloneNode(!0).style.backgroundClip="",vt.clearCloneStyle="content-box"===s.style.backgroundClip,a.style.cssText="border:0;width:8px;height:0;top:0;left:-9999px;padding:0;margin-top:1px;position:absolute",a.appendChild(s),yt.extend(vt,{pixelPosition:function(){return t(),e},boxSizingReliable:function(){return t(),r},pixelMarginRight:function(){return t(),o},reliableMarginLeft:function(){return t(),i}}))}();var de=/^(none|table(?!-c[ea]).+)/,pe={position:"absolute",visibility:"hidden",display:"block"},he={letterSpacing:"0",fontWeight:"400"},ge=["Webkit","Moz","ms"],ve=it.createElement("div").style;yt.extend({cssHooks:{opacity:{get:function(t,e){if(e){var n=R(t,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{float:"cssFloat"},style:function(t,e,n,r){if(t&&3!==t.nodeType&&8!==t.nodeType&&t.style){var o,i,a,s=yt.camelCase(e),l=t.style;return e=yt.cssProps[s]||(yt.cssProps[s]=F(s)||s),a=yt.cssHooks[e]||yt.cssHooks[s],void 0===n?a&&"get"in a&&void 0!==(o=a.get(t,!1,r))?o:l[e]:(i=typeof n,"string"===i&&(o=qt.exec(n))&&o[1]&&(n=y(t,e,o),i="number"),null!=n&&n===n&&("number"===i&&(n+=o&&o[3]||(yt.cssNumber[s]?"":"px")),vt.clearCloneStyle||""!==n||0!==e.indexOf("background")||(l[e]="inherit"),a&&"set"in a&&void 0===(n=a.set(t,n,r))||(l[e]=n)),void 0)}},css:function(t,e,n,r){var o,i,a,s=yt.camelCase(e);return e=yt.cssProps[s]||(yt.cssProps[s]=F(s)||s),a=yt.cssHooks[e]||yt.cssHooks[s],a&&"get"in a&&(o=a.get(t,!0,n)),void 0===o&&(o=R(t,e,r)),"normal"===o&&e in he&&(o=he[e]),""===n||n?(i=parseFloat(o),n===!0||isFinite(i)?i||0:o):o}}),yt.each(["height","width"],function(t,e){yt.cssHooks[e]={get:function(t,n,r){if(n)return!de.test(yt.css(t,"display"))||t.getClientRects().length&&t.getBoundingClientRect().width?U(t,e,r):Yt(t,pe,function(){return U(t,e,r)})},set:function(t,n,r){var o,i=r&&fe(t),a=r&&B(t,e,r,"border-box"===yt.css(t,"boxSizing",!1,i),i);return a&&(o=qt.exec(n))&&"px"!==(o[3]||"px")&&(t.style[e]=n,n=yt.css(t,e)),j(t,n,a)}}}),yt.cssHooks.marginLeft=L(vt.reliableMarginLeft,function(t,e){if(e)return(parseFloat(R(t,"marginLeft"))||t.getBoundingClientRect().left-Yt(t,{marginLeft:0},function(){return t.getBoundingClientRect().left}))+"px"}),yt.each({margin:"",padding:"",border:"Width"},function(t,e){yt.cssHooks[t+e]={expand:function(n){for(var r=0,o={},i="string"==typeof n?n.split(" "):[n];r<4;r++)o[t+Vt[r]+e]=i[r]||i[r-2]||i[0];return o}},ue.test(t)||(yt.cssHooks[t+e].set=j)}),yt.fn.extend({css:function(t,e){return Ft(this,function(t,e,n){var r,o,i={},a=0;if(yt.isArray(e)){for(r=fe(t),o=e.length;a<o;a++)i[e[a]]=yt.css(t,e[a],!1,r);return i}return void 0!==n?yt.style(t,e,n):yt.css(t,e)},t,e,arguments.length>1)}}),yt.Tween=H,H.prototype={constructor:H,init:function(t,e,n,r,o,i){this.elem=t,this.prop=n,this.easing=o||yt.easing._default,this.options=e,this.start=this.now=this.cur(),this.end=r,this.unit=i||(yt.cssNumber[n]?"":"px")},cur:function(){var t=H.propHooks[this.prop];return t&&t.get?t.get(this):H.propHooks._default.get(this)},run:function(t){var e,n=H.propHooks[this.prop];return this.options.duration?this.pos=e=yt.easing[this.easing](t,this.options.duration*t,0,1,this.options.duration):this.pos=e=t,this.now=(this.end-this.start)*e+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):H.propHooks._default.set(this),this}},H.prototype.init.prototype=H.prototype,H.propHooks={_default:{get:function(t){var e;return 1!==t.elem.nodeType||null!=t.elem[t.prop]&&null==t.elem.style[t.prop]?t.elem[t.prop]:(e=yt.css(t.elem,t.prop,""),e&&"auto"!==e?e:0)},set:function(t){yt.fx.step[t.prop]?yt.fx.step[t.prop](t):1!==t.elem.nodeType||null==t.elem.style[yt.cssProps[t.prop]]&&!yt.cssHooks[t.prop]?t.elem[t.prop]=t.now:yt.style(t.elem,t.prop,t.now+t.unit)}}},H.propHooks.scrollTop=H.propHooks.scrollLeft={set:function(t){t.elem.nodeType&&t.elem.parentNode&&(t.elem[t.prop]=t.now)}},yt.easing={linear:function(t){return t},swing:function(t){return.5-Math.cos(t*Math.PI)/2},_default:"swing"},yt.fx=H.prototype.init,yt.fx.step={};var me,ye,be=/^(?:toggle|show|hide)$/,xe=/queueHooks$/;yt.Animation=yt.extend(G,{tweeners:{"*":[function(t,e){var n=this.createTween(t,e);return y(n.elem,t,qt.exec(e),n),n}]},tweener:function(t,e){yt.isFunction(t)?(e=t,t=["*"]):t=t.match(It);for(var n,r=0,o=t.length;r<o;r++)n=t[r],G.tweeners[n]=G.tweeners[n]||[],G.tweeners[n].unshift(e)},prefilters:[K],prefilter:function(t,e){e?G.prefilters.unshift(t):G.prefilters.push(t)}}),yt.speed=function(t,e,n){var r=t&&"object"==typeof t?yt.extend({},t):{complete:n||!n&&e||yt.isFunction(t)&&t,duration:t,easing:n&&e||e&&!yt.isFunction(e)&&e};return yt.fx.off||it.hidden?r.duration=0:"number"!=typeof r.duration&&(r.duration in yt.fx.speeds?r.duration=yt.fx.speeds[r.duration]:r.duration=yt.fx.speeds._default),null!=r.queue&&r.queue!==!0||(r.queue="fx"),r.old=r.complete,r.complete=function(){yt.isFunction(r.old)&&r.old.call(this),r.queue&&yt.dequeue(this,r.queue)},r},yt.fn.extend({fadeTo:function(t,e,n,r){return this.filter(Kt).css("opacity",0).show().end().animate({opacity:e},t,n,r)},animate:function(t,e,n,r){var o=yt.isEmptyObject(t),i=yt.speed(e,n,r),a=function(){var e=G(this,yt.extend({},t),i);(o||Bt.get(this,"finish"))&&e.stop(!0)};return a.finish=a,o||i.queue===!1?this.each(a):this.queue(i.queue,a)},stop:function(t,e,n){var r=function(t){var e=t.stop;delete t.stop,e(n)};return"string"!=typeof t&&(n=e,e=t,t=void 0),e&&t!==!1&&this.queue(t||"fx",[]),this.each(function(){var e=!0,o=null!=t&&t+"queueHooks",i=yt.timers,a=Bt.get(this);if(o)a[o]&&a[o].stop&&r(a[o]);else for(o in a)a[o]&&a[o].stop&&xe.test(o)&&r(a[o]);for(o=i.length;o--;)i[o].elem!==this||null!=t&&i[o].queue!==t||(i[o].anim.stop(n),e=!1,i.splice(o,1));!e&&n||yt.dequeue(this,t)})},finish:function(t){return t!==!1&&(t=t||"fx"),this.each(function(){var e,n=Bt.get(this),r=n[t+"queue"],o=n[t+"queueHooks"],i=yt.timers,a=r?r.length:0;for(n.finish=!0,yt.queue(this,t,[]),o&&o.stop&&o.stop.call(this,!0),e=i.length;e--;)i[e].elem===this&&i[e].queue===t&&(i[e].anim.stop(!0),i.splice(e,1));for(e=0;e<a;e++)r[e]&&r[e].finish&&r[e].finish.call(this);delete n.finish})}}),yt.each(["toggle","show","hide"],function(t,e){var n=yt.fn[e];yt.fn[e]=function(t,r,o){return null==t||"boolean"==typeof t?n.apply(this,arguments):this.animate(q(e,!0),t,r,o)}}),yt.each({slideDown:q("show"),slideUp:q("hide"),slideToggle:q("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(t,e){yt.fn[t]=function(t,n,r){return this.animate(e,t,n,r)}}),yt.timers=[],yt.fx.tick=function(){var t,e=0,n=yt.timers;for(me=yt.now();e<n.length;e++)t=n[e],t()||n[e]!==t||n.splice(e--,1);n.length||yt.fx.stop(),me=void 0},yt.fx.timer=function(t){yt.timers.push(t),t()?yt.fx.start():yt.timers.pop()},yt.fx.interval=13,yt.fx.start=function(){ye||(ye=n.requestAnimationFrame?n.requestAnimationFrame(z):n.setInterval(yt.fx.tick,yt.fx.interval))},yt.fx.stop=function(){n.cancelAnimationFrame?n.cancelAnimationFrame(ye):n.clearInterval(ye),ye=null},yt.fx.speeds={slow:600,fast:200,_default:400},yt.fn.delay=function(t,e){return t=yt.fx?yt.fx.speeds[t]||t:t,e=e||"fx",this.queue(e,function(e,r){var o=n.setTimeout(e,t);r.stop=function(){n.clearTimeout(o)}})},function(){var t=it.createElement("input"),e=it.createElement("select"),n=e.appendChild(it.createElement("option"));t.type="checkbox",vt.checkOn=""!==t.value,vt.optSelected=n.selected,t=it.createElement("input"),t.value="t",t.type="radio",vt.radioValue="t"===t.value}();var _e,we=yt.expr.attrHandle;yt.fn.extend({attr:function(t,e){return Ft(this,yt.attr,t,e,arguments.length>1)},removeAttr:function(t){return this.each(function(){yt.removeAttr(this,t)})}}),yt.extend({attr:function(t,e,n){var r,o,i=t.nodeType;if(3!==i&&8!==i&&2!==i)return"undefined"==typeof t.getAttribute?yt.prop(t,e,n):(1===i&&yt.isXMLDoc(t)||(o=yt.attrHooks[e.toLowerCase()]||(yt.expr.match.bool.test(e)?_e:void 0)),void 0!==n?null===n?void yt.removeAttr(t,e):o&&"set"in o&&void 0!==(r=o.set(t,n,e))?r:(t.setAttribute(e,n+""),n):o&&"get"in o&&null!==(r=o.get(t,e))?r:(r=yt.find.attr(t,e),null==r?void 0:r))},attrHooks:{type:{set:function(t,e){if(!vt.radioValue&&"radio"===e&&yt.nodeName(t,"input")){var n=t.value;return t.setAttribute("type",e),n&&(t.value=n),e}}}},removeAttr:function(t,e){var n,r=0,o=e&&e.match(It);if(o&&1===t.nodeType)for(;n=o[r++];)t.removeAttribute(n)}}),_e={set:function(t,e,n){return e===!1?yt.removeAttr(t,n):t.setAttribute(n,n),n}},yt.each(yt.expr.match.bool.source.match(/\w+/g),function(t,e){var n=we[e]||yt.find.attr;we[e]=function(t,e,r){var o,i,a=e.toLowerCase();return r||(i=we[a],we[a]=o,o=null!=n(t,e,r)?a:null,we[a]=i),o}});var Te=/^(?:input|select|textarea|button)$/i,Ce=/^(?:a|area)$/i;yt.fn.extend({prop:function(t,e){return Ft(this,yt.prop,t,e,arguments.length>1)},removeProp:function(t){return this.each(function(){delete this[yt.propFix[t]||t]})}}),yt.extend({prop:function(t,e,n){var r,o,i=t.nodeType;if(3!==i&&8!==i&&2!==i)return 1===i&&yt.isXMLDoc(t)||(e=yt.propFix[e]||e,o=yt.propHooks[e]),void 0!==n?o&&"set"in o&&void 0!==(r=o.set(t,n,e))?r:t[e]=n:o&&"get"in o&&null!==(r=o.get(t,e))?r:t[e]},propHooks:{tabIndex:{get:function(t){var e=yt.find.attr(t,"tabindex");return e?parseInt(e,10):Te.test(t.nodeName)||Ce.test(t.nodeName)&&t.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),vt.optSelected||(yt.propHooks.selected={get:function(t){var e=t.parentNode;return e&&e.parentNode&&e.parentNode.selectedIndex,null},set:function(t){var e=t.parentNode;e&&(e.selectedIndex,e.parentNode&&e.parentNode.selectedIndex)}}),yt.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){yt.propFix[this.toLowerCase()]=this}),yt.fn.extend({addClass:function(t){var e,n,r,o,i,a,s,l=0;if(yt.isFunction(t))return this.each(function(e){yt(this).addClass(t.call(this,e,$(this)))});if("string"==typeof t&&t)for(e=t.match(It)||[];n=this[l++];)if(o=$(n),r=1===n.nodeType&&" "+X(o)+" "){for(a=0;i=e[a++];)r.indexOf(" "+i+" ")<0&&(r+=i+" ");s=X(r),o!==s&&n.setAttribute("class",s)}return this},removeClass:function(t){var e,n,r,o,i,a,s,l=0;if(yt.isFunction(t))return this.each(function(e){yt(this).removeClass(t.call(this,e,$(this)))});if(!arguments.length)return this.attr("class","");if("string"==typeof t&&t)for(e=t.match(It)||[];n=this[l++];)if(o=$(n),r=1===n.nodeType&&" "+X(o)+" "){for(a=0;i=e[a++];)for(;r.indexOf(" "+i+" ")>-1;)r=r.replace(" "+i+" "," ");s=X(r),o!==s&&n.setAttribute("class",s)}return this},toggleClass:function(t,e){var n=typeof t;return"boolean"==typeof e&&"string"===n?e?this.addClass(t):this.removeClass(t):yt.isFunction(t)?this.each(function(n){yt(this).toggleClass(t.call(this,n,$(this),e),e)}):this.each(function(){var e,r,o,i;if("string"===n)for(r=0,o=yt(this),i=t.match(It)||[];e=i[r++];)o.hasClass(e)?o.removeClass(e):o.addClass(e);else void 0!==t&&"boolean"!==n||(e=$(this),e&&Bt.set(this,"__className__",e),this.setAttribute&&this.setAttribute("class",e||t===!1?"":Bt.get(this,"__className__")||""))})},hasClass:function(t){var e,n,r=0;for(e=" "+t+" ";n=this[r++];)if(1===n.nodeType&&(" "+X($(n))+" ").indexOf(e)>-1)return!0;return!1}});var ke=/\r/g;yt.fn.extend({val:function(t){var e,n,r,o=this[0];{if(arguments.length)return r=yt.isFunction(t),this.each(function(n){var o;1===this.nodeType&&(o=r?t.call(this,n,yt(this).val()):t,null==o?o="":"number"==typeof o?o+="":yt.isArray(o)&&(o=yt.map(o,function(t){return null==t?"":t+""})),e=yt.valHooks[this.type]||yt.valHooks[this.nodeName.toLowerCase()],e&&"set"in e&&void 0!==e.set(this,o,"value")||(this.value=o))});if(o)return e=yt.valHooks[o.type]||yt.valHooks[o.nodeName.toLowerCase()],e&&"get"in e&&void 0!==(n=e.get(o,"value"))?n:(n=o.value,"string"==typeof n?n.replace(ke,""):null==n?"":n)}}}),yt.extend({valHooks:{option:{get:function(t){var e=yt.find.attr(t,"value");return null!=e?e:X(yt.text(t))}},select:{get:function(t){var e,n,r,o=t.options,i=t.selectedIndex,a="select-one"===t.type,s=a?null:[],l=a?i+1:o.length;for(r=i<0?l:a?i:0;r<l;r++)if(n=o[r],(n.selected||r===i)&&!n.disabled&&(!n.parentNode.disabled||!yt.nodeName(n.parentNode,"optgroup"))){if(e=yt(n).val(),a)return e;s.push(e)}return s},set:function(t,e){for(var n,r,o=t.options,i=yt.makeArray(e),a=o.length;a--;)r=o[a],(r.selected=yt.inArray(yt.valHooks.option.get(r),i)>-1)&&(n=!0);return n||(t.selectedIndex=-1),i}}}}),yt.each(["radio","checkbox"],function(){yt.valHooks[this]={set:function(t,e){if(yt.isArray(e))return t.checked=yt.inArray(yt(t).val(),e)>-1}},vt.checkOn||(yt.valHooks[this].get=function(t){return null===t.getAttribute("value")?"on":t.value})});var Ee=/^(?:focusinfocus|focusoutblur)$/;yt.extend(yt.event,{trigger:function(t,e,r,o){var i,a,s,l,u,c,f,d=[r||it],p=pt.call(t,"type")?t.type:t,h=pt.call(t,"namespace")?t.namespace.split("."):[];if(a=s=r=r||it,3!==r.nodeType&&8!==r.nodeType&&!Ee.test(p+yt.event.triggered)&&(p.indexOf(".")>-1&&(h=p.split("."),p=h.shift(),h.sort()),u=p.indexOf(":")<0&&"on"+p,t=t[yt.expando]?t:new yt.Event(p,"object"==typeof t&&t),t.isTrigger=o?2:3,t.namespace=h.join("."),t.rnamespace=t.namespace?new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,t.result=void 0,t.target||(t.target=r),e=null==e?[t]:yt.makeArray(e,[t]),f=yt.event.special[p]||{},o||!f.trigger||f.trigger.apply(r,e)!==!1)){if(!o&&!f.noBubble&&!yt.isWindow(r)){for(l=f.delegateType||p,Ee.test(l+p)||(a=a.parentNode);a;a=a.parentNode)d.push(a),s=a;s===(r.ownerDocument||it)&&d.push(s.defaultView||s.parentWindow||n)}for(i=0;(a=d[i++])&&!t.isPropagationStopped();)t.type=i>1?l:f.bindType||p,c=(Bt.get(a,"events")||{})[t.type]&&Bt.get(a,"handle"),c&&c.apply(a,e),c=u&&a[u],c&&c.apply&&jt(a)&&(t.result=c.apply(a,e),t.result===!1&&t.preventDefault());return t.type=p,o||t.isDefaultPrevented()||f._default&&f._default.apply(d.pop(),e)!==!1||!jt(r)||u&&yt.isFunction(r[p])&&!yt.isWindow(r)&&(s=r[u],s&&(r[u]=null),yt.event.triggered=p,r[p](),yt.event.triggered=void 0,s&&(r[u]=s)),t.result}},simulate:function(t,e,n){var r=yt.extend(new yt.Event,n,{type:t,isSimulated:!0});yt.event.trigger(r,null,e)}}),yt.fn.extend({trigger:function(t,e){return this.each(function(){yt.event.trigger(t,e,this)})},triggerHandler:function(t,e){var n=this[0];if(n)return yt.event.trigger(t,e,n,!0)}}),yt.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),function(t,e){yt.fn[e]=function(t,n){return arguments.length>0?this.on(e,null,t,n):this.trigger(e)}}),yt.fn.extend({hover:function(t,e){return this.mouseenter(t).mouseleave(e||t)}}),vt.focusin="onfocusin"in n,vt.focusin||yt.each({focus:"focusin",blur:"focusout"},function(t,e){var n=function(t){yt.event.simulate(e,t.target,yt.event.fix(t))};yt.event.special[e]={setup:function(){var r=this.ownerDocument||this,o=Bt.access(r,e);o||r.addEventListener(t,n,!0),Bt.access(r,e,(o||0)+1)},teardown:function(){var r=this.ownerDocument||this,o=Bt.access(r,e)-1;o?Bt.access(r,e,o):(r.removeEventListener(t,n,!0),Bt.remove(r,e))}}});var Pe=n.location,Se=yt.now(),Me=/\?/;yt.parseXML=function(t){var e;if(!t||"string"!=typeof t)return null;try{e=(new n.DOMParser).parseFromString(t,"text/xml")}catch(t){e=void 0}return e&&!e.getElementsByTagName("parsererror").length||yt.error("Invalid XML: "+t),e};var Ne=/\[\]$/,Ae=/\r?\n/g,Oe=/^(?:submit|button|image|reset|file)$/i,De=/^(?:input|select|textarea|keygen)/i;yt.param=function(t,e){var n,r=[],o=function(t,e){var n=yt.isFunction(e)?e():e;r[r.length]=encodeURIComponent(t)+"="+encodeURIComponent(null==n?"":n)};if(yt.isArray(t)||t.jquery&&!yt.isPlainObject(t))yt.each(t,function(){o(this.name,this.value)});else for(n in t)Z(n,t[n],e,o);return r.join("&")},yt.fn.extend({serialize:function(){return yt.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var t=yt.prop(this,"elements");return t?yt.makeArray(t):this}).filter(function(){var t=this.type;return this.name&&!yt(this).is(":disabled")&&De.test(this.nodeName)&&!Oe.test(t)&&(this.checked||!Xt.test(t))}).map(function(t,e){var n=yt(this).val();return null==n?null:yt.isArray(n)?yt.map(n,function(t){return{name:e.name,value:t.replace(Ae,"\r\n")}}):{name:e.name,value:n.replace(Ae,"\r\n")}}).get()}});var Ie=/%20/g,Re=/#.*$/,Le=/([?&])_=[^&]*/,Fe=/^(.*?):[ \t]*([^\r\n]*)$/gm,je=/^(?:about|app|app-storage|.+-extension|file|res|widget):$/,Be=/^(?:GET|HEAD)$/,Ue=/^\/\//,He={},ze={},We="*/".concat("*"),qe=it.createElement("a");qe.href=Pe.href,yt.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:Pe.href,type:"GET",isLocal:je.test(Pe.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":We,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":yt.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(t,e){return e?tt(tt(t,yt.ajaxSettings),e):tt(yt.ajaxSettings,t)},ajaxPrefilter:J(He),ajaxTransport:J(ze),ajax:function(t,e){function r(t,e,r,s){var u,d,p,x,_,w=e;c||(c=!0,l&&n.clearTimeout(l),o=void 0,a=s||"",T.readyState=t>0?4:0,u=t>=200&&t<300||304===t,r&&(x=et(h,T,r)),x=nt(h,x,T,u),u?(h.ifModified&&(_=T.getResponseHeader("Last-Modified"),_&&(yt.lastModified[i]=_),_=T.getResponseHeader("etag"),_&&(yt.etag[i]=_)),204===t||"HEAD"===h.type?w="nocontent":304===t?w="notmodified":(w=x.state,d=x.data,p=x.error,u=!p)):(p=w,!t&&w||(w="error",t<0&&(t=0))),T.status=t,T.statusText=(e||w)+"",u?m.resolveWith(g,[d,w,T]):m.rejectWith(g,[T,w,p]),T.statusCode(b),b=void 0,f&&v.trigger(u?"ajaxSuccess":"ajaxError",[T,h,u?d:p]),y.fireWith(g,[T,w]),f&&(v.trigger("ajaxComplete",[T,h]),--yt.active||yt.event.trigger("ajaxStop")))}"object"==typeof t&&(e=t,t=void 0),e=e||{};var o,i,a,s,l,u,c,f,d,p,h=yt.ajaxSetup({},e),g=h.context||h,v=h.context&&(g.nodeType||g.jquery)?yt(g):yt.event,m=yt.Deferred(),y=yt.Callbacks("once memory"),b=h.statusCode||{},x={},_={},w="canceled",T={readyState:0,getResponseHeader:function(t){var e;if(c){if(!s)for(s={};e=Fe.exec(a);)s[e[1].toLowerCase()]=e[2];e=s[t.toLowerCase()]}return null==e?null:e},getAllResponseHeaders:function(){return c?a:null},setRequestHeader:function(t,e){return null==c&&(t=_[t.toLowerCase()]=_[t.toLowerCase()]||t,x[t]=e),this},overrideMimeType:function(t){return null==c&&(h.mimeType=t),this},statusCode:function(t){var e;if(t)if(c)T.always(t[T.status]);else for(e in t)b[e]=[b[e],t[e]];return this},abort:function(t){var e=t||w;return o&&o.abort(e),r(0,e),this}};if(m.promise(T),h.url=((t||h.url||Pe.href)+"").replace(Ue,Pe.protocol+"//"),h.type=e.method||e.type||h.method||h.type,h.dataTypes=(h.dataType||"*").toLowerCase().match(It)||[""],null==h.crossDomain){u=it.createElement("a");try{u.href=h.url,u.href=u.href,h.crossDomain=qe.protocol+"//"+qe.host!=u.protocol+"//"+u.host}catch(t){h.crossDomain=!0}}if(h.data&&h.processData&&"string"!=typeof h.data&&(h.data=yt.param(h.data,h.traditional)),Q(He,h,e,T),c)return T;f=yt.event&&h.global,f&&0===yt.active++&&yt.event.trigger("ajaxStart"),h.type=h.type.toUpperCase(),h.hasContent=!Be.test(h.type),i=h.url.replace(Re,""),h.hasContent?h.data&&h.processData&&0===(h.contentType||"").indexOf("application/x-www-form-urlencoded")&&(h.data=h.data.replace(Ie,"+")):(p=h.url.slice(i.length),h.data&&(i+=(Me.test(i)?"&":"?")+h.data,delete h.data),h.cache===!1&&(i=i.replace(Le,"$1"),p=(Me.test(i)?"&":"?")+"_="+Se++ +p),h.url=i+p),h.ifModified&&(yt.lastModified[i]&&T.setRequestHeader("If-Modified-Since",yt.lastModified[i]),yt.etag[i]&&T.setRequestHeader("If-None-Match",yt.etag[i])),(h.data&&h.hasContent&&h.contentType!==!1||e.contentType)&&T.setRequestHeader("Content-Type",h.contentType),T.setRequestHeader("Accept",h.dataTypes[0]&&h.accepts[h.dataTypes[0]]?h.accepts[h.dataTypes[0]]+("*"!==h.dataTypes[0]?", "+We+"; q=0.01":""):h.accepts["*"]);for(d in h.headers)T.setRequestHeader(d,h.headers[d]);if(h.beforeSend&&(h.beforeSend.call(g,T,h)===!1||c))return T.abort();if(w="abort",y.add(h.complete),T.done(h.success),T.fail(h.error),o=Q(ze,h,e,T)){if(T.readyState=1,f&&v.trigger("ajaxSend",[T,h]),c)return T;h.async&&h.timeout>0&&(l=n.setTimeout(function(){T.abort("timeout")},h.timeout));try{c=!1,o.send(x,r)}catch(t){if(c)throw t;r(-1,t)}}else r(-1,"No Transport");return T},getJSON:function(t,e,n){return yt.get(t,e,n,"json")},getScript:function(t,e){return yt.get(t,void 0,e,"script")}}),yt.each(["get","post"],function(t,e){yt[e]=function(t,n,r,o){return yt.isFunction(n)&&(o=o||r,r=n,n=void 0),yt.ajax(yt.extend({url:t,type:e,dataType:o,data:n,success:r},yt.isPlainObject(t)&&t))}}),yt._evalUrl=function(t){return yt.ajax({url:t,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,throws:!0})},yt.fn.extend({wrapAll:function(t){var e;return this[0]&&(yt.isFunction(t)&&(t=t.call(this[0])),e=yt(t,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&e.insertBefore(this[0]),e.map(function(){for(var t=this;t.firstElementChild;)t=t.firstElementChild;return t}).append(this)),this},wrapInner:function(t){return yt.isFunction(t)?this.each(function(e){yt(this).wrapInner(t.call(this,e))}):this.each(function(){var e=yt(this),n=e.contents();n.length?n.wrapAll(t):e.append(t)})},wrap:function(t){var e=yt.isFunction(t);return this.each(function(n){yt(this).wrapAll(e?t.call(this,n):t)})},unwrap:function(t){return this.parent(t).not("body").each(function(){
yt(this).replaceWith(this.childNodes)}),this}}),yt.expr.pseudos.hidden=function(t){return!yt.expr.pseudos.visible(t)},yt.expr.pseudos.visible=function(t){return!!(t.offsetWidth||t.offsetHeight||t.getClientRects().length)},yt.ajaxSettings.xhr=function(){try{return new n.XMLHttpRequest}catch(t){}};var Ve={0:200,1223:204},Ke=yt.ajaxSettings.xhr();vt.cors=!!Ke&&"withCredentials"in Ke,vt.ajax=Ke=!!Ke,yt.ajaxTransport(function(t){var e,r;if(vt.cors||Ke&&!t.crossDomain)return{send:function(o,i){var a,s=t.xhr();if(s.open(t.type,t.url,t.async,t.username,t.password),t.xhrFields)for(a in t.xhrFields)s[a]=t.xhrFields[a];t.mimeType&&s.overrideMimeType&&s.overrideMimeType(t.mimeType),t.crossDomain||o["X-Requested-With"]||(o["X-Requested-With"]="XMLHttpRequest");for(a in o)s.setRequestHeader(a,o[a]);e=function(t){return function(){e&&(e=r=s.onload=s.onerror=s.onabort=s.onreadystatechange=null,"abort"===t?s.abort():"error"===t?"number"!=typeof s.status?i(0,"error"):i(s.status,s.statusText):i(Ve[s.status]||s.status,s.statusText,"text"!==(s.responseType||"text")||"string"!=typeof s.responseText?{binary:s.response}:{text:s.responseText},s.getAllResponseHeaders()))}},s.onload=e(),r=s.onerror=e("error"),void 0!==s.onabort?s.onabort=r:s.onreadystatechange=function(){4===s.readyState&&n.setTimeout(function(){e&&r()})},e=e("abort");try{s.send(t.hasContent&&t.data||null)}catch(t){if(e)throw t}},abort:function(){e&&e()}}}),yt.ajaxPrefilter(function(t){t.crossDomain&&(t.contents.script=!1)}),yt.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(t){return yt.globalEval(t),t}}}),yt.ajaxPrefilter("script",function(t){void 0===t.cache&&(t.cache=!1),t.crossDomain&&(t.type="GET")}),yt.ajaxTransport("script",function(t){if(t.crossDomain){var e,n;return{send:function(r,o){e=yt("<script>").prop({charset:t.scriptCharset,src:t.url}).on("load error",n=function(t){e.remove(),n=null,t&&o("error"===t.type?404:200,t.type)}),it.head.appendChild(e[0])},abort:function(){n&&n()}}}});var Ye=[],Ge=/(=)\?(?=&|$)|\?\?/;yt.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var t=Ye.pop()||yt.expando+"_"+Se++;return this[t]=!0,t}}),yt.ajaxPrefilter("json jsonp",function(t,e,r){var o,i,a,s=t.jsonp!==!1&&(Ge.test(t.url)?"url":"string"==typeof t.data&&0===(t.contentType||"").indexOf("application/x-www-form-urlencoded")&&Ge.test(t.data)&&"data");if(s||"jsonp"===t.dataTypes[0])return o=t.jsonpCallback=yt.isFunction(t.jsonpCallback)?t.jsonpCallback():t.jsonpCallback,s?t[s]=t[s].replace(Ge,"$1"+o):t.jsonp!==!1&&(t.url+=(Me.test(t.url)?"&":"?")+t.jsonp+"="+o),t.converters["script json"]=function(){return a||yt.error(o+" was not called"),a[0]},t.dataTypes[0]="json",i=n[o],n[o]=function(){a=arguments},r.always(function(){void 0===i?yt(n).removeProp(o):n[o]=i,t[o]&&(t.jsonpCallback=e.jsonpCallback,Ye.push(o)),a&&yt.isFunction(i)&&i(a[0]),a=i=void 0}),"script"}),vt.createHTMLDocument=function(){var t=it.implementation.createHTMLDocument("").body;return t.innerHTML="<form></form><form></form>",2===t.childNodes.length}(),yt.parseHTML=function(t,e,n){if("string"!=typeof t)return[];"boolean"==typeof e&&(n=e,e=!1);var r,o,i;return e||(vt.createHTMLDocument?(e=it.implementation.createHTMLDocument(""),r=e.createElement("base"),r.href=it.location.href,e.head.appendChild(r)):e=it),o=Pt.exec(t),i=!n&&[],o?[e.createElement(o[1])]:(o=T([t],e,i),i&&i.length&&yt(i).remove(),yt.merge([],o.childNodes))},yt.fn.load=function(t,e,n){var r,o,i,a=this,s=t.indexOf(" ");return s>-1&&(r=X(t.slice(s)),t=t.slice(0,s)),yt.isFunction(e)?(n=e,e=void 0):e&&"object"==typeof e&&(o="POST"),a.length>0&&yt.ajax({url:t,type:o||"GET",dataType:"html",data:e}).done(function(t){i=arguments,a.html(r?yt("<div>").append(yt.parseHTML(t)).find(r):t)}).always(n&&function(t,e){a.each(function(){n.apply(this,i||[t.responseText,e,t])})}),this},yt.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(t,e){yt.fn[e]=function(t){return this.on(e,t)}}),yt.expr.pseudos.animated=function(t){return yt.grep(yt.timers,function(e){return t===e.elem}).length},yt.offset={setOffset:function(t,e,n){var r,o,i,a,s,l,u,c=yt.css(t,"position"),f=yt(t),d={};"static"===c&&(t.style.position="relative"),s=f.offset(),i=yt.css(t,"top"),l=yt.css(t,"left"),u=("absolute"===c||"fixed"===c)&&(i+l).indexOf("auto")>-1,u?(r=f.position(),a=r.top,o=r.left):(a=parseFloat(i)||0,o=parseFloat(l)||0),yt.isFunction(e)&&(e=e.call(t,n,yt.extend({},s))),null!=e.top&&(d.top=e.top-s.top+a),null!=e.left&&(d.left=e.left-s.left+o),"using"in e?e.using.call(t,d):f.css(d)}},yt.fn.extend({offset:function(t){if(arguments.length)return void 0===t?this:this.each(function(e){yt.offset.setOffset(this,t,e)});var e,n,r,o,i=this[0];if(i)return i.getClientRects().length?(r=i.getBoundingClientRect(),r.width||r.height?(o=i.ownerDocument,n=rt(o),e=o.documentElement,{top:r.top+n.pageYOffset-e.clientTop,left:r.left+n.pageXOffset-e.clientLeft}):r):{top:0,left:0}},position:function(){if(this[0]){var t,e,n=this[0],r={top:0,left:0};return"fixed"===yt.css(n,"position")?e=n.getBoundingClientRect():(t=this.offsetParent(),e=this.offset(),yt.nodeName(t[0],"html")||(r=t.offset()),r={top:r.top+yt.css(t[0],"borderTopWidth",!0),left:r.left+yt.css(t[0],"borderLeftWidth",!0)}),{top:e.top-r.top-yt.css(n,"marginTop",!0),left:e.left-r.left-yt.css(n,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){for(var t=this.offsetParent;t&&"static"===yt.css(t,"position");)t=t.offsetParent;return t||te})}}),yt.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(t,e){var n="pageYOffset"===e;yt.fn[t]=function(r){return Ft(this,function(t,r,o){var i=rt(t);return void 0===o?i?i[e]:t[r]:void(i?i.scrollTo(n?i.pageXOffset:o,n?o:i.pageYOffset):t[r]=o)},t,r,arguments.length)}}),yt.each(["top","left"],function(t,e){yt.cssHooks[e]=L(vt.pixelPosition,function(t,n){if(n)return n=R(t,e),ce.test(n)?yt(t).position()[e]+"px":n})}),yt.each({Height:"height",Width:"width"},function(t,e){yt.each({padding:"inner"+t,content:e,"":"outer"+t},function(n,r){yt.fn[r]=function(o,i){var a=arguments.length&&(n||"boolean"!=typeof o),s=n||(o===!0||i===!0?"margin":"border");return Ft(this,function(e,n,o){var i;return yt.isWindow(e)?0===r.indexOf("outer")?e["inner"+t]:e.document.documentElement["client"+t]:9===e.nodeType?(i=e.documentElement,Math.max(e.body["scroll"+t],i["scroll"+t],e.body["offset"+t],i["offset"+t],i["client"+t])):void 0===o?yt.css(e,n,s):yt.style(e,n,o,s)},e,a?o:void 0,a)}})}),yt.fn.extend({bind:function(t,e,n){return this.on(t,null,e,n)},unbind:function(t,e){return this.off(t,null,e)},delegate:function(t,e,n,r){return this.on(e,t,n,r)},undelegate:function(t,e,n){return 1===arguments.length?this.off(t,"**"):this.off(e,t||"**",n)}}),yt.parseJSON=JSON.parse,r=[],o=function(){return yt}.apply(e,r),!(void 0!==o&&(t.exports=o));var Xe=n.jQuery,$e=n.$;return yt.noConflict=function(t){return n.$===yt&&(n.$=$e),t&&n.jQuery===yt&&(n.jQuery=Xe),yt},i||(n.jQuery=n.$=yt),yt})},function(t,e,n){var r,o;!function(){function i(t){return t&&(t.ownerDocument||t.document||t).documentElement}function a(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}function s(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function l(t){return null===t?NaN:+t}function u(t){return!isNaN(t)}function c(t){return{left:function(e,n,r,o){for(arguments.length<3&&(r=0),arguments.length<4&&(o=e.length);r<o;){var i=r+o>>>1;t(e[i],n)<0?r=i+1:o=i}return r},right:function(e,n,r,o){for(arguments.length<3&&(r=0),arguments.length<4&&(o=e.length);r<o;){var i=r+o>>>1;t(e[i],n)>0?o=i:r=i+1}return r}}}function f(t){return t.length}function d(t){for(var e=1;t*e%1;)e*=10;return e}function p(t,e){for(var n in e)Object.defineProperty(t.prototype,n,{value:e[n],enumerable:!1})}function h(){this._=Object.create(null)}function g(t){return(t+="")===Ca||t[0]===ka?ka+t:t}function v(t){return(t+="")[0]===ka?t.slice(1):t}function m(t){return g(t)in this._}function y(t){return(t=g(t))in this._&&delete this._[t]}function b(){var t=[];for(var e in this._)t.push(v(e));return t}function x(){var t=0;for(var e in this._)++t;return t}function _(){for(var t in this._)return!1;return!0}function w(){this._=Object.create(null)}function T(t){return t}function C(t,e,n){return function(){var r=n.apply(e,arguments);return r===e?t:r}}function k(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var n=0,r=Ea.length;n<r;++n){var o=Ea[n]+e;if(o in t)return o}}function E(){}function P(){}function S(t){function e(){for(var e,r=n,o=-1,i=r.length;++o<i;)(e=r[o].on)&&e.apply(this,arguments);return t}var n=[],r=new h;return e.on=function(e,o){var i,a=r.get(e);return arguments.length<2?a&&a.on:(a&&(a.on=null,n=n.slice(0,i=n.indexOf(a)).concat(n.slice(i+1)),r.remove(e)),o&&n.push(r.set(e,{on:o})),t)},e}function M(){pa.event.preventDefault()}function N(){for(var t,e=pa.event;t=e.sourceEvent;)e=t;return e}function A(t){for(var e=new P,n=0,r=arguments.length;++n<r;)e[arguments[n]]=S(e);return e.of=function(n,r){return function(o){try{var i=o.sourceEvent=pa.event;o.target=t,pa.event=o,e[o.type].apply(n,r)}finally{pa.event=i}}},e}function O(t){return Sa(t,Oa),t}function D(t){return"function"==typeof t?t:function(){return Ma(t,this)}}function I(t){return"function"==typeof t?t:function(){return Na(t,this)}}function R(t,e){function n(){this.removeAttribute(t)}function r(){this.removeAttributeNS(t.space,t.local)}function o(){this.setAttribute(t,e)}function i(){this.setAttributeNS(t.space,t.local,e)}function a(){var n=e.apply(this,arguments);null==n?this.removeAttribute(t):this.setAttribute(t,n)}function s(){var n=e.apply(this,arguments);null==n?this.removeAttributeNS(t.space,t.local):this.setAttributeNS(t.space,t.local,n)}return t=pa.ns.qualify(t),null==e?t.local?r:n:"function"==typeof e?t.local?s:a:t.local?i:o}function L(t){return t.trim().replace(/\s+/g," ")}function F(t){return new RegExp("(?:^|\\s+)"+pa.requote(t)+"(?:\\s+|$)","g")}function j(t){return(t+"").trim().split(/^|\s+/)}function B(t,e){function n(){for(var n=-1;++n<o;)t[n](this,e)}function r(){for(var n=-1,r=e.apply(this,arguments);++n<o;)t[n](this,r)}t=j(t).map(U);var o=t.length;return"function"==typeof e?r:n}function U(t){var e=F(t);return function(n,r){if(o=n.classList)return r?o.add(t):o.remove(t);var o=n.getAttribute("class")||"";r?(e.lastIndex=0,e.test(o)||n.setAttribute("class",L(o+" "+t))):n.setAttribute("class",L(o.replace(e," ")))}}function H(t,e,n){function r(){this.style.removeProperty(t)}function o(){this.style.setProperty(t,e,n)}function i(){var r=e.apply(this,arguments);null==r?this.style.removeProperty(t):this.style.setProperty(t,r,n)}return null==e?r:"function"==typeof e?i:o}function z(t,e){function n(){delete this[t]}function r(){this[t]=e}function o(){var n=e.apply(this,arguments);null==n?delete this[t]:this[t]=n}return null==e?n:"function"==typeof e?o:r}function W(t){function e(){var e=this.ownerDocument,n=this.namespaceURI;return n===Da&&e.documentElement.namespaceURI===Da?e.createElement(t):e.createElementNS(n,t)}function n(){return this.ownerDocument.createElementNS(t.space,t.local)}return"function"==typeof t?t:(t=pa.ns.qualify(t)).local?n:e}function q(){var t=this.parentNode;t&&t.removeChild(this)}function V(t){return{__data__:t}}function K(t){return function(){return Aa(this,t)}}function Y(t){return arguments.length||(t=s),function(e,n){return e&&n?t(e.__data__,n.__data__):!e-!n}}function G(t,e){for(var n=0,r=t.length;n<r;n++)for(var o,i=t[n],a=0,s=i.length;a<s;a++)(o=i[a])&&e(o,a,n);return t}function X(t){return Sa(t,Ra),t}function $(t){var e,n;return function(r,o,i){var a,s=t[i].update,l=s.length;for(i!=n&&(n=i,e=0),o>=e&&(e=o+1);!(a=s[e])&&++e<l;);return a}}function Z(t,e,n){function r(){var e=this[a];e&&(this.removeEventListener(t,e,e.$),delete this[a])}function o(){var o=l(e,ga(arguments));r.call(this),this.addEventListener(t,this[a]=o,o.$=n),o._=e}function i(){var e,n=new RegExp("^__on([^.]+)"+pa.requote(t)+"$");for(var r in this)if(e=r.match(n)){var o=this[r];this.removeEventListener(e[1],o,o.$),delete this[r]}}var a="__on"+t,s=t.indexOf("."),l=J;s>0&&(t=t.slice(0,s));var u=La.get(t);return u&&(t=u,l=Q),s?e?o:r:e?E:i}function J(t,e){return function(n){var r=pa.event;pa.event=n,e[0]=this.__data__;try{t.apply(this,e)}finally{pa.event=r}}}function Q(t,e){var n=J(t,e);return function(t){var e=this,r=t.relatedTarget;r&&(r===e||8&r.compareDocumentPosition(e))||n.call(e,t)}}function tt(t){var e=".dragsuppress-"+ ++ja,n="click"+e,r=pa.select(a(t)).on("touchmove"+e,M).on("dragstart"+e,M).on("selectstart"+e,M);if(null==Fa&&(Fa=!("onselectstart"in t)&&k(t.style,"userSelect")),Fa){var o=i(t).style,s=o[Fa];o[Fa]="none"}return function(t){if(r.on(e,null),Fa&&(o[Fa]=s),t){var i=function(){r.on(n,null)};r.on(n,function(){M(),i()},!0),setTimeout(i,0)}}}function et(t,e){e.changedTouches&&(e=e.changedTouches[0]);var n=t.ownerSVGElement||t;if(n.createSVGPoint){var r=n.createSVGPoint();if(Ba<0){var o=a(t);if(o.scrollX||o.scrollY){n=pa.select("body").append("svg").style({position:"absolute",top:0,left:0,margin:0,padding:0,border:"none"},"important");var i=n[0][0].getScreenCTM();Ba=!(i.f||i.e),n.remove()}}return Ba?(r.x=e.pageX,r.y=e.pageY):(r.x=e.clientX,r.y=e.clientY),r=r.matrixTransform(t.getScreenCTM().inverse()),[r.x,r.y]}var s=t.getBoundingClientRect();return[e.clientX-s.left-t.clientLeft,e.clientY-s.top-t.clientTop]}function nt(){return pa.event.changedTouches[0].identifier}function rt(t){return t>0?1:t<0?-1:0}function ot(t,e,n){return(e[0]-t[0])*(n[1]-t[1])-(e[1]-t[1])*(n[0]-t[0])}function it(t){return t>1?0:t<-1?za:Math.acos(t)}function at(t){return t>1?Va:t<-1?-Va:Math.asin(t)}function st(t){return((t=Math.exp(t))-1/t)/2}function lt(t){return((t=Math.exp(t))+1/t)/2}function ut(t){return((t=Math.exp(2*t))-1)/(t+1)}function ct(t){return(t=Math.sin(t/2))*t}function ft(){}function dt(t,e,n){return this instanceof dt?(this.h=+t,this.s=+e,void(this.l=+n)):arguments.length<2?t instanceof dt?new dt(t.h,t.s,t.l):Et(""+t,Pt,dt):new dt(t,e,n)}function pt(t,e,n){function r(t){return t>360?t-=360:t<0&&(t+=360),t<60?i+(a-i)*t/60:t<180?a:t<240?i+(a-i)*(240-t)/60:i}function o(t){return Math.round(255*r(t))}var i,a;return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=n<0?0:n>1?1:n,a=n<=.5?n*(1+e):n+e-n*e,i=2*n-a,new wt(o(t+120),o(t),o(t-120))}function ht(t,e,n){return this instanceof ht?(this.h=+t,this.c=+e,void(this.l=+n)):arguments.length<2?t instanceof ht?new ht(t.h,t.c,t.l):t instanceof vt?yt(t.l,t.a,t.b):yt((t=St((t=pa.rgb(t)).r,t.g,t.b)).l,t.a,t.b):new ht(t,e,n)}function gt(t,e,n){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new vt(n,Math.cos(t*=Ka)*e,Math.sin(t)*e)}function vt(t,e,n){return this instanceof vt?(this.l=+t,this.a=+e,void(this.b=+n)):arguments.length<2?t instanceof vt?new vt(t.l,t.a,t.b):t instanceof ht?gt(t.h,t.c,t.l):St((t=wt(t)).r,t.g,t.b):new vt(t,e,n)}function mt(t,e,n){var r=(t+16)/116,o=r+e/500,i=r-n/200;return o=bt(o)*rs,r=bt(r)*os,i=bt(i)*is,new wt(_t(3.2404542*o-1.5371385*r-.4985314*i),_t(-.969266*o+1.8760108*r+.041556*i),_t(.0556434*o-.2040259*r+1.0572252*i))}function yt(t,e,n){return t>0?new ht(Math.atan2(n,e)*Ya,Math.sqrt(e*e+n*n),t):new ht(NaN,NaN,t)}function bt(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function xt(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function _t(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function wt(t,e,n){return this instanceof wt?(this.r=~~t,this.g=~~e,void(this.b=~~n)):arguments.length<2?t instanceof wt?new wt(t.r,t.g,t.b):Et(""+t,wt,pt):new wt(t,e,n)}function Tt(t){return new wt(t>>16,t>>8&255,255&t)}function Ct(t){return Tt(t)+""}function kt(t){return t<16?"0"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function Et(t,e,n){var r,o,i,a=0,s=0,l=0;if(r=/([a-z]+)\((.*)\)/.exec(t=t.toLowerCase()))switch(o=r[2].split(","),r[1]){case"hsl":return n(parseFloat(o[0]),parseFloat(o[1])/100,parseFloat(o[2])/100);case"rgb":return e(Nt(o[0]),Nt(o[1]),Nt(o[2]))}return(i=ls.get(t))?e(i.r,i.g,i.b):(null==t||"#"!==t.charAt(0)||isNaN(i=parseInt(t.slice(1),16))||(4===t.length?(a=(3840&i)>>4,a|=a>>4,s=240&i,s|=s>>4,l=15&i,l|=l<<4):7===t.length&&(a=(16711680&i)>>16,s=(65280&i)>>8,l=255&i)),e(a,s,l))}function Pt(t,e,n){var r,o,i=Math.min(t/=255,e/=255,n/=255),a=Math.max(t,e,n),s=a-i,l=(a+i)/2;return s?(o=l<.5?s/(a+i):s/(2-a-i),r=t==a?(e-n)/s+(e<n?6:0):e==a?(n-t)/s+2:(t-e)/s+4,r*=60):(r=NaN,o=l>0&&l<1?0:r),new dt(r,o,l)}function St(t,e,n){t=Mt(t),e=Mt(e),n=Mt(n);var r=xt((.4124564*t+.3575761*e+.1804375*n)/rs),o=xt((.2126729*t+.7151522*e+.072175*n)/os),i=xt((.0193339*t+.119192*e+.9503041*n)/is);return vt(116*o-16,500*(r-o),200*(o-i))}function Mt(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function Nt(t){var e=parseFloat(t);return"%"===t.charAt(t.length-1)?Math.round(2.55*e):e}function At(t){return"function"==typeof t?t:function(){return t}}function Ot(t){return function(e,n,r){return 2===arguments.length&&"function"==typeof n&&(r=n,n=null),Dt(e,n,t,r)}}function Dt(t,e,n,r){function o(){var t,e=l.status;if(!e&&Rt(l)||e>=200&&e<300||304===e){try{t=n.call(i,l)}catch(t){return void a.error.call(i,t)}a.load.call(i,t)}else a.error.call(i,l)}var i={},a=pa.dispatch("beforesend","progress","load","error"),s={},l=new XMLHttpRequest,u=null;return!this.XDomainRequest||"withCredentials"in l||!/^(http(s)?:)?\/\//.test(t)||(l=new XDomainRequest),"onload"in l?l.onload=l.onerror=o:l.onreadystatechange=function(){l.readyState>3&&o()},l.onprogress=function(t){var e=pa.event;pa.event=t;try{a.progress.call(i,l)}finally{pa.event=e}},i.header=function(t,e){return t=(t+"").toLowerCase(),arguments.length<2?s[t]:(null==e?delete s[t]:s[t]=e+"",i)},i.mimeType=function(t){return arguments.length?(e=null==t?null:t+"",i):e},i.responseType=function(t){return arguments.length?(u=t,i):u},i.response=function(t){return n=t,i},["get","post"].forEach(function(t){i[t]=function(){return i.send.apply(i,[t].concat(ga(arguments)))}}),i.send=function(n,r,o){if(2===arguments.length&&"function"==typeof r&&(o=r,r=null),l.open(n,t,!0),null==e||"accept"in s||(s.accept=e+",*/*"),l.setRequestHeader)for(var c in s)l.setRequestHeader(c,s[c]);return null!=e&&l.overrideMimeType&&l.overrideMimeType(e),null!=u&&(l.responseType=u),null!=o&&i.on("error",o).on("load",function(t){o(null,t)}),a.beforesend.call(i,l),l.send(null==r?null:r),i},i.abort=function(){return l.abort(),i},pa.rebind(i,a,"on"),null==r?i:i.get(It(r))}function It(t){return 1===t.length?function(e,n){t(null==e?n:null)}:t}function Rt(t){var e=t.responseType;return e&&"text"!==e?t.response:t.responseText}function Lt(t,e,n){var r=arguments.length;r<2&&(e=0),r<3&&(n=Date.now());var o=n+e,i={c:t,t:o,n:null};return cs?cs.n=i:us=i,cs=i,fs||(ds=clearTimeout(ds),fs=1,ps(Ft)),i}function Ft(){var t=jt(),e=Bt()-t;e>24?(isFinite(e)&&(clearTimeout(ds),ds=setTimeout(Ft,e)),fs=0):(fs=1,ps(Ft))}function jt(){for(var t=Date.now(),e=us;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Bt(){for(var t,e=us,n=1/0;e;)e.c?(e.t<n&&(n=e.t),e=(t=e).n):e=t?t.n=e.n:us=e.n;return cs=t,n}function Ut(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}function Ht(t,e){var n=Math.pow(10,3*Ta(8-e));return{scale:e>8?function(t){return t/n}:function(t){return t*n},symbol:t}}function zt(t){var e=t.decimal,n=t.thousands,r=t.grouping,o=t.currency,i=r&&n?function(t,e){for(var o=t.length,i=[],a=0,s=r[0],l=0;o>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),i.push(t.substring(o-=s,o+s)),!((l+=s+1)>e));)s=r[a=(a+1)%r.length];return i.reverse().join(n)}:T;return function(t){var n=gs.exec(t),r=n[1]||" ",a=n[2]||">",s=n[3]||"-",l=n[4]||"",u=n[5],c=+n[6],f=n[7],d=n[8],p=n[9],h=1,g="",v="",m=!1,y=!0;switch(d&&(d=+d.substring(1)),(u||"0"===r&&"="===a)&&(u=r="0",a="="),p){case"n":f=!0,p="g";break;case"%":h=100,v="%",p="f";break;case"p":h=100,v="%",p="r";break;case"b":case"o":case"x":case"X":"#"===l&&(g="0"+p.toLowerCase());case"c":y=!1;case"d":m=!0,d=0;break;case"s":h=-1,p="r"}"$"===l&&(g=o[0],v=o[1]),"r"!=p||d||(p="g"),null!=d&&("g"==p?d=Math.max(1,Math.min(21,d)):"e"!=p&&"f"!=p||(d=Math.max(0,Math.min(20,d)))),p=vs.get(p)||Wt;var b=u&&f;return function(t){var n=v;if(m&&t%1)return"";var o=t<0||0===t&&1/t<0?(t=-t,"-"):"-"===s?"":s;if(h<0){var l=pa.formatPrefix(t,d);t=l.scale(t),n=l.symbol+v}else t*=h;t=p(t,d);var x,_,w=t.lastIndexOf(".");if(w<0){var T=y?t.lastIndexOf("e"):-1;T<0?(x=t,_=""):(x=t.substring(0,T),_=t.substring(T))}else x=t.substring(0,w),_=e+t.substring(w+1);!u&&f&&(x=i(x,1/0));var C=g.length+x.length+_.length+(b?0:o.length),k=C<c?new Array(C=c-C+1).join(r):"";return b&&(x=i(k+x,k.length?c-_.length:1/0)),o+=g,t=x+_,("<"===a?o+t+k:">"===a?k+o+t:"^"===a?k.substring(0,C>>=1)+o+t+k.substring(C):o+(b?t:k+t))+n}}}function Wt(t){return t+""}function qt(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}function Vt(t,e,n){function r(e){var n=t(e),r=i(n,1);return e-n<r-e?n:r}function o(n){return e(n=t(new ys(n-1)),1),n}function i(t,n){return e(t=new ys(+t),n),t}function a(t,r,i){var a=o(t),s=[];if(i>1)for(;a<r;)n(a)%i||s.push(new Date(+a)),e(a,1);else for(;a<r;)s.push(new Date(+a)),e(a,1);return s}function s(t,e,n){try{ys=qt;var r=new qt;return r._=t,a(r,e,n)}finally{ys=Date}}t.floor=t,t.round=r,t.ceil=o,t.offset=i,t.range=a;var l=t.utc=Kt(t);return l.floor=l,l.round=Kt(r),l.ceil=Kt(o),l.offset=Kt(i),l.range=s,t}function Kt(t){return function(e,n){try{ys=qt;var r=new qt;return r._=e,t(r,n)._}finally{ys=Date}}}function Yt(t){function e(t){function e(e){for(var n,o,i,a=[],s=-1,l=0;++s<r;)37===t.charCodeAt(s)&&(a.push(t.slice(l,s)),null!=(o=xs[n=t.charAt(++s)])&&(n=t.charAt(++s)),(i=S[n])&&(n=i(e,null==o?"e"===n?" ":"0":o)),a.push(n),l=s+1);return a.push(t.slice(l,s)),a.join("")}var r=t.length;return e.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null},o=n(r,t,e,0);if(o!=e.length)return null;"p"in r&&(r.H=r.H%12+12*r.p);var i=null!=r.Z&&ys!==qt,a=new(i?qt:ys);return"j"in r?a.setFullYear(r.y,0,r.j):"W"in r||"U"in r?("w"in r||(r.w="W"in r?1:0),a.setFullYear(r.y,0,1),a.setFullYear(r.y,0,"W"in r?(r.w+6)%7+7*r.W-(a.getDay()+5)%7:r.w+7*r.U-(a.getDay()+6)%7)):a.setFullYear(r.y,r.m,r.d),a.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),i?a._:a},e.toString=function(){return t},e}function n(t,e,n,r){for(var o,i,a,s=0,l=e.length,u=n.length;s<l;){if(r>=u)return-1;if(o=e.charCodeAt(s++),37===o){if(a=e.charAt(s++),i=M[a in xs?e.charAt(s++):a],!i||(r=i(t,n,r))<0)return-1}else if(o!=n.charCodeAt(r++))return-1}return r}function r(t,e,n){w.lastIndex=0;var r=w.exec(e.slice(n));return r?(t.w=T.get(r[0].toLowerCase()),n+r[0].length):-1}function o(t,e,n){x.lastIndex=0;var r=x.exec(e.slice(n));return r?(t.w=_.get(r[0].toLowerCase()),n+r[0].length):-1}function i(t,e,n){E.lastIndex=0;var r=E.exec(e.slice(n));return r?(t.m=P.get(r[0].toLowerCase()),n+r[0].length):-1}function a(t,e,n){C.lastIndex=0;var r=C.exec(e.slice(n));return r?(t.m=k.get(r[0].toLowerCase()),n+r[0].length):-1}function s(t,e,r){return n(t,S.c.toString(),e,r)}function l(t,e,r){return n(t,S.x.toString(),e,r)}function u(t,e,r){return n(t,S.X.toString(),e,r)}function c(t,e,n){var r=b.get(e.slice(n,n+=2).toLowerCase());return null==r?-1:(t.p=r,n)}var f=t.dateTime,d=t.date,p=t.time,h=t.periods,g=t.days,v=t.shortDays,m=t.months,y=t.shortMonths;e.utc=function(t){function n(t){try{ys=qt;var e=new ys;return e._=t,r(e)}finally{ys=Date}}var r=e(t);return n.parse=function(t){try{ys=qt;var e=r.parse(t);return e&&e._}finally{ys=Date}},n.toString=r.toString,n},e.multi=e.utc.multi=pe;var b=pa.map(),x=Xt(g),_=$t(g),w=Xt(v),T=$t(v),C=Xt(m),k=$t(m),E=Xt(y),P=$t(y);h.forEach(function(t,e){b.set(t.toLowerCase(),e)});var S={a:function(t){return v[t.getDay()]},A:function(t){return g[t.getDay()]},b:function(t){return y[t.getMonth()]},B:function(t){return m[t.getMonth()]},c:e(f),d:function(t,e){return Gt(t.getDate(),e,2)},e:function(t,e){return Gt(t.getDate(),e,2)},H:function(t,e){return Gt(t.getHours(),e,2)},I:function(t,e){return Gt(t.getHours()%12||12,e,2)},j:function(t,e){return Gt(1+ms.dayOfYear(t),e,3)},L:function(t,e){return Gt(t.getMilliseconds(),e,3)},m:function(t,e){return Gt(t.getMonth()+1,e,2)},M:function(t,e){return Gt(t.getMinutes(),e,2)},p:function(t){return h[+(t.getHours()>=12)]},S:function(t,e){return Gt(t.getSeconds(),e,2)},U:function(t,e){return Gt(ms.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Gt(ms.mondayOfYear(t),e,2)},x:e(d),X:e(p),y:function(t,e){return Gt(t.getFullYear()%100,e,2)},Y:function(t,e){return Gt(t.getFullYear()%1e4,e,4)},Z:fe,"%":function(){return"%"}},M={a:r,A:o,b:i,B:a,c:s,d:ie,e:ie,H:se,I:se,j:ae,L:ce,m:oe,M:le,p:c,S:ue,U:Jt,w:Zt,W:Qt,x:l,X:u,y:ee,Y:te,Z:ne,"%":de};return e}function Gt(t,e,n){var r=t<0?"-":"",o=(r?-t:t)+"",i=o.length;return r+(i<n?new Array(n-i+1).join(e)+o:o)}function Xt(t){return new RegExp("^(?:"+t.map(pa.requote).join("|")+")","i")}function $t(t){for(var e=new h,n=-1,r=t.length;++n<r;)e.set(t[n].toLowerCase(),n);return e}function Zt(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+1));return r?(t.w=+r[0],n+r[0].length):-1}function Jt(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n));return r?(t.U=+r[0],n+r[0].length):-1}function Qt(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n));return r?(t.W=+r[0],n+r[0].length):-1}function te(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+4));return r?(t.y=+r[0],n+r[0].length):-1}function ee(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+2));return r?(t.y=re(+r[0]),n+r[0].length):-1}function ne(t,e,n){return/^[+-]\d{4}$/.test(e=e.slice(n,n+5))?(t.Z=-e,n+5):-1}function re(t){return t+(t>68?1900:2e3)}function oe(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+2));return r?(t.m=r[0]-1,n+r[0].length):-1}function ie(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+2));return r?(t.d=+r[0],n+r[0].length):-1}function ae(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+3));return r?(t.j=+r[0],n+r[0].length):-1}function se(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+2));return r?(t.H=+r[0],n+r[0].length):-1}function le(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+2));return r?(t.M=+r[0],n+r[0].length):-1}function ue(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+2));return r?(t.S=+r[0],n+r[0].length):-1}function ce(t,e,n){_s.lastIndex=0;var r=_s.exec(e.slice(n,n+3));return r?(t.L=+r[0],n+r[0].length):-1}function fe(t){var e=t.getTimezoneOffset(),n=e>0?"-":"+",r=Ta(e)/60|0,o=Ta(e)%60;return n+Gt(r,"0",2)+Gt(o,"0",2)}function de(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+1));return r?n+r[0].length:-1}function pe(t){for(var e=t.length,n=-1;++n<e;)t[n][0]=this(t[n][0]);return function(e){for(var n=0,r=t[n];!r[1](e);)r=t[++n];return r[0](e)}}function he(){}function ge(t,e,n){var r=n.s=t+e,o=r-t,i=r-o;n.t=t-i+(e-o)}function ve(t,e){t&&Es.hasOwnProperty(t.type)&&Es[t.type](t,e)}function me(t,e,n){var r,o=-1,i=t.length-n;for(e.lineStart();++o<i;)r=t[o],e.point(r[0],r[1],r[2]);e.lineEnd()}function ye(t,e){var n=-1,r=t.length;for(e.polygonStart();++n<r;)me(t[n],e,1);e.polygonEnd()}function be(){function t(t,e){t*=Ka,e=e*Ka/2+za/4;var n=t-r,a=n>=0?1:-1,s=a*n,l=Math.cos(e),u=Math.sin(e),c=i*u,f=o*l+c*Math.cos(s),d=c*a*Math.sin(s);Ss.add(Math.atan2(d,f)),r=t,o=l,i=u}var e,n,r,o,i;Ms.point=function(a,s){Ms.point=t,r=(e=a)*Ka,o=Math.cos(s=(n=s)*Ka/2+za/4),i=Math.sin(s)},Ms.lineEnd=function(){t(e,n)}}function xe(t){var e=t[0],n=t[1],r=Math.cos(n);return[r*Math.cos(e),r*Math.sin(e),Math.sin(n)]}function _e(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function we(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Te(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Ce(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function ke(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Ee(t){return[Math.atan2(t[1],t[0]),at(t[2])]}function Pe(t,e){return Ta(t[0]-e[0])<Ua&&Ta(t[1]-e[1])<Ua}function Se(t,e){t*=Ka;var n=Math.cos(e*=Ka);Me(n*Math.cos(t),n*Math.sin(t),Math.sin(e))}function Me(t,e,n){++Ns,Os+=(t-Os)/Ns,Ds+=(e-Ds)/Ns,Is+=(n-Is)/Ns}function Ne(){function t(t,o){t*=Ka;var i=Math.cos(o*=Ka),a=i*Math.cos(t),s=i*Math.sin(t),l=Math.sin(o),u=Math.atan2(Math.sqrt((u=n*l-r*s)*u+(u=r*a-e*l)*u+(u=e*s-n*a)*u),e*a+n*s+r*l);As+=u,Rs+=u*(e+(e=a)),Ls+=u*(n+(n=s)),Fs+=u*(r+(r=l)),Me(e,n,r)}var e,n,r;Hs.point=function(o,i){o*=Ka;var a=Math.cos(i*=Ka);e=a*Math.cos(o),n=a*Math.sin(o),r=Math.sin(i),Hs.point=t,Me(e,n,r)}}function Ae(){Hs.point=Se}function Oe(){function t(t,e){t*=Ka;var n=Math.cos(e*=Ka),a=n*Math.cos(t),s=n*Math.sin(t),l=Math.sin(e),u=o*l-i*s,c=i*a-r*l,f=r*s-o*a,d=Math.sqrt(u*u+c*c+f*f),p=r*a+o*s+i*l,h=d&&-it(p)/d,g=Math.atan2(d,p);js+=h*u,Bs+=h*c,Us+=h*f,As+=g,Rs+=g*(r+(r=a)),Ls+=g*(o+(o=s)),Fs+=g*(i+(i=l)),Me(r,o,i)}var e,n,r,o,i;Hs.point=function(a,s){e=a,n=s,Hs.point=t,a*=Ka;var l=Math.cos(s*=Ka);r=l*Math.cos(a),o=l*Math.sin(a),i=Math.sin(s),Me(r,o,i)},Hs.lineEnd=function(){t(e,n),Hs.lineEnd=Ae,Hs.point=Se}}function De(t,e){function n(n,r){return n=t(n,r),e(n[0],n[1])}return t.invert&&e.invert&&(n.invert=function(n,r){return n=e.invert(n,r),n&&t.invert(n[0],n[1])}),n}function Ie(){return!0}function Re(t,e,n,r,o){var i=[],a=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,n=t[0],r=t[e];if(Pe(n,r)){o.lineStart();for(var s=0;s<e;++s)o.point((n=t[s])[0],n[1]);return void o.lineEnd()}var l=new Fe(n,t,null,!0),u=new Fe(n,null,l,!1);l.o=u,i.push(l),a.push(u),l=new Fe(r,t,null,!1),u=new Fe(r,null,l,!0),l.o=u,i.push(l),a.push(u)}}),a.sort(e),Le(i),Le(a),i.length){for(var s=0,l=n,u=a.length;s<u;++s)a[s].e=l=!l;for(var c,f,d=i[0];;){for(var p=d,h=!0;p.v;)if((p=p.n)===d)return;c=p.z,o.lineStart();do{if(p.v=p.o.v=!0,p.e){if(h)for(var s=0,u=c.length;s<u;++s)o.point((f=c[s])[0],f[1]);else r(p.x,p.n.x,1,o);p=p.n}else{if(h){c=p.p.z;for(var s=c.length-1;s>=0;--s)o.point((f=c[s])[0],f[1])}else r(p.x,p.p.x,-1,o);p=p.p}p=p.o,c=p.z,h=!h}while(!p.v);o.lineEnd()}}}function Le(t){if(e=t.length){for(var e,n,r=0,o=t[0];++r<e;)o.n=n=t[r],n.p=o,o=n;o.n=n=t[0],n.p=o}}function Fe(t,e,n,r){this.x=t,this.z=e,this.o=n,this.e=r,this.v=!1,this.n=this.p=null}function je(t,e,n,r){return function(o,i){function a(e,n){var r=o(e,n);t(e=r[0],n=r[1])&&i.point(e,n)}function s(t,e){var n=o(t,e);v.point(n[0],n[1])}function l(){y.point=s,v.lineStart()}function u(){y.point=a,v.lineEnd()}function c(t,e){g.push([t,e]);var n=o(t,e);x.point(n[0],n[1])}function f(){x.lineStart(),g=[]}function d(){c(g[0][0],g[0][1]),x.lineEnd();var t,e=x.clean(),n=b.buffer(),r=n.length;if(g.pop(),h.push(g),g=null,r)if(1&e){t=n[0];var o,r=t.length-1,a=-1;if(r>0){for(_||(i.polygonStart(),_=!0),i.lineStart();++a<r;)i.point((o=t[a])[0],o[1]);i.lineEnd()}}else r>1&&2&e&&n.push(n.pop().concat(n.shift())),p.push(n.filter(Be))}var p,h,g,v=e(i),m=o.invert(r[0],r[1]),y={point:a,lineStart:l,lineEnd:u,polygonStart:function(){y.point=c,y.lineStart=f,y.lineEnd=d,p=[],h=[]},polygonEnd:function(){y.point=a,y.lineStart=l,y.lineEnd=u,p=pa.merge(p);var t=Ve(m,h);p.length?(_||(i.polygonStart(),_=!0),Re(p,He,t,n,i)):t&&(_||(i.polygonStart(),_=!0),i.lineStart(),n(null,null,1,i),i.lineEnd()),_&&(i.polygonEnd(),_=!1),p=h=null},sphere:function(){i.polygonStart(),i.lineStart(),n(null,null,1,i),i.lineEnd(),i.polygonEnd()}},b=Ue(),x=e(b),_=!1;return y}}function Be(t){return t.length>1}function Ue(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,n){t.push([e,n])},lineEnd:E,buffer:function(){var n=e;return e=[],t=null,n},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function He(t,e){return((t=t.x)[0]<0?t[1]-Va-Ua:Va-t[1])-((e=e.x)[0]<0?e[1]-Va-Ua:Va-e[1])}function ze(t){var e,n=NaN,r=NaN,o=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(i,a){var s=i>0?za:-za,l=Ta(i-n);Ta(l-za)<Ua?(t.point(n,r=(r+a)/2>0?Va:-Va),t.point(o,r),t.lineEnd(),t.lineStart(),t.point(s,r),t.point(i,r),e=0):o!==s&&l>=za&&(Ta(n-o)<Ua&&(n-=o*Ua),Ta(i-s)<Ua&&(i-=s*Ua),r=We(n,r,i,a),t.point(o,r),t.lineEnd(),t.lineStart(),t.point(s,r),e=0),t.point(n=i,r=a),
o=s},lineEnd:function(){t.lineEnd(),n=r=NaN},clean:function(){return 2-e}}}function We(t,e,n,r){var o,i,a=Math.sin(t-n);return Ta(a)>Ua?Math.atan((Math.sin(e)*(i=Math.cos(r))*Math.sin(n)-Math.sin(r)*(o=Math.cos(e))*Math.sin(t))/(o*i*a)):(e+r)/2}function qe(t,e,n,r){var o;if(null==t)o=n*Va,r.point(-za,o),r.point(0,o),r.point(za,o),r.point(za,0),r.point(za,-o),r.point(0,-o),r.point(-za,-o),r.point(-za,0),r.point(-za,o);else if(Ta(t[0]-e[0])>Ua){var i=t[0]<e[0]?za:-za;o=n*i/2,r.point(-i,o),r.point(0,o),r.point(i,o)}else r.point(e[0],e[1])}function Ve(t,e){var n=t[0],r=t[1],o=[Math.sin(n),-Math.cos(n),0],i=0,a=0;Ss.reset();for(var s=0,l=e.length;s<l;++s){var u=e[s],c=u.length;if(c)for(var f=u[0],d=f[0],p=f[1]/2+za/4,h=Math.sin(p),g=Math.cos(p),v=1;;){v===c&&(v=0),t=u[v];var m=t[0],y=t[1]/2+za/4,b=Math.sin(y),x=Math.cos(y),_=m-d,w=_>=0?1:-1,T=w*_,C=T>za,k=h*b;if(Ss.add(Math.atan2(k*w*Math.sin(T),g*x+k*Math.cos(T))),i+=C?_+w*Wa:_,C^d>=n^m>=n){var E=we(xe(f),xe(t));ke(E);var P=we(o,E);ke(P);var S=(C^_>=0?-1:1)*at(P[2]);(r>S||r===S&&(E[0]||E[1]))&&(a+=C^_>=0?1:-1)}if(!v++)break;d=m,h=b,g=x,f=t}}return(i<-Ua||i<Ua&&Ss<-Ua)^1&a}function Ke(t){function e(t,e){return Math.cos(t)*Math.cos(e)>i}function n(t){var n,i,l,u,c;return{lineStart:function(){u=l=!1,c=1},point:function(f,d){var p,h=[f,d],g=e(f,d),v=a?g?0:o(f,d):g?o(f+(f<0?za:-za),d):0;if(!n&&(u=l=g)&&t.lineStart(),g!==l&&(p=r(n,h),(Pe(n,p)||Pe(h,p))&&(h[0]+=Ua,h[1]+=Ua,g=e(h[0],h[1]))),g!==l)c=0,g?(t.lineStart(),p=r(h,n),t.point(p[0],p[1])):(p=r(n,h),t.point(p[0],p[1]),t.lineEnd()),n=p;else if(s&&n&&a^g){var m;v&i||!(m=r(h,n,!0))||(c=0,a?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||n&&Pe(n,h)||t.point(h[0],h[1]),n=h,l=g,i=v},lineEnd:function(){l&&t.lineEnd(),n=null},clean:function(){return c|(u&&l)<<1}}}function r(t,e,n){var r=xe(t),o=xe(e),a=[1,0,0],s=we(r,o),l=_e(s,s),u=s[0],c=l-u*u;if(!c)return!n&&t;var f=i*l/c,d=-i*u/c,p=we(a,s),h=Ce(a,f),g=Ce(s,d);Te(h,g);var v=p,m=_e(h,v),y=_e(v,v),b=m*m-y*(_e(h,h)-1);if(!(b<0)){var x=Math.sqrt(b),_=Ce(v,(-m-x)/y);if(Te(_,h),_=Ee(_),!n)return _;var w,T=t[0],C=e[0],k=t[1],E=e[1];C<T&&(w=T,T=C,C=w);var P=C-T,S=Ta(P-za)<Ua,M=S||P<Ua;if(!S&&E<k&&(w=k,k=E,E=w),M?S?k+E>0^_[1]<(Ta(_[0]-T)<Ua?k:E):k<=_[1]&&_[1]<=E:P>za^(T<=_[0]&&_[0]<=C)){var N=Ce(v,(-m+x)/y);return Te(N,h),[_,Ee(N)]}}}function o(e,n){var r=a?t:za-t,o=0;return e<-r?o|=1:e>r&&(o|=2),n<-r?o|=4:n>r&&(o|=8),o}var i=Math.cos(t),a=i>0,s=Ta(i)>Ua,l=xn(t,6*Ka);return je(e,n,l,a?[0,-t]:[-za,t-za])}function Ye(t,e,n,r){return function(o){var i,a=o.a,s=o.b,l=a.x,u=a.y,c=s.x,f=s.y,d=0,p=1,h=c-l,g=f-u;if(i=t-l,h||!(i>0)){if(i/=h,h<0){if(i<d)return;i<p&&(p=i)}else if(h>0){if(i>p)return;i>d&&(d=i)}if(i=n-l,h||!(i<0)){if(i/=h,h<0){if(i>p)return;i>d&&(d=i)}else if(h>0){if(i<d)return;i<p&&(p=i)}if(i=e-u,g||!(i>0)){if(i/=g,g<0){if(i<d)return;i<p&&(p=i)}else if(g>0){if(i>p)return;i>d&&(d=i)}if(i=r-u,g||!(i<0)){if(i/=g,g<0){if(i>p)return;i>d&&(d=i)}else if(g>0){if(i<d)return;i<p&&(p=i)}return d>0&&(o.a={x:l+d*h,y:u+d*g}),p<1&&(o.b={x:l+p*h,y:u+p*g}),o}}}}}}function Ge(t,e,n,r){function o(r,o){return Ta(r[0]-t)<Ua?o>0?0:3:Ta(r[0]-n)<Ua?o>0?2:1:Ta(r[1]-e)<Ua?o>0?1:0:o>0?3:2}function i(t,e){return a(t.x,e.x)}function a(t,e){var n=o(t,1),r=o(e,1);return n!==r?n-r:0===n?e[1]-t[1]:1===n?t[0]-e[0]:2===n?t[1]-e[1]:e[0]-t[0]}return function(s){function l(t){for(var e=0,n=v.length,r=t[1],o=0;o<n;++o)for(var i,a=1,s=v[o],l=s.length,u=s[0];a<l;++a)i=s[a],u[1]<=r?i[1]>r&&ot(u,i,t)>0&&++e:i[1]<=r&&ot(u,i,t)<0&&--e,u=i;return 0!==e}function u(i,s,l,u){var c=0,f=0;if(null==i||(c=o(i,l))!==(f=o(s,l))||a(i,s)<0^l>0){do u.point(0===c||3===c?t:n,c>1?r:e);while((c=(c+l+4)%4)!==f)}else u.point(s[0],s[1])}function c(o,i){return t<=o&&o<=n&&e<=i&&i<=r}function f(t,e){c(t,e)&&s.point(t,e)}function d(){M.point=h,v&&v.push(m=[]),C=!0,T=!1,_=w=NaN}function p(){g&&(h(y,b),x&&T&&P.rejoin(),g.push(P.buffer())),M.point=f,T&&s.lineEnd()}function h(t,e){t=Math.max(-Ws,Math.min(Ws,t)),e=Math.max(-Ws,Math.min(Ws,e));var n=c(t,e);if(v&&m.push([t,e]),C)y=t,b=e,x=n,C=!1,n&&(s.lineStart(),s.point(t,e));else if(n&&T)s.point(t,e);else{var r={a:{x:_,y:w},b:{x:t,y:e}};S(r)?(T||(s.lineStart(),s.point(r.a.x,r.a.y)),s.point(r.b.x,r.b.y),n||s.lineEnd(),k=!1):n&&(s.lineStart(),s.point(t,e),k=!1)}_=t,w=e,T=n}var g,v,m,y,b,x,_,w,T,C,k,E=s,P=Ue(),S=Ye(t,e,n,r),M={point:f,lineStart:d,lineEnd:p,polygonStart:function(){s=P,g=[],v=[],k=!0},polygonEnd:function(){s=E,g=pa.merge(g);var e=l([t,r]),n=k&&e,o=g.length;(n||o)&&(s.polygonStart(),n&&(s.lineStart(),u(null,null,1,s),s.lineEnd()),o&&Re(g,i,e,u,s),s.polygonEnd()),g=v=m=null}};return M}}function Xe(t){var e=0,n=za/3,r=dn(t),o=r(e,n);return o.parallels=function(t){return arguments.length?r(e=t[0]*za/180,n=t[1]*za/180):[e/za*180,n/za*180]},o}function $e(t,e){function n(t,e){var n=Math.sqrt(i-2*o*Math.sin(e))/o;return[n*Math.sin(t*=o),a-n*Math.cos(t)]}var r=Math.sin(t),o=(r+Math.sin(e))/2,i=1+r*(2*o-r),a=Math.sqrt(i)/o;return n.invert=function(t,e){var n=a-e;return[Math.atan2(t,n)/o,at((i-(t*t+n*n)*o*o)/(2*o))]},n}function Ze(){function t(t,e){Vs+=o*t-r*e,r=t,o=e}var e,n,r,o;$s.point=function(i,a){$s.point=t,e=r=i,n=o=a},$s.lineEnd=function(){t(e,n)}}function Je(t,e){t<Ks&&(Ks=t),t>Gs&&(Gs=t),e<Ys&&(Ys=e),e>Xs&&(Xs=e)}function Qe(){function t(t,e){a.push("M",t,",",e,i)}function e(t,e){a.push("M",t,",",e),s.point=n}function n(t,e){a.push("L",t,",",e)}function r(){s.point=t}function o(){a.push("Z")}var i=tn(4.5),a=[],s={point:t,lineStart:function(){s.point=e},lineEnd:r,polygonStart:function(){s.lineEnd=o},polygonEnd:function(){s.lineEnd=r,s.point=t},pointRadius:function(t){return i=tn(t),s},result:function(){if(a.length){var t=a.join("");return a=[],t}}};return s}function tn(t){return"m0,"+t+"a"+t+","+t+" 0 1,1 0,"+-2*t+"a"+t+","+t+" 0 1,1 0,"+2*t+"z"}function en(t,e){Os+=t,Ds+=e,++Is}function nn(){function t(t,r){var o=t-e,i=r-n,a=Math.sqrt(o*o+i*i);Rs+=a*(e+t)/2,Ls+=a*(n+r)/2,Fs+=a,en(e=t,n=r)}var e,n;Js.point=function(r,o){Js.point=t,en(e=r,n=o)}}function rn(){Js.point=en}function on(){function t(t,e){var n=t-r,i=e-o,a=Math.sqrt(n*n+i*i);Rs+=a*(r+t)/2,Ls+=a*(o+e)/2,Fs+=a,a=o*t-r*e,js+=a*(r+t),Bs+=a*(o+e),Us+=3*a,en(r=t,o=e)}var e,n,r,o;Js.point=function(i,a){Js.point=t,en(e=r=i,n=o=a)},Js.lineEnd=function(){t(e,n)}}function an(t){function e(e,n){t.moveTo(e+a,n),t.arc(e,n,a,0,Wa)}function n(e,n){t.moveTo(e,n),s.point=r}function r(e,n){t.lineTo(e,n)}function o(){s.point=e}function i(){t.closePath()}var a=4.5,s={point:e,lineStart:function(){s.point=n},lineEnd:o,polygonStart:function(){s.lineEnd=i},polygonEnd:function(){s.lineEnd=o,s.point=e},pointRadius:function(t){return a=t,s},result:E};return s}function sn(t){function e(t){return(s?r:n)(t)}function n(e){return cn(e,function(n,r){n=t(n,r),e.point(n[0],n[1])})}function r(e){function n(n,r){n=t(n,r),e.point(n[0],n[1])}function r(){b=NaN,C.point=i,e.lineStart()}function i(n,r){var i=xe([n,r]),a=t(n,r);o(b,x,y,_,w,T,b=a[0],x=a[1],y=n,_=i[0],w=i[1],T=i[2],s,e),e.point(b,x)}function a(){C.point=n,e.lineEnd()}function l(){r(),C.point=u,C.lineEnd=c}function u(t,e){i(f=t,d=e),p=b,h=x,g=_,v=w,m=T,C.point=i}function c(){o(b,x,y,_,w,T,p,h,f,g,v,m,s,e),C.lineEnd=a,a()}var f,d,p,h,g,v,m,y,b,x,_,w,T,C={point:n,lineStart:r,lineEnd:a,polygonStart:function(){e.polygonStart(),C.lineStart=l},polygonEnd:function(){e.polygonEnd(),C.lineStart=r}};return C}function o(e,n,r,s,l,u,c,f,d,p,h,g,v,m){var y=c-e,b=f-n,x=y*y+b*b;if(x>4*i&&v--){var _=s+p,w=l+h,T=u+g,C=Math.sqrt(_*_+w*w+T*T),k=Math.asin(T/=C),E=Ta(Ta(T)-1)<Ua||Ta(r-d)<Ua?(r+d)/2:Math.atan2(w,_),P=t(E,k),S=P[0],M=P[1],N=S-e,A=M-n,O=b*N-y*A;(O*O/x>i||Ta((y*N+b*A)/x-.5)>.3||s*p+l*h+u*g<a)&&(o(e,n,r,s,l,u,S,M,E,_/=C,w/=C,T,v,m),m.point(S,M),o(S,M,E,_,w,T,c,f,d,p,h,g,v,m))}}var i=.5,a=Math.cos(30*Ka),s=16;return e.precision=function(t){return arguments.length?(s=(i=t*t)>0&&16,e):Math.sqrt(i)},e}function ln(t){var e=sn(function(e,n){return t([e*Ya,n*Ya])});return function(t){return pn(e(t))}}function un(t){this.stream=t}function cn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function fn(t){return dn(function(){return t})()}function dn(t){function e(t){return t=s(t[0]*Ka,t[1]*Ka),[t[0]*d+l,u-t[1]*d]}function n(t){return t=s.invert((t[0]-l)/d,(u-t[1])/d),t&&[t[0]*Ya,t[1]*Ya]}function r(){s=De(a=vn(m,y,b),i);var t=i(g,v);return l=p-t[0]*d,u=h+t[1]*d,o()}function o(){return c&&(c.valid=!1,c=null),e}var i,a,s,l,u,c,f=sn(function(t,e){return t=i(t,e),[t[0]*d+l,u-t[1]*d]}),d=150,p=480,h=250,g=0,v=0,m=0,y=0,b=0,x=zs,_=T,w=null,C=null;return e.stream=function(t){return c&&(c.valid=!1),c=pn(x(a,f(_(t)))),c.valid=!0,c},e.clipAngle=function(t){return arguments.length?(x=null==t?(w=t,zs):Ke((w=+t)*Ka),o()):w},e.clipExtent=function(t){return arguments.length?(C=t,_=t?Ge(t[0][0],t[0][1],t[1][0],t[1][1]):T,o()):C},e.scale=function(t){return arguments.length?(d=+t,r()):d},e.translate=function(t){return arguments.length?(p=+t[0],h=+t[1],r()):[p,h]},e.center=function(t){return arguments.length?(g=t[0]%360*Ka,v=t[1]%360*Ka,r()):[g*Ya,v*Ya]},e.rotate=function(t){return arguments.length?(m=t[0]%360*Ka,y=t[1]%360*Ka,b=t.length>2?t[2]%360*Ka:0,r()):[m*Ya,y*Ya,b*Ya]},pa.rebind(e,f,"precision"),function(){return i=t.apply(this,arguments),e.invert=i.invert&&n,r()}}function pn(t){return cn(t,function(e,n){t.point(e*Ka,n*Ka)})}function hn(t,e){return[t,e]}function gn(t,e){return[t>za?t-Wa:t<-za?t+Wa:t,e]}function vn(t,e,n){return t?e||n?De(yn(t),bn(e,n)):yn(t):e||n?bn(e,n):gn}function mn(t){return function(e,n){return e+=t,[e>za?e-Wa:e<-za?e+Wa:e,n]}}function yn(t){var e=mn(t);return e.invert=mn(-t),e}function bn(t,e){function n(t,e){var n=Math.cos(e),s=Math.cos(t)*n,l=Math.sin(t)*n,u=Math.sin(e),c=u*r+s*o;return[Math.atan2(l*i-c*a,s*r-u*o),at(c*i+l*a)]}var r=Math.cos(t),o=Math.sin(t),i=Math.cos(e),a=Math.sin(e);return n.invert=function(t,e){var n=Math.cos(e),s=Math.cos(t)*n,l=Math.sin(t)*n,u=Math.sin(e),c=u*i-l*a;return[Math.atan2(l*i+u*a,s*r+c*o),at(c*r-s*o)]},n}function xn(t,e){var n=Math.cos(t),r=Math.sin(t);return function(o,i,a,s){var l=a*e;null!=o?(o=_n(n,o),i=_n(n,i),(a>0?o<i:o>i)&&(o+=a*Wa)):(o=t+a*Wa,i=t-.5*l);for(var u,c=o;a>0?c>i:c<i;c-=l)s.point((u=Ee([n,-r*Math.cos(c),-r*Math.sin(c)]))[0],u[1])}}function _n(t,e){var n=xe(e);n[0]-=t,ke(n);var r=it(-n[1]);return((-n[2]<0?-r:r)+2*Math.PI-Ua)%(2*Math.PI)}function wn(t,e,n){var r=pa.range(t,e-Ua,n).concat(e);return function(t){return r.map(function(e){return[t,e]})}}function Tn(t,e,n){var r=pa.range(t,e-Ua,n).concat(e);return function(t){return r.map(function(e){return[e,t]})}}function Cn(t){return t.source}function kn(t){return t.target}function En(t,e,n,r){var o=Math.cos(e),i=Math.sin(e),a=Math.cos(r),s=Math.sin(r),l=o*Math.cos(t),u=o*Math.sin(t),c=a*Math.cos(n),f=a*Math.sin(n),d=2*Math.asin(Math.sqrt(ct(r-e)+o*a*ct(n-t))),p=1/Math.sin(d),h=d?function(t){var e=Math.sin(t*=d)*p,n=Math.sin(d-t)*p,r=n*l+e*c,o=n*u+e*f,a=n*i+e*s;return[Math.atan2(o,r)*Ya,Math.atan2(a,Math.sqrt(r*r+o*o))*Ya]}:function(){return[t*Ya,e*Ya]};return h.distance=d,h}function Pn(){function t(t,o){var i=Math.sin(o*=Ka),a=Math.cos(o),s=Ta((t*=Ka)-e),l=Math.cos(s);Qs+=Math.atan2(Math.sqrt((s=a*Math.sin(s))*s+(s=r*i-n*a*l)*s),n*i+r*a*l),e=t,n=i,r=a}var e,n,r;tl.point=function(o,i){e=o*Ka,n=Math.sin(i*=Ka),r=Math.cos(i),tl.point=t},tl.lineEnd=function(){tl.point=tl.lineEnd=E}}function Sn(t,e){function n(e,n){var r=Math.cos(e),o=Math.cos(n),i=t(r*o);return[i*o*Math.sin(e),i*Math.sin(n)]}return n.invert=function(t,n){var r=Math.sqrt(t*t+n*n),o=e(r),i=Math.sin(o),a=Math.cos(o);return[Math.atan2(t*i,r*a),Math.asin(r&&n*i/r)]},n}function Mn(t,e){function n(t,e){a>0?e<-Va+Ua&&(e=-Va+Ua):e>Va-Ua&&(e=Va-Ua);var n=a/Math.pow(o(e),i);return[n*Math.sin(i*t),a-n*Math.cos(i*t)]}var r=Math.cos(t),o=function(t){return Math.tan(za/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(o(e)/o(t)),a=r*Math.pow(o(t),i)/i;return i?(n.invert=function(t,e){var n=a-e,r=rt(i)*Math.sqrt(t*t+n*n);return[Math.atan2(t,n)/i,2*Math.atan(Math.pow(a/r,1/i))-Va]},n):An}function Nn(t,e){function n(t,e){var n=i-e;return[n*Math.sin(o*t),i-n*Math.cos(o*t)]}var r=Math.cos(t),o=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/o+t;return Ta(o)<Ua?hn:(n.invert=function(t,e){var n=i-e;return[Math.atan2(t,n)/o,i-rt(o)*Math.sqrt(t*t+n*n)]},n)}function An(t,e){return[t,Math.log(Math.tan(za/4+e/2))]}function On(t){var e,n=fn(t),r=n.scale,o=n.translate,i=n.clipExtent;return n.scale=function(){var t=r.apply(n,arguments);return t===n?e?n.clipExtent(null):n:t},n.translate=function(){var t=o.apply(n,arguments);return t===n?e?n.clipExtent(null):n:t},n.clipExtent=function(t){var a=i.apply(n,arguments);if(a===n){if(e=null==t){var s=za*r(),l=o();i([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(a=null);return a},n.clipExtent(null)}function Dn(t,e){return[Math.log(Math.tan(za/4+e/2)),-t]}function In(t){return t[0]}function Rn(t){return t[1]}function Ln(t){for(var e=t.length,n=[0,1],r=2,o=2;o<e;o++){for(;r>1&&ot(t[n[r-2]],t[n[r-1]],t[o])<=0;)--r;n[r++]=o}return n.slice(0,r)}function Fn(t,e){return t[0]-e[0]||t[1]-e[1]}function jn(t,e,n){return(n[0]-e[0])*(t[1]-e[1])<(n[1]-e[1])*(t[0]-e[0])}function Bn(t,e,n,r){var o=t[0],i=n[0],a=e[0]-o,s=r[0]-i,l=t[1],u=n[1],c=e[1]-l,f=r[1]-u,d=(s*(l-u)-f*(o-i))/(f*a-s*c);return[o+d*a,l+d*c]}function Un(t){var e=t[0],n=t[t.length-1];return!(e[0]-n[0]||e[1]-n[1])}function Hn(){lr(this),this.edge=this.site=this.circle=null}function zn(t){var e=dl.pop()||new Hn;return e.site=t,e}function Wn(t){Qn(t),ul.remove(t),dl.push(t),lr(t)}function qn(t){var e=t.circle,n=e.x,r=e.cy,o={x:n,y:r},i=t.P,a=t.N,s=[t];Wn(t);for(var l=i;l.circle&&Ta(n-l.circle.x)<Ua&&Ta(r-l.circle.cy)<Ua;)i=l.P,s.unshift(l),Wn(l),l=i;s.unshift(l),Qn(l);for(var u=a;u.circle&&Ta(n-u.circle.x)<Ua&&Ta(r-u.circle.cy)<Ua;)a=u.N,s.push(u),Wn(u),u=a;s.push(u),Qn(u);var c,f=s.length;for(c=1;c<f;++c)u=s[c],l=s[c-1],ir(u.edge,l.site,u.site,o);l=s[0],u=s[f-1],u.edge=rr(l.site,u.site,null,o),Jn(l),Jn(u)}function Vn(t){for(var e,n,r,o,i=t.x,a=t.y,s=ul._;s;)if(r=Kn(s,a)-i,r>Ua)s=s.L;else{if(o=i-Yn(s,a),!(o>Ua)){r>-Ua?(e=s.P,n=s):o>-Ua?(e=s,n=s.N):e=n=s;break}if(!s.R){e=s;break}s=s.R}var l=zn(t);if(ul.insert(e,l),e||n){if(e===n)return Qn(e),n=zn(e.site),ul.insert(l,n),l.edge=n.edge=rr(e.site,l.site),Jn(e),void Jn(n);if(!n)return void(l.edge=rr(e.site,l.site));Qn(e),Qn(n);var u=e.site,c=u.x,f=u.y,d=t.x-c,p=t.y-f,h=n.site,g=h.x-c,v=h.y-f,m=2*(d*v-p*g),y=d*d+p*p,b=g*g+v*v,x={x:(v*y-p*b)/m+c,y:(d*b-g*y)/m+f};ir(n.edge,u,h,x),l.edge=rr(u,t,null,x),n.edge=rr(t,h,null,x),Jn(e),Jn(n)}}function Kn(t,e){var n=t.site,r=n.x,o=n.y,i=o-e;if(!i)return r;var a=t.P;if(!a)return-(1/0);n=a.site;var s=n.x,l=n.y,u=l-e;if(!u)return s;var c=s-r,f=1/i-1/u,d=c/u;return f?(-d+Math.sqrt(d*d-2*f*(c*c/(-2*u)-l+u/2+o-i/2)))/f+r:(r+s)/2}function Yn(t,e){var n=t.N;if(n)return Kn(n,e);var r=t.site;return r.y===e?r.x:1/0}function Gn(t){this.site=t,this.edges=[]}function Xn(t){for(var e,n,r,o,i,a,s,l,u,c,f=t[0][0],d=t[1][0],p=t[0][1],h=t[1][1],g=ll,v=g.length;v--;)if(i=g[v],i&&i.prepare())for(s=i.edges,l=s.length,a=0;a<l;)c=s[a].end(),r=c.x,o=c.y,u=s[++a%l].start(),e=u.x,n=u.y,(Ta(r-e)>Ua||Ta(o-n)>Ua)&&(s.splice(a,0,new ar(or(i.site,c,Ta(r-f)<Ua&&h-o>Ua?{x:f,y:Ta(e-f)<Ua?n:h}:Ta(o-h)<Ua&&d-r>Ua?{x:Ta(n-h)<Ua?e:d,y:h}:Ta(r-d)<Ua&&o-p>Ua?{x:d,y:Ta(e-d)<Ua?n:p}:Ta(o-p)<Ua&&r-f>Ua?{x:Ta(n-p)<Ua?e:f,y:p}:null),i.site,null)),++l)}function $n(t,e){return e.angle-t.angle}function Zn(){lr(this),this.x=this.y=this.arc=this.site=this.cy=null}function Jn(t){var e=t.P,n=t.N;if(e&&n){var r=e.site,o=t.site,i=n.site;if(r!==i){var a=o.x,s=o.y,l=r.x-a,u=r.y-s,c=i.x-a,f=i.y-s,d=2*(l*f-u*c);if(!(d>=-Ha)){var p=l*l+u*u,h=c*c+f*f,g=(f*p-u*h)/d,v=(l*h-c*p)/d,f=v+s,m=pl.pop()||new Zn;m.arc=t,m.site=o,m.x=g+a,m.y=f+Math.sqrt(g*g+v*v),m.cy=f,t.circle=m;for(var y=null,b=fl._;b;)if(m.y<b.y||m.y===b.y&&m.x<=b.x){if(!b.L){y=b.P;break}b=b.L}else{if(!b.R){y=b;break}b=b.R}fl.insert(y,m),y||(cl=m)}}}}function Qn(t){var e=t.circle;e&&(e.P||(cl=e.N),fl.remove(e),pl.push(e),lr(e),t.circle=null)}function tr(t){for(var e,n=sl,r=Ye(t[0][0],t[0][1],t[1][0],t[1][1]),o=n.length;o--;)e=n[o],(!er(e,t)||!r(e)||Ta(e.a.x-e.b.x)<Ua&&Ta(e.a.y-e.b.y)<Ua)&&(e.a=e.b=null,n.splice(o,1))}function er(t,e){var n=t.b;if(n)return!0;var r,o,i=t.a,a=e[0][0],s=e[1][0],l=e[0][1],u=e[1][1],c=t.l,f=t.r,d=c.x,p=c.y,h=f.x,g=f.y,v=(d+h)/2,m=(p+g)/2;if(g===p){if(v<a||v>=s)return;if(d>h){if(i){if(i.y>=u)return}else i={x:v,y:l};n={x:v,y:u}}else{if(i){if(i.y<l)return}else i={x:v,y:u};n={x:v,y:l}}}else if(r=(d-h)/(g-p),o=m-r*v,r<-1||r>1)if(d>h){if(i){if(i.y>=u)return}else i={x:(l-o)/r,y:l};n={x:(u-o)/r,y:u}}else{if(i){if(i.y<l)return}else i={x:(u-o)/r,y:u};n={x:(l-o)/r,y:l}}else if(p<g){if(i){if(i.x>=s)return}else i={x:a,y:r*a+o};n={x:s,y:r*s+o}}else{if(i){if(i.x<a)return}else i={x:s,y:r*s+o};n={x:a,y:r*a+o}}return t.a=i,t.b=n,!0}function nr(t,e){this.l=t,this.r=e,this.a=this.b=null}function rr(t,e,n,r){var o=new nr(t,e);return sl.push(o),n&&ir(o,t,e,n),r&&ir(o,e,t,r),ll[t.i].edges.push(new ar(o,t,e)),ll[e.i].edges.push(new ar(o,e,t)),o}function or(t,e,n){var r=new nr(t,null);return r.a=e,r.b=n,sl.push(r),r}function ir(t,e,n,r){t.a||t.b?t.l===n?t.b=r:t.a=r:(t.a=r,t.l=e,t.r=n)}function ar(t,e,n){var r=t.a,o=t.b;this.edge=t,this.site=e,this.angle=n?Math.atan2(n.y-e.y,n.x-e.x):t.l===e?Math.atan2(o.x-r.x,r.y-o.y):Math.atan2(r.x-o.x,o.y-r.y)}function sr(){this._=null}function lr(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function ur(t,e){var n=e,r=e.R,o=n.U;o?o.L===n?o.L=r:o.R=r:t._=r,r.U=o,n.U=r,n.R=r.L,n.R&&(n.R.U=n),r.L=n}function cr(t,e){var n=e,r=e.L,o=n.U;o?o.L===n?o.L=r:o.R=r:t._=r,r.U=o,n.U=r,n.L=r.R,n.L&&(n.L.U=n),r.R=n}function fr(t){for(;t.L;)t=t.L;return t}function dr(t,e){var n,r,o,i=t.sort(pr).pop();for(sl=[],ll=new Array(t.length),ul=new sr,fl=new sr;;)if(o=cl,i&&(!o||i.y<o.y||i.y===o.y&&i.x<o.x))i.x===n&&i.y===r||(ll[i.i]=new Gn(i),Vn(i),n=i.x,r=i.y),i=t.pop();else{if(!o)break;qn(o.arc)}e&&(tr(e),Xn(e));var a={cells:ll,edges:sl};return ul=fl=sl=ll=null,a}function pr(t,e){return e.y-t.y||e.x-t.x}function hr(t,e,n){return(t.x-n.x)*(e.y-t.y)-(t.x-e.x)*(n.y-t.y)}function gr(t){return t.x}function vr(t){return t.y}function mr(){return{leaf:!0,nodes:[],point:null,x:null,y:null}}function yr(t,e,n,r,o,i){if(!t(e,n,r,o,i)){var a=.5*(n+o),s=.5*(r+i),l=e.nodes;l[0]&&yr(t,l[0],n,r,a,s),l[1]&&yr(t,l[1],a,r,o,s),l[2]&&yr(t,l[2],n,s,a,i),l[3]&&yr(t,l[3],a,s,o,i)}}function br(t,e,n,r,o,i,a){var s,l=1/0;return function t(u,c,f,d,p){if(!(c>i||f>a||d<r||p<o)){if(h=u.point){var h,g=e-u.x,v=n-u.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);r=e-y,o=n-y,i=e+y,a=n+y,s=h}}for(var b=u.nodes,x=.5*(c+d),_=.5*(f+p),w=e>=x,T=n>=_,C=T<<1|w,k=C+4;C<k;++C)if(u=b[3&C])switch(3&C){case 0:t(u,c,f,x,_);break;case 1:t(u,x,f,d,_);break;case 2:t(u,c,_,x,p);break;case 3:t(u,x,_,d,p)}}}(t,r,o,i,a),s}function xr(t,e){t=pa.rgb(t),e=pa.rgb(e);var n=t.r,r=t.g,o=t.b,i=e.r-n,a=e.g-r,s=e.b-o;return function(t){return"#"+kt(Math.round(n+i*t))+kt(Math.round(r+a*t))+kt(Math.round(o+s*t))}}function _r(t,e){var n,r={},o={};for(n in t)n in e?r[n]=Cr(t[n],e[n]):o[n]=t[n];for(n in e)n in t||(o[n]=e[n]);return function(t){for(n in r)o[n]=r[n](t);return o}}function wr(t,e){return t=+t,e=+e,function(n){return t*(1-n)+e*n}}function Tr(t,e){var n,r,o,i=gl.lastIndex=vl.lastIndex=0,a=-1,s=[],l=[];for(t+="",e+="";(n=gl.exec(t))&&(r=vl.exec(e));)(o=r.index)>i&&(o=e.slice(i,o),s[a]?s[a]+=o:s[++a]=o),(n=n[0])===(r=r[0])?s[a]?s[a]+=r:s[++a]=r:(s[++a]=null,l.push({i:a,x:wr(n,r)})),i=vl.lastIndex;return i<e.length&&(o=e.slice(i),s[a]?s[a]+=o:s[++a]=o),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+""}):function(){return e}:(e=l.length,function(t){for(var n,r=0;r<e;++r)s[(n=l[r]).i]=n.x(t);return s.join("")})}function Cr(t,e){for(var n,r=pa.interpolators.length;--r>=0&&!(n=pa.interpolators[r](t,e)););return n}function kr(t,e){var n,r=[],o=[],i=t.length,a=e.length,s=Math.min(t.length,e.length);for(n=0;n<s;++n)r.push(Cr(t[n],e[n]));for(;n<i;++n)o[n]=t[n];for(;n<a;++n)o[n]=e[n];return function(t){for(n=0;n<s;++n)o[n]=r[n](t);return o}}function Er(t){return function(e){return e<=0?0:e>=1?1:t(e)}}function Pr(t){return function(e){return 1-t(1-e)}}function Sr(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function Mr(t){return t*t}function Nr(t){return t*t*t}function Ar(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,n=e*t;return 4*(t<.5?n:3*(t-e)+n-.75)}function Or(t){return function(e){return Math.pow(e,t)}}function Dr(t){return 1-Math.cos(t*Va)}function Ir(t){return Math.pow(2,10*(t-1))}function Rr(t){return 1-Math.sqrt(1-t*t)}function Lr(t,e){var n;return arguments.length<2&&(e=.45),arguments.length?n=e/Wa*Math.asin(1/t):(t=1,n=e/4),function(r){return 1+t*Math.pow(2,-10*r)*Math.sin((r-n)*Wa/e)}}function Fr(t){return t||(t=1.70158),function(e){return e*e*((t+1)*e-t)}}function jr(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function Br(t,e){t=pa.hcl(t),e=pa.hcl(e);var n=t.h,r=t.c,o=t.l,i=e.h-n,a=e.c-r,s=e.l-o;return isNaN(a)&&(a=0,r=isNaN(r)?e.c:r),isNaN(i)?(i=0,n=isNaN(n)?e.h:n):i>180?i-=360:i<-180&&(i+=360),function(t){return gt(n+i*t,r+a*t,o+s*t)+""}}function Ur(t,e){t=pa.hsl(t),e=pa.hsl(e);var n=t.h,r=t.s,o=t.l,i=e.h-n,a=e.s-r,s=e.l-o;return isNaN(a)&&(a=0,r=isNaN(r)?e.s:r),isNaN(i)?(i=0,n=isNaN(n)?e.h:n):i>180?i-=360:i<-180&&(i+=360),function(t){return pt(n+i*t,r+a*t,o+s*t)+""}}function Hr(t,e){t=pa.lab(t),e=pa.lab(e);var n=t.l,r=t.a,o=t.b,i=e.l-n,a=e.a-r,s=e.b-o;return function(t){return mt(n+i*t,r+a*t,o+s*t)+""}}function zr(t,e){return e-=t,function(n){return Math.round(t+e*n)}}function Wr(t){var e=[t.a,t.b],n=[t.c,t.d],r=Vr(e),o=qr(e,n),i=Vr(Kr(n,e,-o))||0;e[0]*n[1]<n[0]*e[1]&&(e[0]*=-1,e[1]*=-1,r*=-1,o*=-1),this.rotate=(r?Math.atan2(e[1],e[0]):Math.atan2(-n[0],n[1]))*Ya,this.translate=[t.e,t.f],this.scale=[r,i],this.skew=i?Math.atan2(o,i)*Ya:0}function qr(t,e){return t[0]*e[0]+t[1]*e[1]}function Vr(t){var e=Math.sqrt(qr(t,t));return e&&(t[0]/=e,t[1]/=e),e}function Kr(t,e,n){return t[0]+=n*e[0],t[1]+=n*e[1],t}function Yr(t){return t.length?t.pop()+",":""}function Gr(t,e,n,r){if(t[0]!==e[0]||t[1]!==e[1]){var o=n.push("translate(",null,",",null,")");r.push({i:o-4,x:wr(t[0],e[0])},{i:o-2,x:wr(t[1],e[1])})}else(e[0]||e[1])&&n.push("translate("+e+")")}function Xr(t,e,n,r){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),r.push({i:n.push(Yr(n)+"rotate(",null,")")-2,x:wr(t,e)})):e&&n.push(Yr(n)+"rotate("+e+")")}function $r(t,e,n,r){t!==e?r.push({i:n.push(Yr(n)+"skewX(",null,")")-2,x:wr(t,e)}):e&&n.push(Yr(n)+"skewX("+e+")")}function Zr(t,e,n,r){if(t[0]!==e[0]||t[1]!==e[1]){var o=n.push(Yr(n)+"scale(",null,",",null,")");r.push({i:o-4,x:wr(t[0],e[0])},{i:o-2,x:wr(t[1],e[1])})}else 1===e[0]&&1===e[1]||n.push(Yr(n)+"scale("+e+")")}function Jr(t,e){var n=[],r=[];return t=pa.transform(t),e=pa.transform(e),Gr(t.translate,e.translate,n,r),Xr(t.rotate,e.rotate,n,r),$r(t.skew,e.skew,n,r),Zr(t.scale,e.scale,n,r),t=e=null,function(t){for(var e,o=-1,i=r.length;++o<i;)n[(e=r[o]).i]=e.x(t);return n.join("")}}function Qr(t,e){return e=(e-=t=+t)||1/e,function(n){return(n-t)/e}}function to(t,e){return e=(e-=t=+t)||1/e,function(n){return Math.max(0,Math.min(1,(n-t)/e))}}function eo(t){for(var e=t.source,n=t.target,r=ro(e,n),o=[e];e!==r;)e=e.parent,o.push(e);for(var i=o.length;n!==r;)o.splice(i,0,n),n=n.parent;return o}function no(t){for(var e=[],n=t.parent;null!=n;)e.push(t),t=n,n=n.parent;return e.push(t),e}function ro(t,e){if(t===e)return t;for(var n=no(t),r=no(e),o=n.pop(),i=r.pop(),a=null;o===i;)a=o,o=n.pop(),i=r.pop();return a}function oo(t){t.fixed|=2}function io(t){t.fixed&=-7}function ao(t){t.fixed|=4,t.px=t.x,t.py=t.y}function so(t){t.fixed&=-5}function lo(t,e,n){var r=0,o=0;if(t.charge=0,!t.leaf)for(var i,a=t.nodes,s=a.length,l=-1;++l<s;)i=a[l],null!=i&&(lo(i,e,n),t.charge+=i.charge,r+=i.charge*i.cx,o+=i.charge*i.cy);if(t.point){t.leaf||(t.point.x+=Math.random()-.5,t.point.y+=Math.random()-.5);var u=e*n[t.point.index];t.charge+=t.pointCharge=u,r+=u*t.point.x,o+=u*t.point.y}t.cx=r/t.charge,t.cy=o/t.charge}function uo(t,e){return pa.rebind(t,e,"sort","children","value"),t.nodes=t,t.links=vo,t}function co(t,e){for(var n=[t];null!=(t=n.pop());)if(e(t),(o=t.children)&&(r=o.length))for(var r,o;--r>=0;)n.push(o[r])}function fo(t,e){for(var n=[t],r=[];null!=(t=n.pop());)if(r.push(t),(i=t.children)&&(o=i.length))for(var o,i,a=-1;++a<o;)n.push(i[a]);for(;null!=(t=r.pop());)e(t)}function po(t){return t.children}function ho(t){return t.value}function go(t,e){return e.value-t.value}function vo(t){return pa.merge(t.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}function mo(t){return t.x}function yo(t){return t.y}function bo(t,e,n){t.y0=e,t.y=n}function xo(t){return pa.range(t.length)}function _o(t){for(var e=-1,n=t[0].length,r=[];++e<n;)r[e]=0;return r}function wo(t){for(var e,n=1,r=0,o=t[0][1],i=t.length;n<i;++n)(e=t[n][1])>o&&(r=n,o=e);return r}function To(t){return t.reduce(Co,0)}function Co(t,e){return t+e[1]}function ko(t,e){return Eo(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Eo(t,e){for(var n=-1,r=+t[0],o=(t[1]-r)/e,i=[];++n<=e;)i[n]=o*n+r;return i}function Po(t){return[pa.min(t),pa.max(t)]}function So(t,e){return t.value-e.value}function Mo(t,e){var n=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=n,n._pack_prev=e}function No(t,e){t._pack_next=e,e._pack_prev=t}function Ao(t,e){var n=e.x-t.x,r=e.y-t.y,o=t.r+e.r;return.999*o*o>n*n+r*r}function Oo(t){function e(t){c=Math.min(t.x-t.r,c),f=Math.max(t.x+t.r,f),d=Math.min(t.y-t.r,d),p=Math.max(t.y+t.r,p)}if((n=t.children)&&(u=n.length)){var n,r,o,i,a,s,l,u,c=1/0,f=-(1/0),d=1/0,p=-(1/0);if(n.forEach(Do),r=n[0],r.x=-r.r,r.y=0,e(r),u>1&&(o=n[1],o.x=o.r,o.y=0,e(o),u>2))for(i=n[2],Lo(r,o,i),e(i),Mo(r,i),r._pack_prev=i,Mo(i,o),o=r._pack_next,a=3;a<u;a++){Lo(r,o,i=n[a]);var h=0,g=1,v=1;for(s=o._pack_next;s!==o;s=s._pack_next,g++)if(Ao(s,i)){h=1;break}if(1==h)for(l=r._pack_prev;l!==s._pack_prev&&!Ao(l,i);l=l._pack_prev,v++);h?(g<v||g==v&&o.r<r.r?No(r,o=s):No(r=l,o),a--):(Mo(r,i),o=i,e(i))}var m=(c+f)/2,y=(d+p)/2,b=0;for(a=0;a<u;a++)i=n[a],i.x-=m,i.y-=y,b=Math.max(b,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=b,n.forEach(Io)}}function Do(t){t._pack_next=t._pack_prev=t}function Io(t){delete t._pack_next,delete t._pack_prev}function Ro(t,e,n,r){var o=t.children;if(t.x=e+=r*t.x,t.y=n+=r*t.y,t.r*=r,o)for(var i=-1,a=o.length;++i<a;)Ro(o[i],e,n,r)}function Lo(t,e,n){var r=t.r+n.r,o=e.x-t.x,i=e.y-t.y;if(r&&(o||i)){var a=e.r+n.r,s=o*o+i*i;a*=a,r*=r;var l=.5+(r-a)/(2*s),u=Math.sqrt(Math.max(0,2*a*(r+s)-(r-=s)*r-a*a))/(2*s);n.x=t.x+l*o+u*i,n.y=t.y+l*i-u*o}else n.x=t.x+r,n.y=t.y}function Fo(t,e){return t.parent==e.parent?1:2}function jo(t){var e=t.children;return e.length?e[0]:t.t}function Bo(t){var e,n=t.children;return(e=n.length)?n[e-1]:t.t}function Uo(t,e,n){var r=n/(e.i-t.i);e.c-=r,e.s+=n,t.c+=r,e.z+=n,e.m+=n}function Ho(t){for(var e,n=0,r=0,o=t.children,i=o.length;--i>=0;)e=o[i],e.z+=n,e.m+=n,n+=e.s+(r+=e.c)}function zo(t,e,n){return t.a.parent===e.parent?t.a:n}function Wo(t){return 1+pa.max(t,function(t){return t.y})}function qo(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}function Vo(t){var e=t.children;return e&&e.length?Vo(e[0]):t}function Ko(t){var e,n=t.children;return n&&(e=n.length)?Ko(n[e-1]):t}function Yo(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function Go(t,e){var n=t.x+e[3],r=t.y+e[0],o=t.dx-e[1]-e[3],i=t.dy-e[0]-e[2];return o<0&&(n+=o/2,o=0),i<0&&(r+=i/2,i=0),{x:n,y:r,dx:o,dy:i}}function Xo(t){var e=t[0],n=t[t.length-1];return e<n?[e,n]:[n,e]}function $o(t){return t.rangeExtent?t.rangeExtent():Xo(t.range())}function Zo(t,e,n,r){var o=n(t[0],t[1]),i=r(e[0],e[1]);return function(t){return i(o(t))}}function Jo(t,e){var n,r=0,o=t.length-1,i=t[r],a=t[o];return a<i&&(n=r,r=o,o=n,n=i,i=a,a=n),t[r]=e.floor(i),t[o]=e.ceil(a),t}function Qo(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:Pl}function ti(t,e,n,r){var o=[],i=[],a=0,s=Math.min(t.length,e.length)-1;for(t[s]<t[0]&&(t=t.slice().reverse(),e=e.slice().reverse());++a<=s;)o.push(n(t[a-1],t[a])),i.push(r(e[a-1],e[a]));return function(e){var n=pa.bisect(t,e,1,s)-1;return i[n](o[n](e))}}function ei(t,e,n,r){function o(){var o=Math.min(t.length,e.length)>2?ti:Zo,l=r?to:Qr;return a=o(t,e,l,n),s=o(e,t,l,Cr),i}function i(t){return a(t)}var a,s;return i.invert=function(t){return s(t)},i.domain=function(e){return arguments.length?(t=e.map(Number),o()):t},i.range=function(t){return arguments.length?(e=t,o()):e},i.rangeRound=function(t){return i.range(t).interpolate(zr)},i.clamp=function(t){return arguments.length?(r=t,o()):r},i.interpolate=function(t){return arguments.length?(n=t,o()):n},i.ticks=function(e){return ii(t,e)},i.tickFormat=function(e,n){return ai(t,e,n)},i.nice=function(e){return ri(t,e),o()},i.copy=function(){return ei(t,e,n,r)},o()}function ni(t,e){return pa.rebind(t,e,"range","rangeRound","interpolate","clamp")}function ri(t,e){return Jo(t,Qo(oi(t,e)[2])),Jo(t,Qo(oi(t,e)[2])),t}function oi(t,e){null==e&&(e=10);var n=Xo(t),r=n[1]-n[0],o=Math.pow(10,Math.floor(Math.log(r/e)/Math.LN10)),i=e/r*o;return i<=.15?o*=10:i<=.35?o*=5:i<=.75&&(o*=2),n[0]=Math.ceil(n[0]/o)*o,n[1]=Math.floor(n[1]/o)*o+.5*o,n[2]=o,n}function ii(t,e){return pa.range.apply(pa,oi(t,e))}function ai(t,e,n){var r=oi(t,e);if(n){var o=gs.exec(n);if(o.shift(),"s"===o[8]){var i=pa.formatPrefix(Math.max(Ta(r[0]),Ta(r[1])));return o[7]||(o[7]="."+si(i.scale(r[2]))),o[8]="f",n=pa.format(o.join("")),function(t){return n(i.scale(t))+i.symbol}}o[7]||(o[7]="."+li(o[8],r)),n=o.join("")}else n=",."+si(r[2])+"f";return pa.format(n)}function si(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}function li(t,e){var n=si(e[2]);return t in Sl?Math.abs(n-si(Math.max(Ta(e[0]),Ta(e[1]))))+ +("e"!==t):n-2*("%"===t)}function ui(t,e,n,r){function o(t){return(n?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(e)}function i(t){return n?Math.pow(e,t):-Math.pow(e,-t)}function a(e){return t(o(e))}return a.invert=function(e){return i(t.invert(e))},a.domain=function(e){return arguments.length?(n=e[0]>=0,t.domain((r=e.map(Number)).map(o)),a):r},a.base=function(n){return arguments.length?(e=+n,t.domain(r.map(o)),a):e},a.nice=function(){var e=Jo(r.map(o),n?Math:Nl);return t.domain(e),r=e.map(i),a},a.ticks=function(){var t=Xo(r),a=[],s=t[0],l=t[1],u=Math.floor(o(s)),c=Math.ceil(o(l)),f=e%1?2:e;if(isFinite(c-u)){if(n){for(;u<c;u++)for(var d=1;d<f;d++)a.push(i(u)*d);a.push(i(u))}else for(a.push(i(u));u++<c;)for(var d=f-1;d>0;d--)a.push(i(u)*d);for(u=0;a[u]<s;u++);for(c=a.length;a[c-1]>l;c--);a=a.slice(u,c)}return a},a.tickFormat=function(t,n){if(!arguments.length)return Ml;arguments.length<2?n=Ml:"function"!=typeof n&&(n=pa.format(n));var r=Math.max(1,e*t/a.ticks().length);return function(t){var a=t/i(Math.round(o(t)));return a*e<e-.5&&(a*=e),a<=r?n(t):""}},a.copy=function(){return ui(t.copy(),e,n,r)},ni(a,t)}function ci(t,e,n){function r(e){return t(o(e))}var o=fi(e),i=fi(1/e);return r.invert=function(e){return i(t.invert(e))},r.domain=function(e){return arguments.length?(t.domain((n=e.map(Number)).map(o)),r):n},r.ticks=function(t){return ii(n,t)},r.tickFormat=function(t,e){return ai(n,t,e)},r.nice=function(t){return r.domain(ri(n,t))},r.exponent=function(a){return arguments.length?(o=fi(e=a),i=fi(1/e),t.domain(n.map(o)),r):e},r.copy=function(){return ci(t.copy(),e,n)},ni(r,t)}function fi(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}function di(t,e){function n(n){return i[((o.get(n)||("range"===e.t?o.set(n,t.push(n)):NaN))-1)%i.length]}function r(e,n){return pa.range(t.length).map(function(t){return e+n*t})}var o,i,a;return n.domain=function(r){if(!arguments.length)return t;t=[],o=new h;for(var i,a=-1,s=r.length;++a<s;)o.has(i=r[a])||o.set(i,t.push(i));return n[e.t].apply(n,e.a);
},n.range=function(t){return arguments.length?(i=t,a=0,e={t:"range",a:arguments},n):i},n.rangePoints=function(o,s){arguments.length<2&&(s=0);var l=o[0],u=o[1],c=t.length<2?(l=(l+u)/2,0):(u-l)/(t.length-1+s);return i=r(l+c*s/2,c),a=0,e={t:"rangePoints",a:arguments},n},n.rangeRoundPoints=function(o,s){arguments.length<2&&(s=0);var l=o[0],u=o[1],c=t.length<2?(l=u=Math.round((l+u)/2),0):(u-l)/(t.length-1+s)|0;return i=r(l+Math.round(c*s/2+(u-l-(t.length-1+s)*c)/2),c),a=0,e={t:"rangeRoundPoints",a:arguments},n},n.rangeBands=function(o,s,l){arguments.length<2&&(s=0),arguments.length<3&&(l=s);var u=o[1]<o[0],c=o[u-0],f=o[1-u],d=(f-c)/(t.length-s+2*l);return i=r(c+d*l,d),u&&i.reverse(),a=d*(1-s),e={t:"rangeBands",a:arguments},n},n.rangeRoundBands=function(o,s,l){arguments.length<2&&(s=0),arguments.length<3&&(l=s);var u=o[1]<o[0],c=o[u-0],f=o[1-u],d=Math.floor((f-c)/(t.length-s+2*l));return i=r(c+Math.round((f-c-(t.length-s)*d)/2),d),u&&i.reverse(),a=Math.round(d*(1-s)),e={t:"rangeRoundBands",a:arguments},n},n.rangeBand=function(){return a},n.rangeExtent=function(){return Xo(e.a[0])},n.copy=function(){return di(t,e)},n.domain(t)}function pi(t,e){function n(){var n=0,i=e.length;for(o=[];++n<i;)o[n-1]=pa.quantile(t,n/i);return r}function r(t){if(!isNaN(t=+t))return e[pa.bisect(o,t)]}var o;return r.domain=function(e){return arguments.length?(t=e.map(l).filter(u).sort(s),n()):t},r.range=function(t){return arguments.length?(e=t,n()):e},r.quantiles=function(){return o},r.invertExtent=function(n){return n=e.indexOf(n),n<0?[NaN,NaN]:[n>0?o[n-1]:t[0],n<o.length?o[n]:t[t.length-1]]},r.copy=function(){return pi(t,e)},n()}function hi(t,e,n){function r(e){return n[Math.max(0,Math.min(a,Math.floor(i*(e-t))))]}function o(){return i=n.length/(e-t),a=n.length-1,r}var i,a;return r.domain=function(n){return arguments.length?(t=+n[0],e=+n[n.length-1],o()):[t,e]},r.range=function(t){return arguments.length?(n=t,o()):n},r.invertExtent=function(e){return e=n.indexOf(e),e=e<0?NaN:e/i+t,[e,e+1/i]},r.copy=function(){return hi(t,e,n)},o()}function gi(t,e){function n(n){if(n<=n)return e[pa.bisect(t,n)]}return n.domain=function(e){return arguments.length?(t=e,n):t},n.range=function(t){return arguments.length?(e=t,n):e},n.invertExtent=function(n){return n=e.indexOf(n),[t[n-1],t[n]]},n.copy=function(){return gi(t,e)},n}function vi(t){function e(t){return+t}return e.invert=e,e.domain=e.range=function(n){return arguments.length?(t=n.map(e),e):t},e.ticks=function(e){return ii(t,e)},e.tickFormat=function(e,n){return ai(t,e,n)},e.copy=function(){return vi(t)},e}function mi(){return 0}function yi(t){return t.innerRadius}function bi(t){return t.outerRadius}function xi(t){return t.startAngle}function _i(t){return t.endAngle}function wi(t){return t&&t.padAngle}function Ti(t,e,n,r){return(t-n)*e-(e-r)*t>0?0:1}function Ci(t,e,n,r,o){var i=t[0]-e[0],a=t[1]-e[1],s=(o?r:-r)/Math.sqrt(i*i+a*a),l=s*a,u=-s*i,c=t[0]+l,f=t[1]+u,d=e[0]+l,p=e[1]+u,h=(c+d)/2,g=(f+p)/2,v=d-c,m=p-f,y=v*v+m*m,b=n-r,x=c*p-d*f,_=(m<0?-1:1)*Math.sqrt(Math.max(0,b*b*y-x*x)),w=(x*m-v*_)/y,T=(-x*v-m*_)/y,C=(x*m+v*_)/y,k=(-x*v+m*_)/y,E=w-h,P=T-g,S=C-h,M=k-g;return E*E+P*P>S*S+M*M&&(w=C,T=k),[[w-l,T-u],[w*n/b,T*n/b]]}function ki(t){function e(e){function a(){u.push("M",i(t(c),s))}for(var l,u=[],c=[],f=-1,d=e.length,p=At(n),h=At(r);++f<d;)o.call(this,l=e[f],f)?c.push([+p.call(this,l,f),+h.call(this,l,f)]):c.length&&(a(),c=[]);return c.length&&a(),u.length?u.join(""):null}var n=In,r=Rn,o=Ie,i=Ei,a=i.key,s=.7;return e.x=function(t){return arguments.length?(n=t,e):n},e.y=function(t){return arguments.length?(r=t,e):r},e.defined=function(t){return arguments.length?(o=t,e):o},e.interpolate=function(t){return arguments.length?(a="function"==typeof t?i=t:(i=Ll.get(t)||Ei).key,e):a},e.tension=function(t){return arguments.length?(s=t,e):s},e}function Ei(t){return t.length>1?t.join("L"):t+"Z"}function Pi(t){return t.join("L")+"Z"}function Si(t){for(var e=0,n=t.length,r=t[0],o=[r[0],",",r[1]];++e<n;)o.push("H",(r[0]+(r=t[e])[0])/2,"V",r[1]);return n>1&&o.push("H",r[0]),o.join("")}function Mi(t){for(var e=0,n=t.length,r=t[0],o=[r[0],",",r[1]];++e<n;)o.push("V",(r=t[e])[1],"H",r[0]);return o.join("")}function Ni(t){for(var e=0,n=t.length,r=t[0],o=[r[0],",",r[1]];++e<n;)o.push("H",(r=t[e])[0],"V",r[1]);return o.join("")}function Ai(t,e){return t.length<4?Ei(t):t[1]+Ii(t.slice(1,-1),Ri(t,e))}function Oi(t,e){return t.length<3?Pi(t):t[0]+Ii((t.push(t[0]),t),Ri([t[t.length-2]].concat(t,[t[1]]),e))}function Di(t,e){return t.length<3?Ei(t):t[0]+Ii(t,Ri(t,e))}function Ii(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Ei(t);var n=t.length!=e.length,r="",o=t[0],i=t[1],a=e[0],s=a,l=1;if(n&&(r+="Q"+(i[0]-2*a[0]/3)+","+(i[1]-2*a[1]/3)+","+i[0]+","+i[1],o=t[1],l=2),e.length>1){s=e[1],i=t[l],l++,r+="C"+(o[0]+a[0])+","+(o[1]+a[1])+","+(i[0]-s[0])+","+(i[1]-s[1])+","+i[0]+","+i[1];for(var u=2;u<e.length;u++,l++)i=t[l],s=e[u],r+="S"+(i[0]-s[0])+","+(i[1]-s[1])+","+i[0]+","+i[1]}if(n){var c=t[l];r+="Q"+(i[0]+2*s[0]/3)+","+(i[1]+2*s[1]/3)+","+c[0]+","+c[1]}return r}function Ri(t,e){for(var n,r=[],o=(1-e)/2,i=t[0],a=t[1],s=1,l=t.length;++s<l;)n=i,i=a,a=t[s],r.push([o*(a[0]-n[0]),o*(a[1]-n[1])]);return r}function Li(t){if(t.length<3)return Ei(t);var e=1,n=t.length,r=t[0],o=r[0],i=r[1],a=[o,o,o,(r=t[1])[0]],s=[i,i,i,r[1]],l=[o,",",i,"L",Ui(Bl,a),",",Ui(Bl,s)];for(t.push(t[n-1]);++e<=n;)r=t[e],a.shift(),a.push(r[0]),s.shift(),s.push(r[1]),Hi(l,a,s);return t.pop(),l.push("L",r),l.join("")}function Fi(t){if(t.length<4)return Ei(t);for(var e,n=[],r=-1,o=t.length,i=[0],a=[0];++r<3;)e=t[r],i.push(e[0]),a.push(e[1]);for(n.push(Ui(Bl,i)+","+Ui(Bl,a)),--r;++r<o;)e=t[r],i.shift(),i.push(e[0]),a.shift(),a.push(e[1]),Hi(n,i,a);return n.join("")}function ji(t){for(var e,n,r=-1,o=t.length,i=o+4,a=[],s=[];++r<4;)n=t[r%o],a.push(n[0]),s.push(n[1]);for(e=[Ui(Bl,a),",",Ui(Bl,s)],--r;++r<i;)n=t[r%o],a.shift(),a.push(n[0]),s.shift(),s.push(n[1]),Hi(e,a,s);return e.join("")}function Bi(t,e){var n=t.length-1;if(n)for(var r,o,i=t[0][0],a=t[0][1],s=t[n][0]-i,l=t[n][1]-a,u=-1;++u<=n;)r=t[u],o=u/n,r[0]=e*r[0]+(1-e)*(i+o*s),r[1]=e*r[1]+(1-e)*(a+o*l);return Li(t)}function Ui(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}function Hi(t,e,n){t.push("C",Ui(Fl,e),",",Ui(Fl,n),",",Ui(jl,e),",",Ui(jl,n),",",Ui(Bl,e),",",Ui(Bl,n))}function zi(t,e){return(e[1]-t[1])/(e[0]-t[0])}function Wi(t){for(var e=0,n=t.length-1,r=[],o=t[0],i=t[1],a=r[0]=zi(o,i);++e<n;)r[e]=(a+(a=zi(o=i,i=t[e+1])))/2;return r[e]=a,r}function qi(t){for(var e,n,r,o,i=[],a=Wi(t),s=-1,l=t.length-1;++s<l;)e=zi(t[s],t[s+1]),Ta(e)<Ua?a[s]=a[s+1]=0:(n=a[s]/e,r=a[s+1]/e,o=n*n+r*r,o>9&&(o=3*e/Math.sqrt(o),a[s]=o*n,a[s+1]=o*r));for(s=-1;++s<=l;)o=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+a[s]*a[s])),i.push([o||0,a[s]*o||0]);return i}function Vi(t){return t.length<3?Ei(t):t[0]+Ii(t,qi(t))}function Ki(t){for(var e,n,r,o=-1,i=t.length;++o<i;)e=t[o],n=e[0],r=e[1]-Va,e[0]=n*Math.cos(r),e[1]=n*Math.sin(r);return t}function Yi(t){function e(e){function l(){g.push("M",s(t(m),f),c,u(t(v.reverse()),f),"Z")}for(var d,p,h,g=[],v=[],m=[],y=-1,b=e.length,x=At(n),_=At(o),w=n===r?function(){return p}:At(r),T=o===i?function(){return h}:At(i);++y<b;)a.call(this,d=e[y],y)?(v.push([p=+x.call(this,d,y),h=+_.call(this,d,y)]),m.push([+w.call(this,d,y),+T.call(this,d,y)])):v.length&&(l(),v=[],m=[]);return v.length&&l(),g.length?g.join(""):null}var n=In,r=In,o=0,i=Rn,a=Ie,s=Ei,l=s.key,u=s,c="L",f=.7;return e.x=function(t){return arguments.length?(n=r=t,e):r},e.x0=function(t){return arguments.length?(n=t,e):n},e.x1=function(t){return arguments.length?(r=t,e):r},e.y=function(t){return arguments.length?(o=i=t,e):i},e.y0=function(t){return arguments.length?(o=t,e):o},e.y1=function(t){return arguments.length?(i=t,e):i},e.defined=function(t){return arguments.length?(a=t,e):a},e.interpolate=function(t){return arguments.length?(l="function"==typeof t?s=t:(s=Ll.get(t)||Ei).key,u=s.reverse||s,c=s.closed?"M":"L",e):l},e.tension=function(t){return arguments.length?(f=t,e):f},e}function Gi(t){return t.radius}function Xi(t){return[t.x,t.y]}function $i(t){return function(){var e=t.apply(this,arguments),n=e[0],r=e[1]-Va;return[n*Math.cos(r),n*Math.sin(r)]}}function Zi(){return 64}function Ji(){return"circle"}function Qi(t){var e=Math.sqrt(t/za);return"M0,"+e+"A"+e+","+e+" 0 1,1 0,"+-e+"A"+e+","+e+" 0 1,1 0,"+e+"Z"}function ta(t){return function(){var e,n,r;(e=this[t])&&(r=e[n=e.active])&&(r.timer.c=null,r.timer.t=NaN,--e.count?delete e[n]:delete this[t],e.active+=.5,r.event&&r.event.interrupt.call(this,this.__data__,r.index))}}function ea(t,e,n){return Sa(t,Kl),t.namespace=e,t.id=n,t}function na(t,e,n,r){var o=t.id,i=t.namespace;return G(t,"function"==typeof n?function(t,a,s){t[i][o].tween.set(e,r(n.call(t,t.__data__,a,s)))}:(n=r(n),function(t){t[i][o].tween.set(e,n)}))}function ra(t){return null==t&&(t=""),function(){this.textContent=t}}function oa(t){return null==t?"__transition__":"__transition_"+t+"__"}function ia(t,e,n,r,o){function i(t){var e=g.delay;return u.t=e+l,e<=t?a(t-e):void(u.c=a)}function a(n){var o=p.active,i=p[o];i&&(i.timer.c=null,i.timer.t=NaN,--p.count,delete p[o],i.event&&i.event.interrupt.call(t,t.__data__,i.index));for(var a in p)if(+a<r){var h=p[a];h.timer.c=null,h.timer.t=NaN,--p.count,delete p[a]}u.c=s,Lt(function(){return u.c&&s(n||1)&&(u.c=null,u.t=NaN),1},0,l),p.active=r,g.event&&g.event.start.call(t,t.__data__,e),d=[],g.tween.forEach(function(n,r){(r=r.call(t,t.__data__,e))&&d.push(r)}),f=g.ease,c=g.duration}function s(o){for(var i=o/c,a=f(i),s=d.length;s>0;)d[--s].call(t,a);if(i>=1)return g.event&&g.event.end.call(t,t.__data__,e),--p.count?delete p[r]:delete t[n],1}var l,u,c,f,d,p=t[n]||(t[n]={active:0,count:0}),g=p[r];g||(l=o.time,u=Lt(i,0,l),g=p[r]={tween:new h,time:l,timer:u,delay:o.delay,duration:o.duration,ease:o.ease,index:e},o=null,++p.count)}function aa(t,e,n){t.attr("transform",function(t){var r=e(t);return"translate("+(isFinite(r)?r:n(t))+",0)"})}function sa(t,e,n){t.attr("transform",function(t){var r=e(t);return"translate(0,"+(isFinite(r)?r:n(t))+")"})}function la(t){return t.toISOString()}function ua(t,e,n){function r(e){return t(e)}function o(t,n){var r=t[1]-t[0],o=r/n,i=pa.bisect(eu,o);return i==eu.length?[e.year,oi(t.map(function(t){return t/31536e6}),n)[2]]:i?e[o/eu[i-1]<eu[i]/o?i-1:i]:[ou,oi(t,n)[2]]}return r.invert=function(e){return ca(t.invert(e))},r.domain=function(e){return arguments.length?(t.domain(e),r):t.domain().map(ca)},r.nice=function(t,e){function n(n){return!isNaN(n)&&!t.range(n,ca(+n+1),e).length}var i=r.domain(),a=Xo(i),s=null==t?o(a,10):"number"==typeof t&&o(a,t);return s&&(t=s[0],e=s[1]),r.domain(Jo(i,e>1?{floor:function(e){for(;n(e=t.floor(e));)e=ca(e-1);return e},ceil:function(e){for(;n(e=t.ceil(e));)e=ca(+e+1);return e}}:t))},r.ticks=function(t,e){var n=Xo(r.domain()),i=null==t?o(n,10):"number"==typeof t?o(n,t):!t.range&&[{range:t},e];return i&&(t=i[0],e=i[1]),t.range(n[0],ca(+n[1]+1),e<1?1:e)},r.tickFormat=function(){return n},r.copy=function(){return ua(t.copy(),e,n)},ni(r,t)}function ca(t){return new Date(t)}function fa(t){return JSON.parse(t.responseText)}function da(t){var e=va.createRange();return e.selectNode(va.body),e.createContextualFragment(t.responseText)}var pa={version:"3.5.17"},ha=[].slice,ga=function(t){return ha.call(t)},va=this.document;if(va)try{ga(va.documentElement.childNodes)[0].nodeType}catch(t){ga=function(t){for(var e=t.length,n=new Array(e);e--;)n[e]=t[e];return n}}if(Date.now||(Date.now=function(){return+new Date}),va)try{va.createElement("DIV").style.setProperty("opacity",0,"")}catch(t){var ma=this.Element.prototype,ya=ma.setAttribute,ba=ma.setAttributeNS,xa=this.CSSStyleDeclaration.prototype,_a=xa.setProperty;ma.setAttribute=function(t,e){ya.call(this,t,e+"")},ma.setAttributeNS=function(t,e,n){ba.call(this,t,e,n+"")},xa.setProperty=function(t,e,n){_a.call(this,t,e+"",n)}}pa.ascending=s,pa.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},pa.min=function(t,e){var n,r,o=-1,i=t.length;if(1===arguments.length){for(;++o<i;)if(null!=(r=t[o])&&r>=r){n=r;break}for(;++o<i;)null!=(r=t[o])&&n>r&&(n=r)}else{for(;++o<i;)if(null!=(r=e.call(t,t[o],o))&&r>=r){n=r;break}for(;++o<i;)null!=(r=e.call(t,t[o],o))&&n>r&&(n=r)}return n},pa.max=function(t,e){var n,r,o=-1,i=t.length;if(1===arguments.length){for(;++o<i;)if(null!=(r=t[o])&&r>=r){n=r;break}for(;++o<i;)null!=(r=t[o])&&r>n&&(n=r)}else{for(;++o<i;)if(null!=(r=e.call(t,t[o],o))&&r>=r){n=r;break}for(;++o<i;)null!=(r=e.call(t,t[o],o))&&r>n&&(n=r)}return n},pa.extent=function(t,e){var n,r,o,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(r=t[i])&&r>=r){n=o=r;break}for(;++i<a;)null!=(r=t[i])&&(n>r&&(n=r),o<r&&(o=r))}else{for(;++i<a;)if(null!=(r=e.call(t,t[i],i))&&r>=r){n=o=r;break}for(;++i<a;)null!=(r=e.call(t,t[i],i))&&(n>r&&(n=r),o<r&&(o=r))}return[n,o]},pa.sum=function(t,e){var n,r=0,o=t.length,i=-1;if(1===arguments.length)for(;++i<o;)u(n=+t[i])&&(r+=n);else for(;++i<o;)u(n=+e.call(t,t[i],i))&&(r+=n);return r},pa.mean=function(t,e){var n,r=0,o=t.length,i=-1,a=o;if(1===arguments.length)for(;++i<o;)u(n=l(t[i]))?r+=n:--a;else for(;++i<o;)u(n=l(e.call(t,t[i],i)))?r+=n:--a;if(a)return r/a},pa.quantile=function(t,e){var n=(t.length-1)*e+1,r=Math.floor(n),o=+t[r-1],i=n-r;return i?o+i*(t[r]-o):o},pa.median=function(t,e){var n,r=[],o=t.length,i=-1;if(1===arguments.length)for(;++i<o;)u(n=l(t[i]))&&r.push(n);else for(;++i<o;)u(n=l(e.call(t,t[i],i)))&&r.push(n);if(r.length)return pa.quantile(r.sort(s),.5)},pa.variance=function(t,e){var n,r,o=t.length,i=0,a=0,s=-1,c=0;if(1===arguments.length)for(;++s<o;)u(n=l(t[s]))&&(r=n-i,i+=r/++c,a+=r*(n-i));else for(;++s<o;)u(n=l(e.call(t,t[s],s)))&&(r=n-i,i+=r/++c,a+=r*(n-i));if(c>1)return a/(c-1)},pa.deviation=function(){var t=pa.variance.apply(this,arguments);return t?Math.sqrt(t):t};var wa=c(s);pa.bisectLeft=wa.left,pa.bisect=pa.bisectRight=wa.right,pa.bisector=function(t){return c(1===t.length?function(e,n){return s(t(e),n)}:t)},pa.shuffle=function(t,e,n){(i=arguments.length)<3&&(n=t.length,i<2&&(e=0));for(var r,o,i=n-e;i;)o=Math.random()*i--|0,r=t[i+e],t[i+e]=t[o+e],t[o+e]=r;return t},pa.permute=function(t,e){for(var n=e.length,r=new Array(n);n--;)r[n]=t[e[n]];return r},pa.pairs=function(t){for(var e,n=0,r=t.length-1,o=t[0],i=new Array(r<0?0:r);n<r;)i[n]=[e=o,o=t[++n]];return i},pa.transpose=function(t){if(!(o=t.length))return[];for(var e=-1,n=pa.min(t,f),r=new Array(n);++e<n;)for(var o,i=-1,a=r[e]=new Array(o);++i<o;)a[i]=t[i][e];return r},pa.zip=function(){return pa.transpose(arguments)},pa.keys=function(t){var e=[];for(var n in t)e.push(n);return e},pa.values=function(t){var e=[];for(var n in t)e.push(t[n]);return e},pa.entries=function(t){var e=[];for(var n in t)e.push({key:n,value:t[n]});return e},pa.merge=function(t){for(var e,n,r,o=t.length,i=-1,a=0;++i<o;)a+=t[i].length;for(n=new Array(a);--o>=0;)for(r=t[o],e=r.length;--e>=0;)n[--a]=r[e];return n};var Ta=Math.abs;pa.range=function(t,e,n){if(arguments.length<3&&(n=1,arguments.length<2&&(e=t,t=0)),(e-t)/n===1/0)throw new Error("infinite range");var r,o=[],i=d(Ta(n)),a=-1;if(t*=i,e*=i,n*=i,n<0)for(;(r=t+n*++a)>e;)o.push(r/i);else for(;(r=t+n*++a)<e;)o.push(r/i);return o},pa.map=function(t,e){var n=new h;if(t instanceof h)t.forEach(function(t,e){n.set(t,e)});else if(Array.isArray(t)){var r,o=-1,i=t.length;if(1===arguments.length)for(;++o<i;)n.set(o,t[o]);else for(;++o<i;)n.set(e.call(t,r=t[o],o),r)}else for(var a in t)n.set(a,t[a]);return n};var Ca="__proto__",ka="\0";p(h,{has:m,get:function(t){return this._[g(t)]},set:function(t,e){return this._[g(t)]=e},remove:y,keys:b,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:v(e),value:this._[e]});return t},size:x,empty:_,forEach:function(t){for(var e in this._)t.call(this,v(e),this._[e])}}),pa.nest=function(){function t(e,a,s){if(s>=i.length)return r?r.call(o,a):n?a.sort(n):a;for(var l,u,c,f,d=-1,p=a.length,g=i[s++],v=new h;++d<p;)(f=v.get(l=g(u=a[d])))?f.push(u):v.set(l,[u]);return e?(u=e(),c=function(n,r){u.set(n,t(e,r,s))}):(u={},c=function(n,r){u[n]=t(e,r,s)}),v.forEach(c),u}function e(t,n){if(n>=i.length)return t;var r=[],o=a[n++];return t.forEach(function(t,o){r.push({key:t,values:e(o,n)})}),o?r.sort(function(t,e){return o(t.key,e.key)}):r}var n,r,o={},i=[],a=[];return o.map=function(e,n){return t(n,e,0)},o.entries=function(n){return e(t(pa.map,n,0),0)},o.key=function(t){return i.push(t),o},o.sortKeys=function(t){return a[i.length-1]=t,o},o.sortValues=function(t){return n=t,o},o.rollup=function(t){return r=t,o},o},pa.set=function(t){var e=new w;if(t)for(var n=0,r=t.length;n<r;++n)e.add(t[n]);return e},p(w,{has:m,add:function(t){return this._[g(t+="")]=!0,t},remove:y,values:b,size:x,empty:_,forEach:function(t){for(var e in this._)t.call(this,v(e))}}),pa.behavior={},pa.rebind=function(t,e){for(var n,r=1,o=arguments.length;++r<o;)t[n=arguments[r]]=C(t,e,e[n]);return t};var Ea=["webkit","ms","moz","Moz","o","O"];pa.dispatch=function(){for(var t=new P,e=-1,n=arguments.length;++e<n;)t[arguments[e]]=S(t);return t},P.prototype.on=function(t,e){var n=t.indexOf("."),r="";if(n>=0&&(r=t.slice(n+1),t=t.slice(0,n)),t)return arguments.length<2?this[t].on(r):this[t].on(r,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(r,null);return this}},pa.event=null,pa.requote=function(t){return t.replace(Pa,"\\$&")};var Pa=/[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g,Sa={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var n in e)t[n]=e[n]},Ma=function(t,e){return e.querySelector(t)},Na=function(t,e){return e.querySelectorAll(t)},Aa=function(t,e){var n=t.matches||t[k(t,"matchesSelector")];return(Aa=function(t,e){return n.call(t,e)})(t,e)};"function"==typeof Sizzle&&(Ma=function(t,e){return Sizzle(t,e)[0]||null},Na=Sizzle,Aa=Sizzle.matchesSelector),pa.selection=function(){return pa.select(va.documentElement)};var Oa=pa.selection.prototype=[];Oa.select=function(t){var e,n,r,o,i=[];t=D(t);for(var a=-1,s=this.length;++a<s;){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var l=-1,u=r.length;++l<u;)(o=r[l])?(e.push(n=t.call(o,o.__data__,l,a)),n&&"__data__"in o&&(n.__data__=o.__data__)):e.push(null)}return O(i)},Oa.selectAll=function(t){var e,n,r=[];t=I(t);for(var o=-1,i=this.length;++o<i;)for(var a=this[o],s=-1,l=a.length;++s<l;)(n=a[s])&&(r.push(e=ga(t.call(n,n.__data__,s,o))),e.parentNode=n);return O(r)};var Da="http://www.w3.org/1999/xhtml",Ia={svg:"http://www.w3.org/2000/svg",xhtml:Da,xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"};pa.ns={prefix:Ia,qualify:function(t){var e=t.indexOf(":"),n=t;return e>=0&&"xmlns"!==(n=t.slice(0,e))&&(t=t.slice(e+1)),Ia.hasOwnProperty(n)?{space:Ia[n],local:t}:t}},Oa.attr=function(t,e){if(arguments.length<2){if("string"==typeof t){var n=this.node();return t=pa.ns.qualify(t),t.local?n.getAttributeNS(t.space,t.local):n.getAttribute(t)}for(e in t)this.each(R(e,t[e]));return this}return this.each(R(t,e))},Oa.classed=function(t,e){if(arguments.length<2){if("string"==typeof t){var n=this.node(),r=(t=j(t)).length,o=-1;if(e=n.classList){for(;++o<r;)if(!e.contains(t[o]))return!1}else for(e=n.getAttribute("class");++o<r;)if(!F(t[o]).test(e))return!1;return!0}for(e in t)this.each(B(e,t[e]));return this}return this.each(B(t,e))},Oa.style=function(t,e,n){var r=arguments.length;if(r<3){if("string"!=typeof t){r<2&&(e="");for(n in t)this.each(H(n,t[n],e));return this}if(r<2){var o=this.node();return a(o).getComputedStyle(o,null).getPropertyValue(t)}n=""}return this.each(H(t,e,n))},Oa.property=function(t,e){if(arguments.length<2){if("string"==typeof t)return this.node()[t];for(e in t)this.each(z(e,t[e]));return this}return this.each(z(t,e))},Oa.text=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?"":e}:null==t?function(){this.textContent=""}:function(){this.textContent=t}):this.node().textContent},Oa.html=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?"":e}:null==t?function(){this.innerHTML=""}:function(){this.innerHTML=t}):this.node().innerHTML},Oa.append=function(t){return t=W(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},Oa.insert=function(t,e){return t=W(t),e=D(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},Oa.remove=function(){return this.each(q)},Oa.data=function(t,e){function n(t,n){var r,o,i,a=t.length,c=n.length,f=Math.min(a,c),d=new Array(c),p=new Array(c),g=new Array(a);if(e){var v,m=new h,y=new Array(a);for(r=-1;++r<a;)(o=t[r])&&(m.has(v=e.call(o,o.__data__,r))?g[r]=o:m.set(v,o),y[r]=v);for(r=-1;++r<c;)(o=m.get(v=e.call(n,i=n[r],r)))?o!==!0&&(d[r]=o,o.__data__=i):p[r]=V(i),m.set(v,!0);for(r=-1;++r<a;)r in y&&m.get(y[r])!==!0&&(g[r]=t[r])}else{for(r=-1;++r<f;)o=t[r],i=n[r],o?(o.__data__=i,d[r]=o):p[r]=V(i);for(;r<c;++r)p[r]=V(n[r]);for(;r<a;++r)g[r]=t[r]}p.update=d,p.parentNode=d.parentNode=g.parentNode=t.parentNode,s.push(p),l.push(d),u.push(g)}var r,o,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(o=r[i])&&(t[i]=o.__data__);return t}var s=X([]),l=O([]),u=O([]);if("function"==typeof t)for(;++i<a;)n(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)n(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return u},l},Oa.datum=function(t){return arguments.length?this.property("__data__",t):this.property("__data__")},Oa.filter=function(t){var e,n,r,o=[];"function"!=typeof t&&(t=K(t));for(var i=0,a=this.length;i<a;i++){o.push(e=[]),e.parentNode=(n=this[i]).parentNode;for(var s=0,l=n.length;s<l;s++)(r=n[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return O(o)},Oa.order=function(){for(var t=-1,e=this.length;++t<e;)for(var n,r=this[t],o=r.length-1,i=r[o];--o>=0;)(n=r[o])&&(i&&i!==n.nextSibling&&i.parentNode.insertBefore(n,i),i=n);return this},Oa.sort=function(t){t=Y.apply(this,arguments);for(var e=-1,n=this.length;++e<n;)this[e].sort(t);return this.order()},Oa.each=function(t){return G(this,function(e,n,r){t.call(e,e.__data__,n,r)})},Oa.call=function(t){var e=ga(arguments);return t.apply(e[0]=this,e),this},Oa.empty=function(){return!this.node()},Oa.node=function(){for(var t=0,e=this.length;t<e;t++)for(var n=this[t],r=0,o=n.length;r<o;r++){var i=n[r];if(i)return i}return null},Oa.size=function(){var t=0;return G(this,function(){++t}),t};var Ra=[];pa.selection.enter=X,pa.selection.enter.prototype=Ra,Ra.append=Oa.append,Ra.empty=Oa.empty,Ra.node=Oa.node,Ra.call=Oa.call,Ra.size=Oa.size,Ra.select=function(t){for(var e,n,r,o,i,a=[],s=-1,l=this.length;++s<l;){r=(o=this[s]).update,a.push(e=[]),e.parentNode=o.parentNode;for(var u=-1,c=o.length;++u<c;)(i=o[u])?(e.push(r[u]=n=t.call(o.parentNode,i.__data__,u,s)),n.__data__=i.__data__):e.push(null)}return O(a)},Ra.insert=function(t,e){return arguments.length<2&&(e=$(this)),Oa.insert.call(this,t,e)},pa.select=function(t){var e;return"string"==typeof t?(e=[Ma(t,va)],e.parentNode=va.documentElement):(e=[t],e.parentNode=i(t)),O([e])},pa.selectAll=function(t){var e;return"string"==typeof t?(e=ga(Na(t,va)),e.parentNode=va.documentElement):(e=ga(t),e.parentNode=null),O([e])},Oa.on=function(t,e,n){var r=arguments.length;if(r<3){if("string"!=typeof t){r<2&&(e=!1);for(n in t)this.each(Z(n,t[n],e));return this}if(r<2)return(r=this.node()["__on"+t])&&r._;n=!1}return this.each(Z(t,e,n))};var La=pa.map({mouseenter:"mouseover",mouseleave:"mouseout"});va&&La.forEach(function(t){"on"+t in va&&La.remove(t)});var Fa,ja=0;pa.mouse=function(t){return et(t,N())};var Ba=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;pa.touch=function(t,e,n){if(arguments.length<3&&(n=e,e=N().changedTouches),e)for(var r,o=0,i=e.length;o<i;++o)if((r=e[o]).identifier===n)return et(t,r)},pa.behavior.drag=function(){function t(){this.on("mousedown.drag",o).on("touchstart.drag",i)}function e(t,e,o,i,a){return function(){function s(){var t,n,r=e(d,g);r&&(t=r[0]-b[0],n=r[1]-b[1],h|=t|n,b=r,p({type:"drag",x:r[0]+u[0],y:r[1]+u[1],dx:t,dy:n}))}function l(){e(d,g)&&(m.on(i+v,null).on(a+v,null),y(h),p({type:"dragend"}))}var u,c=this,f=pa.event.target.correspondingElement||pa.event.target,d=c.parentNode,p=n.of(c,arguments),h=0,g=t(),v=".drag"+(null==g?"":"-"+g),m=pa.select(o(f)).on(i+v,s).on(a+v,l),y=tt(f),b=e(d,g);r?(u=r.apply(c,arguments),u=[u.x-b[0],u.y-b[1]]):u=[0,0],p({type:"dragstart"})}}var n=A(t,"drag","dragstart","dragend"),r=null,o=e(E,pa.mouse,a,"mousemove","mouseup"),i=e(nt,pa.touch,T,"touchmove","touchend");return t.origin=function(e){return arguments.length?(r=e,t):r},pa.rebind(t,n,"on")},pa.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?ga(e).map(function(e){var n=et(t,e);return n.identifier=e.identifier,n}):[]};var Ua=1e-6,Ha=Ua*Ua,za=Math.PI,Wa=2*za,qa=Wa-Ua,Va=za/2,Ka=za/180,Ya=180/za,Ga=Math.SQRT2,Xa=2,$a=4;pa.interpolateZoom=function(t,e){var n,r,o=t[0],i=t[1],a=t[2],s=e[0],l=e[1],u=e[2],c=s-o,f=l-i,d=c*c+f*f;if(d<Ha)r=Math.log(u/a)/Ga,n=function(t){return[o+t*c,i+t*f,a*Math.exp(Ga*t*r)]};else{var p=Math.sqrt(d),h=(u*u-a*a+$a*d)/(2*a*Xa*p),g=(u*u-a*a-$a*d)/(2*u*Xa*p),v=Math.log(Math.sqrt(h*h+1)-h),m=Math.log(Math.sqrt(g*g+1)-g);r=(m-v)/Ga,n=function(t){var e=t*r,n=lt(v),s=a/(Xa*p)*(n*ut(Ga*e+v)-st(v));return[o+s*c,i+s*f,a*n/lt(Ga*e+v)]}}return n.duration=1e3*r,n},pa.behavior.zoom=function(){function t(t){t.on(N,f).on(Ja+".zoom",p).on("dblclick.zoom",h).on(I,d)}function e(t){return[(t[0]-C.x)/C.k,(t[1]-C.y)/C.k]}function n(t){return[t[0]*C.k+C.x,t[1]*C.k+C.y]}function r(t){C.k=Math.max(E[0],Math.min(E[1],t))}function o(t,e){e=n(e),C.x+=t[0]-e[0],C.y+=t[1]-e[1]}function i(e,n,i,a){e.__chart__={x:C.x,y:C.y,k:C.k},r(Math.pow(2,a)),o(v=n,i),e=pa.select(e),P>0&&(e=e.transition().duration(P)),e.call(t.event)}function s(){_&&_.domain(x.range().map(function(t){return(t-C.x)/C.k}).map(x.invert)),T&&T.domain(w.range().map(function(t){return(t-C.y)/C.k}).map(w.invert))}function l(t){S++||t({type:"zoomstart"})}function u(t){s(),t({type:"zoom",scale:C.k,translate:[C.x,C.y]})}function c(t){--S||(t({type:"zoomend"}),v=null)}function f(){function t(){s=1,o(pa.mouse(r),d),u(i)}function n(){f.on(O,null).on(D,null),p(s),c(i)}var r=this,i=R.of(r,arguments),s=0,f=pa.select(a(r)).on(O,t).on(D,n),d=e(pa.mouse(r)),p=tt(r);Vl.call(r),l(i)}function d(){function t(){var t=pa.touches(h);return p=C.k,t.forEach(function(t){t.identifier in v&&(v[t.identifier]=e(t))}),t}function n(){var e=pa.event.target;pa.select(e).on(x,a).on(_,s),w.push(e);for(var n=pa.event.changedTouches,r=0,o=n.length;r<o;++r)v[n[r].identifier]=null;var l=t(),u=Date.now();if(1===l.length){if(u-b<500){var c=l[0];i(h,c,v[c.identifier],Math.floor(Math.log(C.k)/Math.LN2)+1),M()}b=u}else if(l.length>1){var c=l[0],f=l[1],d=c[0]-f[0],p=c[1]-f[1];m=d*d+p*p}}function a(){var t,e,n,i,a=pa.touches(h);Vl.call(h);for(var s=0,l=a.length;s<l;++s,i=null)if(n=a[s],i=v[n.identifier]){if(e)break;t=n,e=i}if(i){var c=(c=n[0]-t[0])*c+(c=n[1]-t[1])*c,f=m&&Math.sqrt(c/m);t=[(t[0]+n[0])/2,(t[1]+n[1])/2],e=[(e[0]+i[0])/2,(e[1]+i[1])/2],r(f*p)}b=null,o(t,e),u(g)}function s(){if(pa.event.touches.length){for(var e=pa.event.changedTouches,n=0,r=e.length;n<r;++n)delete v[e[n].identifier];for(var o in v)return void t()}pa.selectAll(w).on(y,null),T.on(N,f).on(I,d),k(),c(g)}var p,h=this,g=R.of(h,arguments),v={},m=0,y=".zoom-"+pa.event.changedTouches[0].identifier,x="touchmove"+y,_="touchend"+y,w=[],T=pa.select(h),k=tt(h);n(),l(g),T.on(N,null).on(I,n)}function p(){var t=R.of(this,arguments);y?clearTimeout(y):(Vl.call(this),g=e(v=m||pa.mouse(this)),l(t)),y=setTimeout(function(){y=null,c(t)},50),M(),r(Math.pow(2,.002*Za())*C.k),o(v,g),u(t)}function h(){var t=pa.mouse(this),n=Math.log(C.k)/Math.LN2;i(this,t,e(t),pa.event.shiftKey?Math.ceil(n)-1:Math.floor(n)+1)}var g,v,m,y,b,x,_,w,T,C={x:0,y:0,k:1},k=[960,500],E=Qa,P=250,S=0,N="mousedown.zoom",O="mousemove.zoom",D="mouseup.zoom",I="touchstart.zoom",R=A(t,"zoomstart","zoom","zoomend");return Ja||(Ja="onwheel"in va?(Za=function(){return-pa.event.deltaY*(pa.event.deltaMode?120:1)},"wheel"):"onmousewheel"in va?(Za=function(){return pa.event.wheelDelta},"mousewheel"):(Za=function(){return-pa.event.detail},"MozMousePixelScroll")),t.event=function(t){t.each(function(){var t=R.of(this,arguments),e=C;Wl?pa.select(this).transition().each("start.zoom",function(){C=this.__chart__||{x:0,y:0,k:1},l(t)}).tween("zoom:zoom",function(){var n=k[0],r=k[1],o=v?v[0]:n/2,i=v?v[1]:r/2,a=pa.interpolateZoom([(o-C.x)/C.k,(i-C.y)/C.k,n/C.k],[(o-e.x)/e.k,(i-e.y)/e.k,n/e.k]);return function(e){var r=a(e),s=n/r[2];this.__chart__=C={x:o-r[0]*s,y:i-r[1]*s,k:s},u(t)}}).each("interrupt.zoom",function(){c(t)}).each("end.zoom",function(){c(t)}):(this.__chart__=C,l(t),u(t),c(t))})},t.translate=function(e){return arguments.length?(C={x:+e[0],y:+e[1],k:C.k},s(),t):[C.x,C.y]},t.scale=function(e){return arguments.length?(C={x:C.x,y:C.y,k:null},r(+e),s(),t):C.k},t.scaleExtent=function(e){return arguments.length?(E=null==e?Qa:[+e[0],+e[1]],t):E},t.center=function(e){return arguments.length?(m=e&&[+e[0],+e[1]],t):m},t.size=function(e){return arguments.length?(k=e&&[+e[0],+e[1]],t):k},t.duration=function(e){return arguments.length?(P=+e,t):P},t.x=function(e){return arguments.length?(_=e,x=e.copy(),C={x:0,y:0,k:1},t):_},t.y=function(e){return arguments.length?(T=e,w=e.copy(),C={x:0,y:0,k:1},t):T},pa.rebind(t,R,"on")};var Za,Ja,Qa=[0,1/0];pa.color=ft,ft.prototype.toString=function(){return this.rgb()+""},pa.hsl=dt;var ts=dt.prototype=new ft;ts.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new dt(this.h,this.s,this.l/t)},ts.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new dt(this.h,this.s,t*this.l)},ts.rgb=function(){return pt(this.h,this.s,this.l)},pa.hcl=ht;var es=ht.prototype=new ft;es.brighter=function(t){return new ht(this.h,this.c,Math.min(100,this.l+ns*(arguments.length?t:1)))},es.darker=function(t){return new ht(this.h,this.c,Math.max(0,this.l-ns*(arguments.length?t:1)))},es.rgb=function(){return gt(this.h,this.c,this.l).rgb()},pa.lab=vt;var ns=18,rs=.95047,os=1,is=1.08883,as=vt.prototype=new ft;as.brighter=function(t){return new vt(Math.min(100,this.l+ns*(arguments.length?t:1)),this.a,this.b)},as.darker=function(t){return new vt(Math.max(0,this.l-ns*(arguments.length?t:1)),this.a,this.b)},as.rgb=function(){return mt(this.l,this.a,this.b)},pa.rgb=wt;var ss=wt.prototype=new ft;ss.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,n=this.g,r=this.b,o=30;return e||n||r?(e&&e<o&&(e=o),n&&n<o&&(n=o),r&&r<o&&(r=o),new wt(Math.min(255,e/t),Math.min(255,n/t),Math.min(255,r/t))):new wt(o,o,o)},ss.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new wt(t*this.r,t*this.g,t*this.b)},ss.hsl=function(){return Pt(this.r,this.g,this.b)},ss.toString=function(){return"#"+kt(this.r)+kt(this.g)+kt(this.b)};var ls=pa.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,
grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});ls.forEach(function(t,e){ls.set(t,Tt(e))}),pa.functor=At,pa.xhr=Ot(T),pa.dsv=function(t,e){function n(t,n,i){arguments.length<3&&(i=n,n=null);var a=Dt(t,e,null==n?r:o(n),i);return a.row=function(t){return arguments.length?a.response(null==(n=t)?r:o(t)):n},a}function r(t){return n.parse(t.responseText)}function o(t){return function(e){return n.parse(e.responseText,t)}}function i(e){return e.map(a).join(t)}function a(t){return s.test(t)?'"'+t.replace(/\"/g,'""')+'"':t}var s=new RegExp('["'+t+"\n]"),l=t.charCodeAt(0);return n.parse=function(t,e){var r;return n.parseRows(t,function(t,n){if(r)return r(t,n-1);var o=new Function("d","return {"+t.map(function(t,e){return JSON.stringify(t)+": d["+e+"]"}).join(",")+"}");r=e?function(t,n){return e(o(t),n)}:o})},n.parseRows=function(t,e){function n(){if(c>=u)return a;if(o)return o=!1,i;var e=c;if(34===t.charCodeAt(e)){for(var n=e;n++<u;)if(34===t.charCodeAt(n)){if(34!==t.charCodeAt(n+1))break;++n}c=n+2;var r=t.charCodeAt(n+1);return 13===r?(o=!0,10===t.charCodeAt(n+2)&&++c):10===r&&(o=!0),t.slice(e+1,n).replace(/""/g,'"')}for(;c<u;){var r=t.charCodeAt(c++),s=1;if(10===r)o=!0;else if(13===r)o=!0,10===t.charCodeAt(c)&&(++c,++s);else if(r!==l)continue;return t.slice(e,c-s)}return t.slice(e)}for(var r,o,i={},a={},s=[],u=t.length,c=0,f=0;(r=n())!==a;){for(var d=[];r!==i&&r!==a;)d.push(r),r=n();e&&null==(d=e(d,f++))||s.push(d)}return s},n.format=function(e){if(Array.isArray(e[0]))return n.formatRows(e);var r=new w,o=[];return e.forEach(function(t){for(var e in t)r.has(e)||o.push(r.add(e))}),[o.map(a).join(t)].concat(e.map(function(e){return o.map(function(t){return a(e[t])}).join(t)})).join("\n")},n.formatRows=function(t){return t.map(i).join("\n")},n},pa.csv=pa.dsv(",","text/csv"),pa.tsv=pa.dsv("\t","text/tab-separated-values");var us,cs,fs,ds,ps=this[k(this,"requestAnimationFrame")]||function(t){setTimeout(t,17)};pa.timer=function(){Lt.apply(this,arguments)},pa.timer.flush=function(){jt(),Bt()},pa.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var hs=["y","z","a","f","p","n","µ","m","","k","M","G","T","P","E","Z","Y"].map(Ht);pa.formatPrefix=function(t,e){var n=0;return(t=+t)&&(t<0&&(t*=-1),e&&(t=pa.round(t,Ut(t,e))),n=1+Math.floor(1e-12+Math.log(t)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),hs[8+n/3]};var gs=/(?:([^{])?([<>=^]))?([+\- ])?([$#])?(0)?(\d+)?(,)?(\.-?\d+)?([a-z%])?/i,vs=pa.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(t,e){return(t=pa.round(t,Ut(t,e))).toFixed(Math.max(0,Math.min(20,Ut(t*(1+1e-15),e))))}}),ms=pa.time={},ys=Date;qt.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){bs.setUTCDate.apply(this._,arguments)},setDay:function(){bs.setUTCDay.apply(this._,arguments)},setFullYear:function(){bs.setUTCFullYear.apply(this._,arguments)},setHours:function(){bs.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){bs.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){bs.setUTCMinutes.apply(this._,arguments)},setMonth:function(){bs.setUTCMonth.apply(this._,arguments)},setSeconds:function(){bs.setUTCSeconds.apply(this._,arguments)},setTime:function(){bs.setTime.apply(this._,arguments)}};var bs=Date.prototype;ms.year=Vt(function(t){return t=ms.day(t),t.setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ms.years=ms.year.range,ms.years.utc=ms.year.utc.range,ms.day=Vt(function(t){var e=new ys(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ms.days=ms.day.range,ms.days.utc=ms.day.utc.range,ms.dayOfYear=function(t){var e=ms.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},["sunday","monday","tuesday","wednesday","thursday","friday","saturday"].forEach(function(t,e){e=7-e;var n=ms[t]=Vt(function(t){return(t=ms.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var n=ms.year(t).getDay();return Math.floor((ms.dayOfYear(t)+(n+e)%7)/7)-(n!==e)});ms[t+"s"]=n.range,ms[t+"s"].utc=n.utc.range,ms[t+"OfYear"]=function(t){var n=ms.year(t).getDay();return Math.floor((ms.dayOfYear(t)+(n+e)%7)/7)}}),ms.week=ms.sunday,ms.weeks=ms.sunday.range,ms.weeks.utc=ms.sunday.utc.range,ms.weekOfYear=ms.sundayOfYear;var xs={"-":"",_:" ",0:"0"},_s=/^\s*\d+/,ws=/^%/;pa.locale=function(t){return{numberFormat:zt(t),timeFormat:Yt(t)}};var Ts=pa.locale({decimal:".",thousands:",",grouping:[3],currency:["$",""],dateTime:"%a %b %e %X %Y",date:"%m/%d/%Y",time:"%H:%M:%S",periods:["AM","PM"],days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]});pa.format=Ts.numberFormat,pa.geo={},he.prototype={s:0,t:0,add:function(t){ge(t,this.t,Cs),ge(Cs.s,this.s,this),this.s?this.t+=Cs.t:this.s=Cs.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var Cs=new he;pa.geo.stream=function(t,e){t&&ks.hasOwnProperty(t.type)?ks[t.type](t,e):ve(t,e)};var ks={Feature:function(t,e){ve(t.geometry,e)},FeatureCollection:function(t,e){for(var n=t.features,r=-1,o=n.length;++r<o;)ve(n[r].geometry,e)}},Es={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var n=t.coordinates,r=-1,o=n.length;++r<o;)t=n[r],e.point(t[0],t[1],t[2])},LineString:function(t,e){me(t.coordinates,e,0)},MultiLineString:function(t,e){for(var n=t.coordinates,r=-1,o=n.length;++r<o;)me(n[r],e,0)},Polygon:function(t,e){ye(t.coordinates,e)},MultiPolygon:function(t,e){for(var n=t.coordinates,r=-1,o=n.length;++r<o;)ye(n[r],e)},GeometryCollection:function(t,e){for(var n=t.geometries,r=-1,o=n.length;++r<o;)ve(n[r],e)}};pa.geo.area=function(t){return Ps=0,pa.geo.stream(t,Ms),Ps};var Ps,Ss=new he,Ms={sphere:function(){Ps+=4*za},point:E,lineStart:E,lineEnd:E,polygonStart:function(){Ss.reset(),Ms.lineStart=be},polygonEnd:function(){var t=2*Ss;Ps+=t<0?4*za+t:t,Ms.lineStart=Ms.lineEnd=Ms.point=E}};pa.geo.bounds=function(){function t(t,e){b.push(x=[c=t,d=t]),e<f&&(f=e),e>p&&(p=e)}function e(e,n){var r=xe([e*Ka,n*Ka]);if(m){var o=we(m,r),i=[o[1],-o[0],0],a=we(i,o);ke(a),a=Ee(a);var l=e-h,u=l>0?1:-1,g=a[0]*Ya*u,v=Ta(l)>180;if(v^(u*h<g&&g<u*e)){var y=a[1]*Ya;y>p&&(p=y)}else if(g=(g+360)%360-180,v^(u*h<g&&g<u*e)){var y=-a[1]*Ya;y<f&&(f=y)}else n<f&&(f=n),n>p&&(p=n);v?e<h?s(c,e)>s(c,d)&&(d=e):s(e,d)>s(c,d)&&(c=e):d>=c?(e<c&&(c=e),e>d&&(d=e)):e>h?s(c,e)>s(c,d)&&(d=e):s(e,d)>s(c,d)&&(c=e)}else t(e,n);m=r,h=e}function n(){_.point=e}function r(){x[0]=c,x[1]=d,_.point=t,m=null}function o(t,n){if(m){var r=t-h;y+=Ta(r)>180?r+(r>0?360:-360):r}else g=t,v=n;Ms.point(t,n),e(t,n)}function i(){Ms.lineStart()}function a(){o(g,v),Ms.lineEnd(),Ta(y)>Ua&&(c=-(d=180)),x[0]=c,x[1]=d,m=null}function s(t,e){return(e-=t)<0?e+360:e}function l(t,e){return t[0]-e[0]}function u(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}var c,f,d,p,h,g,v,m,y,b,x,_={point:t,lineStart:n,lineEnd:r,polygonStart:function(){_.point=o,_.lineStart=i,_.lineEnd=a,y=0,Ms.polygonStart()},polygonEnd:function(){Ms.polygonEnd(),_.point=t,_.lineStart=n,_.lineEnd=r,Ss<0?(c=-(d=180),f=-(p=90)):y>Ua?p=90:y<-Ua&&(f=-90),x[0]=c,x[1]=d}};return function(t){p=d=-(c=f=1/0),b=[],pa.geo.stream(t,_);var e=b.length;if(e){b.sort(l);for(var n,r=1,o=b[0],i=[o];r<e;++r)n=b[r],u(n[0],o)||u(n[1],o)?(s(o[0],n[1])>s(o[0],o[1])&&(o[1]=n[1]),s(n[0],o[1])>s(o[0],o[1])&&(o[0]=n[0])):i.push(o=n);for(var a,n,h=-(1/0),e=i.length-1,r=0,o=i[e];r<=e;o=n,++r)n=i[r],(a=s(o[1],n[0]))>h&&(h=a,c=n[0],d=o[1])}return b=x=null,c===1/0||f===1/0?[[NaN,NaN],[NaN,NaN]]:[[c,f],[d,p]]}}(),pa.geo.centroid=function(t){Ns=As=Os=Ds=Is=Rs=Ls=Fs=js=Bs=Us=0,pa.geo.stream(t,Hs);var e=js,n=Bs,r=Us,o=e*e+n*n+r*r;return o<Ha&&(e=Rs,n=Ls,r=Fs,As<Ua&&(e=Os,n=Ds,r=Is),o=e*e+n*n+r*r,o<Ha)?[NaN,NaN]:[Math.atan2(n,e)*Ya,at(r/Math.sqrt(o))*Ya]};var Ns,As,Os,Ds,Is,Rs,Ls,Fs,js,Bs,Us,Hs={sphere:E,point:Se,lineStart:Ne,lineEnd:Ae,polygonStart:function(){Hs.lineStart=Oe},polygonEnd:function(){Hs.lineStart=Ne}},zs=je(Ie,ze,qe,[-za,-za/2]),Ws=1e9;pa.geo.clipExtent=function(){var t,e,n,r,o,i,a={stream:function(t){return o&&(o.valid=!1),o=i(t),o.valid=!0,o},extent:function(s){return arguments.length?(i=Ge(t=+s[0][0],e=+s[0][1],n=+s[1][0],r=+s[1][1]),o&&(o.valid=!1,o=null),a):[[t,e],[n,r]]}};return a.extent([[0,0],[960,500]])},(pa.geo.conicEqualArea=function(){return Xe($e)}).raw=$e,pa.geo.albers=function(){return pa.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},pa.geo.albersUsa=function(){function t(t){var i=t[0],a=t[1];return e=null,n(i,a),e||(r(i,a),e)||o(i,a),e}var e,n,r,o,i=pa.geo.albers(),a=pa.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=pa.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,n){e=[t,n]}};return t.invert=function(t){var e=i.scale(),n=i.translate(),r=(t[0]-n[0])/e,o=(t[1]-n[1])/e;return(o>=.12&&o<.234&&r>=-.425&&r<-.214?a:o>=.166&&o<.234&&r>=-.214&&r<-.115?s:i).invert(t)},t.stream=function(t){var e=i.stream(t),n=a.stream(t),r=s.stream(t);return{point:function(t,o){e.point(t,o),n.point(t,o),r.point(t,o)},sphere:function(){e.sphere(),n.sphere(),r.sphere()},lineStart:function(){e.lineStart(),n.lineStart(),r.lineStart()},lineEnd:function(){e.lineEnd(),n.lineEnd(),r.lineEnd()},polygonStart:function(){e.polygonStart(),n.polygonStart(),r.polygonStart()},polygonEnd:function(){e.polygonEnd(),n.polygonEnd(),r.polygonEnd()}}},t.precision=function(e){return arguments.length?(i.precision(e),a.precision(e),s.precision(e),t):i.precision()},t.scale=function(e){return arguments.length?(i.scale(e),a.scale(.35*e),s.scale(e),t.translate(i.translate())):i.scale()},t.translate=function(e){if(!arguments.length)return i.translate();var u=i.scale(),c=+e[0],f=+e[1];return n=i.translate(e).clipExtent([[c-.455*u,f-.238*u],[c+.455*u,f+.238*u]]).stream(l).point,r=a.translate([c-.307*u,f+.201*u]).clipExtent([[c-.425*u+Ua,f+.12*u+Ua],[c-.214*u-Ua,f+.234*u-Ua]]).stream(l).point,o=s.translate([c-.205*u,f+.212*u]).clipExtent([[c-.214*u+Ua,f+.166*u+Ua],[c-.115*u-Ua,f+.234*u-Ua]]).stream(l).point,t},t.scale(1070)};var qs,Vs,Ks,Ys,Gs,Xs,$s={point:E,lineStart:E,lineEnd:E,polygonStart:function(){Vs=0,$s.lineStart=Ze},polygonEnd:function(){$s.lineStart=$s.lineEnd=$s.point=E,qs+=Ta(Vs/2)}},Zs={point:Je,lineStart:E,lineEnd:E,polygonStart:E,polygonEnd:E},Js={point:en,lineStart:nn,lineEnd:rn,polygonStart:function(){Js.lineStart=on},polygonEnd:function(){Js.point=en,Js.lineStart=nn,Js.lineEnd=rn}};pa.geo.path=function(){function t(t){return t&&("function"==typeof s&&i.pointRadius(+s.apply(this,arguments)),a&&a.valid||(a=o(i)),pa.geo.stream(t,a)),i.result()}function e(){return a=null,t}var n,r,o,i,a,s=4.5;return t.area=function(t){return qs=0,pa.geo.stream(t,o($s)),qs},t.centroid=function(t){return Os=Ds=Is=Rs=Ls=Fs=js=Bs=Us=0,pa.geo.stream(t,o(Js)),Us?[js/Us,Bs/Us]:Fs?[Rs/Fs,Ls/Fs]:Is?[Os/Is,Ds/Is]:[NaN,NaN]},t.bounds=function(t){return Gs=Xs=-(Ks=Ys=1/0),pa.geo.stream(t,o(Zs)),[[Ks,Ys],[Gs,Xs]]},t.projection=function(t){return arguments.length?(o=(n=t)?t.stream||ln(t):T,e()):n},t.context=function(t){return arguments.length?(i=null==(r=t)?new Qe:new an(t),"function"!=typeof s&&i.pointRadius(s),e()):r},t.pointRadius=function(e){return arguments.length?(s="function"==typeof e?e:(i.pointRadius(+e),+e),t):s},t.projection(pa.geo.albersUsa()).context(null)},pa.geo.transform=function(t){return{stream:function(e){var n=new un(e);for(var r in t)n[r]=t[r];return n}}},un.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},pa.geo.projection=fn,pa.geo.projectionMutator=dn,(pa.geo.equirectangular=function(){return fn(hn)}).raw=hn.invert=hn,pa.geo.rotation=function(t){function e(e){return e=t(e[0]*Ka,e[1]*Ka),e[0]*=Ya,e[1]*=Ya,e}return t=vn(t[0]%360*Ka,t[1]*Ka,t.length>2?t[2]*Ka:0),e.invert=function(e){return e=t.invert(e[0]*Ka,e[1]*Ka),e[0]*=Ya,e[1]*=Ya,e},e},gn.invert=hn,pa.geo.circle=function(){function t(){var t="function"==typeof r?r.apply(this,arguments):r,e=vn(-t[0]*Ka,-t[1]*Ka,0).invert,o=[];return n(null,null,1,{point:function(t,n){o.push(t=e(t,n)),t[0]*=Ya,t[1]*=Ya}}),{type:"Polygon",coordinates:[o]}}var e,n,r=[0,0],o=6;return t.origin=function(e){return arguments.length?(r=e,t):r},t.angle=function(r){return arguments.length?(n=xn((e=+r)*Ka,o*Ka),t):e},t.precision=function(r){return arguments.length?(n=xn(e*Ka,(o=+r)*Ka),t):o},t.angle(90)},pa.geo.distance=function(t,e){var n,r=(e[0]-t[0])*Ka,o=t[1]*Ka,i=e[1]*Ka,a=Math.sin(r),s=Math.cos(r),l=Math.sin(o),u=Math.cos(o),c=Math.sin(i),f=Math.cos(i);return Math.atan2(Math.sqrt((n=f*a)*n+(n=u*c-l*f*s)*n),l*c+u*f*s)},pa.geo.graticule=function(){function t(){return{type:"MultiLineString",coordinates:e()}}function e(){return pa.range(Math.ceil(i/v)*v,o,v).map(d).concat(pa.range(Math.ceil(u/m)*m,l,m).map(p)).concat(pa.range(Math.ceil(r/h)*h,n,h).filter(function(t){return Ta(t%v)>Ua}).map(c)).concat(pa.range(Math.ceil(s/g)*g,a,g).filter(function(t){return Ta(t%m)>Ua}).map(f))}var n,r,o,i,a,s,l,u,c,f,d,p,h=10,g=h,v=90,m=360,y=2.5;return t.lines=function(){return e().map(function(t){return{type:"LineString",coordinates:t}})},t.outline=function(){return{type:"Polygon",coordinates:[d(i).concat(p(l).slice(1),d(o).reverse().slice(1),p(u).reverse().slice(1))]}},t.extent=function(e){return arguments.length?t.majorExtent(e).minorExtent(e):t.minorExtent()},t.majorExtent=function(e){return arguments.length?(i=+e[0][0],o=+e[1][0],u=+e[0][1],l=+e[1][1],i>o&&(e=i,i=o,o=e),u>l&&(e=u,u=l,l=e),t.precision(y)):[[i,u],[o,l]]},t.minorExtent=function(e){return arguments.length?(r=+e[0][0],n=+e[1][0],s=+e[0][1],a=+e[1][1],r>n&&(e=r,r=n,n=e),s>a&&(e=s,s=a,a=e),t.precision(y)):[[r,s],[n,a]]},t.step=function(e){return arguments.length?t.majorStep(e).minorStep(e):t.minorStep()},t.majorStep=function(e){return arguments.length?(v=+e[0],m=+e[1],t):[v,m]},t.minorStep=function(e){return arguments.length?(h=+e[0],g=+e[1],t):[h,g]},t.precision=function(e){return arguments.length?(y=+e,c=wn(s,a,90),f=Tn(r,n,y),d=wn(u,l,90),p=Tn(i,o,y),t):y},t.majorExtent([[-180,-90+Ua],[180,90-Ua]]).minorExtent([[-180,-80-Ua],[180,80+Ua]])},pa.geo.greatArc=function(){function t(){return{type:"LineString",coordinates:[e||r.apply(this,arguments),n||o.apply(this,arguments)]}}var e,n,r=Cn,o=kn;return t.distance=function(){return pa.geo.distance(e||r.apply(this,arguments),n||o.apply(this,arguments))},t.source=function(n){return arguments.length?(r=n,e="function"==typeof n?null:n,t):r},t.target=function(e){return arguments.length?(o=e,n="function"==typeof e?null:e,t):o},t.precision=function(){return arguments.length?t:0},t},pa.geo.interpolate=function(t,e){return En(t[0]*Ka,t[1]*Ka,e[0]*Ka,e[1]*Ka)},pa.geo.length=function(t){return Qs=0,pa.geo.stream(t,tl),Qs};var Qs,tl={sphere:E,point:E,lineStart:Pn,lineEnd:E,polygonStart:E,polygonEnd:E},el=Sn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(pa.geo.azimuthalEqualArea=function(){return fn(el)}).raw=el;var nl=Sn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},T);(pa.geo.azimuthalEquidistant=function(){return fn(nl)}).raw=nl,(pa.geo.conicConformal=function(){return Xe(Mn)}).raw=Mn,(pa.geo.conicEquidistant=function(){return Xe(Nn)}).raw=Nn;var rl=Sn(function(t){return 1/t},Math.atan);(pa.geo.gnomonic=function(){return fn(rl)}).raw=rl,An.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Va]},(pa.geo.mercator=function(){return On(An)}).raw=An;var ol=Sn(function(){return 1},Math.asin);(pa.geo.orthographic=function(){return fn(ol)}).raw=ol;var il=Sn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});(pa.geo.stereographic=function(){return fn(il)}).raw=il,Dn.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Va]},(pa.geo.transverseMercator=function(){var t=On(Dn),e=t.center,n=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):(t=e(),[t[1],-t[0]])},t.rotate=function(t){return t?n([t[0],t[1],t.length>2?t[2]+90:90]):(t=n(),[t[0],t[1],t[2]-90])},n([0,0,90])}).raw=Dn,pa.geom={},pa.geom.hull=function(t){function e(t){if(t.length<3)return[];var e,o=At(n),i=At(r),a=t.length,s=[],l=[];for(e=0;e<a;e++)s.push([+o.call(this,t[e],e),+i.call(this,t[e],e),e]);for(s.sort(Fn),e=0;e<a;e++)l.push([s[e][0],-s[e][1]]);var u=Ln(s),c=Ln(l),f=c[0]===u[0],d=c[c.length-1]===u[u.length-1],p=[];for(e=u.length-1;e>=0;--e)p.push(t[s[u[e]][2]]);for(e=+f;e<c.length-d;++e)p.push(t[s[c[e]][2]]);return p}var n=In,r=Rn;return arguments.length?e(t):(e.x=function(t){return arguments.length?(n=t,e):n},e.y=function(t){return arguments.length?(r=t,e):r},e)},pa.geom.polygon=function(t){return Sa(t,al),t};var al=pa.geom.polygon.prototype=[];al.area=function(){for(var t,e=-1,n=this.length,r=this[n-1],o=0;++e<n;)t=r,r=this[e],o+=t[1]*r[0]-t[0]*r[1];return.5*o},al.centroid=function(t){var e,n,r=-1,o=this.length,i=0,a=0,s=this[o-1];for(arguments.length||(t=-1/(6*this.area()));++r<o;)e=s,s=this[r],n=e[0]*s[1]-s[0]*e[1],i+=(e[0]+s[0])*n,a+=(e[1]+s[1])*n;return[i*t,a*t]},al.clip=function(t){for(var e,n,r,o,i,a,s=Un(t),l=-1,u=this.length-Un(this),c=this[u-1];++l<u;){for(e=t.slice(),t.length=0,o=this[l],i=e[(r=e.length-s)-1],n=-1;++n<r;)a=e[n],jn(a,c,o)?(jn(i,c,o)||t.push(Bn(i,a,c,o)),t.push(a)):jn(i,c,o)&&t.push(Bn(i,a,c,o)),i=a;s&&t.push(t[0]),c=o}return t};var sl,ll,ul,cl,fl,dl=[],pl=[];Gn.prototype.prepare=function(){for(var t,e=this.edges,n=e.length;n--;)t=e[n].edge,t.b&&t.a||e.splice(n,1);return e.sort($n),e.length},ar.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},sr.prototype={insert:function(t,e){var n,r,o;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;n=t}else this._?(t=fr(this._),e.P=null,e.N=t,t.P=t.L=e,n=t):(e.P=e.N=null,this._=e,n=null);for(e.L=e.R=null,e.U=n,e.C=!0,t=e;n&&n.C;)r=n.U,n===r.L?(o=r.R,o&&o.C?(n.C=o.C=!1,r.C=!0,t=r):(t===n.R&&(ur(this,n),t=n,n=t.U),n.C=!1,r.C=!0,cr(this,r))):(o=r.L,o&&o.C?(n.C=o.C=!1,r.C=!0,t=r):(t===n.L&&(cr(this,n),t=n,n=t.U),n.C=!1,r.C=!0,ur(this,r))),n=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,n,r,o=t.U,i=t.L,a=t.R;if(n=i?a?fr(a):i:a,o?o.L===t?o.L=n:o.R=n:this._=n,i&&a?(r=n.C,n.C=t.C,n.L=i,i.U=n,n!==a?(o=n.U,n.U=t.U,t=n.R,o.L=t,n.R=a,a.U=n):(n.U=o,o=n,t=n.R)):(r=t.C,t=n),t&&(t.U=o),!r){if(t&&t.C)return void(t.C=!1);do{if(t===this._)break;if(t===o.L){if(e=o.R,e.C&&(e.C=!1,o.C=!0,ur(this,o),e=o.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,cr(this,e),e=o.R),e.C=o.C,o.C=e.R.C=!1,ur(this,o),t=this._;break}}else if(e=o.L,e.C&&(e.C=!1,o.C=!0,cr(this,o),e=o.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,ur(this,e),e=o.L),e.C=o.C,o.C=e.L.C=!1,cr(this,o),t=this._;break}e.C=!0,t=o,o=o.U}while(!t.C);t&&(t.C=!1)}}},pa.geom.voronoi=function(t){function e(t){var e=new Array(t.length),r=s[0][0],o=s[0][1],i=s[1][0],a=s[1][1];return dr(n(t),s).cells.forEach(function(n,s){var l=n.edges,u=n.site,c=e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):u.x>=r&&u.x<=i&&u.y>=o&&u.y<=a?[[r,a],[i,a],[i,o],[r,o]]:[];c.point=t[s]}),e}function n(t){return t.map(function(t,e){return{x:Math.round(i(t,e)/Ua)*Ua,y:Math.round(a(t,e)/Ua)*Ua,i:e}})}var r=In,o=Rn,i=r,a=o,s=hl;return t?e(t):(e.links=function(t){return dr(n(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},e.triangles=function(t){var e=[];return dr(n(t)).cells.forEach(function(n,r){for(var o,i,a=n.site,s=n.edges.sort($n),l=-1,u=s.length,c=s[u-1].edge,f=c.l===a?c.r:c.l;++l<u;)o=c,i=f,c=s[l].edge,f=c.l===a?c.r:c.l,r<i.i&&r<f.i&&hr(a,i,f)<0&&e.push([t[r],t[i.i],t[f.i]])}),e},e.x=function(t){return arguments.length?(i=At(r=t),e):r},e.y=function(t){return arguments.length?(a=At(o=t),e):o},e.clipExtent=function(t){return arguments.length?(s=null==t?hl:t,e):s===hl?null:s},e.size=function(t){return arguments.length?e.clipExtent(t&&[[0,0],t]):s===hl?null:s&&s[1]},e)};var hl=[[-1e6,-1e6],[1e6,1e6]];pa.geom.delaunay=function(t){return pa.geom.voronoi().triangles(t)},pa.geom.quadtree=function(t,e,n,r,o){function i(t){function i(t,e,n,r,o,i,a,s){if(!isNaN(n)&&!isNaN(r))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(Ta(l-n)+Ta(c-r)<.01)u(t,e,n,r,o,i,a,s);else{var f=t.point;t.x=t.y=t.point=null,u(t,f,l,c,o,i,a,s),u(t,e,n,r,o,i,a,s)}else t.x=n,t.y=r,t.point=e}else u(t,e,n,r,o,i,a,s)}function u(t,e,n,r,o,a,s,l){var u=.5*(o+s),c=.5*(a+l),f=n>=u,d=r>=c,p=d<<1|f;t.leaf=!1,t=t.nodes[p]||(t.nodes[p]=mr()),f?o=u:s=u,d?a=c:l=c,i(t,e,n,r,o,a,s,l)}var c,f,d,p,h,g,v,m,y,b=At(s),x=At(l);if(null!=e)g=e,v=n,m=r,y=o;else if(m=y=-(g=v=1/0),f=[],d=[],h=t.length,a)for(p=0;p<h;++p)c=t[p],c.x<g&&(g=c.x),c.y<v&&(v=c.y),c.x>m&&(m=c.x),c.y>y&&(y=c.y),f.push(c.x),d.push(c.y);else for(p=0;p<h;++p){var _=+b(c=t[p],p),w=+x(c,p);_<g&&(g=_),w<v&&(v=w),_>m&&(m=_),w>y&&(y=w),f.push(_),d.push(w)}var T=m-g,C=y-v;T>C?y=v+T:m=g+C;var k=mr();if(k.add=function(t){i(k,t,+b(t,++p),+x(t,p),g,v,m,y)},k.visit=function(t){yr(t,k,g,v,m,y)},k.find=function(t){return br(k,t[0],t[1],g,v,m,y)},p=-1,null==e){for(;++p<h;)i(k,t[p],f[p],d[p],g,v,m,y);--p}else t.forEach(k.add);return f=d=t=c=null,k}var a,s=In,l=Rn;return(a=arguments.length)?(s=gr,l=vr,3===a&&(o=n,r=e,n=e=0),i(t)):(i.x=function(t){return arguments.length?(s=t,i):s},i.y=function(t){return arguments.length?(l=t,i):l},i.extent=function(t){return arguments.length?(null==t?e=n=r=o=null:(e=+t[0][0],n=+t[0][1],r=+t[1][0],o=+t[1][1]),i):null==e?null:[[e,n],[r,o]]},i.size=function(t){return arguments.length?(null==t?e=n=r=o=null:(e=n=0,r=+t[0],o=+t[1]),i):null==e?null:[r-e,o-n]},i)},pa.interpolateRgb=xr,pa.interpolateObject=_r,pa.interpolateNumber=wr,pa.interpolateString=Tr;var gl=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,vl=new RegExp(gl.source,"g");pa.interpolate=Cr,pa.interpolators=[function(t,e){var n=typeof e;return("string"===n?ls.has(e.toLowerCase())||/^(#|rgb\(|hsl\()/i.test(e)?xr:Tr:e instanceof ft?xr:Array.isArray(e)?kr:"object"===n&&isNaN(e)?_r:wr)(t,e)}],pa.interpolateArray=kr;var ml=function(){return T},yl=pa.map({linear:ml,poly:Or,quad:function(){return Mr},cubic:function(){return Nr},sin:function(){return Dr},exp:function(){return Ir},circle:function(){return Rr},elastic:Lr,back:Fr,bounce:function(){return jr}}),bl=pa.map({in:T,out:Pr,"in-out":Sr,"out-in":function(t){return Sr(Pr(t))}});pa.ease=function(t){var e=t.indexOf("-"),n=e>=0?t.slice(0,e):t,r=e>=0?t.slice(e+1):"in";return n=yl.get(n)||ml,r=bl.get(r)||T,Er(r(n.apply(null,ha.call(arguments,1))))},pa.interpolateHcl=Br,pa.interpolateHsl=Ur,pa.interpolateLab=Hr,pa.interpolateRound=zr,pa.transform=function(t){var e=va.createElementNS(pa.ns.prefix.svg,"g");return(pa.transform=function(t){if(null!=t){e.setAttribute("transform",t);var n=e.transform.baseVal.consolidate()}return new Wr(n?n.matrix:xl)})(t)},Wr.prototype.toString=function(){return"translate("+this.translate+")rotate("+this.rotate+")skewX("+this.skew+")scale("+this.scale+")"};var xl={a:1,b:0,c:0,d:1,e:0,f:0};pa.interpolateTransform=Jr,pa.layout={},pa.layout.bundle=function(){return function(t){for(var e=[],n=-1,r=t.length;++n<r;)e.push(eo(t[n]));return e}},pa.layout.chord=function(){function t(){var t,u,f,d,p,h={},g=[],v=pa.range(i),m=[];for(n=[],r=[],t=0,d=-1;++d<i;){for(u=0,p=-1;++p<i;)u+=o[d][p];g.push(u),m.push(pa.range(i)),t+=u}for(a&&v.sort(function(t,e){return a(g[t],g[e])}),s&&m.forEach(function(t,e){t.sort(function(t,n){return s(o[e][t],o[e][n])})}),t=(Wa-c*i)/t,u=0,d=-1;++d<i;){for(f=u,p=-1;++p<i;){var y=v[d],b=m[y][p],x=o[y][b],_=u,w=u+=x*t;h[y+"-"+b]={index:y,subindex:b,startAngle:_,endAngle:w,value:x}}r[y]={index:y,startAngle:f,endAngle:u,value:g[y]},u+=c}for(d=-1;++d<i;)for(p=d-1;++p<i;){var T=h[d+"-"+p],C=h[p+"-"+d];(T.value||C.value)&&n.push(T.value<C.value?{source:C,target:T}:{source:T,target:C})}l&&e()}function e(){n.sort(function(t,e){return l((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}var n,r,o,i,a,s,l,u={},c=0;return u.matrix=function(t){return arguments.length?(i=(o=t)&&o.length,n=r=null,u):o},u.padding=function(t){return arguments.length?(c=t,n=r=null,u):c},u.sortGroups=function(t){return arguments.length?(a=t,n=r=null,u):a},u.sortSubgroups=function(t){return arguments.length?(s=t,n=null,u):s},u.sortChords=function(t){return arguments.length?(l=t,n&&e(),u):l},u.chords=function(){return n||t(),n},u.groups=function(){return r||t(),r},u},pa.layout.force=function(){function t(t){return function(e,n,r,o){if(e.point!==t){var i=e.cx-t.x,a=e.cy-t.y,s=o-n,l=i*i+a*a;if(s*s/m<l){if(l<g){var u=e.charge/l;t.px-=i*u,t.py-=a*u}return!0}if(e.point&&l&&l<g){var u=e.pointCharge/l;t.px-=i*u,t.py-=a*u}}return!e.charge}}function e(t){t.px=pa.event.x,t.py=pa.event.y,l.resume()}var n,r,o,i,a,s,l={},u=pa.dispatch("start","tick","end"),c=[1,1],f=.9,d=_l,p=wl,h=-30,g=Tl,v=.1,m=.64,y=[],b=[];return l.tick=function(){if((o*=.99)<.005)return n=null,u.end({type:"end",alpha:o=0}),!0;var e,r,l,d,p,g,m,x,_,w=y.length,T=b.length;for(r=0;r<T;++r)l=b[r],d=l.source,p=l.target,x=p.x-d.x,_=p.y-d.y,(g=x*x+_*_)&&(g=o*a[r]*((g=Math.sqrt(g))-i[r])/g,x*=g,_*=g,p.x-=x*(m=d.weight+p.weight?d.weight/(d.weight+p.weight):.5),p.y-=_*m,d.x+=x*(m=1-m),d.y+=_*m);if((m=o*v)&&(x=c[0]/2,_=c[1]/2,r=-1,m))for(;++r<w;)l=y[r],l.x+=(x-l.x)*m,l.y+=(_-l.y)*m;if(h)for(lo(e=pa.geom.quadtree(y),o,s),r=-1;++r<w;)(l=y[r]).fixed||e.visit(t(l));for(r=-1;++r<w;)l=y[r],l.fixed?(l.x=l.px,l.y=l.py):(l.x-=(l.px-(l.px=l.x))*f,l.y-=(l.py-(l.py=l.y))*f);u.tick({type:"tick",alpha:o})},l.nodes=function(t){return arguments.length?(y=t,l):y},l.links=function(t){return arguments.length?(b=t,l):b},l.size=function(t){return arguments.length?(c=t,l):c},l.linkDistance=function(t){return arguments.length?(d="function"==typeof t?t:+t,l):d},l.distance=l.linkDistance,l.linkStrength=function(t){return arguments.length?(p="function"==typeof t?t:+t,l):p},l.friction=function(t){return arguments.length?(f=+t,l):f},l.charge=function(t){return arguments.length?(h="function"==typeof t?t:+t,l):h},l.chargeDistance=function(t){return arguments.length?(g=t*t,l):Math.sqrt(g)},l.gravity=function(t){return arguments.length?(v=+t,l):v},l.theta=function(t){return arguments.length?(m=t*t,l):Math.sqrt(m)},l.alpha=function(t){return arguments.length?(t=+t,o?t>0?o=t:(n.c=null,n.t=NaN,n=null,u.end({type:"end",alpha:o=0})):t>0&&(u.start({type:"start",alpha:o=t}),n=Lt(l.tick)),l):o},l.start=function(){function t(t,r){if(!n){for(n=new Array(o),l=0;l<o;++l)n[l]=[];for(l=0;l<u;++l){var i=b[l];n[i.source.index].push(i.target),n[i.target.index].push(i.source)}}for(var a,s=n[e],l=-1,c=s.length;++l<c;)if(!isNaN(a=s[l][t]))return a;return Math.random()*r}var e,n,r,o=y.length,u=b.length,f=c[0],g=c[1];for(e=0;e<o;++e)(r=y[e]).index=e,r.weight=0;for(e=0;e<u;++e)r=b[e],"number"==typeof r.source&&(r.source=y[r.source]),"number"==typeof r.target&&(r.target=y[r.target]),++r.source.weight,++r.target.weight;for(e=0;e<o;++e)r=y[e],isNaN(r.x)&&(r.x=t("x",f)),isNaN(r.y)&&(r.y=t("y",g)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],"function"==typeof d)for(e=0;e<u;++e)i[e]=+d.call(this,b[e],e);else for(e=0;e<u;++e)i[e]=d;if(a=[],"function"==typeof p)for(e=0;e<u;++e)a[e]=+p.call(this,b[e],e);else for(e=0;e<u;++e)a[e]=p;if(s=[],"function"==typeof h)for(e=0;e<o;++e)s[e]=+h.call(this,y[e],e);else for(e=0;e<o;++e)s[e]=h;return l.resume()},l.resume=function(){return l.alpha(.1)},l.stop=function(){return l.alpha(0)},l.drag=function(){return r||(r=pa.behavior.drag().origin(T).on("dragstart.force",oo).on("drag.force",e).on("dragend.force",io)),arguments.length?void this.on("mouseover.force",ao).on("mouseout.force",so).call(r):r},pa.rebind(l,u,"on")};var _l=20,wl=1,Tl=1/0;pa.layout.hierarchy=function(){function t(o){var i,a=[o],s=[];for(o.depth=0;null!=(i=a.pop());)if(s.push(i),(u=n.call(t,i,i.depth))&&(l=u.length)){for(var l,u,c;--l>=0;)a.push(c=u[l]),c.parent=i,c.depth=i.depth+1;r&&(i.value=0),i.children=u}else r&&(i.value=+r.call(t,i,i.depth)||0),delete i.children;return fo(o,function(t){var n,o;e&&(n=t.children)&&n.sort(e),r&&(o=t.parent)&&(o.value+=t.value)}),s}var e=go,n=po,r=ho;return t.sort=function(n){return arguments.length?(e=n,t):e},t.children=function(e){return arguments.length?(n=e,t):n},t.value=function(e){return arguments.length?(r=e,t):r},t.revalue=function(e){return r&&(co(e,function(t){t.children&&(t.value=0)}),fo(e,function(e){var n;e.children||(e.value=+r.call(t,e,e.depth)||0),(n=e.parent)&&(n.value+=e.value)})),e},t},pa.layout.partition=function(){function t(e,n,r,o){var i=e.children;if(e.x=n,e.y=e.depth*o,e.dx=r,e.dy=o,i&&(a=i.length)){var a,s,l,u=-1;for(r=e.value?r/e.value:0;++u<a;)t(s=i[u],n,l=s.value*r,o),n+=l}}function e(t){var n=t.children,r=0;if(n&&(o=n.length))for(var o,i=-1;++i<o;)r=Math.max(r,e(n[i]));return 1+r}function n(n,i){var a=r.call(this,n,i);return t(a[0],0,o[0],o[1]/e(a[0])),a}var r=pa.layout.hierarchy(),o=[1,1];return n.size=function(t){return arguments.length?(o=t,n):o},uo(n,r)},pa.layout.pie=function(){function t(a){var s,l=a.length,u=a.map(function(n,r){
return+e.call(t,n,r)}),c=+("function"==typeof r?r.apply(this,arguments):r),f=("function"==typeof o?o.apply(this,arguments):o)-c,d=Math.min(Math.abs(f)/l,+("function"==typeof i?i.apply(this,arguments):i)),p=d*(f<0?-1:1),h=pa.sum(u),g=h?(f-l*p)/h:0,v=pa.range(l),m=[];return null!=n&&v.sort(n===Cl?function(t,e){return u[e]-u[t]}:function(t,e){return n(a[t],a[e])}),v.forEach(function(t){m[t]={data:a[t],value:s=u[t],startAngle:c,endAngle:c+=s*g+p,padAngle:d}}),m}var e=Number,n=Cl,r=0,o=Wa,i=0;return t.value=function(n){return arguments.length?(e=n,t):e},t.sort=function(e){return arguments.length?(n=e,t):n},t.startAngle=function(e){return arguments.length?(r=e,t):r},t.endAngle=function(e){return arguments.length?(o=e,t):o},t.padAngle=function(e){return arguments.length?(i=e,t):i},t};var Cl={};pa.layout.stack=function(){function t(s,l){if(!(d=s.length))return s;var u=s.map(function(n,r){return e.call(t,n,r)}),c=u.map(function(e){return e.map(function(e,n){return[i.call(t,e,n),a.call(t,e,n)]})}),f=n.call(t,c,l);u=pa.permute(u,f),c=pa.permute(c,f);var d,p,h,g,v=r.call(t,c,l),m=u[0].length;for(h=0;h<m;++h)for(o.call(t,u[0][h],g=v[h],c[0][h][1]),p=1;p<d;++p)o.call(t,u[p][h],g+=c[p-1][h][1],c[p][h][1]);return s}var e=T,n=xo,r=_o,o=bo,i=mo,a=yo;return t.values=function(n){return arguments.length?(e=n,t):e},t.order=function(e){return arguments.length?(n="function"==typeof e?e:kl.get(e)||xo,t):n},t.offset=function(e){return arguments.length?(r="function"==typeof e?e:El.get(e)||_o,t):r},t.x=function(e){return arguments.length?(i=e,t):i},t.y=function(e){return arguments.length?(a=e,t):a},t.out=function(e){return arguments.length?(o=e,t):o},t};var kl=pa.map({"inside-out":function(t){var e,n,r=t.length,o=t.map(wo),i=t.map(To),a=pa.range(r).sort(function(t,e){return o[t]-o[e]}),s=0,l=0,u=[],c=[];for(e=0;e<r;++e)n=a[e],s<l?(s+=i[n],u.push(n)):(l+=i[n],c.push(n));return c.reverse().concat(u)},reverse:function(t){return pa.range(t.length).reverse()},default:xo}),El=pa.map({silhouette:function(t){var e,n,r,o=t.length,i=t[0].length,a=[],s=0,l=[];for(n=0;n<i;++n){for(e=0,r=0;e<o;e++)r+=t[e][n][1];r>s&&(s=r),a.push(r)}for(n=0;n<i;++n)l[n]=(s-a[n])/2;return l},wiggle:function(t){var e,n,r,o,i,a,s,l,u,c=t.length,f=t[0],d=f.length,p=[];for(p[0]=l=u=0,n=1;n<d;++n){for(e=0,o=0;e<c;++e)o+=t[e][n][1];for(e=0,i=0,s=f[n][0]-f[n-1][0];e<c;++e){for(r=0,a=(t[e][n][1]-t[e][n-1][1])/(2*s);r<e;++r)a+=(t[r][n][1]-t[r][n-1][1])/s;i+=a*t[e][n][1]}p[n]=l-=o?i/o*s:0,l<u&&(u=l)}for(n=0;n<d;++n)p[n]-=u;return p},expand:function(t){var e,n,r,o=t.length,i=t[0].length,a=1/o,s=[];for(n=0;n<i;++n){for(e=0,r=0;e<o;e++)r+=t[e][n][1];if(r)for(e=0;e<o;e++)t[e][n][1]/=r;else for(e=0;e<o;e++)t[e][n][1]=a}for(n=0;n<i;++n)s[n]=0;return s},zero:_o});pa.layout.histogram=function(){function t(t,i){for(var a,s,l=[],u=t.map(n,this),c=r.call(this,u,i),f=o.call(this,c,u,i),i=-1,d=u.length,p=f.length-1,h=e?1:1/d;++i<p;)a=l[i]=[],a.dx=f[i+1]-(a.x=f[i]),a.y=0;if(p>0)for(i=-1;++i<d;)s=u[i],s>=c[0]&&s<=c[1]&&(a=l[pa.bisect(f,s,1,p)-1],a.y+=h,a.push(t[i]));return l}var e=!0,n=Number,r=Po,o=ko;return t.value=function(e){return arguments.length?(n=e,t):n},t.range=function(e){return arguments.length?(r=At(e),t):r},t.bins=function(e){return arguments.length?(o="number"==typeof e?function(t){return Eo(t,e)}:At(e),t):o},t.frequency=function(n){return arguments.length?(e=!!n,t):e},t},pa.layout.pack=function(){function t(t,i){var a=n.call(this,t,i),s=a[0],l=o[0],u=o[1],c=null==e?Math.sqrt:"function"==typeof e?e:function(){return e};if(s.x=s.y=0,fo(s,function(t){t.r=+c(t.value)}),fo(s,Oo),r){var f=r*(e?1:Math.max(2*s.r/l,2*s.r/u))/2;fo(s,function(t){t.r+=f}),fo(s,Oo),fo(s,function(t){t.r-=f})}return Ro(s,l/2,u/2,e?1:1/Math.max(2*s.r/l,2*s.r/u)),a}var e,n=pa.layout.hierarchy().sort(So),r=0,o=[1,1];return t.size=function(e){return arguments.length?(o=e,t):o},t.radius=function(n){return arguments.length?(e=null==n||"function"==typeof n?n:+n,t):e},t.padding=function(e){return arguments.length?(r=+e,t):r},uo(t,n)},pa.layout.tree=function(){function t(t,o){var c=a.call(this,t,o),f=c[0],d=e(f);if(fo(d,n),d.parent.m=-d.z,co(d,r),u)co(f,i);else{var p=f,h=f,g=f;co(f,function(t){t.x<p.x&&(p=t),t.x>h.x&&(h=t),t.depth>g.depth&&(g=t)});var v=s(p,h)/2-p.x,m=l[0]/(h.x+s(h,p)/2+v),y=l[1]/(g.depth||1);co(f,function(t){t.x=(t.x+v)*m,t.y=t.depth*y})}return c}function e(t){for(var e,n={A:null,children:[t]},r=[n];null!=(e=r.pop());)for(var o,i=e.children,a=0,s=i.length;a<s;++a)r.push((i[a]=o={_:i[a],parent:e,children:(o=i[a].children)&&o.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:a}).a=o);return n.children[0]}function n(t){var e=t.children,n=t.parent.children,r=t.i?n[t.i-1]:null;if(e.length){Ho(t);var i=(e[0].z+e[e.length-1].z)/2;r?(t.z=r.z+s(t._,r._),t.m=t.z-i):t.z=i}else r&&(t.z=r.z+s(t._,r._));t.parent.A=o(t,r,t.parent.A||n[0])}function r(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function o(t,e,n){if(e){for(var r,o=t,i=t,a=e,l=o.parent.children[0],u=o.m,c=i.m,f=a.m,d=l.m;a=Bo(a),o=jo(o),a&&o;)l=jo(l),i=Bo(i),i.a=t,r=a.z+f-o.z-u+s(a._,o._),r>0&&(Uo(zo(a,t,n),t,r),u+=r,c+=r),f+=a.m,u+=o.m,d+=l.m,c+=i.m;a&&!Bo(i)&&(i.t=a,i.m+=f-c),o&&!jo(l)&&(l.t=o,l.m+=u-d,n=t)}return n}function i(t){t.x*=l[0],t.y=t.depth*l[1]}var a=pa.layout.hierarchy().sort(null).value(null),s=Fo,l=[1,1],u=null;return t.separation=function(e){return arguments.length?(s=e,t):s},t.size=function(e){return arguments.length?(u=null==(l=e)?i:null,t):u?null:l},t.nodeSize=function(e){return arguments.length?(u=null==(l=e)?null:i,t):u?l:null},uo(t,a)},pa.layout.cluster=function(){function t(t,i){var a,s=e.call(this,t,i),l=s[0],u=0;fo(l,function(t){var e=t.children;e&&e.length?(t.x=qo(e),t.y=Wo(e)):(t.x=a?u+=n(t,a):0,t.y=0,a=t)});var c=Vo(l),f=Ko(l),d=c.x-n(c,f)/2,p=f.x+n(f,c)/2;return fo(l,o?function(t){t.x=(t.x-l.x)*r[0],t.y=(l.y-t.y)*r[1]}:function(t){t.x=(t.x-d)/(p-d)*r[0],t.y=(1-(l.y?t.y/l.y:1))*r[1]}),s}var e=pa.layout.hierarchy().sort(null).value(null),n=Fo,r=[1,1],o=!1;return t.separation=function(e){return arguments.length?(n=e,t):n},t.size=function(e){return arguments.length?(o=null==(r=e),t):o?null:r},t.nodeSize=function(e){return arguments.length?(o=null!=(r=e),t):o?r:null},uo(t,e)},pa.layout.treemap=function(){function t(t,e){for(var n,r,o=-1,i=t.length;++o<i;)r=(n=t[o]).value*(e<0?0:e),n.area=isNaN(r)||r<=0?0:r}function e(n){var i=n.children;if(i&&i.length){var a,s,l,u=f(n),c=[],d=i.slice(),h=1/0,g="slice"===p?u.dx:"dice"===p?u.dy:"slice-dice"===p?1&n.depth?u.dy:u.dx:Math.min(u.dx,u.dy);for(t(d,u.dx*u.dy/n.value),c.area=0;(l=d.length)>0;)c.push(a=d[l-1]),c.area+=a.area,"squarify"!==p||(s=r(c,g))<=h?(d.pop(),h=s):(c.area-=c.pop().area,o(c,g,u,!1),g=Math.min(u.dx,u.dy),c.length=c.area=0,h=1/0);c.length&&(o(c,g,u,!0),c.length=c.area=0),i.forEach(e)}}function n(e){var r=e.children;if(r&&r.length){var i,a=f(e),s=r.slice(),l=[];for(t(s,a.dx*a.dy/e.value),l.area=0;i=s.pop();)l.push(i),l.area+=i.area,null!=i.z&&(o(l,i.z?a.dx:a.dy,a,!s.length),l.length=l.area=0);r.forEach(n)}}function r(t,e){for(var n,r=t.area,o=0,i=1/0,a=-1,s=t.length;++a<s;)(n=t[a].area)&&(n<i&&(i=n),n>o&&(o=n));return r*=r,e*=e,r?Math.max(e*o*h/r,r/(e*i*h)):1/0}function o(t,e,n,r){var o,i=-1,a=t.length,s=n.x,u=n.y,c=e?l(t.area/e):0;if(e==n.dx){for((r||c>n.dy)&&(c=n.dy);++i<a;)o=t[i],o.x=s,o.y=u,o.dy=c,s+=o.dx=Math.min(n.x+n.dx-s,c?l(o.area/c):0);o.z=!0,o.dx+=n.x+n.dx-s,n.y+=c,n.dy-=c}else{for((r||c>n.dx)&&(c=n.dx);++i<a;)o=t[i],o.x=s,o.y=u,o.dx=c,u+=o.dy=Math.min(n.y+n.dy-u,c?l(o.area/c):0);o.z=!1,o.dy+=n.y+n.dy-u,n.x+=c,n.dx-=c}}function i(r){var o=a||s(r),i=o[0];return i.x=i.y=0,i.value?(i.dx=u[0],i.dy=u[1]):i.dx=i.dy=0,a&&s.revalue(i),t([i],i.dx*i.dy/i.value),(a?n:e)(i),d&&(a=o),o}var a,s=pa.layout.hierarchy(),l=Math.round,u=[1,1],c=null,f=Yo,d=!1,p="squarify",h=.5*(1+Math.sqrt(5));return i.size=function(t){return arguments.length?(u=t,i):u},i.padding=function(t){function e(e){var n=t.call(i,e,e.depth);return null==n?Yo(e):Go(e,"number"==typeof n?[n,n,n,n]:n)}function n(e){return Go(e,t)}if(!arguments.length)return c;var r;return f=null==(c=t)?Yo:"function"==(r=typeof t)?e:"number"===r?(t=[t,t,t,t],n):n,i},i.round=function(t){return arguments.length?(l=t?Math.round:Number,i):l!=Number},i.sticky=function(t){return arguments.length?(d=t,a=null,i):d},i.ratio=function(t){return arguments.length?(h=t,i):h},i.mode=function(t){return arguments.length?(p=t+"",i):p},uo(i,s)},pa.random={normal:function(t,e){var n=arguments.length;return n<2&&(e=1),n<1&&(t=0),function(){var n,r,o;do n=2*Math.random()-1,r=2*Math.random()-1,o=n*n+r*r;while(!o||o>1);return t+e*n*Math.sqrt(-2*Math.log(o)/o)}},logNormal:function(){var t=pa.random.normal.apply(pa,arguments);return function(){return Math.exp(t())}},bates:function(t){var e=pa.random.irwinHall(t);return function(){return e()/t}},irwinHall:function(t){return function(){for(var e=0,n=0;n<t;n++)e+=Math.random();return e}}},pa.scale={};var Pl={floor:T,ceil:T};pa.scale.linear=function(){return ei([0,1],[0,1],Cr,!1)};var Sl={s:1,g:1,p:1,r:1,e:1};pa.scale.log=function(){return ui(pa.scale.linear().domain([0,1]),10,!0,[1,10])};var Ml=pa.format(".0e"),Nl={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};pa.scale.pow=function(){return ci(pa.scale.linear(),1,[0,1])},pa.scale.sqrt=function(){return pa.scale.pow().exponent(.5)},pa.scale.ordinal=function(){return di([],{t:"range",a:[[]]})},pa.scale.category10=function(){return pa.scale.ordinal().range(Al)},pa.scale.category20=function(){return pa.scale.ordinal().range(Ol)},pa.scale.category20b=function(){return pa.scale.ordinal().range(Dl)},pa.scale.category20c=function(){return pa.scale.ordinal().range(Il)};var Al=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(Ct),Ol=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(Ct),Dl=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(Ct),Il=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(Ct);pa.scale.quantile=function(){return pi([],[])},pa.scale.quantize=function(){return hi(0,1,[0,1])},pa.scale.threshold=function(){return gi([.5],[0,1])},pa.scale.identity=function(){return vi([0,1])},pa.svg={},pa.svg.arc=function(){function t(){var t=Math.max(0,+n.apply(this,arguments)),u=Math.max(0,+r.apply(this,arguments)),c=a.apply(this,arguments)-Va,f=s.apply(this,arguments)-Va,d=Math.abs(f-c),p=c>f?0:1;if(u<t&&(h=u,u=t,t=h),d>=qa)return e(u,p)+(t?e(t,1-p):"")+"Z";var h,g,v,m,y,b,x,_,w,T,C,k,E=0,P=0,S=[];if((m=(+l.apply(this,arguments)||0)/2)&&(v=i===Rl?Math.sqrt(t*t+u*u):+i.apply(this,arguments),p||(P*=-1),u&&(P=at(v/u*Math.sin(m))),t&&(E=at(v/t*Math.sin(m)))),u){y=u*Math.cos(c+P),b=u*Math.sin(c+P),x=u*Math.cos(f-P),_=u*Math.sin(f-P);var M=Math.abs(f-c-2*P)<=za?0:1;if(P&&Ti(y,b,x,_)===p^M){var N=(c+f)/2;y=u*Math.cos(N),b=u*Math.sin(N),x=_=null}}else y=b=0;if(t){w=t*Math.cos(f-E),T=t*Math.sin(f-E),C=t*Math.cos(c+E),k=t*Math.sin(c+E);var A=Math.abs(c-f+2*E)<=za?0:1;if(E&&Ti(w,T,C,k)===1-p^A){var O=(c+f)/2;w=t*Math.cos(O),T=t*Math.sin(O),C=k=null}}else w=T=0;if(d>Ua&&(h=Math.min(Math.abs(u-t)/2,+o.apply(this,arguments)))>.001){g=t<u^p?0:1;var D=h,I=h;if(d<za){var R=null==C?[w,T]:null==x?[y,b]:Bn([y,b],[C,k],[x,_],[w,T]),L=y-R[0],F=b-R[1],j=x-R[0],B=_-R[1],U=1/Math.sin(Math.acos((L*j+F*B)/(Math.sqrt(L*L+F*F)*Math.sqrt(j*j+B*B)))/2),H=Math.sqrt(R[0]*R[0]+R[1]*R[1]);I=Math.min(h,(t-H)/(U-1)),D=Math.min(h,(u-H)/(U+1))}if(null!=x){var z=Ci(null==C?[w,T]:[C,k],[y,b],u,D,p),W=Ci([x,_],[w,T],u,D,p);h===D?S.push("M",z[0],"A",D,",",D," 0 0,",g," ",z[1],"A",u,",",u," 0 ",1-p^Ti(z[1][0],z[1][1],W[1][0],W[1][1]),",",p," ",W[1],"A",D,",",D," 0 0,",g," ",W[0]):S.push("M",z[0],"A",D,",",D," 0 1,",g," ",W[0])}else S.push("M",y,",",b);if(null!=C){var q=Ci([y,b],[C,k],t,-I,p),V=Ci([w,T],null==x?[y,b]:[x,_],t,-I,p);h===I?S.push("L",V[0],"A",I,",",I," 0 0,",g," ",V[1],"A",t,",",t," 0 ",p^Ti(V[1][0],V[1][1],q[1][0],q[1][1]),",",1-p," ",q[1],"A",I,",",I," 0 0,",g," ",q[0]):S.push("L",V[0],"A",I,",",I," 0 0,",g," ",q[0])}else S.push("L",w,",",T)}else S.push("M",y,",",b),null!=x&&S.push("A",u,",",u," 0 ",M,",",p," ",x,",",_),S.push("L",w,",",T),null!=C&&S.push("A",t,",",t," 0 ",A,",",1-p," ",C,",",k);return S.push("Z"),S.join("")}function e(t,e){return"M0,"+t+"A"+t+","+t+" 0 1,"+e+" 0,"+-t+"A"+t+","+t+" 0 1,"+e+" 0,"+t}var n=yi,r=bi,o=mi,i=Rl,a=xi,s=_i,l=wi;return t.innerRadius=function(e){return arguments.length?(n=At(e),t):n},t.outerRadius=function(e){return arguments.length?(r=At(e),t):r},t.cornerRadius=function(e){return arguments.length?(o=At(e),t):o},t.padRadius=function(e){return arguments.length?(i=e==Rl?Rl:At(e),t):i},t.startAngle=function(e){return arguments.length?(a=At(e),t):a},t.endAngle=function(e){return arguments.length?(s=At(e),t):s},t.padAngle=function(e){return arguments.length?(l=At(e),t):l},t.centroid=function(){var t=(+n.apply(this,arguments)+ +r.apply(this,arguments))/2,e=(+a.apply(this,arguments)+ +s.apply(this,arguments))/2-Va;return[Math.cos(e)*t,Math.sin(e)*t]},t};var Rl="auto";pa.svg.line=function(){return ki(T)};var Ll=pa.map({linear:Ei,"linear-closed":Pi,step:Si,"step-before":Mi,"step-after":Ni,basis:Li,"basis-open":Fi,"basis-closed":ji,bundle:Bi,cardinal:Di,"cardinal-open":Ai,"cardinal-closed":Oi,monotone:Vi});Ll.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Fl=[0,2/3,1/3,0],jl=[0,1/3,2/3,0],Bl=[0,1/6,2/3,1/6];pa.svg.line.radial=function(){var t=ki(Ki);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Mi.reverse=Ni,Ni.reverse=Mi,pa.svg.area=function(){return Yi(T)},pa.svg.area.radial=function(){var t=Yi(Ki);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},pa.svg.chord=function(){function t(t,s){var l=e(this,i,t,s),u=e(this,a,t,s);return"M"+l.p0+r(l.r,l.p1,l.a1-l.a0)+(n(l,u)?o(l.r,l.p1,l.r,l.p0):o(l.r,l.p1,u.r,u.p0)+r(u.r,u.p1,u.a1-u.a0)+o(u.r,u.p1,l.r,l.p0))+"Z"}function e(t,e,n,r){var o=e.call(t,n,r),i=s.call(t,o,r),a=l.call(t,o,r)-Va,c=u.call(t,o,r)-Va;return{r:i,a0:a,a1:c,p0:[i*Math.cos(a),i*Math.sin(a)],p1:[i*Math.cos(c),i*Math.sin(c)]}}function n(t,e){return t.a0==e.a0&&t.a1==e.a1}function r(t,e,n){return"A"+t+","+t+" 0 "+ +(n>za)+",1 "+e}function o(t,e,n,r){return"Q 0,0 "+r}var i=Cn,a=kn,s=Gi,l=xi,u=_i;return t.radius=function(e){return arguments.length?(s=At(e),t):s},t.source=function(e){return arguments.length?(i=At(e),t):i},t.target=function(e){return arguments.length?(a=At(e),t):a},t.startAngle=function(e){return arguments.length?(l=At(e),t):l},t.endAngle=function(e){return arguments.length?(u=At(e),t):u},t},pa.svg.diagonal=function(){function t(t,o){var i=e.call(this,t,o),a=n.call(this,t,o),s=(i.y+a.y)/2,l=[i,{x:i.x,y:s},{x:a.x,y:s},a];return l=l.map(r),"M"+l[0]+"C"+l[1]+" "+l[2]+" "+l[3]}var e=Cn,n=kn,r=Xi;return t.source=function(n){return arguments.length?(e=At(n),t):e},t.target=function(e){return arguments.length?(n=At(e),t):n},t.projection=function(e){return arguments.length?(r=e,t):r},t},pa.svg.diagonal.radial=function(){var t=pa.svg.diagonal(),e=Xi,n=t.projection;return t.projection=function(t){return arguments.length?n($i(e=t)):e},t},pa.svg.symbol=function(){function t(t,r){return(Ul.get(e.call(this,t,r))||Qi)(n.call(this,t,r))}var e=Ji,n=Zi;return t.type=function(n){return arguments.length?(e=At(n),t):e},t.size=function(e){return arguments.length?(n=At(e),t):n},t};var Ul=pa.map({circle:Qi,cross:function(t){var e=Math.sqrt(t/5)/2;return"M"+-3*e+","+-e+"H"+-e+"V"+-3*e+"H"+e+"V"+-e+"H"+3*e+"V"+e+"H"+e+"V"+3*e+"H"+-e+"V"+e+"H"+-3*e+"Z"},diamond:function(t){var e=Math.sqrt(t/(2*zl)),n=e*zl;return"M0,"+-e+"L"+n+",0 0,"+e+" "+-n+",0Z"},square:function(t){var e=Math.sqrt(t)/2;return"M"+-e+","+-e+"L"+e+","+-e+" "+e+","+e+" "+-e+","+e+"Z"},"triangle-down":function(t){var e=Math.sqrt(t/Hl),n=e*Hl/2;return"M0,"+n+"L"+e+","+-n+" "+-e+","+-n+"Z"},"triangle-up":function(t){var e=Math.sqrt(t/Hl),n=e*Hl/2;return"M0,"+-n+"L"+e+","+n+" "+-e+","+n+"Z"}});pa.svg.symbolTypes=Ul.keys();var Hl=Math.sqrt(3),zl=Math.tan(30*Ka);Oa.transition=function(t){for(var e,n,r=Wl||++Yl,o=oa(t),i=[],a=ql||{time:Date.now(),ease:Ar,delay:0,duration:250},s=-1,l=this.length;++s<l;){i.push(e=[]);for(var u=this[s],c=-1,f=u.length;++c<f;)(n=u[c])&&ia(n,c,o,r,a),e.push(n)}return ea(i,o,r)},Oa.interrupt=function(t){return this.each(null==t?Vl:ta(oa(t)))};var Wl,ql,Vl=ta(oa()),Kl=[],Yl=0;Kl.call=Oa.call,Kl.empty=Oa.empty,Kl.node=Oa.node,Kl.size=Oa.size,pa.transition=function(t,e){return t&&t.transition?Wl?t.transition(e):t:pa.selection().transition(t)},pa.transition.prototype=Kl,Kl.select=function(t){var e,n,r,o=this.id,i=this.namespace,a=[];t=D(t);for(var s=-1,l=this.length;++s<l;){a.push(e=[]);for(var u=this[s],c=-1,f=u.length;++c<f;)(r=u[c])&&(n=t.call(r,r.__data__,c,s))?("__data__"in r&&(n.__data__=r.__data__),ia(n,c,i,o,r[i][o]),e.push(n)):e.push(null)}return ea(a,i,o)},Kl.selectAll=function(t){var e,n,r,o,i,a=this.id,s=this.namespace,l=[];t=I(t);for(var u=-1,c=this.length;++u<c;)for(var f=this[u],d=-1,p=f.length;++d<p;)if(r=f[d]){i=r[s][a],n=t.call(r,r.__data__,d,u),l.push(e=[]);for(var h=-1,g=n.length;++h<g;)(o=n[h])&&ia(o,h,s,a,i),e.push(o)}return ea(l,s,a)},Kl.filter=function(t){var e,n,r,o=[];"function"!=typeof t&&(t=K(t));for(var i=0,a=this.length;i<a;i++){o.push(e=[]);for(var n=this[i],s=0,l=n.length;s<l;s++)(r=n[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ea(o,this.namespace,this.id)},Kl.tween=function(t,e){var n=this.id,r=this.namespace;return arguments.length<2?this.node()[r][n].tween.get(t):G(this,null==e?function(e){e[r][n].tween.remove(t)}:function(o){o[r][n].tween.set(t,e)})},Kl.attr=function(t,e){function n(){this.removeAttribute(s)}function r(){this.removeAttributeNS(s.space,s.local)}function o(t){return null==t?n:(t+="",function(){var e,n=this.getAttribute(s);return n!==t&&(e=a(n,t),function(t){this.setAttribute(s,e(t))})})}function i(t){return null==t?r:(t+="",function(){var e,n=this.getAttributeNS(s.space,s.local);return n!==t&&(e=a(n,t),function(t){this.setAttributeNS(s.space,s.local,e(t))})})}if(arguments.length<2){for(e in t)this.attr(e,t[e]);return this}var a="transform"==t?Jr:Cr,s=pa.ns.qualify(t);return na(this,"attr."+t,e,s.local?i:o)},Kl.attrTween=function(t,e){function n(t,n){var r=e.call(this,t,n,this.getAttribute(o));return r&&function(t){this.setAttribute(o,r(t))}}function r(t,n){var r=e.call(this,t,n,this.getAttributeNS(o.space,o.local));return r&&function(t){this.setAttributeNS(o.space,o.local,r(t))}}var o=pa.ns.qualify(t);return this.tween("attr."+t,o.local?r:n)},Kl.style=function(t,e,n){function r(){this.style.removeProperty(t)}function o(e){return null==e?r:(e+="",function(){var r,o=a(this).getComputedStyle(this,null).getPropertyValue(t);return o!==e&&(r=Cr(o,e),function(e){this.style.setProperty(t,r(e),n)})})}var i=arguments.length;if(i<3){if("string"!=typeof t){i<2&&(e="");for(n in t)this.style(n,t[n],e);return this}n=""}return na(this,"style."+t,e,o)},Kl.styleTween=function(t,e,n){function r(r,o){var i=e.call(this,r,o,a(this).getComputedStyle(this,null).getPropertyValue(t));return i&&function(e){this.style.setProperty(t,i(e),n)}}return arguments.length<3&&(n=""),this.tween("style."+t,r)},Kl.text=function(t){return na(this,"text",t,ra)},Kl.remove=function(){var t=this.namespace;return this.each("end.transition",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},Kl.ease=function(t){var e=this.id,n=this.namespace;return arguments.length<1?this.node()[n][e].ease:("function"!=typeof t&&(t=pa.ease.apply(pa,arguments)),G(this,function(r){r[n][e].ease=t}))},Kl.delay=function(t){var e=this.id,n=this.namespace;return arguments.length<1?this.node()[n][e].delay:G(this,"function"==typeof t?function(r,o,i){r[n][e].delay=+t.call(r,r.__data__,o,i)}:(t=+t,function(r){r[n][e].delay=t}))},Kl.duration=function(t){var e=this.id,n=this.namespace;return arguments.length<1?this.node()[n][e].duration:G(this,"function"==typeof t?function(r,o,i){r[n][e].duration=Math.max(1,t.call(r,r.__data__,o,i))}:(t=Math.max(1,t),function(r){r[n][e].duration=t}))},Kl.each=function(t,e){var n=this.id,r=this.namespace;if(arguments.length<2){var o=ql,i=Wl;try{Wl=n,G(this,function(e,o,i){ql=e[r][n],t.call(e,e.__data__,o,i)})}finally{ql=o,Wl=i}}else G(this,function(o){var i=o[r][n];(i.event||(i.event=pa.dispatch("start","end","interrupt"))).on(t,e)});return this},Kl.transition=function(){for(var t,e,n,r,o=this.id,i=++Yl,a=this.namespace,s=[],l=0,u=this.length;l<u;l++){s.push(t=[]);for(var e=this[l],c=0,f=e.length;c<f;c++)(n=e[c])&&(r=n[a][o],ia(n,c,a,i,{time:r.time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration})),t.push(n)}return ea(s,a,i)},pa.svg.axis=function(){function t(t){t.each(function(){var t,u=pa.select(this),c=this.__chart__||n,f=this.__chart__=n.copy(),d=null==l?f.ticks?f.ticks.apply(f,s):f.domain():l,p=null==e?f.tickFormat?f.tickFormat.apply(f,s):T:e,h=u.selectAll(".tick").data(d,f),g=h.enter().insert("g",".domain").attr("class","tick").style("opacity",Ua),v=pa.transition(h.exit()).style("opacity",Ua).remove(),m=pa.transition(h.order()).style("opacity",1),y=Math.max(o,0)+a,b=$o(f),x=u.selectAll(".domain").data([0]),_=(x.enter().append("path").attr("class","domain"),pa.transition(x));g.append("line"),g.append("text");var w,C,k,E,P=g.select("line"),S=m.select("line"),M=h.select("text").text(p),N=g.select("text"),A=m.select("text"),O="top"===r||"left"===r?-1:1;if("bottom"===r||"top"===r?(t=aa,w="x",k="y",C="x2",E="y2",M.attr("dy",O<0?"0em":".71em").style("text-anchor","middle"),_.attr("d","M"+b[0]+","+O*i+"V0H"+b[1]+"V"+O*i)):(t=sa,w="y",k="x",C="y2",E="x2",M.attr("dy",".32em").style("text-anchor",O<0?"end":"start"),_.attr("d","M"+O*i+","+b[0]+"H0V"+b[1]+"H"+O*i)),P.attr(E,O*o),N.attr(k,O*y),S.attr(C,0).attr(E,O*o),A.attr(w,0).attr(k,O*y),f.rangeBand){var D=f,I=D.rangeBand()/2;c=f=function(t){return D(t)+I}}else c.rangeBand?c=f:v.call(t,f,c);g.call(t,c,f),m.call(t,f,f)})}var e,n=pa.scale.linear(),r=Gl,o=6,i=6,a=3,s=[10],l=null;return t.scale=function(e){return arguments.length?(n=e,t):n},t.orient=function(e){return arguments.length?(r=e in Xl?e+"":Gl,t):r},t.ticks=function(){return arguments.length?(s=ga(arguments),t):s},t.tickValues=function(e){return arguments.length?(l=e,t):l},t.tickFormat=function(n){return arguments.length?(e=n,t):e},t.tickSize=function(e){var n=arguments.length;return n?(o=+e,i=+arguments[n-1],t):o},t.innerTickSize=function(e){return arguments.length?(o=+e,t):o},t.outerTickSize=function(e){return arguments.length?(i=+e,t):i},t.tickPadding=function(e){return arguments.length?(a=+e,t):a},t.tickSubdivide=function(){return arguments.length&&t},t};var Gl="bottom",Xl={top:1,right:1,bottom:1,left:1};pa.svg.brush=function(){function t(i){i.each(function(){var i=pa.select(this).style("pointer-events","all").style("-webkit-tap-highlight-color","rgba(0,0,0,0)").on("mousedown.brush",o).on("touchstart.brush",o),a=i.selectAll(".background").data([0]);a.enter().append("rect").attr("class","background").style("visibility","hidden").style("cursor","crosshair"),i.selectAll(".extent").data([0]).enter().append("rect").attr("class","extent").style("cursor","move");var s=i.selectAll(".resize").data(g,T);s.exit().remove(),s.enter().append("g").attr("class",function(t){return"resize "+t}).style("cursor",function(t){return $l[t]}).append("rect").attr("x",function(t){return/[ew]$/.test(t)?-3:null}).attr("y",function(t){return/^[ns]/.test(t)?-3:null}).attr("width",6).attr("height",6).style("visibility","hidden"),s.style("display",t.empty()?"none":null);var l,f=pa.transition(i),d=pa.transition(a);u&&(l=$o(u),d.attr("x",l[0]).attr("width",l[1]-l[0]),n(f)),c&&(l=$o(c),d.attr("y",l[0]).attr("height",l[1]-l[0]),r(f)),e(f)})}function e(t){t.selectAll(".resize").attr("transform",function(t){return"translate("+f[+/e$/.test(t)]+","+d[+/^s/.test(t)]+")"})}function n(t){t.select(".extent").attr("x",f[0]),t.selectAll(".extent,.n>rect,.s>rect").attr("width",f[1]-f[0])}function r(t){t.select(".extent").attr("y",d[0]),t.selectAll(".extent,.e>rect,.w>rect").attr("height",d[1]-d[0])}function o(){function o(){32==pa.event.keyCode&&(S||(b=null,A[0]-=f[1],A[1]-=d[1],S=2),M())}function g(){32==pa.event.keyCode&&2==S&&(A[0]+=f[1],A[1]+=d[1],S=0,M())}function v(){var t=pa.mouse(_),o=!1;x&&(t[0]+=x[0],t[1]+=x[1]),S||(pa.event.altKey?(b||(b=[(f[0]+f[1])/2,(d[0]+d[1])/2]),A[0]=f[+(t[0]<b[0])],A[1]=d[+(t[1]<b[1])]):b=null),E&&m(t,u,0)&&(n(C),o=!0),P&&m(t,c,1)&&(r(C),o=!0),o&&(e(C),T({type:"brush",mode:S?"move":"resize"}))}function m(t,e,n){var r,o,a=$o(e),l=a[0],u=a[1],c=A[n],g=n?d:f,v=g[1]-g[0];if(S&&(l-=c,u-=v+c),r=(n?h:p)?Math.max(l,Math.min(u,t[n])):t[n],S?o=(r+=c)+v:(b&&(c=Math.max(l,Math.min(u,2*b[n]-r))),c<r?(o=r,r=c):o=c),g[0]!=r||g[1]!=o)return n?s=null:i=null,g[0]=r,g[1]=o,!0}function y(){v(),C.style("pointer-events","all").selectAll(".resize").style("display",t.empty()?"none":null),pa.select("body").style("cursor",null),O.on("mousemove.brush",null).on("mouseup.brush",null).on("touchmove.brush",null).on("touchend.brush",null).on("keydown.brush",null).on("keyup.brush",null),N(),T({type:"brushend"})}var b,x,_=this,w=pa.select(pa.event.target),T=l.of(_,arguments),C=pa.select(_),k=w.datum(),E=!/^(n|s)$/.test(k)&&u,P=!/^(e|w)$/.test(k)&&c,S=w.classed("extent"),N=tt(_),A=pa.mouse(_),O=pa.select(a(_)).on("keydown.brush",o).on("keyup.brush",g);if(pa.event.changedTouches?O.on("touchmove.brush",v).on("touchend.brush",y):O.on("mousemove.brush",v).on("mouseup.brush",y),C.interrupt().selectAll("*").interrupt(),S)A[0]=f[0]-A[0],A[1]=d[0]-A[1];else if(k){var D=+/w$/.test(k),I=+/^n/.test(k);x=[f[1-D]-A[0],d[1-I]-A[1]],A[0]=f[D],A[1]=d[I]}else pa.event.altKey&&(b=A.slice());C.style("pointer-events","none").selectAll(".resize").style("display",null),pa.select("body").style("cursor",w.style("cursor")),T({type:"brushstart"}),v()}var i,s,l=A(t,"brushstart","brush","brushend"),u=null,c=null,f=[0,0],d=[0,0],p=!0,h=!0,g=Zl[0];return t.event=function(t){t.each(function(){var t=l.of(this,arguments),e={x:f,y:d,i:i,j:s},n=this.__chart__||e;this.__chart__=e,Wl?pa.select(this).transition().each("start.brush",function(){i=n.i,s=n.j,f=n.x,d=n.y,t({type:"brushstart"})}).tween("brush:brush",function(){var n=kr(f,e.x),r=kr(d,e.y);return i=s=null,function(o){f=e.x=n(o),d=e.y=r(o),t({type:"brush",mode:"resize"})}}).each("end.brush",function(){i=e.i,s=e.j,t({type:"brush",mode:"resize"}),t({type:"brushend"})}):(t({type:"brushstart"}),t({type:"brush",mode:"resize"}),t({type:"brushend"}))})},t.x=function(e){return arguments.length?(u=e,g=Zl[!u<<1|!c],t):u},t.y=function(e){return arguments.length?(c=e,g=Zl[!u<<1|!c],t):c},t.clamp=function(e){return arguments.length?(u&&c?(p=!!e[0],h=!!e[1]):u?p=!!e:c&&(h=!!e),t):u&&c?[p,h]:u?p:c?h:null},t.extent=function(e){var n,r,o,a,l;return arguments.length?(u&&(n=e[0],r=e[1],c&&(n=n[0],r=r[0]),i=[n,r],u.invert&&(n=u(n),r=u(r)),r<n&&(l=n,n=r,r=l),n==f[0]&&r==f[1]||(f=[n,r])),c&&(o=e[0],a=e[1],u&&(o=o[1],a=a[1]),s=[o,a],c.invert&&(o=c(o),a=c(a)),a<o&&(l=o,o=a,a=l),o==d[0]&&a==d[1]||(d=[o,a])),t):(u&&(i?(n=i[0],r=i[1]):(n=f[0],r=f[1],u.invert&&(n=u.invert(n),r=u.invert(r)),r<n&&(l=n,n=r,r=l))),c&&(s?(o=s[0],a=s[1]):(o=d[0],a=d[1],c.invert&&(o=c.invert(o),a=c.invert(a)),a<o&&(l=o,o=a,a=l))),u&&c?[[n,o],[r,a]]:u?[n,r]:c&&[o,a])},t.clear=function(){return t.empty()||(f=[0,0],d=[0,0],i=s=null),t},t.empty=function(){return!!u&&f[0]==f[1]||!!c&&d[0]==d[1]},pa.rebind(t,l,"on")};var $l={n:"ns-resize",e:"ew-resize",s:"ns-resize",w:"ew-resize",nw:"nwse-resize",ne:"nesw-resize",se:"nwse-resize",sw:"nesw-resize"},Zl=[["n","e","s","w","nw","ne","se","sw"],["e","w"],["n","s"],[]],Jl=ms.format=Ts.timeFormat,Ql=Jl.utc,tu=Ql("%Y-%m-%dT%H:%M:%S.%LZ");Jl.iso=Date.prototype.toISOString&&+new Date("2000-01-01T00:00:00.000Z")?la:tu,la.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},la.toString=tu.toString,ms.second=Vt(function(t){return new ys(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ms.seconds=ms.second.range,ms.seconds.utc=ms.second.utc.range,ms.minute=Vt(function(t){return new ys(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ms.minutes=ms.minute.range,ms.minutes.utc=ms.minute.utc.range,ms.hour=Vt(function(t){var e=t.getTimezoneOffset()/60;return new ys(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ms.hours=ms.hour.range,ms.hours.utc=ms.hour.utc.range,ms.month=Vt(function(t){return t=ms.day(t),t.setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ms.months=ms.month.range,ms.months.utc=ms.month.utc.range;var eu=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],nu=[[ms.second,1],[ms.second,5],[ms.second,15],[ms.second,30],[ms.minute,1],[ms.minute,5],[ms.minute,15],[ms.minute,30],[ms.hour,1],[ms.hour,3],[ms.hour,6],[ms.hour,12],[ms.day,1],[ms.day,2],[ms.week,1],[ms.month,1],[ms.month,3],[ms.year,1]],ru=Jl.multi([[".%L",function(t){return t.getMilliseconds()}],[":%S",function(t){return t.getSeconds()}],["%I:%M",function(t){return t.getMinutes()}],["%I %p",function(t){return t.getHours()}],["%a %d",function(t){return t.getDay()&&1!=t.getDate()}],["%b %d",function(t){return 1!=t.getDate()}],["%B",function(t){return t.getMonth()}],["%Y",Ie]]),ou={range:function(t,e,n){return pa.range(Math.ceil(t/n)*n,+e,n).map(ca)},floor:T,ceil:T};nu.year=ms.year,ms.scale=function(){return ua(pa.scale.linear(),nu,ru)};var iu=nu.map(function(t){return[t[0].utc,t[1]]}),au=Ql.multi([[".%L",function(t){return t.getUTCMilliseconds()}],[":%S",function(t){return t.getUTCSeconds()}],["%I:%M",function(t){return t.getUTCMinutes()}],["%I %p",function(t){return t.getUTCHours()}],["%a %d",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],["%b %d",function(t){return 1!=t.getUTCDate()}],["%B",function(t){return t.getUTCMonth()}],["%Y",Ie]]);iu.year=ms.year.utc,ms.scale.utc=function(){return ua(pa.scale.linear(),iu,au)},pa.text=Ot(function(t){return t.responseText}),pa.json=function(t,e){return Dt(t,"application/json",fa,e)},pa.html=function(t,e){return Dt(t,"text/html",da,e)},pa.xml=Ot(function(t){return t.responseXML}),this.d3=pa,r=pa,o="function"==typeof r?r.call(e,n,e,t):r,!(void 0!==o&&(t.exports=o))}()},function(t,e,n){var r,o,i;(function(a,s,l,u){!function(a,s){o=[n(172)],r=s,i="function"==typeof r?r.apply(e,o):r,!(void 0!==i&&(t.exports=i))}(this,function(t){function e(){return"undefined"!=typeof l||"undefined"!=typeof u}function n(t){var e;switch(t.processed.x_time_frame){case"millis":e=s.time_format(t.utc_time,"%b %e, %Y  %H:%M:%S.%L");break;case"seconds":e=s.time_format(t.utc_time,"%b %e, %Y  %H:%M:%S");break;case"less-than-a-day":e=s.time_format(t.utc_time,"%b %e, %Y  %I:%M%p");break;case"four-days":e=s.time_format(t.utc_time,"%b %e, %Y  %I:%M%p");break;default:e=s.time_format(t.utc_time,"%b %e, %Y")}return e}function r(t,e){return t[e.x_accessor]>=e.processed.min_x&&t[e.x_accessor]<=e.processed.max_x&&t[e.y_accessor]>=e.processed.min_y&&t[e.y_accessor]<=e.processed.max_y}function o(t){return"[object Array]"===Object.prototype.toString.call(t)}function i(t){return"[object Function]"===Object.prototype.toString.call(t)}function c(t){return o(t)&&0===t.length}function f(t){return"[object Object]"===Object.prototype.toString.call(t)}function d(e){var n=e.map(function(t){return o(t)===!0&&t.length>0});return t.sum(n)===e.length}function p(e){var n=e.map(function(t){return f(t)===!0});return t.sum(n)===e.length}function h(t){return c(t)||p(t)}function g(t,e){return t.map(function(t){
return t[e]})}function v(t){return t.reduce(function(t,e){return t[e]=t[e]+1||1,t},{})}function m(t){return t.height-t.bottom}function y(t){return m(t)-t.buffer}function b(t){return t.top}function x(t){return b(t)+t.buffer}function _(t){return t.left}function w(t){return _(t)+t.buffer}function T(t){return t.width-t.right}function C(t){return T(t)-t.buffer}function k(t){t.exit().remove()}function E(t,e){t.selectAll(e).remove()}function P(t,e){return t.append("g").classed(e,!0)}function S(t,e){var n=F(t.target),r=j(t.data),o=n.selectAll("line."+e).data(r);return o.enter().append("line").attr("class",e).attr("opacity",.3),k(o),k(o),o}function M(t,e,n){e.color_accessor?(t.attr("stroke",e.scalefns.colorf),t.classed(n,!1)):(t.attr("stroke",null),t.classed(n,!0))}function N(e,n){n&&e.attr({dy:0,transform:function(){var e=t.select(this);return"rotate("+n+" "+e.attr("x")+","+e.attr("y")+")"}})}function A(t){if(t=t.node(),!t)return!1;for(var e=0;e<t.length;e++)if(R(t[e],t))return!0;return!1}function O(e,n){if(e&&1!=e.length)for(var r=0;r<e.length;r++)if(R(e[r],e)){var o=t.select(e[r]),i=+o.attr("y");i+8>=n.top&&(i=n.top-16),o.attr("y",i)}}function D(e,n){if(e&&1!=e.length){e.sort(function(e,n){return t.select(n).attr("y")-t.select(e).attr("y")}),e.reverse();for(var r,o,i,a=0;a<e.length;a++){o=t.select(e[a]).text();for(var s=0;s<e.length;s++)if(i=t.select(e[s]).text(),r=I(e[a],e[s]),r!==!1&&o!==i){var l=t.select(e[a]),u=+l.attr("y");u+=r,l.attr("y",u)}}}}function I(t,e){var n=t.getBoundingClientRect(),r=e.getBoundingClientRect();return n.top<=r.bottom&&n.top>=r.top&&r.bottom-n.top}function R(t,e){for(var n=t.getBoundingClientRect(),r=0;r<e.length;r++)if(e[r]!=t){var o=e[r].getBoundingClientRect();if(n.top===o.top&&!(o.left>n.right||o.right<n.left))return!0}return!1}function L(t,e){var n=j(t.data);return n=n[0][t[e+"_accessor"]],"string"==typeof n?"categorical":"numerical"}function F(e){return t.select(e).select("svg")}function j(t){var e=[];return e.concat.apply(e,t)}function B(){return"undefined"==typeof s._next_elem_id&&(s._next_elem_id=0),"mg-"+s._next_elem_id++}function U(t){if("string"==typeof t)return H(t);if(t instanceof window.HTMLElement){var e=t.getAttribute("data-mg-uid");return e||(e=B(),t.setAttribute("data-mg-uid",e)),e}return console.warn("The specified target should be a string or an HTMLElement.",t),H(t)}function H(t){return t.replace(/[^a-zA-Z0-9 _-]+/g,"").replace(/ +?/g,"")}function z(e,n){return Number(t.select(e).style(n).replace(/px/g,""))}function W(t){return z(t,"width")}function q(t){return z(t,"height")}function V(t){return zn(Array.prototype.slice.call(arguments,1),function(e){if(e)for(var n in e)void 0===t[n]&&(t[n]=e[n])}),t}function K(t){return"[object Date]"===Object.prototype.toString.call(t)}function Y(t){return"[object Object]"===Object.prototype.toString.call(t)}function G(t){return Array.isArray?Array.isArray(t):"[object Array]"===Object.prototype.toString.call(t)}function X(t,e){var n,r=[],o=[];for(n=0;n<e.length;n++)r[e[n]]=!0;for(n=0;n<t.length;n++)r[t[n]]||o.push(t[n]);return o}function $(t,e){console.warn("Deprecation: "+t+(e?". This feature will be removed in "+e+".":" the near future.")),console.trace()}function Z(t,e,n){var r,o=0;for(t.textContent=e,r=t.getBBox();r.width>n&&(t.textContent=e.slice(0,--o)+"...",r=t.getBBox(),"..."!==t.textContent););}function J(e,n,r,o){e.each(function(){for(var e,i=t.select(this),a=i.text().split(r||/\s+/).reverse(),s=[],l=0,u=1.1,c=(i.attr("y"),0),f=i.text(null).append("tspan").attr("x",0).attr("y",c+"em").attr(o||{});e=a.pop();)s.push(e),f.text(s.join(" ")),(null===n||f.node().getComputedTextLength()>n)&&(s.pop(),f.text(s.join(" ")),s=[e],f=i.append("tspan").attr("x",0).attr("y",++l*u+c+"em").attr(o||{}).text(e))})}function Q(t,e,n){s.charts[t]={descriptor:e,defaults:n||{}}}function tt(n){"use strict";var r=F(n.target);if(r.select(".mg-header").remove(),n.target&&n.title){var o=r.insert("text").attr("class","mg-header").attr("x",n.center_title_full_width?n.width/2:(n.width+n.left-n.right)/2).attr("y",n.title_y_position).attr("text-anchor","middle").attr("dy","0.55em");if(o.append("tspan").attr("class","mg-chart-title").text(n.title),n.show_tooltips&&n.description&&e()){o.append("tspan").attr("class","mg-chart-description").attr("dx","0.3em").text("");var i=u(o.node());i.popover({html:!0,animation:!1,placement:"top",content:n.description,container:n.target,trigger:"manual",template:'<div class="popover mg-popover"><div class="arrow"></div><div class="popover-inner"><h3 class="popover-title"></h3><div class="popover-content"><p></p></div></div></div>'}).on("mouseenter",function(){t.selectAll(n.target).selectAll(".mg-popover").remove(),u(this).popover("show"),u(t.select(n.target).select(".popover").node()).on("mouseleave",function(){i.popover("hide")})}).on("mouseleave",function(){setTimeout(function(){u(".popover:hover").length||i.popover("hide")},120)})}else n.show_tooltips&&n.description&&"undefined"==typeof u&&(n.error="In order to enable tooltips, please make sure you include jQuery.")}n.error&&Un(n)}function et(t,e,n,r,o){t.scalefns[e]=function(e){return void 0===o?t.scales[n](e[r]):t.scales[n](e[r])+o}}function nt(t,e){return"bottom"===t||"top"===t?[w(e),C(e)]:"left"===t||"right"===t?[y(e),e.top]:void 0}function rt(e){var n={};return n.use_inflator=!1,n.zero_bottom=!1,n.scaleType="numerical",this.namespace=function(t){return n.namespace=t,n.namespace_accessor_name=n.namespace+"_accessor",n.scale_name=n.namespace.toUpperCase(),n.scalefn_name=n.namespace+"f",this},this.scaleName=function(t){return n.scale_name=t.toUpperCase(),n.scalefn_name=t+"f",this},this.inflateDomain=function(t){return n.use_inflator=t,this},this.zeroBottom=function(t){return n.zero_bottom=t,this},this.numericalDomainFromData=function(){var r=[];arguments.length>0&&(r=arguments);for(var o,i=0;i<e.data.length;i++)e.data[i].length>0&&(o=e.data[i]);n.is_time_series=!!K(o[0][e[n.namespace_accessor_name]]),et(e,n.scalefn_name,n.scale_name,e[n.namespace_accessor_name]),ot(e,n,r,n.use_inflator);var a=e.utc_time?t.scaleUtc():t.scaleTime();return e.scales[n.scale_name]=n.is_time_series?a:"log"===e[n.namespace+"_scale_type"]?t.scaleLog():t.scaleLinear(),e.scales[n.scale_name].domain([e.processed["min_"+n.namespace],e.processed["max_"+n.namespace]]),n.scaleType="numerical",this},this.categoricalDomain=function(r){return e.scales[n.scale_name]=t.scaleOrdinal().domain(r),et(e,n.scalefn_name,n.scale_name,e[n.namespace_accessor_name]),this},this.categoricalDomainFromData=function(){var r=j(e.data);return n.categoricalVariables=t.set(r.map(function(t){return t[e[n.namespace_accessor_name]]})).values(),e.scales[n.scale_name]=t.scaleBand().domain(n.categoricalVariables),n.scaleType="categorical",this},this.numericalRange=function(t){return"string"==typeof t?e.scales[n.scale_name].range(nt(t,e)):e.scales[n.scale_name].range(t),this},this.categoricalRangeBands=function(t,r){void 0===r&&(r=!1);var o=n.namespace,i=e[o+"_padding_percentage"],a=e[o+"_outer_padding_percentage"];return"string"==typeof t?e.scales[n.scale_name].range(nt(t,e)).paddingInner(i).paddingOuter(a):e.scales[n.scale_name].range(t).paddingInner(i).paddingOuter(a),et(e,n.scalefn_name,n.scale_name,e[n.namespace_accessor_name],r?e.scales[n.scale_name].bandwidth()/2:0),this},this.categoricalRange=function(t){return e.scales[n.scale_name].range(t),et(e,n.scalefn_name,n.scale_name,e[n.namespace_accessor_name]),this},this.categoricalColorRange=function(){return e.scales[n.scale_name]=e.scales[n.scale_name].domain().length>10?t.scaleOrdinal(t.schemeCategory20):t.scaleOrdinal(t.schemeCategory10),e.scales[n.scale_name].domain(n.categoricalVariables),et(e,n.scalefn_name,n.scale_name,e[n.namespace_accessor_name]),this},this.clamp=function(t){return e.scales[n.scale_name].clamp(t),this},this}function ot(e,n,r){var o=n.namespace,i=n.namespace_accessor_name,a=n.use_inflator,l=n.zero_bottom,u=e[i],c=j(e.data).map(function(t){return t[u]}).concat(j(r));"log"===e[o+"_scale_type"]&&(c=c.filter(function(t){return t>0}));var f=t.extent(c),d=f[0],p=f[1];l&&!e["min_"+o+"_from_data"]&&d>0&&!n.is_time_series&&(d="log"===e[o+"_scale_type"]?1:0),"log"!==e[o+"_scale_type"]&&d<0&&!n.is_time_series&&(d-=(d-d*e.inflator)*a),n.is_time_series||(p=p<0?p+(p-p*e.inflator)*a:p*(a?e.inflator:1)),d=e["min_"+o]||d,p=e["max_"+o]||p,d!==p||e["min_"+o]&&e["max_"+o]||(K(d)?(p=new Date(s.clone(d).setDate(d.getDate()+1)),d=new Date(s.clone(d).setDate(d.getDate()-1))):"number"==typeof d&&(d-=1,p=d+1,ve(e))),e.processed["min_"+o]=d,e.processed["max_"+o]=p,s.call_hook("x_axis.process_min_max",e,e.processed.min_x,e.processed.max_x),s.call_hook("y_axis.process_min_max",e,e.processed.min_y,e.processed.max_y)}function it(e,n){return t.set(e.map(function(t){return t[n]})).values()}function at(e){var n;return null===e.color_domain?"number"===e.color_type?n=t.extent(e.data[0],function(t){return t[e.color_accessor]}):"category"===e.color_type&&(n=it(e.data[0],e.color_accessor)):n=e.color_domain,n}function st(t){var e;return e=null===t.color_range?"number"===t.color_type?["blue","red"]:null:t.color_range}function lt(t,e){function n(t){return 1e3===t?3:1e6===t?7:Math.log(t)/Math.LN10}var r=t[e+"_accessor"],o=t.scales[e.toUpperCase()].ticks(t[e+"ax_count"]),i=t.processed["max_"+e];"log"===t[e+"_scale_type"]&&(o=o.filter(function(t){return Math.abs(n(t))%1<1e-6||Math.abs(n(t))%1>1-1e-6}));var a=o.length,s=!0;t.data.forEach(function(t,e){t.forEach(function(t,e){if(t[r]%1!==0)return s=!1,!1})}),s&&a>i&&"count"===t.format&&(o=o.filter(function(t){return t%1===0})),t.processed[e+"_ticks"]=o}function ut(t,e){var n=e.position,r=e.namespace,o={};return"left"===n&&(o.x1=_(t)+1,o.x2=_(t)+t.rug_buffer_size,o.y1=t.scalefns[r+"f"],o.y2=t.scalefns[r+"f"]),"right"===n&&(o.x1=T(t)-1,o.x2=T(t)-t.rug_buffer_size,o.y1=t.scalefns[r+"f"],o.y2=t.scalefns[r+"f"]),"top"===n&&(o.x1=t.scalefns[r+"f"],o.x2=t.scalefns[r+"f"],o.y1=b(t)+1,o.y2=b(t)+t.rug_buffer_size),"bottom"===n&&(o.x1=t.scalefns[r+"f"],o.x2=t.scalefns[r+"f"],o.y1=m(t)-1,o.y2=m(t)-t.rug_buffer_size),o}function ct(t,e){var n=e.namespace,r=e.position,o=t.processed[n+"_ticks"].length,i=t.processed[n+"_ticks"],a=t.scales[n.toUpperCase()],s={};return"left"===r&&(s.x1=_(t),s.x2=_(t),s.y1=a(i[0]).toFixed(2),s.y2=a(i[o-1]).toFixed(2)),"right"===r&&(s.x1=T(t),s.x2=T(t),s.y1=a(i[0]).toFixed(2),s.y2=a(i[o-1]).toFixed(2)),"top"===r&&(s.x1=_(t),s.x2=T(t),s.y1=b(t),s.y2=b(t)),"bottom"===r&&(s.x1=_(t),s.x2=T(t),s.y1=m(t),s.y2=m(t)),"left"!==r&&"right"!==r||(t.axes_not_compact?(s.y1=m(t),s.y2=b(t)):o&&(s.y1=a(i[0]).toFixed(2),s.y2=a(i[o-1]).toFixed(2))),s}function ft(t,e){var n=e.position,r=e.namespace,o=t[r+"ax_tick_length"],i=t.scales[r.toUpperCase()],a={};return"left"===n&&(a.x=_(t)-3*o/2,a.y=function(t){return i(t).toFixed(2)},a.dx=-3,a.dy=".35em",a.textAnchor="end",a.text=function(e){return St(t)(e)}),"right"===n&&(a.x=T(t)+3*o/2,a.y=function(t){return i(t).toFixed(2)},a.dx=3,a.dy=".35em",a.textAnchor="start",a.text=function(e){return St(t)(e)}),"top"===n&&(a.x=function(t){return i(t).toFixed(2)},a.y=(b(t)-7*o/3).toFixed(2),a.dx=0,a.dy="0em",a.textAnchor="middle",a.text=function(e){return ie(t)(e)}),"bottom"===n&&(a.x=function(t){return i(t).toFixed(2)},a.y=(m(t)+7*o/3).toFixed(2),a.dx=0,a.dy=".50em",a.textAnchor="middle",a.text=function(e){return ie(t)(e)}),a}function dt(t){var e=t.chart_type;t.processed.xax_format||(t.xax_format?t.processed.xax_format=t.xax_format:"line"===e||"point"===e||"histogram"===e?t.processed.xax_format=ie(t):"bar"===e&&(t.processed.xax_format=Gt(t)))}function pt(t,e,n){if(e.time_series&&(e.show_years||e.show_secondary_x_label)){var r=de(e);ht(e,n,t,r.timeframe,r.yformat,r.secondary)}}function ht(t,e,n,r,o,i){var a=i(t.processed.min_x,t.processed.max_x);if(0===a.length){var s=t.scales.X.ticks(t.xax_count)[0];a=[s]}var l=P(n,"mg-year-marker");"default"===r&&t.show_year_markers&&gt(t,e,l,a,o),"years"!=r&&vt(t,e,l,a,o)}function gt(t,e,n,r,o){n.selectAll(".mg-year-marker").data(r).enter().append("line").attr("x1",function(e){return t.scales.X(e).toFixed(2)}).attr("x2",function(e){return t.scales.X(e).toFixed(2)}).attr("y1",b(t)).attr("y2",m(t))}function vt(e,n,r,o,i){var a,s,l,u,c,f=n.position,d=n.namespace,p=e.scales[d.toUpperCase()],h=t.select(e.target).select(".mg-x-axis text").node().getBoundingClientRect();"top"===f&&(a=function(t,e){return p(t).toFixed(2)},s=b(e)-7*e.xax_tick_length/3-h.height,l=".50em",u="middle",c=function(t){return i(new Date(t))}),"bottom"===f&&(a=function(t,e){return p(t).toFixed(2)},s=m(e)+7*e.xax_tick_length/3+.8*h.height,l=".50em",u="middle",c=function(t){return i(new Date(t))}),r.selectAll(".mg-year-marker").data(o).enter().append("text").attr("x",a).attr("y",s).attr("dy",l).attr("text-anchor",u).text(c)}function mt(e,n,r){var o=r.namespace,i=ft(n,r),a=n.processed[o+"_ticks"],s=e.selectAll(".mg-yax-labels").data(a).enter().append("text").attr("x",i.x).attr("dx",i.dx).attr("y",i.y).attr("dy",i.dy).attr("text-anchor",i.textAnchor).text(i.text);if("x"==o&&(dt(n),n.time_series&&n.european_clock?(s.append("tspan").classed("mg-european-hours",!0).text(function(e,n){var r=new Date(e);return 0===n?t.timeFormat("%H")(r):""}),s.append("tspan").classed("mg-european-minutes-seconds",!0).text(function(t,e){var r=new Date(t);return":"+n.processed.xax_format(r)})):s.text(function(t){return n.xax_units+n.processed.xax_format(t)}),pt(e,n,r)),A(s)){s.filter(function(t,e){return(e+1)%2===0}).remove();var l=F(n.target);l.selectAll(".mg-"+o+"ax-ticks").filter(function(t,e){return(e+1)%2===0}).remove()}}function yt(t,e,n){var r,o,i,a,s=n.namespace,l=n.position,u=e.scales[s.toUpperCase()],c=e.processed[s+"_ticks"],f="mg-"+s+"ax-ticks",d="mg-extended-"+s+"ax-ticks",p=e[s+"_extended_ticks"],h=e[s+"ax_tick_length"];"left"===l&&(r=_(e),o=p?T(e):_(e)-h,i=function(t){return u(t).toFixed(2)},a=function(t){return u(t).toFixed(2)}),"right"===l&&(r=T(e),o=p?_(e):T(e)+h,i=function(t){return u(t).toFixed(2)},a=function(t){return u(t).toFixed(2)}),"top"===l&&(r=function(t){return u(t).toFixed(2)},o=function(t){return u(t).toFixed(2)},i=b(e),a=p?m(e):b(e)-h),"bottom"===l&&(r=function(t){return u(t).toFixed(2)},o=function(t){return u(t).toFixed(2)},i=m(e),a=p?b(e):m(e)+h),t.selectAll("."+f).data(c).enter().append("line").classed(d,p).attr("x1",r).attr("x2",o).attr("y1",i).attr("y2",a)}function bt(t,e,n){var r=n.namespace,o=e.processed[r+"_ticks"].length,i=ct(e,n);e[r+"_extended_ticks"]||e[r+"_extended_ticks"]||!o||t.append("line").attr("x1",i.x1).attr("x2",i.x2).attr("y1",i.y1).attr("y2",i.y2)}function xt(t,e){var n=F(t.target),r=j(t.data),o=n.selectAll("line."+e).data(r);return o.enter().append("svg:line").attr("class",e).attr("opacity",.3),k(o),k(o),o}function _t(t,e){"use strict";t.rug_buffer_size="point"===t.chart_type?t.buffer/2:2*t.buffer/3;var n=xt(t,"mg-"+e.namespace+"-rug"),r=ut(t,e);n.attr("x1",r.x1).attr("x2",r.x2).attr("y1",r.y1).attr("y2",r.y2),M(n,t,"mg-"+e.namespace+"-rug-mono")}function wt(t,e,n){var r=e.namespace,o=e.position,i=t.scales[r.toUpperCase()],a=t.scales[(r+"group").toUpperCase()],s={};return s.cat={},s.group={},"left"===o&&(s.cat.x=w(t)-t.buffer,s.cat.y=function(t){return a(n)+i(t)+i.bandwidth()/2},s.cat.dy=".35em",s.cat.textAnchor="end",s.group.x=w(t)-t.buffer,s.group.y=a(n)+(a.bandwidth?a.bandwidth()/2:0),s.group.dy=".35em",s.group.textAnchor=(t["rotate_"+r+"_labels"],"end")),"right"===o&&(s.cat.x=C(t)-t.buffer,s.cat.y=function(t){return a(n)+i(t)+i.bandwidth()/2},s.cat.dy=".35em",s.cat.textAnchor="start",s.group.x=C(t)-t.buffer,s.group.y=a(n)+(a.bandwidth?a.bandwidth()/2:0),s.group.dy=".35em",s.group.textAnchor="start"),"top"===o&&(s.cat.x=function(t){return a(n)+i(t)+i.bandwidth()/2},s.cat.y=x(t)+t.buffer,s.cat.dy=".35em",s.cat.textAnchor=t["rotate_"+r+"_labels"]?"start":"middle",s.group.x=a(n)+(a.bandwidth?a.bandwidth()/2:0),s.group.y=x(t)+t.buffer,s.group.dy=".35em",s.group.textAnchor=t["rotate_"+r+"_labels"]?"start":"middle"),"bottom"===o&&(s.cat.x=function(t){return a(n)+i(t)+i.bandwidth()/2},s.cat.y=y(t)+t.buffer,s.cat.dy=".35em",s.cat.textAnchor=t["rotate_"+r+"_labels"]?"start":"middle",s.group.x=a(n)+(a.bandwidth?a.bandwidth()/2-i.bandwidth()/2:0),s.group.y=y(t)+t.buffer,s.group.dy=".35em",s.group.textAnchor=t["rotate_"+r+"_labels"]?"start":"middle"),s}function Tt(t,e){var n=e.namespace,r="mg-"+n+"-axis",o=t.scales[n.toUpperCase()],i=t.scales[(n+"group").toUpperCase()],a=n+"group_accessor",s=F(t.target);E(s,"."+r);var l,u=P(s,r),c=i.domain&&i.domain()?i.domain():["1"];c.forEach(function(r){var i=wt(t,e,r);if(l=P(u,"mg-group-"+H(r)),null!==t[a])var s=l.append("text").classed("mg-barplot-group-label",!0).attr("x",i.group.x).attr("y",i.group.y).attr("dy",i.group.dy).attr("text-anchor",i.group.textAnchor).text(r);else var s=l.selectAll("text").data(o.domain()).enter().append("text").attr("x",i.cat.x).attr("y",i.cat.y).attr("dy",i.cat.dy).attr("text-anchor",i.cat.textAnchor).text(String);t["rotate_"+n+"_labels"]&&kt(s,t["rotate_"+n+"_labels"])})}function Ct(t,e){var n,r,o,i,a=e.namespace,s=(t.scalefns[a+"f"],t.scalefns[a+"groupf"],t.scales[(a+"group").toUpperCase()]),l=t.scales[a.toUpperCase()],u=e.position,c=F(t.target),f=s.domain&&s.domain()?s.domain():[null];E(c,".mg-category-guides");var d=P(c,"mg-category-guides");f.forEach(function(e){l.domain().forEach(function(a){"left"!==u&&"right"!==u||(n=w(t),r=C(t),o=l(a)+s(e)+l.bandwidth()/2,i=l(a)+s(e)+l.bandwidth()/2),"top"!==u&&"bottom"!==u||(n=l(a)+s(e)+l.bandwidth()/2*(null===e),r=l(a)+s(e)+l.bandwidth()/2*(null===e),o=y(t),i=x(t)),d.append("line").attr("x1",n).attr("x2",r).attr("y1",o).attr("y2",i).attr("stroke-dasharray","2,1")});var a=s(e)+l(l.domain()[0])+l.bandwidth()/2*(null===e||"top"!==u&&"bottom"!=u),c=s(e)+l(l.domain()[l.domain().length-1])+l.bandwidth()/2*(null===e||"top"!==u&&"bottom"!=u);"left"!==u&&"right"!==u||(x11=w(t),x21=w(t),y11=a,y21=c,x12=C(t),x22=C(t),y12=a,y22=c),"bottom"!==u&&"top"!==u||(x11=a,x21=c,y11=y(t),y21=y(t),x12=a,x22=c,y12=x(t),y22=x(t)),d.append("line").attr("x1",x11).attr("x2",x21).attr("y1",y11).attr("y2",y21).attr("stroke-dasharray","2,1"),d.append("line").attr("x1",x12).attr("x2",x22).attr("y1",y12).attr("y2",y22).attr("stroke-dasharray","2,1")})}function kt(e,n){n&&e.attr("transform",function(){var e=t.select(this);return"rotate("+n+" "+e.attr("x")+","+e.attr("y")+")"})}function Et(t){var e={};return e.type="numerical",this.namespace=function(t){return e.namespace=t,this},this.rug=function(t){return e.rug=t,this},this.label=function(t){return e.label=t,this},this.type=function(t){return e.type=t,this},this.position=function(t){return e.position=t,this},this.zeroLine=function(t){return e.zeroLine=t,this},this.draw=function(){return Wn[e.type](t,e),this},this}function Pt(t){"use strict";if(t.y_rug){t.rug_buffer_size="point"===t.chart_type?t.buffer/2:2*t.buffer/3;var e=S(t,"mg-y-rug");e.attr("x1",t.left+1).attr("x2",t.left+t.rug_buffer_size).attr("y1",t.scalefns.yf).attr("y2",t.scalefns.yf),M(e,t,"mg-y-rug-mono")}}function St(e){var n=e.yax_format;return n||("count"===e.format?(e.processed.max_y<1e-4?e.decimals=6:e.processed.max_y<.1&&(e.decimals=4),n=function(n){var r;return r=n<1&&n>-1&&0!==n?t.format(",."+e.decimals+"f"):n<1e3?t.format(",.0f"):t.format(",.2s"),e.yax_units_append?r(n)+e.yax_units:e.yax_units+r(n)}):n=function(e){var n=t.format(".0%");return n(e)}),n}function Mt(t){var e=F(t.target),n=t.scales.X.domain();if(0>=n[0]&&n[1]>=0){var r=t.scales.Y.range(),o=t.categorical_groups.length?t.scales.YGROUP(t.categorical_groups[t.categorical_groups.length-1]):t.scales.YGROUP();e.append("svg:line").attr("x1",t.scales.X(0)).attr("x2",t.scales.X(0)).attr("y1",r[0]+x(t)).attr("y2",r[r.length-1]+o).attr("stroke","black").attr("opacity",.2)}}function Nt(t,e){e.y_label&&t.append("text").attr("class","label").attr("x",function(){return-1*(x(e)+(y(e)-x(e))/2)}).attr("y",function(){return e.left/2}).attr("dy","0.4em").attr("text-anchor","middle").text(function(t){return e.y_label}).attr("transform",function(t){return"rotate(-90)"})}function At(t,e){var n=e.processed.y_ticks.length;if(!e.x_extended_ticks&&!e.y_extended_ticks&&n){var r,o;e.axes_not_compact&&"bar"!==e.chart_type?(r=e.height-e.bottom,o=e.top):n?(r=e.scales.Y(e.processed.y_ticks[0]).toFixed(2),o=e.scales.Y(e.processed.y_ticks[n-1]).toFixed(2)):(r=0,o=0),t.append("line").attr("x1",e.left).attr("x2",e.left).attr("y1",r).attr("y2",o)}}function Ot(t,e){t.selectAll(".mg-yax-ticks").data(e.processed.y_ticks).enter().append("line").classed("mg-extended-yax-ticks",e.y_extended_ticks).attr("x1",e.left).attr("x2",function(){return e.y_extended_ticks?e.width-e.right:e.left-e.yax_tick_length}).attr("y1",function(t){return e.scales.Y(t).toFixed(2)}).attr("y2",function(t){return e.scales.Y(t).toFixed(2)})}function Dt(t,e){var n=St(e);t.selectAll(".mg-yax-labels").data(e.processed.y_ticks).enter().append("text").attr("x",e.left-3*e.yax_tick_length/2).attr("dx",-3).attr("y",function(t){return e.scales.Y(t).toFixed(2)}).attr("dy",".35em").attr("text-anchor","end").text(function(t){var e=n(t);return e})}function It(t){t.processed||(t.processed={});var e=F(t.target);if(s.call_hook("y_axis.process_min_max",t,t.processed.min_y,t.processed.max_y),E(e,".mg-y-axis"),!t.y_axis)return this;var n=P(e,"mg-y-axis");return Nt(n,t),un(t,"y"),At(n,t),Ot(n,t),Dt(n,t),t.y_rug&&Pt(t),this}function Rt(t){var e=F(t.target);E(e,".mg-y-axis");var n,r=P(e,"mg-y-axis");(t.categorical_groups.length?t.categorical_groups:["1"]).forEach(function(e){if(n=P(r,"mg-group-"+H(e)),null!==t.ygroup_accessor)Ft(n,e,t);else{var o=Lt(n,e,t);N(o,t.rotate_y_labels)}})}function Lt(t,e,n){return t.selectAll("text").data(n.scales.Y.domain()).enter().append("svg:text").attr("x",n.left-n.buffer).attr("y",function(t){return n.scales.YGROUP(e)+n.scales.Y(t)+n.scales.Y.bandwidth()/2}).attr("dy",".35em").attr("text-anchor","end").text(String)}function Ft(t,e,n){t.append("svg:text").classed("mg-barplot-group-label",!0).attr("x",n.left-n.buffer).attr("y",n.scales.YGROUP(e)+n.scales.YGROUP.bandwidth()/2).attr("dy",".35em").attr("text-anchor","end").text(e)}function jt(t){var e=F(t.target),n=t.scales.YGROUP.domain();n[0],n[n.length-1];e.select(".mg-category-guides").selectAll("mg-group-lines").data(n).enter().append("line").attr("x1",w(t)).attr("x2",w(t)).attr("y1",function(e){return t.scales.YGROUP(e)}).attr("y2",function(e){return t.scales.YGROUP(e)+t.ygroup_height}).attr("stroke-width",1)}function Bt(t){var e=F(t.target),n=[];t.data[0].forEach(function(r){n.indexOf(r[t.y_accessor])===-1&&e.select(".mg-category-guides").append("line").attr("x1",w(t)).attr("x2",C(t)).attr("y1",t.scalefns.yf(r)+t.scalefns.ygroupf(r)).attr("y2",t.scalefns.yf(r)+t.scalefns.ygroupf(r)).attr("stroke-dasharray","2,1")})}function Ut(t){return t.y_axis?(Rt(t),t.show_bar_zero&&Mt(t),t.ygroup_accessor&&jt(t),t.y_categorical_show_guides&&Bt(t),this):this}function Ht(t){"use strict";if(t.x_rug){t.rug_buffer_size="point"===t.chart_type?t.buffer/2:t.buffer;var e=S(t,"mg-x-rug");e.attr("x1",t.scalefns.xf).attr("x2",t.scalefns.xf).attr("y1",t.height-t.bottom-t.rug_buffer_size).attr("y2",t.height-t.bottom),M(e,t,"mg-x-rug-mono")}}function zt(t){t.processed||(t.processed={})}function Wt(t){"use strict";var e=F(t.target);if(zt(t),me(t),E(e,".mg-x-axis"),!t.x_axis)return this;var n=P(e,"mg-x-axis");return ae(n,t),ue(n,t),t.x_label&&Yt(n,t),t.x_rug&&Ht(t),this}function qt(t){var e=F(t.target),n=0;"bar"===t.chart_type&&(n=t.buffer+5),mg_add_categorical_scale(t,"X",t.categorical_variables.reverse(),t.left,C(t)-n),et(t,"xf","X","value"),E(e,".mg-x-axis");var r=P(e,"mg-x-axis");return t.x_axis?(Vt(r,t,n),this):this}function Vt(t,e,n){var r=t.selectAll("text").data(e.categorical_variables).enter().append("text");r.attr("x",function(t){return e.scales.X(t)+e.scales.X.bandwidth()/2+e.buffer*e.bar_outer_padding_percentage+n/2}).attr("y",y(e)).attr("dy",".35em").attr("text-anchor","middle").text(String),e.truncate_x_labels&&r.each(function(t,n){var r=this,o=e.scales.X.bandwidth();Z(r,t,o)}),N(r,e.rotate_x_labels)}function at(e){var n;return null===e.color_domain?"number"===e.color_type?n=t.extent(e.data[0],function(t){return t[e.color_accessor]}):"category"===e.color_type&&(n=t.set(e.data[0].map(function(t){return t[e.color_accessor]})).values(),n.sort()):n=e.color_domain,n}function st(t){var e;return e=null===t.color_range?"number"===t.color_type?["blue","red"]:null:t.color_range}function Kt(t){var e;return e=null===t.size_range?[1,5]:t.size_range}function Yt(e,n){n.x_label&&e.append("text").attr("class","label").attr("x",function(){return w(n)+(C(n)-w(n))/2}).attr("dx",null!=n.x_label_nudge_x?n.x_label_nudge_x:0).attr("y",function(){var e=t.select(n.target).select(".mg-x-axis text").node().getBoundingClientRect();return m(n)+n.xax_tick_length*(7/3)+.8*e.height+10}).attr("dy",".5em").attr("text-anchor","middle").text(function(t){return n.x_label})}function Gt(e){return function(n){if(n<1&&n>-1&&0!==n)return e.xax_units+n.toFixed(e.decimals);var r=t.format(",.0f");return e.xax_units+r(n)}}function Xt(t){var e;return e=$t(t)?"millis":Zt(t)?"seconds":Jt(t)?"less-than-a-day":Qt(t)?"four-days":te(t)?"many-days":ee(t)?"many-months":ne(t)?"years":"default"}function $t(t){return t<10}function Zt(t){return t<60}function Jt(t){return t/3600<=24}function Qt(t){return t/3600<=96}function te(t){return t/86400<=93}function ee(t){return t/86400<730}function ne(t){return t/86400>=730}function re(t,e){var n;return n=$t(e)?s.time_format(t,"%M:%S.%L"):Zt(e)?s.time_format(t,"%M:%S"):Jt(e)?s.time_format(t,"%H:%M"):Qt(e)?s.time_format(t,"%H:%M"):te(e)?s.time_format(t,"%b %d"):ee(e)?s.time_format(t,"%b"):s.time_format(t,"%Y")}function oe(t){var e,n,r;t.time_series&&(e=(t.processed.max_x-t.processed.min_x)/1e3,r=Xt(e),n=re(t.utc_time,e)),t.processed.main_x_time_format=n,t.processed.x_time_frame=r}function ie(e){if(e.xax_format)return e.xax_format;var n=e.processed.original_data||e.data,r=j(n)[0],o=r[e.processed.original_x_accessor||e.x_accessor];return void 0===o&&(o=r),function(n){if(oe(e),K(o))return e.processed.main_x_time_format(new Date(n));if("number"==typeof o){var r,i=n%1!==0;return r=i?t.format(",."+e.decimals+"f"):n<1e3?t.format(",.0f"):t.format(",.2s"),e.xax_units+r(n)}return e.xax_units+n}}function ae(t,e){un(e,"x"),se(e,t),le(e,t)}function se(t,e){var n=(t.processed.x_ticks.length,t.scales.X.ticks(t.xax_count).length-1);t.x_extended_ticks||e.append("line").attr("x1",function(){return 0===t.xax_count?w(t):t.axes_not_compact&&"bar"!==t.chart_type?t.left:t.scales.X(t.scales.X.ticks(t.xax_count)[0]).toFixed(2)}).attr("x2",function(){return 0===t.xax_count||t.axes_not_compact&&"bar"!==t.chart_type?T(t):t.scales.X(t.scales.X.ticks(t.xax_count)[n]).toFixed(2)}).attr("y1",t.height-t.bottom).attr("y2",t.height-t.bottom)}function le(t,e){e.selectAll(".mg-xax-ticks").data(t.processed.x_ticks).enter().append("line").attr("x1",function(e){return t.scales.X(e).toFixed(2)}).attr("x2",function(e){return t.scales.X(e).toFixed(2)}).attr("y1",t.height-t.bottom).attr("y2",function(){return t.x_extended_ticks?t.top:t.height-t.bottom+t.xax_tick_length}).attr("class",function(){if(t.x_extended_ticks)return"mg-extended-xax-ticks"}).classed("mg-xax-ticks",!0)}function ue(t,e){ce(e,t),fe(e,t)}function ce(e,n){var r=n.selectAll(".mg-xax-labels").data(e.processed.x_ticks).enter().append("text").attr("x",function(t){return e.scales.X(t).toFixed(2)}).attr("y",(e.height-e.bottom+7*e.xax_tick_length/3).toFixed(2)).attr("dy",".50em").attr("text-anchor","middle");if(e.time_series&&e.european_clock?(r.append("tspan").classed("mg-european-hours",!0).text(function(e,n){var r=new Date(e);return 0===n?t.timeFormat("%H")(r):""}),r.append("tspan").classed("mg-european-minutes-seconds",!0).text(function(t,n){var r=new Date(t);return":"+e.processed.xax_format(r)})):r.text(function(t){return e.xax_units+e.processed.xax_format(t)}),A(r)){r.filter(function(t,e){return(e+1)%2===0}).remove();var o=F(e.target);o.selectAll(".mg-xax-ticks").filter(function(t,e){return(e+1)%2===0}).remove()}}function fe(t,e){if(t.time_series&&(t.show_years||t.show_secondary_x_label)){var n=de(t);pe(t,e,n.timeframe,n.yformat,n.secondary)}}function de(e){var n={};switch(n.timeframe=e.processed.x_time_frame,n.timeframe){case"millis":case"seconds":n.secondary=t.timeDays,e.european_clock?n.yformat=s.time_format(e.utc_time,"%b %d"):n.yformat=s.time_format(e.utc_time,"%I %p");break;case"less-than-a-day":n.secondary=t.timeDays,n.yformat=s.time_format(e.utc_time,"%b %d");break;case"four-days":n.secondary=t.timeDays,n.yformat=s.time_format(e.utc_time,"%b %d");break;case"many-days":n.secondary=t.timeYears,n.yformat=s.time_format(e.utc_time,"%Y");break;case"many-months":n.secondary=t.timeYears,n.yformat=s.time_format(e.utc_time,"%Y");break;default:n.secondary=t.timeYears,n.yformat=s.time_format(e.utc_time,"%Y")}return n}function pe(t,e,n,r,o){var i=o(t.processed.min_x,t.processed.max_x);if(0===i.length){var a=t.scales.X.ticks(t.xax_count)[0];i=[a]}var s=P(e,"mg-year-marker");"default"===n&&t.show_year_markers&&he(t,s,i,r),"years"!=n&&ge(t,s,i,r)}function he(t,e,n,r){e.selectAll(".mg-year-marker").data(n).enter().append("line").attr("x1",function(e){return t.scales.X(e).toFixed(2)}).attr("x2",function(e){return t.scales.X(e).toFixed(2)}).attr("y1",b(t)).attr("y2",m(t))}function ge(e,n,r,o){n.selectAll(".mg-year-marker").data(r).enter().append("text").attr("x",function(t,n){return e.scales.X(t).toFixed(2)}).attr("y",function(){var n=t.select(e.target).select(".mg-x-axis text").node().getBoundingClientRect();return m(e)+7*e.xax_tick_length/3+.8*n.height}).attr("dy",".50em").attr("text-anchor","middle").text(function(t){return o(new Date(t))})}function ve(t){t.xax_count=2}function me(t){var e=t.chart_type;t.processed.xax_format||(t.xax_format?t.processed.xax_format=t.xax_format:"line"===e||"point"===e||"histogram"===e?t.processed.xax_format=ie(t):"bar"===e&&(t.processed.xax_format=Gt(t)))}function ye(t){var e={target:null,title:null,description:null};return t||(t={}),t.processed||(t.processed={}),t=V(t,e)}function be(t){var e=j(t.processed.original_data||t.data)[0];t.time_series=K(e[t.processed.original_x_accessor||t.x_accessor])}function xe(t){var e=t.width;t.full_width&&(e=W(t.target)),"categorical"===t.x_axis_type&&null===e&&(e=Re(t,"x")),t.width=e}function _e(t){var e=t.height;t.full_height&&(e=q(t.target)),"categorical"===t.y_axis_type&&null===e&&(e=Re(t,"y")),t.height=e}function we(t,e){(!t.selectAll(".mg-main-line").empty()&&"line"!==e.chart_type||!t.selectAll(".mg-points").empty()&&"point"!==e.chart_type||!t.selectAll(".mg-histogram").empty()&&"histogram"!==e.chart_type||!t.selectAll(".mg-barplot").empty()&&"bar"!==e.chart_type)&&t.remove()}function Te(e,n){return F(n.target).empty()&&(e=t.select(n.target).append("svg").classed("linked",n.linked).attr("width",n.width).attr("height",n.height)),e}function Ce(t,e){t.selectAll(".mg-clip-path").remove(),t.append("defs").attr("class","mg-clip-path").append("clipPath").attr("id","mg-plot-window-"+U(e.target)).append("svg:rect").attr("x",_(e)).attr("y",b(e)).attr("width",e.width-e.left-e.right-e.buffer).attr("height",e.height-e.top-e.bottom-e.buffer+1)}function ke(t,e){e.width!==Number(t.attr("width"))&&t.attr("width",e.width),e.height!==Number(t.attr("height"))&&t.attr("height",e.height)}function Ee(t,e){t.attr("viewBox","0 0 "+e.width+" "+e.height),(e.full_width||e.full_height)&&t.attr("preserveAspectRatio","xMinYMin meet")}function Pe(t){t.classed("mg-missing",!1),t.selectAll(".mg-missing-text").remove(),t.selectAll(".mg-missing-pane").remove()}function Se(t,e){var n=0;if(t.selectAll(".mg-main-line").nodes().length>=e.data.length)if(e.custom_line_color_map.length>0){var r=function(t){for(var e=new Array(t),n=0;n<e.length;n++)e[n]=n+1;return e},o=X(r(e.max_data_size),e.custom_line_color_map);for(n=0;n<o.length;n++)t.selectAll(".mg-main-line.mg-line"+o[n]+"-color").remove()}else{var i=e.data.length,a=t.selectAll(".mg-main-line").nodes()?t.selectAll(".mg-main-line").nodes().length:0;for(n=a;n>i;n--)t.selectAll(".mg-main-line.mg-line"+n+"-color").remove();
}}function Me(t,e){if(t.empty())return void console.warn('The specified target element "'+e.target+'" could not be found in the page. The chart will not be rendered.')}function Ne(t,e){var n="x"===e?t.width:t.height;Ae(t,e),Oe(t,e),De(t,e,n),n&&Ie(t,e)}function Ae(e,n){var r=n+"group_accessor",o=e[r];if(e.categorical_groups=[],o){var i=e.data[0];e.categorical_groups=t.set(i.map(function(t){return t[o]})).values()}}function Oe(e,n){var r=n+"group_accessor",o=e[r];if(e.total_bars=e.data[0].length,o){var i=v(g(e.data[0],o));i=t.max(Object.keys(i).map(function(t){return i[t]})),e.bars_per_group=i}else e.bars_per_group=e.data[0].length}function De(t,e,n){var r=e+"group_height";if(n){var o="y"===e?(t.height-t.top-t.bottom-2*t.buffer)/(t.categorical_groups.length||1):(t.width-t.left-t.right-2*t.buffer)/(t.categorical_groups.length||1);t[r]=o}else{var i=(1+t[e+"_padding_percentage"])*t.bar_thickness;t[r]=t.bars_per_group*i+2*t[e+"_outer_padding_percentage"]*i}}function Ie(t,e){var n=t[e+"group_height"]/(t.bars_per_group+t[e+"_outer_padding_percentage"]);t.bar_thickness=n-n*t[e+"_padding_percentage"]}function Re(t,e){var n=t[e+"group_height"]*(t.categorical_groups.length||1),r="y"===e?t.top+t.bottom+2*t.buffer:t.left+t.right+2*t.buffer;return n+r+t.categorical_groups.length*t[e+"group_height"]*(t[e+"group_padding_percentage"]+t[e+"group_outer_padding_percentage"])}function Le(e){"use strict";e=arguments[0],e=ye(e);var n=t.select(e.target);Me(n,e);var r=n.selectAll("svg");return"categorical"===e.y_axis_type&&Ne(e,"y"),"categorical"===e.x_axis_type&&Ne(e,"x"),be(e),xe(e),_e(e),we(r,e),r=Te(r,e),Ce(r,e),ke(r,e),Ee(r,e),Pe(r),tt(e),Se(r,e),this}function Fe(t){return t.label}function je(t){t.selectAll(".mg-markers").remove(),t.selectAll(".mg-baselines").remove()}function Be(t){return function(e){return t.scales.X(e[t.x_accessor])>=w(t)&&t.scales.X(e[t.x_accessor])<=C(t)}}function Ue(t){return function(e){return t.scales.X(e[t.x_accessor])}}function He(t){var e=Ue(t);return function(t){return e(t).toFixed(2)}}function ze(t){var e=t.scales.Y;return function(t){return e(t.value).toFixed(2)}}function We(t,e,n,r,o,i){var a;t&&(a=r.append("g").attr("class",e),o(a,n),i(a,n))}function qe(t,e){We(t.markers,"mg-markers",t,e,Ke,Ye)}function Ve(t,e){We(t.baselines,"mg-baselines",t,e,Ge,Xe)}function Ke(t,e){var n=He(e);t.selectAll(".mg-markers").data(e.markers.filter(Be(e))).enter().append("line").attr("x1",n).attr("x2",n).attr("y1",e.top).attr("y2",y(e)).attr("class",function(t){return t.lineclass}).attr("stroke-dasharray","3,1")}function Ye(e,n){e.selectAll(".mg-markers").data(n.markers.filter(Be(n))).enter().append("text").attr("class",function(t){return t.textclass||""}).classed("mg-marker-text",!0).attr("x",Ue(n)).attr("y","bottom"===n.x_axis_position?.95*b(n):m(n)+n.buffer).attr("text-anchor","middle").text(Fe).each(function(e){e.click&&t.select(this).style("cursor","pointer").on("click",e.click)}),O(e.selectAll(".mg-marker-text").nodes(),n)}function Ge(t,e){var n=ze(e);t.selectAll(".mg-baselines").data(e.baselines).enter().append("line").attr("x1",w(e)).attr("x2",C(e)).attr("y1",n).attr("y2",n)}function Xe(t,e){var n=ze(e);t.selectAll(".mg-baselines").data(e.baselines).enter().append("text").attr("x",C(e)).attr("y",n).attr("dy",-3).attr("text-anchor","end").text(Fe)}function $e(t){"use strict";var e=F(t.target);return je(e),qe(t,e),Ve(t,e),this}function Ze(t){t.selectAll(".mg-active-datapoint-container").selectAll("*").remove()}function Je(e,n){e.select(".mg-active-datapoint").remove();var r="right"===n.mouseover_align?"end":"left"===n.mouseover_align?"start":"middle",o="right"===n.mouseover_align?C(n):"left"===n.mouseover_align?w(n):(n.width-n.left-n.right)/2+n.left,i=e.select(".mg-active-datapoint-container").append("text").attr("class","mg-active-datapoint").attr("xml:space","preserve").attr("text-anchor",r),a=.75,s="bottom"===n.x_axis_position?b(n)*a:m(n)+3*n.buffer;if(n.markers){var l;e.selectAll(".mg-marker-text").each(function(){l?l!==t.select(this).attr("y")&&(a=.56):l=t.select(this).attr("y")})}i.attr("transform","translate("+o+","+s+")")}function Qe(t,e){var n="",r=null;return 3===arguments.length&&(r=arguments[2]),n=t.append("tspan").text(e),null!==r&&n.classed(r,!0),this.tspan=n,this.bold=function(){return this.tspan.attr("font-weight","bold"),this},this.font_size=function(t){return this.tspan.attr("font-size",t),this},this.x=function(t){return this.tspan.attr("x",t),this},this.y=function(t){return this.tspan.attr("y",t),this},this.elem=function(){return this.tspan},this}function tn(t){var e=t.select(".mg-active-datapoint");return e.selectAll("*").remove(),e}function en(t,e,n){var r=1.1;this.rargs=n;var o=e.append("tspan").attr("x",0).attr("y",t*r+"em");return this.text=function(t){return Qe(o,t)},this}function nn(t,e){return this.row_number=0,this.rargs=e,Je(e.svg,t),this.text_container=tn(e.svg),this.mouseover_row=function(t){var e=this,n=en(e.row_number,e.text_container,t);return e.row_number+=1,n},this}function rn(){function e(){o.forEach(function(e){var n=t.select(e).select("svg");if(!n.empty()&&(n.node().parentNode.offsetWidth>0||n.node().parentNode.offsetHeight>0)){var r=0!==n.attr("width")?n.attr("height")/n.attr("width"):0,o=W(e);n.attr("width",o),n.attr("height",r*o)}})}function n(t){var n=o.indexOf(t);n!==-1&&o.splice(n,1),0===o.length&&window.removeEventListener("resize",e,!0)}var r,o=[];return"undefined"!=typeof MutationObserver?r=MutationObserver:"undefined"!=typeof WebKitMutationObserver&&(r=WebKitMutationObserver),{add_target:function(i){if(0===o.length&&window.addEventListener("resize",e,!0),o.indexOf(i)===-1&&(o.push(i),r)){var a=new r(function(e){var r=t.select(i).node();r&&!e.some(function(t){for(var e=0;e<t.removedNodes.length;e++)if(t.removedNodes[e]===r)return!0})||(a.disconnect(),n(i))});a.observe(t.select(i).node().parentNode,{childList:!0})}}}}function on(t){an(t)}function an(t){(t.full_width||t.full_height)&&qn.add_target(t.target)}function sn(t,e,n){var r=nn(t,{svg:e}),o=r.mouseover_row();if(null!==t.color_accessor&&"category"===t.color_type){var i=n[t.color_accessor];o.text(i+"  ").bold().elem().attr("fill",t.scalefns.colorf(n))}ln(t,o.text("●   ").elem(),n),o.text(On(t,n)),o.text(Dn(t,n,t.time_series===!1))}function ln(t,e,n){null!==t.color_accessor?(e.attr("fill",t.scalefns.colorf(n)),e.attr("stroke",t.scalefns.colorf(n))):e.classed("mg-points-mono",!0)}function un(t,e){function n(t){return 1e3===t?3:1e6===t?7:Math.log(t)/Math.LN10}var r,o,i;"x"===e?(r=t.x_accessor,o=t.scales.X.ticks(t.xax_count),i=t.processed.max_x):"y"===e&&(r=t.y_accessor,o=t.scales.Y.ticks(t.yax_count),i=t.processed.max_y),("x"===e&&"log"===t.x_scale_type||"y"===e&&"log"===t.y_scale_type)&&(o=o.filter(function(t){return Math.abs(n(t))%1<1e-6||Math.abs(n(t))%1>1-1e-6}));var a=o.length,s=!0;t.data.forEach(function(t,e){t.forEach(function(t,e){if(t[r]%1!==0)return s=!1,!1})}),s&&a>i&&"count"===t.format&&(o=o.filter(function(t){return t%1===0})),"x"===e?t.processed.x_ticks=o:"y"===e&&(t.processed.y_ticks=o)}function cn(t){"use strict";if(t.data=s.clone(t.data),t.single_object=!1,t.array_of_objects=!1,t.array_of_arrays=!1,t.nested_array_of_arrays=!1,t.nested_array_of_objects=!1,d(t.data)?(t.nested_array_of_objects=t.data.map(function(t){return h(t)}),t.nested_array_of_arrays=t.data.map(function(t){return d(t)})):(t.array_of_objects=p(t.data),t.array_of_arrays=d(t.data)),"line"===t.chart_type?(t.array_of_objects||t.array_of_arrays)&&(t.data=[t.data]):G(t.data[0])||(t.data=[t.data]),dn(t),pn(t),void 0!==t.color&&(t.colors=t.color),null!==t.colors&&"string"==typeof t.colors&&(t.colors=[t.colors]),"line"===t.chart_type&&t.x_sort===!0)for(var e=0;e<t.data.length;e++)t.data[e].sort(function(e,n){return e[t.x_accessor]-n[t.x_accessor]});return this}function fn(t,e){G(t[e])&&(t.data=t.data.map(function(n){return t[e].map(function(t){return n.map(function(n){if(n=s.clone(n),void 0!==n[t])return n["multiline_"+e]=n[t],n}).filter(function(t){return void 0!==t})})})[0],t[e]="multiline_"+e)}function dn(t){fn(t,"x_accessor")}function pn(t){fn(t,"y_accessor")}function hn(e){"use strict";var n,r=t.sum(e.data.map(function(t){return t.length>0&&K(t[0][e.x_accessor])}))>0;if((e.missing_is_zero||e.missing_is_hidden)&&"line"===e.chart_type&&r)for(var o=0;o<e.data.length;o++)if(!(e.data[o].length<=1)){var i=e.data[o][0],a=e.data[o][e.data[o].length-1],l=[],u=s.clone(i[e.x_accessor]).setDate(i[e.x_accessor].getDate()+1),c=e.min_x?e.min_x:u,f=e.max_x?e.max_x:a[e.x_accessor];if(n=Xt((f-c)/1e3),["four-days","many-days","many-months","years","default"].indexOf(n)!==-1&&null===e.missing_is_hidden_accessor)for(var d=new Date(c);d<=f;d.setDate(d.getDate()+1)){var p={};d.setHours(0,0,0,0),Date.parse(d)===Date.parse(new Date(u))&&l.push(s.clone(e.data[o][0]));var h=null;e.data[o].forEach(function(t,n){if(Date.parse(t[e.x_accessor])===Date.parse(new Date(d)))return h=t,!1}),h?h[e.missing_is_hidden_accessor]||null===h[e.y_accessor]?(h._missing=!0,l.push(h)):l.push(h):(p[e.x_accessor]=new Date(d),p[e.y_accessor]=0,p._missing=!0,l.push(p))}else for(var g=0;g<e.data[o].length;g+=1){var v=s.clone(e.data[o][g]);v._missing=e.data[o][g][e.missing_is_hidden_accessor],l.push(v)}e.data[o]=l}return this}function gn(e){"use strict";var n,r=e.data[0];if(e.binned===!1){if("object"==typeof r[0])n=r.map(function(t){return t[e.x_accessor]});else{if("number"!=typeof r[0])return void console.log("TypeError: expected an array of numbers, found "+typeof r[0]);n=r}var o=t.histogram();e.bins&&o.thresholds(e.bins);var i=o(n);e.processed_data=i.map(function(t){return{x:t.x0,y:t.length}})}else{e.processed_data=r.map(function(t){return{x:t[e.x_accessor],y:t[e.y_accessor]}});for(var a,s,l=0;l<e.processed_data.length;l++)a=e.processed_data[l],l===e.processed_data.length-1?a.dx=e.processed_data[l-1].dx:(s=e.processed_data[l+1],a.dx=s.x-a.x)}return e.processed||(e.processed={}),e.processed.original_data=e.data,e.processed.original_x_accessor=e.x_accessor,e.processed.original_y_accessor=e.y_accessor,e.data=[e.processed_data],e.x_accessor=e.processed_x_accessor,e.y_accessor=e.processed_y_accessor,this}function vn(t){"use strict";"vertical"===t.bar_orientation?t.x_accessor:t.y_accessor,"vertical"===t.bar_orientation?t.y_accessor:t.x_accessor;return this}function mn(t){"use strict";var e=t.data[0],n=e.map(function(e){return e[t.x_accessor]}),r=e.map(function(e){return e[t.y_accessor]});return t.least_squares&&(t.ls_line=wn(n,r)),this}function yn(e){var n=F(e.target),r=e.data[0],o=t.min(r,function(t){return t[e.x_accessor]}),i=t.max(r,function(t){return t[e.x_accessor]});t.select(e.target).selectAll(".mg-least-squares-line").remove(),n.append("svg:line").attr("x1",e.scales.X(o)).attr("x2",e.scales.X(i)).attr("y1",e.scales.Y(e.ls_line.fit(o))).attr("y2",e.scales.Y(e.ls_line.fit(i))).attr("class","mg-least-squares-line")}function bn(e){var n=F(e.target),r=e.lowess_line,o=t.svg.line().x(function(t){return e.scales.X(t.x)}).y(function(t){return e.scales.Y(t.y)}).interpolate(e.interpolate);n.append("path").attr("d",o(r)).attr("class","mg-lowess-line")}function xn(e,n,r,o){var i,a,s=[];t.mean(n);for(a=0;a<e.length;a+=1)s.push(1);i=Mn(e,n,r,o,s);var l=i.x,u=i.y;for(a=0;a<100;a+=1){s=t.zip(u,n).map(function(t){return Math.abs(t[1]-t[0])});var c=t.quantile(s.sort(),.5);s=s.map(function(t){return Cn(t/(6*c))}),i=Mn(e,n,r,o,s),l=i.x,u=i.y}return t.zip(l,u).map(function(t){var e={};return e.x=t[0],e.y=t[1],e})}function _n(t,e,n,r){for(var o=[],i=0;i<t.length;i+=1)o.push(1);Mn(t,e,n,r,o)}function wn(e,n){var r,o,i,a;e.length;r=K(e[0])?e.map(function(t){return t.getTime()}):e,o=K(n[0])?n.map(function(t){return t.getTime()}):n;for(var s=t.mean(r),l=t.mean(o),u=0,c=0,f=0;f<r.length;f++)i=r[f],a=o[f],u+=(i-s)*(a-l),c+=(i-s)*(i-s);var d=u/c,p=l-d*s;return{x0:p,beta:d,fit:function(t){return p+t*d}}}function Tn(t,e){return t>=0&&t<=1?Math.pow(1-Math.pow(t,e),e):0}function Cn(t){return Tn(t,2)}function kn(t){return Tn(t,3)}function En(e){var n=t.sum(e.map(function(t){return t.w}));return{xbar:t.sum(e.map(function(t){return t.w*t.x}))/n,ybar:t.sum(e.map(function(t){return t.w*t.y}))/n}}function Pn(e,n,r){var o=t.sum(e.map(function(t){return Math.pow(t.w,2)*(t.x-n)*(t.y-r)})),i=t.sum(e.map(function(t){return Math.pow(t.w,2)*Math.pow(t.x-n,2)}));return o/i}function Sn(t){var e,n,r=En(t);n=r.xbar,e=r.ybar;var o=Pn(t,n,e);return{beta:o,xbar:n,ybar:e,x0:e-o*n}}function Mn(e,n,r,o,i){var a=Math.floor(e.length*r),s=e.slice();s.sort(function(t,e){return t<e?-1:t>e?1:0});for(var l,u,c,f,d,p=t.quantile(s,.98),h=t.quantile(s,.02),g=t.zip(e,n,i).sort(),v=Math.abs(p-h)/o,m=h,y=p,b=t.range(m,y,v),x=[],_=0;_<b.length;_+=1){u=b[_],l=g.map(function(t){return[Math.abs(t[0]-u),t[0],t[1],t[2]]}).sort().slice(0,a),d=t.max(l)[0],l=l.map(function(t){return{w:kn(t[0]/d)*t[3],x:t[1],y:t[2]}});var w=Sn(l);f=w.x0,c=w.beta,x.push(f+c*u)}return{x:b,y:x}}function Nn(e){var n;return n="count"===e.format?function(n){var r,o=n%1!==0;return r=o?t.format(",."+e.decimals+"f"):t.format(",.0f"),e.yax_units_append?r(n)+e.yax_units:e.yax_units+r(n)}:function(n){var r=(e.decimals?"."+e.decimals:"")+"%",o=t.format(r);return o(n)}}function An(t,e,r,o,i){var a,s,l=n(t);return s="string"==typeof e[o]?function(t){return t}:Nn(t),a=null!==r?i?Vn(r,e,o,t.utc):Kn(r,e,o):i?l(new Date(+e[o]))+"  ":(t.time_series?"":o+": ")+s(e[o])+"   "}function On(t,e){return An(t,e,t.x_mouseover,t.x_accessor,t.time_series)}function Dn(t,e){return An(t,e,t.y_mouseover,t.y_accessor,!1)}function In(t,e){return An(t,e,t.x_mouseover,"key",t.time_series)}function Rn(e,n){return function(){for(var r=this,o=r.cloneNode(),i=r.getTotalLength()||0,a=(o.setAttribute("d",e),o).getTotalLength()||0,s=[0],l=0,u=n/Math.max(i,a);(l+=u)<1;)s.push(l);s.push(1);var c=s.map(function(e){var n=r.getPointAtLength(e*i),s=o.getPointAtLength(e*a);return t.interpolate([n.x,n.y],[s.x,s.y])});return function(t){return t<1?"M"+c.map(function(e){return e(t)}).join("L"):e}}}function Ln(e){var n=s.virtual_window,r=t.select(n.document),o=n.document.createElement("div"),i=a.d3,l=a.window,u=a.document;a.d3=r,a.window=n,a.document=n.document;var c;try{e(o)}catch(t){c=t}if(a.d3=i,a.window=l,a.document=u,c)throw c;return r.select(function(){return o}).html()}function Fn(e){var n=document.createElement("div");return e(n),t.select(n).html()}function jn(t){switch(typeof window){case"undefined":return Ln(t);default:return Fn(t)}}function Bn(t,e){if(!s.virtual_window||e){var n=t.jsdom({html:"",features:{QuerySelector:!0}});s.virtual_window=n.defaultView}}function Un(e){console.error("ERROR : ",e.target," : ",e.error),t.select(e.target).select(".mg-chart-title").append("tspan").attr("class","fa fa-x fa-exclamation-circle mg-warning").attr("dx","0.3em").text("")}function Hn(t){console.error("INTERNAL ERROR : ",t.target," : ",t.internal_error)}("undefined"==typeof window?a:window).MG={version:"2.11"},s.convert={},s.convert.date=function(e,n,r){r="undefined"==typeof r?"%Y-%m-%d":r;var o=t.timeParse(r);return e=e.map(function(t){return t[n]=o(t[n].trim()),t})},s.convert.number=function(t,e){return t=t.map(function(t){return t[e]=Number(t[e]),t})},s.time_format=function(e,n){return e?t.utcFormat(n):t.timeFormat(n)};var zn=function(t,e,n){var r={};if(null===t)return t;if(Array.prototype.forEach&&t.forEach===Array.prototype.forEach)t.forEach(e,n);else if(t.length===+t.length){for(var o=0,i=t.length;o<i;o++)if(e.call(n,t[o],o,t)===r)return}else for(var a in t)if(e.call(n,t[a],a,t)===r)return;return t};s.merge_with_defaults=V,s.clone=function(t){var e;if(null===t||"object"!=typeof t)return t;if(K(t))return e=new Date,e.setTime(t.getTime()),e;if(G(t)){e=[];for(var n=0,r=t.length;n<r;n++)e[n]=s.clone(t[n]);return e}if(Y(t)){e={};for(var o in t)t.hasOwnProperty(o)&&(e[o]=s.clone(t[o]));return e}throw new Error("Unable to copy obj! Its type isn't supported.")},s.arr_diff=X,s.warn_deprecation=$,s.truncate_text=Z,s.wrap_text=J,s.register=Q,s._hooks={},s.add_hook=function(t,e,n){var r;s._hooks[t]||(s._hooks[t]=[]),r=s._hooks[t];var o=r.filter(function(t){return t.func===e}).length>0;if(o)throw"That function is already registered.";r.push({func:e,context:n})},s.call_hook=function(t){var e,n=s._hooks[t],r=[].slice.apply(arguments,[1]);return n&&n.forEach(function(t){if(t.func){var n=e||r;n&&n.constructor!==Array&&(n=[n]),n=[].concat.apply([],n),e=t.func.apply(t.context,n)}}),e||r},s.globals={},s.deprecations={rollover_callback:{replacement:"mouseover",version:"2.0"},rollout_callback:{replacement:"mouseout",version:"2.0"},x_rollover_format:{replacement:"x_mouseover",version:"2.10"},y_rollover_format:{replacement:"y_mouseover",version:"2.10"},show_years:{replacement:"show_secondary_x_label",version:"2.1"},xax_start_at_min:{replacement:"axes_not_compact",version:"2.7"},interpolate_tension:{replacement:"interpolate",version:"2.10"}},s.globals.link=!1,s.globals.version="1.1",s.charts={},s.data_graphic=function(e){"use strict";var n={missing_is_zero:!1,missing_is_hidden:!1,missing_is_hidden_accessor:null,legend:"",legend_target:"",error:"",animate_on_load:!1,top:65,title_y_position:10,center_title_full_width:!1,bottom:45,right:10,left:50,buffer:8,width:350,height:220,full_width:!1,full_height:!1,small_height_threshold:120,small_width_threshold:160,xax_count:6,xax_tick_length:5,axes_not_compact:!0,yax_count:3,yax_tick_length:5,x_extended_ticks:!1,y_extended_ticks:!1,y_scale_type:"linear",max_x:null,max_y:null,min_x:null,min_y:null,min_y_from_data:!1,point_size:2.5,x_accessor:"date",xax_units:"",x_label:"",x_sort:!0,x_axis:!0,y_axis:!0,x_axis_position:"bottom",y_axis_position:"left",x_axis_type:null,y_axis_type:null,ygroup_accessor:null,xgroup_accessor:null,y_padding_percentage:.05,y_outer_padding_percentage:.1,ygroup_padding_percentage:.25,ygroup_outer_padding_percentage:0,x_padding_percentage:.05,x_outer_padding_percentage:.1,xgroup_padding_percentage:.25,xgroup_outer_padding_percentage:0,y_categorical_show_guides:!1,x_categorical_show_guide:!1,rotate_x_labels:0,rotate_y_labels:0,y_accessor:"value",y_label:"",yax_units:"",yax_units_append:!1,x_rug:!1,y_rug:!1,mouseover_align:"right",x_mouseover:null,y_mouseover:null,transition_on_update:!0,mouseover:null,click:null,show_rollover_text:!0,show_confidence_band:null,xax_format:null,area:!0,chart_type:"line",data:[],decimals:2,format:"count",inflator:10/9,linked:!1,linked_format:"%Y-%m-%d",list:!1,baselines:null,markers:null,scalefns:{},scales:{},utc_time:!1,european_clock:!1,show_year_markers:!1,show_secondary_x_label:!0,target:"#viz",interpolate:t.curveCatmullRom.alpha(0),custom_line_color_map:[],colors:null,max_data_size:null,aggregate_rollover:!1,show_tooltips:!0};s.call_hook("global.defaults",n),e||(e={});var r=s.charts[e.chart_type||n.chart_type];V(e,r.defaults,n),e.list&&(e.x_accessor=0,e.y_accessor=1);for(var o in s.deprecations)if(e.hasOwnProperty(o)){var i=s.deprecations[o],a="Use of `args."+o+"` has been deprecated",l=i.replacement;if(l&&(e[l]?a+=". The replacement - `args."+l+"` - has already been defined. This definition will be discarded.":e[l]=e[o]),i.warned)continue;i.warned=!0,l&&(a+=" in favor of `args."+l+"`"),$(a,i.version)}return s.call_hook("global.before_init",e),new r.descriptor(e),e.data},e()&&(+function(t){"use strict";function e(e){return this.each(function(){var r=t(this),o=r.data("bs.tooltip"),i="object"==typeof e&&e;!o&&/destroy|hide/.test(e)||(o||r.data("bs.tooltip",o=new n(this,i)),"string"==typeof e&&o[e]())})}var n=function(t,e){this.type=null,this.options=null,this.enabled=null,this.timeout=null,this.hoverState=null,this.$element=null,this.inState=null,this.init("tooltip",t,e)};n.VERSION="3.3.5",n.TRANSITION_DURATION=150,n.DEFAULTS={animation:!0,placement:"top",selector:!1,template:'<div class="tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',trigger:"hover focus",title:"",delay:0,html:!1,container:!1,viewport:{selector:"body",padding:0}},n.prototype.init=function(e,n,r){if(this.enabled=!0,this.type=e,this.$element=t(n),this.options=this.getOptions(r),this.$viewport=this.options.viewport&&t(t.isFunction(this.options.viewport)?this.options.viewport.call(this,this.$element):this.options.viewport.selector||this.options.viewport),this.inState={click:!1,hover:!1,focus:!1},this.$element[0]instanceof document.constructor&&!this.options.selector)throw new Error("`selector` option must be specified when initializing "+this.type+" on the window.document object!");for(var o=this.options.trigger.split(" "),i=o.length;i--;){var a=o[i];if("click"==a)this.$element.on("click."+this.type,this.options.selector,t.proxy(this.toggle,this));else if("manual"!=a){var s="hover"==a?"mouseenter":"focusin",l="hover"==a?"mouseleave":"focusout";this.$element.on(s+"."+this.type,this.options.selector,t.proxy(this.enter,this)),this.$element.on(l+"."+this.type,this.options.selector,t.proxy(this.leave,this))}}this.options.selector?this._options=t.extend({},this.options,{trigger:"manual",selector:""}):this.fixTitle()},n.prototype.getDefaults=function(){return n.DEFAULTS},n.prototype.getOptions=function(e){return e=t.extend({},this.getDefaults(),this.$element.data(),e),e.delay&&"number"==typeof e.delay&&(e.delay={show:e.delay,hide:e.delay}),e},n.prototype.getDelegateOptions=function(){var e={},n=this.getDefaults();return this._options&&t.each(this._options,function(t,r){n[t]!=r&&(e[t]=r)}),e},n.prototype.enter=function(e){var n=e instanceof this.constructor?e:t(e.currentTarget).data("bs."+this.type);return n||(n=new this.constructor(e.currentTarget,this.getDelegateOptions()),t(e.currentTarget).data("bs."+this.type,n)),e instanceof t.Event&&(n.inState["focusin"==e.type?"focus":"hover"]=!0),n.tip().hasClass("in")||"in"==n.hoverState?void(n.hoverState="in"):(clearTimeout(n.timeout),n.hoverState="in",n.options.delay&&n.options.delay.show?void(n.timeout=setTimeout(function(){"in"==n.hoverState&&n.show()},n.options.delay.show)):n.show())},n.prototype.isInStateTrue=function(){for(var t in this.inState)if(this.inState[t])return!0;return!1},n.prototype.leave=function(e){var n=e instanceof this.constructor?e:t(e.currentTarget).data("bs."+this.type);if(n||(n=new this.constructor(e.currentTarget,this.getDelegateOptions()),t(e.currentTarget).data("bs."+this.type,n)),e instanceof t.Event&&(n.inState["focusout"==e.type?"focus":"hover"]=!1),!n.isInStateTrue())return clearTimeout(n.timeout),n.hoverState="out",n.options.delay&&n.options.delay.hide?void(n.timeout=setTimeout(function(){"out"==n.hoverState&&n.hide()},n.options.delay.hide)):n.hide()},n.prototype.show=function(){var e=t.Event("show.bs."+this.type);if(this.hasContent()&&this.enabled){this.$element.trigger(e);var r=t.contains(this.$element[0].ownerDocument.documentElement,this.$element[0]);if(e.isDefaultPrevented()||!r)return;var o=this,i=this.tip(),a=this.getUID(this.type);this.setContent(),i.attr("id",a),this.$element.attr("aria-describedby",a),this.options.animation&&i.addClass("fade");var s="function"==typeof this.options.placement?this.options.placement.call(this,i[0],this.$element[0]):this.options.placement,l=/\s?auto?\s?/i,u=l.test(s);u&&(s=s.replace(l,"")||"top"),i.detach().css({top:0,left:0,display:"block"}).addClass(s).data("bs."+this.type,this),this.options.container?i.appendTo(this.options.container):i.insertAfter(this.$element),this.$element.trigger("inserted.bs."+this.type);var c=this.getPosition(),f=i[0].offsetWidth,d=i[0].offsetHeight;if(u){var p=s,h=this.getPosition(this.$viewport);s="bottom"==s&&c.bottom+d>h.bottom?"top":"top"==s&&c.top-d<h.top?"bottom":"right"==s&&c.right+f>h.width?"left":"left"==s&&c.left-f<h.left?"right":s,i.removeClass(p).addClass(s)}var g=this.getCalculatedOffset(s,c,f,d);this.applyPlacement(g,s);var v=function(){var t=o.hoverState;o.$element.trigger("shown.bs."+o.type),o.hoverState=null,"out"==t&&o.leave(o)};t.support.transition&&this.$tip.hasClass("fade")?i.one("bsTransitionEnd",v).emulateTransitionEnd(n.TRANSITION_DURATION):v()}},n.prototype.applyPlacement=function(e,n){var r=this.tip(),o=r[0].offsetWidth,i=r[0].offsetHeight,a=parseInt(r.css("margin-top"),10),s=parseInt(r.css("margin-left"),10);isNaN(a)&&(a=0),isNaN(s)&&(s=0),e.top+=a,e.left+=s,t.offset.setOffset(r[0],t.extend({using:function(t){r.css({top:Math.round(t.top),left:Math.round(t.left)})}},e),0),r.addClass("in");var l=r[0].offsetWidth,u=r[0].offsetHeight;"top"==n&&u!=i&&(e.top=e.top+i-u);var c=this.getViewportAdjustedDelta(n,e,l,u);c.left?e.left+=c.left:e.top+=c.top;var f=/top|bottom/.test(n),d=f?2*c.left-o+l:2*c.top-i+u,p=f?"offsetWidth":"offsetHeight";r.offset(e),this.replaceArrow(d,r[0][p],f)},n.prototype.replaceArrow=function(t,e,n){this.arrow().css(n?"left":"top",50*(1-t/e)+"%").css(n?"top":"left","")},n.prototype.setContent=function(){var t=this.tip(),e=this.getTitle();t.find(".tooltip-inner")[this.options.html?"html":"text"](e),t.removeClass("fade in top bottom left right")},n.prototype.hide=function(e){function r(){"in"!=o.hoverState&&i.detach(),o.$element.removeAttr("aria-describedby").trigger("hidden.bs."+o.type),e&&e()}var o=this,i=t(this.$tip),a=t.Event("hide.bs."+this.type);if(this.$element.trigger(a),!a.isDefaultPrevented())return i.removeClass("in"),t.support.transition&&i.hasClass("fade")?i.one("bsTransitionEnd",r).emulateTransitionEnd(n.TRANSITION_DURATION):r(),this.hoverState=null,this},n.prototype.fixTitle=function(){var t=this.$element;(t.attr("title")||"string"!=typeof t.attr("data-original-title"))&&t.attr("data-original-title",t.attr("title")||"").attr("title","")},n.prototype.hasContent=function(){return this.getTitle()},n.prototype.getPosition=function(e){e=e||this.$element;var n=e[0],r="BODY"==n.tagName,o=n.getBoundingClientRect();null==o.width&&(o=t.extend({},o,{width:o.right-o.left,height:o.bottom-o.top}));var i=r?{top:0,left:0}:e.offset(),a={scroll:r?document.documentElement.scrollTop||document.body.scrollTop:e.scrollTop()},s=r?{width:t(window).width(),height:t(window).height()}:null;return t.extend({},o,a,s,i)},n.prototype.getCalculatedOffset=function(t,e,n,r){return"bottom"==t?{top:e.top+e.height,left:e.left+e.width/2-n/2}:"top"==t?{top:e.top-r,left:e.left+e.width/2-n/2}:"left"==t?{top:e.top+e.height/2-r/2,left:e.left-n}:{top:e.top+e.height/2-r/2,left:e.left+e.width}},n.prototype.getViewportAdjustedDelta=function(t,e,n,r){var o={top:0,left:0};if(!this.$viewport)return o;var i=this.options.viewport&&this.options.viewport.padding||0,a=this.getPosition(this.$viewport);if(/right|left/.test(t)){var s=e.top-i-a.scroll,l=e.top+i-a.scroll+r;s<a.top?o.top=a.top-s:l>a.top+a.height&&(o.top=a.top+a.height-l)}else{var u=e.left-i,c=e.left+i+n;u<a.left?o.left=a.left-u:c>a.right&&(o.left=a.left+a.width-c)}return o},n.prototype.getTitle=function(){var t,e=this.$element,n=this.options;return t=e.attr("data-original-title")||("function"==typeof n.title?n.title.call(e[0]):n.title)},n.prototype.getUID=function(t){do t+=~~(1e6*Math.random());while(document.getElementById(t));return t},n.prototype.tip=function(){if(!this.$tip&&(this.$tip=t(this.options.template),1!=this.$tip.length))throw new Error(this.type+" `template` option must consist of exactly 1 top-level element!");return this.$tip},n.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".tooltip-arrow")},n.prototype.enable=function(){this.enabled=!0},n.prototype.disable=function(){this.enabled=!1},n.prototype.toggleEnabled=function(){this.enabled=!this.enabled},n.prototype.toggle=function(e){var n=this;e&&(n=t(e.currentTarget).data("bs."+this.type),n||(n=new this.constructor(e.currentTarget,this.getDelegateOptions()),t(e.currentTarget).data("bs."+this.type,n))),e?(n.inState.click=!n.inState.click,n.isInStateTrue()?n.enter(n):n.leave(n)):n.tip().hasClass("in")?n.leave(n):n.enter(n)},n.prototype.destroy=function(){var t=this;clearTimeout(this.timeout),this.hide(function(){t.$element.off("."+t.type).removeData("bs."+t.type),t.$tip&&t.$tip.detach(),t.$tip=null,t.$arrow=null,t.$viewport=null})};var r=t.fn.tooltip;t.fn.tooltip=e,t.fn.tooltip.Constructor=n,t.fn.tooltip.noConflict=function(){return t.fn.tooltip=r,this}}(l),+function(t){"use strict";function e(e){return this.each(function(){var r=t(this),o=r.data("bs.popover"),i="object"==typeof e&&e;!o&&/destroy|hide/.test(e)||(o||r.data("bs.popover",o=new n(this,i)),"string"==typeof e&&o[e]())})}var n=function(t,e){this.init("popover",t,e)};if(!t.fn.tooltip)throw new Error("Popover requires tooltip.js");n.VERSION="3.3.5",n.DEFAULTS=t.extend({},t.fn.tooltip.Constructor.DEFAULTS,{placement:"right",trigger:"click",content:"",template:'<div class="popover" role="tooltip"><div class="arrow"></div><h3 class="popover-title"></h3><div class="popover-content"></div></div>'}),n.prototype=t.extend({},t.fn.tooltip.Constructor.prototype),n.prototype.constructor=n,n.prototype.getDefaults=function(){return n.DEFAULTS},n.prototype.setContent=function(){var t=this.tip(),e=this.getTitle(),n=this.getContent();t.find(".popover-title")[this.options.html?"html":"text"](e),t.find(".popover-content").children().detach().end()[this.options.html?"string"==typeof n?"html":"append":"text"](n),t.removeClass("fade top bottom left right in"),t.find(".popover-title").html()||t.find(".popover-title").hide()},n.prototype.hasContent=function(){return this.getTitle()||this.getContent()},n.prototype.getContent=function(){var t=this.$element,e=this.options;return t.attr("data-content")||("function"==typeof e.content?e.content.call(t[0]):e.content)},n.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".arrow")};var r=t.fn.popover;t.fn.popover=e,t.fn.popover.Constructor=n,t.fn.popover.noConflict=function(){return t.fn.popover=r,this}}(l)),s.chart_title=tt,s.scale_factory=rt;var Wn={};Wn.categorical=function(t,e){e.namespace;Tt(t,e),Ct(t,e)},Wn.numerical=function(t,e){var n=e.namespace,r=n+"_axis",o="mg-"+n+"-axis",i=F(t.target);if(E(i,"."+o),!t[r])return this;var a=P(i,o);return lt(t,n),bt(a,t,e),yt(a,t,e),mt(a,t,e),t[n+"_label"]&&e.label(i.select(".mg-"+n+"-axis"),t),t[n+"_rug"]&&_t(t,e),t.show_bar_zero&&Mt(t),this},s.axis_factory=Et,s.y_rug=Pt,s.y_axis=It,s.y_axis_categorical=Ut,s.x_rug=Ht,s.x_axis=Wt,s.x_axis_categorical=qt,s.init=Le,s.markers=$e;var qn=new rn;e()&&/*!
	     * Bootstrap v3.3.1 (http://getbootstrap.com)
	     * Copyright 2011-2014 Twitter, Inc.
	     * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
	     */
/*!
	     * Generated using the Bootstrap Customizer (http://getbootstrap.com/customize/?id=c3834cc5b59ef727da53)
	     * Config saved to config.json and https://gist.github.com/c3834cc5b59ef727da53
	     */
+function(t){"use strict";function e(e){e&&3===e.which||(t(o).remove(),t(i).each(function(){var r=t(this),o=n(r),i={relatedTarget:this};o.hasClass("open")&&(o.trigger(e=t.Event("hide.bs.dropdown",i)),e.isDefaultPrevented()||(r.attr("aria-expanded","false"),o.removeClass("open").trigger("hidden.bs.dropdown",i)))}))}function n(e){var n=e.attr("data-target");n||(n=e.attr("href"),n=n&&/#[A-Za-z]/.test(n)&&n.replace(/.*(?=#[^\s]*$)/,""));var r=n&&t(n);return r&&r.length?r:e.parent()}function r(e){return this.each(function(){var n=t(this),r=n.data("bs.dropdown");r||n.data("bs.dropdown",r=new a(this)),"string"==typeof e&&r[e].call(n)})}if("function"==typeof t().dropdown)return!0;var o=".dropdown-backdrop",i='[data-toggle="dropdown"]',a=function(e){t(e).on("click.bs.dropdown",this.toggle)};a.VERSION="3.3.1",a.prototype.toggle=function(r){var o=t(this);if(!o.is(".disabled, :disabled")){var i=n(o),a=i.hasClass("open");if(e(),!a){"ontouchstart"in document.documentElement&&!i.closest(".navbar-nav").length&&t('<div class="dropdown-backdrop"/>').insertAfter(t(this)).on("click",e);var s={relatedTarget:this};if(i.trigger(r=t.Event("show.bs.dropdown",s)),r.isDefaultPrevented())return;o.trigger("focus").attr("aria-expanded","true"),i.toggleClass("open").trigger("shown.bs.dropdown",s)}return!1}},a.prototype.keydown=function(e){if(/(38|40|27|32)/.test(e.which)&&!/input|textarea/i.test(e.target.tagName)){var r=t(this);if(e.preventDefault(),e.stopPropagation(),!r.is(".disabled, :disabled")){var o=n(r),a=o.hasClass("open");if(!a&&27!=e.which||a&&27==e.which)return 27==e.which&&o.find(i).trigger("focus"),r.trigger("click");var s=" li:not(.divider):visible a",l=o.find('[role="menu"]'+s+', [role="listbox"]'+s);if(l.length){var u=l.index(e.target);38==e.which&&u>0&&u--,40==e.which&&u<l.length-1&&u++,~u||(u=0),l.eq(u).trigger("focus")}}}};var s=t.fn.dropdown;t.fn.dropdown=r,t.fn.dropdown.Constructor=a,t.fn.dropdown.noConflict=function(){return t.fn.dropdown=s,this},t(document).on("click.bs.dropdown.data-api",e).on("click.bs.dropdown.data-api",".dropdown form",function(t){t.stopPropagation()}).on("click.bs.dropdown.data-api",i,a.prototype.toggle).on("keydown.bs.dropdown.data-api",i,a.prototype.keydown).on("keydown.bs.dropdown.data-api",'[role="menu"]',a.prototype.keydown).on("keydown.bs.dropdown.data-api",'[role="listbox"]',a.prototype.keydown)}(l),s.button_layout=function(t){"use strict";return this.target=t,this.feature_set={},this.public_name={},this.sorters={},this.manual=[],this.manual_map={},this.manual_callback={},this._strip_punctuation=function(t){var e=t.replace(/[^a-zA-Z0-9 _]+/g,""),n=e.replace(/ +?/g,"");return n},this.data=function(t){return this._data=t,this},this.manual_button=function(t,e,n){return this.feature_set[t]=e,this.manual_map[this._strip_punctuation(t)]=t,this.manual_callback[t]=n,this},this.button=function(t){return arguments.length>1&&(this.public_name[t]=arguments[1]),arguments.length>2&&(this.sorters[t]=arguments[2]),this.feature_set[t]=[],this},this.callback=function(t){return this._callback=t,this},this.display=function(){var t,e,n,r,o=this._callback,i=this.manual_callback,a=this.manual_map;n=Object.keys(this.feature_set);var s,l=function(e){return t[e]};for(s=0;s<this._data.length;s++){t=this._data[s],e=n.map(l);for(var c=0;c<n.length;c++)r=n[c],this.feature_set[r].indexOf(e[c])===-1&&this.feature_set[r].push(e[c])}for(r in this.feature_set)this.sorters.hasOwnProperty(r)&&this.feature_set[r].sort(this.sorters[r]);u(this.target).empty(),u(this.target).append("<div class='col-lg-12 segments text-center'></div>");var f=function(){var t,e=u(this).data("key"),n=u(this).data("feature");return u("."+n+"-btns button.btn span.title").html(e),a.hasOwnProperty(n)?(t=a[n],i[t](e)):o(n,e),!1};for(var d in this.feature_set){for(n=this.feature_set[d],u(this.target+" div.segments").append('<div class="btn-group '+this._strip_punctuation(d)+'-btns text-left"><button type="button" class="btn btn-default btn-lg dropdown-toggle" data-toggle="dropdown"><span class=\'which-button\'>'+(this.public_name.hasOwnProperty(d)?this.public_name[d]:d)+"</span><span class='title'>"+(this.manual_callback.hasOwnProperty(d)?this.feature_set[d][0]:"all")+'</span><span class="caret"></span></button><ul class="dropdown-menu" role="menu">'+(this.manual_callback.hasOwnProperty(d)?"":'<li><a href="#" data-feature="'+d+'" data-key="all">All</a></li>')+(this.manual_callback.hasOwnProperty(d)?"":'<li class="divider"></li>')+"</ul></div>"),s=0;s<n.length;s++)"all"!==n[s]&&void 0!==n[s]&&u(this.target+" div."+this._strip_punctuation(d)+"-btns ul.dropdown-menu").append('<li><a href="#" data-feature="'+this._strip_punctuation(d)+'" data-key="'+n[s]+'">'+n[s]+"</a></li>");u("."+this._strip_punctuation(d)+"-btns .dropdown-menu li a").on("click",f)}return this},this},function(){"use strict";function e(t,e,n){t.classed("mg-hover-line"+e.line_id+"-color",null===n.colors).attr("fill",null===n.colors?"":n.colors[e.line_id-1])}function a(t,e,n){f(t,e),u(t,e),c(t,e),l(t,e,n)}function l(e,n,r){n.existing_band=r.selectAll(".mg-confidence-band").nodes(),e.show_confidence_band&&(n.confidence_area=t.area().defined(n.line.defined()).x(e.scalefns.xf).y0(function(t){var n=e.show_confidence_band[0];return void 0!=t[n]?e.scales.Y(t[n]):e.scales.Y(t[e.y_accessor])}).y1(function(t){var n=e.show_confidence_band[1];return void 0!=t[n]?e.scales.Y(t[n]):e.scales.Y(t[e.y_accessor])}).curve(e.interpolate))}function u(e,n){n.area=t.area().defined(n.line.defined()).x(e.scalefns.xf).y0(e.scales.Y.range()[0]).y1(e.scalefns.yf).curve(e.interpolate)}function c(e,n){n.flat_line=t.line().defined(function(t){return(void 0===t._missing||t._missing!==!0)&&null!==t[e.y_accessor]}).x(e.scalefns.xf).y(function(){return e.scales.Y(n.data_median)}).curve(e.interpolate)}function f(e,n){n.line=t.line().x(e.scalefns.xf).y(e.scalefns.yf).curve(e.interpolate),e.missing_is_zero||(n.line=n.line.defined(function(t){return(void 0===t._missing||t._missing!==!0)&&null!==t[e.y_accessor]}))}function d(t,e,n,r){if(t.show_confidence_band){var o;n.select(".mg-confidence-band-"+r).empty()&&n.append("path").attr("class","mg-confidence-band mg-confidence-band-"+r),o=n.select(".mg-confidence-band-"+r),o.transition().duration(function(){return t.transition_on_update?1e3:0}).attr("d",e.confidence_area(t.data[r-1])).attr("clip-path","url(#mg-plot-window-"+U(t.target)+")")}}function p(t,e,n,r,o){var i=n.selectAll(".mg-main-area.mg-area"+o);e.display_area?i.empty()?n.append("path").classed("mg-main-area",!0).classed("mg-area"+o,!0).classed("mg-area"+o+"-color",null===t.colors).attr("d",e.area(t.data[r])).attr("fill",null===t.colors?"":t.colors[o-1]).attr("clip-path","url(#mg-plot-window-"+U(t.target)+")"):(n.node().appendChild(i.node()),i.transition().duration(e.update_transition_duration).attr("d",e.area(t.data[r])).attr("clip-path","url(#mg-plot-window-"+U(t.target)+")")):i.empty()||i.remove()}function h(t,e){t.classed("mg-line"+e+"-color",!0)}function g(t,e,n,r){t.colors&&t.colors.constructor===Array?(e.attr("stroke",t.colors[n]),t.colors.length<n+1&&h(e,r)):h(e,r)}function v(e,n,r,o){e.animate_on_load?(n.data_median=t.median(e.data[o],function(t){return t[e.y_accessor]}),r.attr("d",n.flat_line(e.data[o])).transition().duration(1e3).attr("d",n.line(e.data[o])).attr("clip-path","url(#mg-plot-window-"+U(e.target)+")")):r.attr("d",n.line(e.data[o])).attr("clip-path","url(#mg-plot-window-"+U(e.target)+")")}function m(t,e,n,r,o,i){if(r.empty()){var a=n.append("path").attr("class","mg-main-line mg-line"+i);g(t,a,o,i),v(t,e,a,o)}else{n.node().appendChild(r.node());var s=r.transition().duration(e.update_transition_duration);e.display_area||!t.transition_on_update||t.missing_is_hidden?s.attr("d",e.line(t.data[o])):s.attrTween("d",Rn(e.line(t.data[o]),4))}}function y(t,e,n,r){var a;if(t.legend)if(o(t.legend)?a=t.legend[n]:i(t.legend)&&(a=t.legend(t.data[n])),t.legend_target)t.colors&&t.colors.constructor===Array?e.legend_text="<span style='color:"+t.colors[n]+"'>&mdash; "+a+"&nbsp; </span>"+e.legend_text:e.legend_text="<span class='mg-line"+r+"-legend-color'>&mdash; "+a+"&nbsp; </span>"+e.legend_text;else{var s,l,u;"left"===t.y_axis_position?(s=t.data[n][t.data[n].length-1],l="start",u=t.buffer):(s=t.data[n][0],l="end",u=-t.buffer);var c=e.legend_group.append("svg:text").attr("x",t.scalefns.xf(s)).attr("dx",u).attr("y",t.scalefns.yf(s)).attr("dy",".35em").attr("font-size",10).attr("text-anchor",l).attr("font-weight","300").text(a);t.colors&&t.colors.constructor===Array?t.colors.length<n+1?c.classed("mg-line"+r+"-legend-color",!0):c.attr("fill",t.colors[n]):c.classed("mg-line"+r+"-legend-color",!0),D(e.legend_group.selectAll(".mg-line-legend text").nodes(),t)}}function b(e,n){e&&t.select(e).html(n)}function x(t,e,n){t.legend&&(e.legend_group=P(n,"mg-line-legend"))}function _(t){E(t,".mg-rollover-rect"),E(t,".mg-voronoi"),E(t,".mg-active-datapoint"),E(t,".mg-line-rollover-circle")}function T(t,e){var n=e.selectAll(".mg-line-rollover-circle").data(t.data).enter().append("circle").attr("cx",0).attr("cy",0).attr("r",0);t.colors&&t.colors.constructor===Array?n.attr("class",function(t){return"mg-line"+t.line_id}).attr("fill",function(e,n){return t.colors[n]}).attr("stroke",function(e,n){return t.colors[n]}):n.attr("class",function(t,e){return["mg-line"+t.line_id,"mg-line"+t.line_id+"-color","mg-area"+t.line_id+"-color"].join(" ")}),n.classed("mg-line-rollover-circle",!0)}function k(t){for(var e=1,n=0;n<t.data.length;n++){for(var r=0;r<t.data[n].length;r++)t.custom_line_color_map.length>0?t.data[n][r].line_id=t.custom_line_color_map[n]:t.data[n][r].line_id=e;e++}}function S(e){return t.merge(e.data)}function M(t){return function(e){var n;if(t.linked){var r=e[t.x_accessor],o=s.time_format(t.utc_time,t.linked_format),i="number"==typeof r?e.line_id-1:o(r);return n="roll_"+i+" mg-line"+e.line_id,null===t.color&&(n+=" mg-line"+e.line_id+"-color"),n}return n="mg-line"+e.line_id,null===t.color&&(n+=" mg-line"+e.line_id+"-color"),n}}function N(e,n,r,o,i){var a=t.voronoi().x(function(t){return e.scales.X(t[e.x_accessor]).toFixed(2)}).y(function(t){return e.scales.Y(t[e.y_accessor]).toFixed(2)}).extent([[e.buffer,e.buffer+e.title_y_position],[e.width-e.buffer,e.height-e.buffer]]),s=P(n,"mg-voronoi");s.selectAll("path").data(a.polygons(S(e))).enter().append("path").filter(function(t){return void 0!==t&&t.length>0}).attr("d",function(t){return null==t?null:"M"+t.join("L")+"Z"}).datum(function(t){return null==t?null:t.data}).attr("class",M(e)).on("mouseover",r).on("mouseout",o).on("mousemove",i),R(e,n)}function A(e){var n=t.nest().key(function(t){return t[e.x_accessor]}).entries(t.merge(e.data));return n.forEach(function(t){var n=t.values[0];t.key=n[e.x_accessor]}),e.x_sort?n.sort(function(t,e){return new Date(t.key)-new Date(e.key)}):n}function O(t,e,n,r,o){var i=A(t),a=i.map(function(e){return t.scales.X(e.key)}),s=e.append("g").attr("class","mg-rollover-rect");s.selectAll(".mg-rollover-rects").data(i).enter().append("rect").attr("x",function(e,n){return 1===a.length?w(t):0===n?a[n].toFixed(2):((a[n-1]+a[n])/2).toFixed(2)}).attr("y",t.top).attr("width",function(e,n){return 1===a.length?C(t):0===n?((a[n+1]-a[n])/2).toFixed(2):n===a.length-1?((a[n]-a[n-1])/2).toFixed(2):((a[n+1]-a[n-1])/2).toFixed(2)}).attr("class",function(e){var n=e.values.map(function(e){var n=L(e.line_id);return null===t.colors&&(n+=" "+j(e.line_id)),n}).join(" ");return t.linked&&e.values.length>0&&(n+=" "+B(H(e.values[0],0,t))),n}).attr("height",t.height-t.bottom-t.top-t.buffer).attr("opacity",0).on("mouseover",n).on("mouseout",r).on("mousemove",o),W(t,e)}function I(t,e){e.select(".mg-rollover-rect rect").on("mouseover")(t.data[0][0],0)}function R(t,e){for(var n=0;n<t.data.length;n++){var r=n+1;t.custom_line_color_map.length>0&&void 0!==t.custom_line_color_map[n]&&(r=t.custom_line_color_map[n]),1!==t.data[n].length||e.selectAll(".mg-voronoi .mg-line"+r).empty()||(e.selectAll(".mg-voronoi .mg-line"+r).on("mouseover")(t.data[n][0],0),e.selectAll(".mg-voronoi .mg-line"+r).on("mouseout")(t.data[n][0],0))}}function L(t){return"mg-line"+t}function j(t){return"mg-line"+t+"-color"}function B(t){return"roll_"+t}function H(t,e,n){var r=t[n.x_accessor],o=s.time_format(n.utc_time,n.linked_format),i="number"==typeof r?e:o(r);return i}function z(t,e,n,r,o){var i=1;t.custom_line_color_map.length>0&&(i=t.custom_line_color_map[0]);var a=e.append("g").attr("class","mg-rollover-rect"),s=t.data[0].map(t.scalefns.xf);a.selectAll(".mg-rollover-rects").data(t.data[0]).enter().append("rect").attr("class",function(e,n){var r=j(i)+" "+L(e.line_id);return t.linked&&(r+=r+" "+B(H(e,n,t))),r}).attr("x",function(e,n){return 1===s.length?w(t):0===n?s[n].toFixed(2):((s[n-1]+s[n])/2).toFixed(2)}).attr("y",function(e,n){return t.data.length>1?t.scalefns.yf(e)-6:t.top}).attr("width",function(e,n){return 1===s.length?C(t):0===n?((s[n+1]-s[n])/2).toFixed(2):n===s.length-1?((s[n]-s[n-1])/2).toFixed(2):((s[n+1]-s[n-1])/2).toFixed(2)}).attr("height",function(e,n){return t.data.length>1?12:t.height-t.bottom-t.top-t.buffer}).attr("opacity",0).on("mouseover",n).on("mouseout",r).on("mousemove",o),K(t)&&I(t,e)}function W(t,e){var n=e.selectAll(".mg-rollover-rect rect"),r=n.nodes()[0][0]||n.nodes()[0];t.data.filter(function(t){return 1===t.length}).length>0&&n.on("mouseover")(r.__data__,0)}function q(t){return t.data.length>1&&!t.aggregate_rollover}function V(t){return t.data.length>1&&t.aggregate_rollover}function K(t){return 1===t.data.length&&1===t.data[0].length}function Y(t,e,n){G(e,n);for(var r=t.data.length-1;r>=0;r--){var o=t.data[r];s.call_hook("line.before_each_series",[o,t]);var i=r+1;if(t.custom_line_color_map.length>0&&(i=t.custom_line_color_map[r]),t.data[r].line_id=i,0!==o.length){var a=n.select("path.mg-main-line.mg-line"+i);d(t,e,n,i),p(t,e,n,r,i),m(t,e,n,a,r,i),y(t,e,r,i),s.call_hook("line.after_each_series",[o,a,t])}}}function G(t,e){t.existing_band[0]&&t.existing_band[0].length>e.selectAll(".mg-main-line").node().length&&e.selectAll(".mg-confidence-band").remove()}function X(t){var e={},n=F(t.target);E(n,".mg-line-legend"),x(t,e,n),e.data_median=0,e.update_transition_duration=t.transition_on_update?1e3:0,e.display_area=t.area&&!t.use_data_y_min&&t.data.length<=1&&t.aggregate_rollover===!1,e.legend_text="",a(t,e,n),e.existing_band=n.selectAll(".mg-confidence-band").nodes();var r=s.call_hook("line.before_all_series",[t]);r!==!1&&Y(t,e,n),b(t.legend_target,e.legend_text)}function $(t,e){var n=F(t.target);0===n.selectAll(".mg-active-datapoint-container").nodes().length&&P(n,"mg-active-datapoint-container"),_(n),T(t,n),k(t),q(t)?N(t,n,e.rolloverOn(t),e.rolloverOff(t),e.rolloverMove(t)):V(t)?O(t,n,e.rolloverOn(t),e.rolloverOff(t),e.rolloverMove(t)):z(t,n,e.rolloverOn(t),e.rolloverOff(t),e.rolloverMove(t))}function Z(t,e,n){if(t.aggregate_rollover&&t.data.length>1)e.selectAll("circle.mg-line-rollover-circle").style("opacity",0),n.values.forEach(function(n){r(n,t)&&J(t,e,n)});else{if(t.missing_is_hidden&&n._missing||null===n[t.y_accessor])return;r(n,t)&&Q(t,e,n)}}function J(t,e,n){e.select("circle.mg-line-rollover-circle.mg-line"+n.line_id).attr("cx",t.scales.X(n[t.x_accessor]).toFixed(2)).attr("cy",t.scales.Y(n[t.y_accessor]).toFixed(2)).attr("r",t.point_size).style("opacity",1)}function Q(t,e,n){e.selectAll("circle.mg-line-rollover-circle.mg-line"+n.line_id).classed("mg-line-rollover-circle",!0).attr("cx",function(){return t.scales.X(n[t.x_accessor]).toFixed(2)}).attr("cy",function(){return t.scales.Y(n[t.y_accessor]).toFixed(2)}).attr("r",t.point_size).style("opacity",1)}function tt(e,n,r){if(e.linked&&!s.globals.link&&(s.globals.link=!0,!e.aggregate_rollover||void 0!==n.value||n.values.length>0)){var o=n.values?n.values[0]:n,i=H(o,r,e);t.selectAll("."+L(o.line_id)+"."+B(i)).each(function(e){t.select(this).on("mouseover")(e,r)})}}function et(e,n,r){if(e.linked&&s.globals.link){s.globals.link=!1;var o=s.time_format(e.utc_time,e.linked_format),i=n.values?n.values:[n];i.forEach(function(n){var i=n[e.x_accessor],a="number"==typeof i?r:o(i);t.selectAll(".roll_"+a).each(function(e){t.select(this).on("mouseout")(e)})})}}function nt(t,e){e.selectAll("circle.mg-line-rollover-circle").filter(function(t){return t.length>1}).style("opacity",0)}function rt(t,e,n){e.selectAll("circle.mg-line-rollover-circle.mg-line"+n.line_id).style("opacity",function(){var e=n.line_id-1;return t.custom_line_color_map.length>0&&void 0!==t.custom_line_color_map.indexOf(n.line_id)&&(e=t.custom_line_color_map.indexOf(n.line_id)),1===t.data[e].length?1:0})}function ot(t){this.init=function(t){if(this.args=t,!t.data||0===t.data.length)return t.internal_error="No data was supplied",Hn(t),this;t.internal_error=void 0,cn(t),hn(t),s.call_hook("line.before_destroy",this),Le(t),new s.scale_factory(t).namespace("x").numericalDomainFromData().numericalRange("bottom");var e=(t.baselines||[]).map(function(e){return e[t.y_accessor]});new s.scale_factory(t).namespace("y").zeroBottom(!0).inflateDomain(!0).numericalDomainFromData(e).numericalRange("left");F(t.target);return t.x_axis&&new s.axis_factory(t).namespace("x").type("numerical").position(t.x_axis_position).rug(Ht(t)).label(Yt).draw(),t.y_axis&&new s.axis_factory(t).namespace("y").type("numerical").position(t.y_axis_position).rug(Pt(t)).label(Nt).draw(),this.markers(),this.mainPlot(),this.rollover(),this.windowListeners(),s.call_hook("line.after_init",this),this},this.mainPlot=function(){return X(t),this},this.markers=function(){return $e(t),this},this.rollover=function(){var e=this;return $(t,e),s.call_hook("line.after_rollover",t),this},this.rolloverOn=function(t){var r=F(t.target);n(t);return function(n,o){if(Z(t,r,n),tt(t,n,o),r.selectAll("text").filter(function(t,e){return n===t}).attr("opacity",.3),t.show_rollover_text&&!(t.missing_is_hidden&&n._missing||null===n[t.y_accessor])){var i=nn(t,{svg:r}),a=i.mouseover_row();t.aggregate_rollover&&a.text((t.aggregate_rollover&&t.data.length>1?In:On)(t,n));var s=t.aggregate_rollover&&t.data.length>1?n.values:[n];s.forEach(function(n){t.aggregate_rollover&&(a=i.mouseover_row()),t.legend&&e(a.text(t.legend[n.line_id-1]+"  ").bold().elem(),n,t),e(a.text("—  ").elem(),n,t),t.aggregate_rollover||a.text(On(t,n)),a.text(Dn(t,n,t.time_series===!1))})}t.mouseover&&t.mouseover(n,o)}},this.rolloverOff=function(t){var e=F(t.target);return function(n,r){et(t,n,r),t.aggregate_rollover?nt(t,e):rt(t,e,n),t.data[0].length>1&&Ze(e),t.mouseout&&t.mouseout(n,r)}},this.rolloverMove=function(t){return function(e,n){t.mousemove&&t.mousemove(e,n)}},this.windowListeners=function(){return on(this.args),this},this.init(t)}s.register("line",ot)}.call(this),function(){"use strict";function e(e){this.init=function(t){this.args=t,cn(t),gn(t),Le(t),new s.scale_factory(t).namespace("x").numericalDomainFromData().numericalRange("bottom");var e=(t.baselines||[]).map(function(e){return e[t.y_accessor]});return new s.scale_factory(t).namespace("y").zeroBottom(!0).inflateDomain(!0).numericalDomainFromData(e).numericalRange("left"),Wt(t),It(t),this.mainPlot(),this.markers(),this.rollover(),this.windowListeners(),this},this.mainPlot=function(){var t=F(e.target);t.selectAll(".mg-histogram").remove();var n=t.append("g").attr("class","mg-histogram"),r=n.selectAll(".mg-bar").data(e.data[0]).enter().append("g").attr("class","mg-bar").attr("transform",function(t){return"translate("+e.scales.X(t[e.x_accessor]).toFixed(2)+","+e.scales.Y(t[e.y_accessor]).toFixed(2)+")"});return r.append("rect").attr("x",1).attr("width",function(t,n){return 1===e.data[0].length?(e.scalefns.xf(e.data[0][0])-e.bar_margin).toFixed(0):n!==e.data[0].length-1?(e.scalefns.xf(e.data[0][n+1])-e.scalefns.xf(t)).toFixed(0):(e.scalefns.xf(e.data[0][1])-e.scalefns.xf(e.data[0][0])).toFixed(0)}).attr("height",function(t){return 0===t[e.y_accessor]?0:(e.height-e.bottom-e.buffer-e.scales.Y(t[e.y_accessor])).toFixed(2)}),this},this.markers=function(){return $e(e),this},this.rollover=function(){var t=F(e.target);0===t.selectAll(".mg-active-datapoint-container").nodes().length&&P(t,"mg-active-datapoint-container"),t.selectAll(".mg-rollover-rect").remove(),t.selectAll(".mg-active-datapoint").remove();var n=t.append("g").attr("class","mg-rollover-rect"),r=n.selectAll(".mg-bar").data(e.data[0]).enter().append("g").attr("class",function(t,n){return e.linked?"mg-rollover-rects roll_"+n:"mg-rollover-rects"}).attr("transform",function(t){return"translate("+e.scales.X(t[e.x_accessor])+",0)"});return r.append("rect").attr("x",1).attr("y",e.buffer+e.title_y_position).attr("width",function(t,n){return 1===e.data[0].length?(e.scalefns.xf(e.data[0][0])-e.bar_margin).toFixed(0):n!==e.data[0].length-1?(e.scalefns.xf(e.data[0][n+1])-e.scalefns.xf(t)).toFixed(0):(e.scalefns.xf(e.data[0][1])-e.scalefns.xf(e.data[0][0])).toFixed(0)}).attr("height",function(t){return e.height}).attr("opacity",0).on("mouseover",this.rolloverOn(e)).on("mouseout",this.rolloverOff(e)).on("mousemove",this.rolloverMove(e)),this},this.rolloverOn=function(e){var n=F(e.target);return function(r,o){n.selectAll("text").filter(function(t,e){return r===t}).attr("opacity",.3);e.processed.xax_format||s.time_format(e.utc_time,"%b %e, %Y"),Nn(e);if(n.selectAll(".mg-bar rect").filter(function(t,e){return e===o}).classed("active",!0),e.linked&&!s.globals.link&&(s.globals.link=!0,t.selectAll(".mg-rollover-rects.roll_"+o+" rect").each(function(e){t.select(this).on("mouseover")(e,o)})),e.show_rollover_text){var i=nn(e,{svg:n}),a=i.mouseover_row();a.text("▟  ").elem().classed("hist-symbol",!0),a.text(On(e,r)),a.text(Dn(e,r,e.time_series===!1))}e.mouseover&&(Je(n,e),e.mouseover(r,o))}},this.rolloverOff=function(e){var n=F(e.target);return function(r,o){e.linked&&s.globals.link&&(s.globals.link=!1,t.selectAll(".mg-rollover-rects.roll_"+o+" rect").each(function(e){t.select(this).on("mouseout")(e,o)})),n.selectAll(".mg-bar rect").classed("active",!1),Ze(n),e.mouseout&&e.mouseout(r,o)}},this.rolloverMove=function(t){return function(e,n){t.mousemove&&t.mousemove(e,n)}},this.windowListeners=function(){return on(this.args),this},this.init(e)}var n={binned:!1,bins:null,processed_x_accessor:"x",processed_y_accessor:"y",processed_dx_accessor:"dx",bar_margin:1};s.register("histogram",e,n)}.call(this),function(){"use strict";function e(t,e){var n=e.x_accessor,r=e.y_accessor,o=t.filter(function(t){return(null===e.min_x||t[n]>=e.min_x)&&(null===e.max_x||t[n]<=e.max_x)&&(null===e.min_y||t[r]>=e.min_y)&&(null===e.max_y||t[r]<=e.max_y)});return o}function n(n){this.init=function(t){this.args=t,t.x_axis_type=L(t,"x"),t.y_axis_type=L(t,"y"),cn(t),mn(t),Le(t);var e,n;if("categorical"===t.x_axis_type?(e=s.scale_factory(t).namespace("x").categoricalDomainFromData().categoricalRangeBands([0,t.xgroup_height],null===t.xgroup_accessor),t.xgroup_accessor?new s.scale_factory(t).namespace("xgroup").categoricalDomainFromData().categoricalRangeBands("bottom"):(t.scales.XGROUP=function(e){return w(t)},t.scalefns.xgroupf=function(e){return w(t)}),t.scalefns.xoutf=function(e){return t.scalefns.xf(e)+t.scalefns.xgroupf(e)}):(e=s.scale_factory(t).namespace("x").inflateDomain(!0).zeroBottom("categorical"===t.y_axis_type).numericalDomainFromData((t.baselines||[]).map(function(e){return e[t.x_accessor]})).numericalRange("bottom"),t.scalefns.xoutf=t.scalefns.xf),"categorical"===t.y_axis_type)n=s.scale_factory(t).namespace("y").zeroBottom(!0).categoricalDomainFromData().categoricalRangeBands([0,t.ygroup_height],!0),t.ygroup_accessor?new s.scale_factory(t).namespace("ygroup").categoricalDomainFromData().categoricalRangeBands("left"):(t.scales.YGROUP=function(){return x(t)},t.scalefns.ygroupf=function(e){return x(t)}),t.scalefns.youtf=function(e){return t.scalefns.yf(e)+t.scalefns.ygroupf(e)};else{var r=(t.baselines||[]).map(function(e){return e[t.y_accessor]});n=s.scale_factory(t).namespace("y").inflateDomain(!0).zeroBottom("categorical"===t.x_axis_type).numericalDomainFromData(r).numericalRange("left"),t.scalefns.youtf=function(e){return t.scalefns.yf(e)}}if(null!==t.color_accessor){var o=s.scale_factory(t).namespace("color");"number"===t.color_type?o.numericalDomainFromData(at(t)).numericalRange(st(t)).clamp(!0):t.color_domain?o.categoricalDomain(t.color_domain).categoricalRange(t.color_range):o.categoricalDomainFromData().categoricalColorRange()}return t.size_accessor&&new s.scale_factory(t).namespace("size").numericalDomainFromData().numericalRange(Kt(t)).clamp(!0),new s.axis_factory(t).namespace("x").type(t.x_axis_type).zeroLine("categorical"===t.y_axis_type).position(t.x_axis_position).rug(Ht(t)).label(Yt).draw(),new s.axis_factory(t).namespace("y").type(t.y_axis_type).zeroLine("categorical"===t.x_axis_type).position(t.y_axis_position).rug(Pt(t)).label(Nt).draw(),this.mainPlot(),this.markers(),this.rollover(),this.windowListeners(),this},this.markers=function(){return $e(n),n.least_squares&&yn(n),this},this.mainPlot=function(){var t,r=F(n.target),o=e(n.data[0],n);r.selectAll(".mg-points").remove(),t=r.append("g").classed("mg-points",!0);var i=t.selectAll("circle").data(o).enter().append("circle").attr("class",function(t,e){return"path-"+e}).attr("cx",n.scalefns.xoutf).attr("cy",function(t){return n.scalefns.youtf(t)});return null!==n.color_accessor?(i.attr("fill",n.scalefns.colorf),i.attr("stroke",n.scalefns.colorf)):i.classed("mg-points-mono",!0),null!==n.size_accessor?i.attr("r",n.scalefns.sizef):i.attr("r",n.point_size),this},this.rollover=function(){var r=F(n.target);0===r.selectAll(".mg-active-datapoint-container").nodes().length&&P(r,"mg-active-datapoint-container"),r.selectAll(".mg-voronoi").remove();var o=t.voronoi().x(n.scalefns.xoutf).y(n.scalefns.youtf).extent([[n.buffer,n.buffer+n.title_y_position],[n.width-n.buffer,n.height-n.buffer]]),i=r.append("g").attr("class","mg-voronoi");return i.selectAll("path").data(o.polygons(e(n.data[0],n))).enter().append("path").attr("d",function(t){return null==t?null:"M"+t.join(",")+"Z"}).attr("class",function(t,e){return"path-"+e}).style("fill-opacity",0).on("mouseover",this.rolloverOn(n)).on("mouseout",this.rolloverOff(n)).on("mousemove",this.rolloverMove(n)),1===n.data[0].length&&sn(n,r,n.data[0][0]),this},this.rolloverOn=function(e){var n=F(e.target);return function(r,o){n.selectAll(".mg-points circle").classed("selected",!1);var i=n.selectAll(".mg-points circle.path-"+o).classed("selected",!0);e.size_accessor?i.attr("r",function(t){return e.scalefns.sizef(t)+e.active_point_size_increase}):i.attr("r",e.point_size+e.active_point_size_increase),e.linked&&!s.globals.link&&(s.globals.link=!0,t.selectAll(".mg-voronoi .path-"+o).each(function(){t.select(this).on("mouseover")(r,o)})),e.show_rollover_text&&sn(e,n,r.data),e.mouseover&&e.mouseover(r,o)}},this.rolloverOff=function(e){var n=F(e.target);return function(r,o){e.linked&&s.globals.link&&(s.globals.link=!1,t.selectAll(".mg-voronoi .path-"+o).each(function(){t.select(this).on("mouseout")(r,o)}));var i=n.selectAll(".mg-points circle").classed("unselected",!1).classed("selected",!1);e.size_accessor?i.attr("r",e.scalefns.sizef):i.attr("r",e.point_size),e.data[0].length>1&&Ze(n),e.mouseout&&e.mouseout(r,o)}},this.rolloverMove=function(t){return function(e,n){t.mousemove&&t.mousemove(e,n)}},this.update=function(t){return this},this.windowListeners=function(){return on(this.args),this},this.init(n)}var r={y_padding_percentage:.05,y_outer_padding_percentage:.2,ygroup_padding_percentage:0,ygroup_outer_padding_percentage:0,x_padding_percentage:.05,x_outer_padding_percentage:.2,xgroup_padding_percentage:0,xgroup_outer_padding_percentage:0,y_categorical_show_guides:!0,x_categorical_show_guides:!0,buffer:16,ls:!1,lowess:!1,point_size:2.5,label_accessor:null,size_accessor:null,color_accessor:null,size_range:null,color_range:null,size_domain:null,color_domain:null,active_point_size_increase:1,color_type:"number"};s.register("point",n,r)}.call(this),function(){"use strict";function e(e){var n;if(e.legend_target){var r=t.select(e.legend_target).append("div").classed("mg-bar-target-legend",!0);n="horizontal"==e.orientation?e.scales.Y.domain():e.scales.X.domain(),n.forEach(function(t){var n=r.append("span").classed("mg-bar-target-element",!0);n.append("span").classed("mg-bar-target-legend-shape",!0).style("color",e.scales.COLOR(t)).text("◼ "),n.append("span").classed("mg-bar-target-legend-text",!0).text(t)})}}function n(t,e){var n;n="horizontal"==e.orientation?e.scales.Y.domain():e.scales.X.domain();var r=0,o=1.1,i=t.append("g").classed("mg-bar-legend",!0),a=i.append("text");a.selectAll("*").remove(),a.attr("width",e.right).attr("height",100).attr("text-anchor","start"),n.forEach(function(t){var n=a.append("tspan").attr("x",C(e)).attr("y",e.height/2).attr("dy",r*o+"em");n.append("tspan").text("■ ").attr("fill",e.scales.COLOR(t)).attr("font-size",20),n.append("tspan").text(t).attr("font-weight",300).attr("font-size",10),r++})}function r(r){this.args=r,this.init=function(t){this.args=t,t.x_axis_type=L(t,"x"),t.y_axis_type=L(t,"y"),"categorical"==t.x_axis_type?t.orientation="vertical":"categorical"==t.y_axis_type?t.orientation="horizontal":"categorical"!=t.x_axis_type&&"categorical"!=t.y_axis_type&&(t.orientation="vertical"),cn(t),mn(t),Le(t);var e,n;if("categorical"===t.x_axis_type?(e=s.scale_factory(t).namespace("x").categoricalDomainFromData().categoricalRangeBands([0,t.xgroup_height],null===t.xgroup_accessor),t.xgroup_accessor?new s.scale_factory(t).namespace("xgroup").categoricalDomainFromData().categoricalRangeBands("bottom"):(t.scales.XGROUP=function(e){return w(t)},t.scalefns.xgroupf=function(e){return w(t)}),t.scalefns.xoutf=function(e){return t.scalefns.xf(e)+t.scalefns.xgroupf(e)}):(e=s.scale_factory(t).namespace("x").inflateDomain(!0).zeroBottom("categorical"===t.y_axis_type).numericalDomainFromData((t.baselines||[]).map(function(e){return e[t.x_accessor]})).numericalRange("bottom"),t.scalefns.xoutf=t.scalefns.xf),"categorical"===t.y_axis_type)n=s.scale_factory(t).namespace("y").zeroBottom(!0).categoricalDomainFromData().categoricalRangeBands([0,t.ygroup_height],!0),t.ygroup_accessor?new s.scale_factory(t).namespace("ygroup").categoricalDomainFromData().categoricalRangeBands("left"):(t.scales.YGROUP=function(){return x(t)},t.scalefns.ygroupf=function(e){return x(t)}),t.scalefns.youtf=function(e){return t.scalefns.yf(e)+t.scalefns.ygroupf(e)};else{var r=(t.baselines||[]).map(function(e){return e[t.y_accessor]});n=s.scale_factory(t).namespace("y").inflateDomain(!0).zeroBottom("categorical"===t.x_axis_type).numericalDomainFromData(r).numericalRange("left"),t.scalefns.youtf=function(e){return t.scalefns.yf(e)}}return null!==t.ygroup_accessor&&(t.ycolor_accessor=t.y_accessor,s.scale_factory(t).namespace("ycolor").scaleName("color").categoricalDomainFromData().categoricalColorRange()),null!==t.xgroup_accessor&&(t.xcolor_accessor=t.x_accessor,s.scale_factory(t).namespace("xcolor").scaleName("color").categoricalDomainFromData().categoricalColorRange()),new s.axis_factory(t).namespace("x").type(t.x_axis_type).zeroLine("categorical"===t.y_axis_type).position(t.x_axis_position).draw(),new s.axis_factory(t).namespace("y").type(t.y_axis_type).zeroLine("categorical"===t.x_axis_type).position(t.y_axis_position).draw(),this.mainPlot(),this.markers(),this.rollover(),this.windowListeners(),this},this.mainPlot=function(){var t,o=F(r.target),i=r.data[0],a=o.select("g.mg-barplot"),s=a.empty(),l=s&&r.animate_on_load;l||r.transition_on_update,r.transition_duration||1e3;s&&(a=o.append("g").classed("mg-barplot",!0)),t=a.selectAll(".mg-bar").data(i).enter().append("rect").classed("mg-bar",!0).classed("default-bar",!r.scales.hasOwnProperty("COLOR"));var u,c,f,d,p,h,g,v,m,y,b,x,_,w,T,C;if("vertical"==r.orientation&&(u="height",c="width",f=r.y_axis_type,d=r.x_axis_type,p="y",h="x",g="categorical"==f?r.scalefns.youtf:r.scalefns.yf,v="categorical"==d?r.scalefns.xoutf:r.scalefns.xf,m=r.scales.Y,y=r.scales.X,b=r.y_accessor,x=r.x_accessor,_=function(t){var e;return e=g(t),t[b]<0&&(e=m(0)),e},w=function(t){return Math.abs(g(t)-m(0))},T=function(t){
return Math.abs(m(t[r.reference_accessor])-m(0))},C=function(t){return m(t[r.reference_accessor])}),"horizontal"==r.orientation&&(u="width",c="height",f=r.x_axis_type,d=r.y_axis_type,p="x",h="y",g="categorical"==f?r.scalefns.xoutf:r.scalefns.xf,v="categorical"==d?r.scalefns.youtf:r.scalefns.yf,m=r.scales.X,y=r.scales.Y,b=r.x_accessor,x=r.y_accessor,_=function(t){var e;return e=m(0)},w=function(t){return Math.abs(g(t)-m(0))},T=function(t){return Math.abs(m(t[r.reference_accessor])-m(0))},C=function(t){return m(0)}),t.attr(p,_),t.attr(h,function(t){var e;return"categorical"==d?e=v(t):(e=y(0),t[x]<0&&(e=v(t))),e-=r.bar_thickness/2}),r.scales.COLOR&&t.attr("fill",r.scalefns.colorf),t.attr(u,w).attr(c,function(t){return r.bar_thickness}),null!==r.reference_accessor){var k=i.filter(function(t){return t.hasOwnProperty(r.reference_accessor)}),E=a.selectAll(".mg-categorical-reference").data(k).enter().append("rect");E.attr(p,C).attr(h,function(t){return v(t)-r.reference_thickness/2}).attr(u,T).attr(c,r.reference_thickness)}if(null!==r.comparison_accessor){var P=null;P=null===r.comparison_thickness?r.bar_thickness/2:r.comparison_thickness;var S=i.filter(function(t){return t.hasOwnProperty(r.comparison_accessor)}),M=a.selectAll(".mg-categorical-comparison").data(S).enter().append("line");M.attr(p+"1",function(t){return m(t[r.comparison_accessor])}).attr(p+"2",function(t){return m(t[r.comparison_accessor])}).attr(h+"1",function(t){return v(t)-P/2}).attr(h+"2",function(t){return v(t)+P/2}).attr("stroke","black").attr("stroke-width",r.comparison_width)}return(r.legend||null!==r.color_accessor&&r.ygroup_accessor!==r.color_accessor)&&(r.legend_target?e(r):n(o,r)),this},this.markers=function(){return $e(r),this},this.rollover=function(){var t,e=F(r.target);0===e.selectAll(".mg-active-datapoint-container").nodes().length&&P(e,"mg-active-datapoint-container"),e.selectAll(".mg-rollover-rect").remove(),e.selectAll(".mg-active-datapoint").remove();var n,o,i,a,s,l,u,c,f,d,p,h,g,v;"vertical"==r.orientation&&(n="height",o="width",i=r.y_axis_type,a=r.x_axis_type,s="y",l="x",u="categorical"==i?r.scalefns.youtf:r.scalefns.yf,c="categorical"==a?r.scalefns.xoutf:r.scalefns.xf,f=r.scales.Y,d=r.scales.X,p=r.y_accessor,h=r.x_accessor,g=function(t){return x(r)},v=function(t){return r.height-r.top-r.bottom-2*r.buffer}),"horizontal"==r.orientation&&(n="width",o="height",i=r.x_axis_type,a=r.y_axis_type,s="x",l="y",u="categorical"==i?r.scalefns.xoutf:r.scalefns.xf,c="categorical"==a?r.scalefns.youtf:r.scalefns.yf,f=r.scales.X,d=r.scales.Y,p=r.x_accessor,h=r.y_accessor,g=function(t){var e;return e=f(0)},v=function(t){return r.width-r.left-r.right-2*r.buffer});var m,y;"right"===r.rollover_align?(m=r.width-r.right,y="end"):"left"===r.rollover_align?(m=r.left,y="start"):(m=(r.width-r.left-r.right)/2+r.left,y="middle"),e.append("text").attr("class","mg-active-datapoint").attr("xml:space","preserve").attr("x",m).attr("y",.75*r.top).attr("dy",".35em").attr("text-anchor",y),t=e.append("g").attr("class","mg-rollover-rect");var b=t.selectAll(".mg-bar-rollover").data(r.data[0]).enter().append("rect").attr("class","mg-bar-rollover");return b.attr("opacity",0).attr(s,g).attr(l,function(t){var e;return"categorical"==a?e=c(t):(e=d(0),t[h]<0&&(e=c(t))),e-=r.bar_thickness/2}),b.attr(n,v),b.attr(o,function(t){return r.bar_thickness}),b.on("mouseover",this.rolloverOn(r)).on("mouseout",this.rolloverOff(r)).on("mousemove",this.rolloverMove(r)),this},this.rolloverOn=function(e){var n=F(e.target);this.is_vertical?e.x_accessor:e.y_accessor,this.is_vertical?e.y_accessor:e.x_accessor,this.is_vertical?e.yax_units:e.xax_units;return function(r,o){var i=(s.time_format(e.utc_time,"%b %e, %Y"),Nn(e),n.selectAll("g.mg-barplot .mg-bar").filter(function(t,e){return e===o}).classed("active",!0));if(e.scales.hasOwnProperty("COLOR")?i.attr("fill",t.rgb(e.scalefns.colorf(r)).darker()):i.classed("default-active",!0),e.show_rollover_text){var a=nn(e,{svg:n}),l=a.mouseover_row();e.ygroup_accessor&&l.text(r[e.ygroup_accessor]+"   ").bold(),l.text(On(e,r)),l.text(e.y_accessor+": "+r[e.y_accessor]),(e.predictor_accessor||e.baseline_accessor)&&(l=a.mouseover_row(),e.predictor_accessor&&l.text(An(e,r,null,e.predictor_accessor,!1)),e.baseline_accessor&&l.text(An(e,r,null,e.baseline_accessor,!1)))}e.mouseover&&e.mouseover(r,o)}},this.rolloverOff=function(t){var e=F(t.target);return function(n,r){var o=e.selectAll("g.mg-barplot .mg-bar.active").classed("active",!1);t.scales.hasOwnProperty("COLOR")?o.attr("fill",t.scalefns.colorf(n)):o.classed("default-active",!1),e.select(".mg-active-datapoint").text(""),Ze(e),t.mouseout&&t.mouseout(n,r)}},this.rolloverMove=function(t){return function(e,n){t.mousemove&&t.mousemove(e,n)}},this.windowListeners=function(){return on(this.args),this},this.init(r)}var o={y_padding_percentage:.05,y_outer_padding_percentage:.2,ygroup_padding_percentage:0,ygroup_outer_padding_percentage:0,x_padding_percentage:.05,x_outer_padding_percentage:.2,xgroup_padding_percentage:0,xgroup_outer_padding_percentage:0,buffer:16,y_accessor:"factor",x_accessor:"value",reference_accessor:null,comparison_accessor:null,secondary_label_accessor:null,color_accessor:null,color_type:"category",color_domain:null,reference_thickness:1,comparison_width:3,comparison_thickness:null,legend:!1,legend_target:null,mouseover_align:"right",baseline_accessor:null,predictor_accessor:null,predictor_proportion:5,show_bar_zero:!0,binned:!0,truncate_x_labels:!0,truncate_y_labels:!0};s.register("bar",r,o)}.call(this),s.data_table=function(n){"use strict";return this.args=n,this.args.standard_col={width:150,font_size:12,font_weight:"normal"},this.args.columns=[],this.formatting_options=[["color","color"],["font-weight","font_weight"],["font-style","font_style"],["font-size","font_size"]],this._strip_punctuation=function(t){var e=t.replace(/[^a-zA-Z0-9 _]+/g,""),n=e.replace(/ +?/g,"");return n},this._format_element=function(t,e,n){this.formatting_options.forEach(function(r){var o=r[0],i=r[1];n[i]&&t.style(o,"string"==typeof n[i]||"number"==typeof n[i]?n[i]:n[i](e))})},this._add_column=function(t,e){var n=this.args.standard_col,r=V(s.clone(t),s.clone(n));r.type=e,this.args.columns.push(r)},this.target=function(){var t=arguments[0];return this.args.target=t,this},this.title=function(){return this._add_column(arguments[0],"title"),this},this.text=function(){return this._add_column(arguments[0],"text"),this},this.bullet=function(){return this},this.sparkline=function(){return this},this.number=function(){return this._add_column(arguments[0],"number"),this},this.display=function(){var n=this.args;tt(n);var r,o,i,a,s,l,c,f,d,p,h,g,v=n.target,m=t.select(v).append("table").classed("mg-data-table",!0),y=m.append("colgroup"),b=m.append("thead"),x=m.append("tbody");for(i=b.append("tr"),g=0;g<n.columns.length;g++){var _=n.columns[g];l=_.type,f=_.label,f=void 0===f?"":f,a=i.append("th").style("width",_.width).style("text-align","title"===l?"left":"right").text(f),n.show_tooltips&&_.description&&e()&&(a.append("i").classed("fa",!0).classed("fa-question-circle",!0).classed("fa-inverse",!0),u(a.node()).popover({html:!0,animation:!1,content:_.description,trigger:"hover",placement:"top",container:u(a.node())}))}for(g=0;g<n.columns.length;g++)h=y.append("col"),"number"===n.columns[g].type&&h.attr("align","char").attr("char",".");for(var w=0;w<n.data.length;w++){i=x.append("tr");for(var T=0;T<n.columns.length;T++){if(r=n.columns[T],s=r.accessor,c=d=n.data[w][s],l=r.type,"number"===l){if(r.hasOwnProperty("round")&&!r.hasOwnProperty("format")&&(d=t.format("0,."+r.round+"f")(d)),r.hasOwnProperty("value_formatter")&&(d=r.value_formatter(d)),r.hasOwnProperty("format")){r.round&&(d=Math.round(d,r.round));var C,k=r.format;"percentage"===k&&(C=t.format(".0%")),"count"===k&&(C=t.format(",.0f")),"temperature"===k&&(C=function(t){return t+"°"}),d=C(d)}r.hasOwnProperty("currency")&&(d=r.currency+d)}p=i.append("td").classed("table-"+l,!0).classed("table-"+l+"-"+this._strip_punctuation(s),!0).attr("data-value",c).style("width",r.width).style("text-align","title"===l||"text"===l?"left":"right"),this._format_element(p,c,r),"title"===l?(o=p.append("div").text(d),this._format_element(o,d,r),n.columns[T].hasOwnProperty("secondary_accessor")&&p.append("div").text(n.data[w][n.columns[T].secondary_accessor]).classed("secondary-title",!0)):p.text(d)}}return this},this},function(){"use strict";function e(t,e){t.selectAll(".mg-missing-text").data([e.missing_text]).enter().append("text").attr("class","mg-missing-text").attr("x",e.width/2).attr("y",e.height/2).attr("dy",".50em").attr("text-anchor","middle").text(e.missing_text)}function n(e){e.scales.X=t.scaleLinear().domain([0,e.data.length]).range([w(e),C(e)]),e.scalefns.yf=function(t){return e.scales.Y(t.y)}}function r(e){e.scales.Y=t.scaleLinear().domain([-2,2]).range([e.height-e.bottom-2*e.buffer,e.top]),e.scalefns.xf=function(t){return e.scales.X(t.x)}}function o(t){for(var e=[],n=1;n<=50;n++)e.push({x:n,y:Math.random()-.03*n});t.data=e}function i(t,e){t.append("svg:rect").classed("mg-missing-background",!0).attr("x",e.buffer).attr("y",e.buffer+2*e.title_y_position).attr("width",e.width-2*e.buffer).attr("height",e.height-2*e.buffer-2*e.title_y_position).attr("rx",15).attr("ry",15)}function a(e,n){var r=t.line().x(n.scalefns.xf).y(n.scalefns.yf).curve(n.interpolate);e.append("path").attr("class","mg-main-line mg-line1-color").attr("d",r(n.data))}function l(e,n){var r=t.area().x(n.scalefns.xf).y0(n.scales.Y.range()[0]).y1(n.scalefns.yf).curve(n.interpolate);e.append("path").attr("class","mg-main-area mg-area1-color").attr("d",r(n.data))}function u(e){t.select(e.target).selectAll("svg *").remove()}function c(e){e.legend_target&&t.select(e.legend_target).html("")}function f(s){this.init=function(s){this.args=s,xe(s),_e(s);var f=t.select(s.target);Me(f,s);var d=f.selectAll("svg");if(we(d,s),d=Te(d,s),ke(d,s),Ee(d,s),u(s),d.classed("mg-missing",!0),c(s),tt(s),s.show_missing_background){o(s),n(s),r(s);var p=P(d,"mg-missing-pane");i(p,s),a(p,s),l(p,s)}return e(d,s),this.windowListeners(),this},this.windowListeners=function(){return on(this.args),this},this.init(s)}var d={top:40,bottom:30,right:10,left:0,buffer:8,legend_target:"",width:350,height:220,missing_text:"Data currently missing or unavailable",scalefns:{},scales:{},show_tooltips:!0,show_missing_background:!0};s.register("missing-data",f,d)}.call(this),s.raw_data_transformation=cn,s.process_line=hn,s.process_histogram=gn,s.process_categorical_variables=vn,s.process_point=mn,s.add_ls=yn,s.add_lowess=bn,s.lowess_robust=xn,s.lowess=_n,s.least_squares=wn;var Vn=function(t,e,n,r){var o;return o="string"==typeof t?s.time_format(r,t)(e[n]):"function"==typeof t?t(e):e[n]},Kn=function(e,n,r){var o;return o="string"==typeof e?t.format("s")(n[r]):"function"==typeof e?e(n):n[r]};return s.format_rollover_number=Nn,s.path_tween=Rn,s.render_markup=jn,s.init_virtual_window=Bn,s.error=Un,s})}).call(e,function(){return this}(),n(171),n(169),n(169))},function(t,e,n){!function(t,n){n(e)}(this,function(t){"use strict";function e(t){return function(e,n){return Tu(t(e),n)}}function n(t,e,n){var r=Math.abs(e-t)/Math.max(0,n),o=Math.pow(10,Math.floor(Math.log(r)/Math.LN10)),i=r/o;return i>=Bu?o*=10:i>=Uu?o*=5:i>=Hu&&(o*=2),e<t?-o:o}function r(t){return t.length}function o(){}function i(t,e){var n=new o;if(t instanceof o)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var r,i=-1,a=t.length;if(null==e)for(;++i<a;)n.set(i,t[i]);else for(;++i<a;)n.set(e(r=t[i],i,t),r)}else if(t)for(var s in t)n.set(s,t[s]);return n}function a(){return{}}function s(t,e,n){t[e]=n}function l(){return i()}function u(t,e,n){t.set(e,n)}function c(){}function f(t,e){var n=new c;if(t instanceof c)t.each(function(t){n.add(t)});else if(t){var r=-1,o=t.length;if(null==e)for(;++r<o;)n.add(t[r]);else for(;++r<o;)n.add(e(t[r],r,t))}return n}function d(t){return+t}function p(t){return t*t}function h(t){return t*(2-t)}function g(t){return((t*=2)<=1?t*t:--t*(2-t)+1)/2}function v(t){return t*t*t}function m(t){return--t*t*t+1}function y(t){return((t*=2)<=1?t*t*t:(t-=2)*t*t+2)/2}function b(t){return 1-Math.cos(t*Tc)}function x(t){return Math.sin(t*Tc)}function _(t){return(1-Math.cos(wc*t))/2}function w(t){return Math.pow(2,10*t-10)}function T(t){return 1-Math.pow(2,-10*t)}function C(t){return((t*=2)<=1?Math.pow(2,10*t-10):2-Math.pow(2,10-10*t))/2}function k(t){return 1-Math.sqrt(1-t*t)}function E(t){return Math.sqrt(1- --t*t)}function P(t){return((t*=2)<=1?1-Math.sqrt(1-t*t):Math.sqrt(1-(t-=2)*t)+1)/2}function S(t){return 1-M(1-t)}function M(t){return(t=+t)<Cc?Dc*t*t:t<Ec?Dc*(t-=kc)*t+Pc:t<Mc?Dc*(t-=Sc)*t+Nc:Dc*(t-=Ac)*t+Oc}function N(t){return((t*=2)<=1?1-M(1-t):M(t-1)+1)/2}function A(t,e){return t[0]-e[0]||t[1]-e[1]}function O(t){for(var e=t.length,n=[0,1],r=2,o=2;o<e;++o){for(;r>1&&Kc(t[n[r-2]],t[n[r-1]],t[o])<=0;)--r;n[r++]=o}return n.slice(0,r)}function D(){this._x0=this._y0=this._x1=this._y1=null,this._=""}function I(){return new D}function R(t,e,n,r){if(isNaN(e)||isNaN(n))return t;var o,i,a,s,l,u,c,f,d,p=t._root,h={data:r},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=h,t;for(;p.length;)if((u=e>=(i=(g+m)/2))?g=i:m=i,(c=n>=(a=(v+y)/2))?v=a:y=a,o=p,!(p=p[f=c<<1|u]))return o[f]=h,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&n===l)return h.next=p,o?o[f]=h:t._root=h,t;do o=o?o[f]=new Array(4):t._root=new Array(4),(u=e>=(i=(g+m)/2))?g=i:m=i,(c=n>=(a=(v+y)/2))?v=a:y=a;while((f=c<<1|u)===(d=(l>=a)<<1|s>=i));return o[d]=p,o[f]=h,t}function L(t){var e,n,r,o,i=t.length,a=new Array(i),s=new Array(i),l=1/0,u=1/0,c=-(1/0),f=-(1/0);for(n=0;n<i;++n)isNaN(r=+this._x.call(null,e=t[n]))||isNaN(o=+this._y.call(null,e))||(a[n]=r,s[n]=o,r<l&&(l=r),r>c&&(c=r),o<u&&(u=o),o>f&&(f=o));for(c<l&&(l=this._x0,c=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(l,u).cover(c,f),n=0;n<i;++n)R(this,a[n],s[n],t[n]);return this}function F(t){for(var e=0,n=t.length;e<n;++e)this.remove(t[e]);return this}function j(t){return t[0]}function B(t){return t[1]}function U(t,e,n){var r=new H(null==e?j:e,null==n?B:n,NaN,NaN,NaN,NaN);return null==t?r:r.addAll(t)}function H(t,e,n,r,o,i){this._x=t,this._y=e,this._x0=n,this._y0=r,this._x1=o,this._y1=i,this._root=void 0}function z(t){for(var e={data:t.data},n=e;t=t.next;)n=n.next={data:t.data};return e}function W(t){if(!(t>=1))throw new Error;this._size=t,this._call=this._error=null,this._tasks=[],this._data=[],this._waiting=this._active=this._ended=this._start=0}function q(t){if(!t._start)try{V(t)}catch(e){if(t._tasks[t._ended+t._active-1])Y(t,e);else if(!t._data)throw e}}function V(t){for(;t._start=t._waiting&&t._active<t._size;){var e=t._ended+t._active,n=t._tasks[e],r=n.length-1,o=n[r];n[r]=K(t,e),--t._waiting,++t._active,n=o.apply(null,n),t._tasks[e]&&(t._tasks[e]=n||vf)}}function K(t,e){return function(n,r){t._tasks[e]&&(--t._active,++t._ended,t._tasks[e]=null,null==t._error&&(null!=n?Y(t,n):(t._data[e]=r,t._waiting?q(t):G(t))))}}function Y(t,e){var n,r=t._tasks.length;for(t._error=e,t._data=void 0,t._waiting=NaN;--r>=0;)if((n=t._tasks[r])&&(t._tasks[r]=null,n.abort))try{n.abort()}catch(t){}t._active=NaN,G(t)}function G(t){if(!t._active&&t._call){var e=t._data;t._data=void 0,t._call(t._error,e)}}function X(t){return new W(arguments.length?+t:1/0)}function $(t){return t.innerRadius}function Z(t){return t.outerRadius}function J(t){return t.startAngle}function Q(t){return t.endAngle}function tt(t){return t&&t.padAngle}function et(t){return t>=1?xf:t<=-1?-xf:Math.asin(t)}function nt(t,e,n,r,o,i,a,s){var l=n-t,u=r-e,c=a-o,f=s-i,d=(c*(e-i)-f*(t-o))/(f*l-c*u);return[t+d*l,e+d*u]}function rt(t,e,n,r,o,i,a){var s=t-n,l=e-r,u=(a?i:-i)/Math.sqrt(s*s+l*l),c=u*l,f=-u*s,d=t+c,p=e+f,h=n+c,g=r+f,v=(d+h)/2,m=(p+g)/2,y=h-d,b=g-p,x=y*y+b*b,_=o-i,w=d*g-h*p,T=(b<0?-1:1)*Math.sqrt(Math.max(0,_*_*x-w*w)),C=(w*b-y*T)/x,k=(-w*y-b*T)/x,E=(w*b+y*T)/x,P=(-w*y+b*T)/x,S=C-v,M=k-m,N=E-v,A=P-m;return S*S+M*M>N*N+A*A&&(C=E,k=P),{cx:C,cy:k,x01:-c,y01:-f,x11:C*(o/_-1),y11:k*(o/_-1)}}function ot(t){this._context=t}function it(t){return t[0]}function at(t){return t[1]}function st(t){this._curve=t}function lt(t){function e(e){return new st(t(e))}return e._curve=t,e}function ut(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(lt(t)):e()._curve},t}function ct(t,e,n){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+n)/6)}function ft(t){this._context=t}function dt(t){this._context=t}function pt(t){this._context=t}function ht(t,e){this._basis=new ft(t),this._beta=e}function gt(t,e,n){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-n),t._x2,t._y2)}function vt(t,e){this._context=t,this._k=(1-e)/6}function mt(t,e){this._context=t,this._k=(1-e)/6}function yt(t,e){this._context=t,this._k=(1-e)/6}function bt(t,e,n){var r=t._x1,o=t._y1,i=t._x2,a=t._y2;if(t._l01_a>yf){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);r=(r*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,o=(o*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>yf){var u=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,c=3*t._l23_a*(t._l23_a+t._l12_a);i=(i*u+t._x1*t._l23_2a-e*t._l12_2a)/c,a=(a*u+t._y1*t._l23_2a-n*t._l12_2a)/c}t._context.bezierCurveTo(r,o,i,a,t._x2,t._y2)}function xt(t,e){this._context=t,this._alpha=e}function _t(t,e){this._context=t,this._alpha=e}function wt(t,e){this._context=t,this._alpha=e}function Tt(t){this._context=t}function Ct(t){return t<0?-1:1}function kt(t,e,n){var r=t._x1-t._x0,o=e-t._x1,i=(t._y1-t._y0)/(r||o<0&&-0),a=(n-t._y1)/(o||r<0&&-0),s=(i*o+a*r)/(r+o);return(Ct(i)+Ct(a))*Math.min(Math.abs(i),Math.abs(a),.5*Math.abs(s))||0}function Et(t,e){var n=t._x1-t._x0;return n?(3*(t._y1-t._y0)/n-e)/2:e}function Pt(t,e,n){var r=t._x0,o=t._y0,i=t._x1,a=t._y1,s=(i-r)/3;t._context.bezierCurveTo(r+s,o+s*e,i-s,a-s*n,i,a)}function St(t){this._context=t}function Mt(t){this._context=new Nt(t)}function Nt(t){this._context=t}function At(t){return new St(t)}function Ot(t){return new Mt(t)}function Dt(t){this._context=t}function It(t){var e,n,r=t.length-1,o=new Array(r),i=new Array(r),a=new Array(r);for(o[0]=0,i[0]=2,a[0]=t[0]+2*t[1],e=1;e<r-1;++e)o[e]=1,i[e]=4,a[e]=4*t[e]+2*t[e+1];for(o[r-1]=2,i[r-1]=7,a[r-1]=8*t[r-1]+t[r],e=1;e<r;++e)n=o[e]/i[e-1],i[e]-=n,a[e]-=n*a[e-1];for(o[r-1]=a[r-1]/i[r-1],e=r-2;e>=0;--e)o[e]=(a[e]-o[e+1])/i[e];for(i[r-1]=(t[r]+o[r-1])/2,e=0;e<r-1;++e)i[e]=2*t[e+1]-o[e+1];return[o,i]}function Rt(t,e){this._context=t,this._t=e}function Lt(t){return new Rt(t,0)}function Ft(t){return new Rt(t,1)}function jt(t,e){return t[e]}function Bt(t){for(var e,n=0,r=-1,o=t.length;++r<o;)(e=+t[r][1])&&(n+=e);return n}function Ut(t,e){var n=Object.create(t.prototype);for(var r in e)n[r]=e[r];return n}function Ht(){}function zt(t){var e;return t=(t+"").trim().toLowerCase(),(e=Md.exec(t))?(e=parseInt(e[1],16),new Yt(e>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1)):(e=Nd.exec(t))?Wt(parseInt(e[1],16)):(e=Ad.exec(t))?new Yt(e[1],e[2],e[3],1):(e=Od.exec(t))?new Yt(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=Dd.exec(t))?qt(e[1],e[2],e[3],e[4]):(e=Id.exec(t))?qt(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=Rd.exec(t))?Gt(e[1],e[2]/100,e[3]/100,1):(e=Ld.exec(t))?Gt(e[1],e[2]/100,e[3]/100,e[4]):Fd.hasOwnProperty(t)?Wt(Fd[t]):"transparent"===t?new Yt(NaN,NaN,NaN,0):null}function Wt(t){return new Yt(t>>16&255,t>>8&255,255&t,1)}function qt(t,e,n,r){return r<=0&&(t=e=n=NaN),new Yt(t,e,n,r)}function Vt(t){return t instanceof Ht||(t=zt(t)),t?(t=t.rgb(),new Yt(t.r,t.g,t.b,t.opacity)):new Yt}function Kt(t,e,n,r){return 1===arguments.length?Vt(t):new Yt(t,e,n,null==r?1:r)}function Yt(t,e,n,r){this.r=+t,this.g=+e,this.b=+n,this.opacity=+r}function Gt(t,e,n,r){return r<=0?t=e=n=NaN:n<=0||n>=1?t=e=NaN:e<=0&&(t=NaN),new Zt(t,e,n,r)}function Xt(t){if(t instanceof Zt)return new Zt(t.h,t.s,t.l,t.opacity);if(t instanceof Ht||(t=zt(t)),!t)return new Zt;if(t instanceof Zt)return t;t=t.rgb();var e=t.r/255,n=t.g/255,r=t.b/255,o=Math.min(e,n,r),i=Math.max(e,n,r),a=NaN,s=i-o,l=(i+o)/2;return s?(a=e===i?(n-r)/s+6*(n<r):n===i?(r-e)/s+2:(e-n)/s+4,s/=l<.5?i+o:2-i-o,a*=60):s=l>0&&l<1?0:a,new Zt(a,s,l,t.opacity)}function $t(t,e,n,r){return 1===arguments.length?Xt(t):new Zt(t,e,n,null==r?1:r)}function Zt(t,e,n,r){this.h=+t,this.s=+e,this.l=+n,this.opacity=+r}function Jt(t,e,n){return 255*(t<60?e+(n-e)*t/60:t<180?n:t<240?e+(n-e)*(240-t)/60:e)}function Qt(t){if(t instanceof ee)return new ee(t.l,t.a,t.b,t.opacity);if(t instanceof le){var e=t.h*jd;return new ee(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof Yt||(t=Vt(t));var n=ie(t.r),r=ie(t.g),o=ie(t.b),i=ne((.4124564*n+.3575761*r+.1804375*o)/Hd),a=ne((.2126729*n+.7151522*r+.072175*o)/zd),s=ne((.0193339*n+.119192*r+.9503041*o)/Wd);return new ee(116*a-16,500*(i-a),200*(a-s),t.opacity)}function te(t,e,n,r){return 1===arguments.length?Qt(t):new ee(t,e,n,null==r?1:r)}function ee(t,e,n,r){this.l=+t,this.a=+e,this.b=+n,this.opacity=+r}function ne(t){return t>Yd?Math.pow(t,1/3):t/Kd+qd}function re(t){return t>Vd?t*t*t:Kd*(t-qd)}function oe(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function ie(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function ae(t){if(t instanceof le)return new le(t.h,t.c,t.l,t.opacity);t instanceof ee||(t=Qt(t));var e=Math.atan2(t.b,t.a)*Bd;return new le(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function se(t,e,n,r){return 1===arguments.length?ae(t):new le(t,e,n,null==r?1:r)}function le(t,e,n,r){this.h=+t,this.c=+e,this.l=+n,this.opacity=+r}function ue(t){if(t instanceof fe)return new fe(t.h,t.s,t.l,t.opacity);t instanceof Yt||(t=Vt(t));var e=t.r/255,n=t.g/255,r=t.b/255,o=(ep*r+Qd*e-tp*n)/(ep+Qd-tp),i=r-o,a=(Jd*(n-o)-$d*i)/Zd,s=Math.sqrt(a*a+i*i)/(Jd*o*(1-o)),l=s?Math.atan2(a,i)*Bd-120:NaN;return new fe(l<0?l+360:l,s,o,t.opacity)}function ce(t,e,n,r){return 1===arguments.length?ue(t):new fe(t,e,n,null==r?1:r)}function fe(t,e,n,r){this.h=+t,this.s=+e,this.l=+n,this.opacity=+r}function de(t,e,n,r,o){var i=t*t,a=i*t;return((1-3*t+3*i-a)*e+(4-6*i+3*a)*n+(1+3*t+3*i-3*a)*r+a*o)/6}function pe(t,e){return function(n){return t+n*e}}function he(t,e,n){return t=Math.pow(t,n),e=Math.pow(e,n)-t,n=1/n,function(r){return Math.pow(t+r*e,n)}}function ge(t,e){var n=e-t;return n?pe(t,n>180||n<-180?n-360*Math.round(n/360):n):lp(isNaN(t)?e:t)}function ve(t){return 1===(t=+t)?me:function(e,n){return n-e?he(e,n,t):lp(isNaN(e)?n:e)}}function me(t,e){var n=e-t;return n?pe(t,n):lp(isNaN(t)?e:t)}function ye(t){return function(e){var n,r,o=e.length,i=new Array(o),a=new Array(o),s=new Array(o);for(n=0;n<o;++n)r=Kt(e[n]),i[n]=r.r||0,a[n]=r.g||0,s[n]=r.b||0;return i=t(i),a=t(a),s=t(s),r.opacity=1,function(t){return r.r=i(t),r.g=a(t),r.b=s(t),r+""}}}function be(t){return function(){return t}}function xe(t){return function(e){return t(e)+""}}function _e(t){return"none"===t?wp:(np||(np=document.createElement("DIV"),rp=document.documentElement,op=document.defaultView),np.style.transform=t,t=op.getComputedStyle(rp.appendChild(np),null).getPropertyValue("transform"),rp.removeChild(np),t=t.slice(7,-1).split(","),Tp(+t[0],+t[1],+t[2],+t[3],+t[4],+t[5]))}function we(t){return null==t?wp:(ip||(ip=document.createElementNS("http://www.w3.org/2000/svg","g")),ip.setAttribute("transform",t),(t=ip.transform.baseVal.consolidate())?(t=t.matrix,Tp(t.a,t.b,t.c,t.d,t.e,t.f)):wp)}function Te(t,e,n,r){function o(t){return t.length?t.pop()+" ":""}function i(t,r,o,i,a,s){if(t!==o||r!==i){var l=a.push("translate(",null,e,null,n);s.push({i:l-4,x:hp(t,o)},{i:l-2,x:hp(r,i)})}else(o||i)&&a.push("translate("+o+e+i+n)}function a(t,e,n,i){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),i.push({i:n.push(o(n)+"rotate(",null,r)-2,x:hp(t,e)})):e&&n.push(o(n)+"rotate("+e+r)}function s(t,e,n,i){t!==e?i.push({i:n.push(o(n)+"skewX(",null,r)-2,x:hp(t,e)}):e&&n.push(o(n)+"skewX("+e+r)}function l(t,e,n,r,i,a){if(t!==n||e!==r){var s=i.push(o(i)+"scale(",null,",",null,")");a.push({i:s-4,x:hp(t,n)},{i:s-2,x:hp(e,r)})}else 1===n&&1===r||i.push(o(i)+"scale("+n+","+r+")")}return function(e,n){var r=[],o=[];return e=t(e),n=t(n),i(e.translateX,e.translateY,n.translateX,n.translateY,r,o),a(e.rotate,n.rotate,r,o),s(e.skewX,n.skewX,r,o),l(e.scaleX,e.scaleY,n.scaleX,n.scaleY,r,o),e=n=null,function(t){for(var e,n=-1,i=o.length;++n<i;)r[(e=o[n]).i]=e.x(t);return r.join("")}}}function Ce(t){return((t=Math.exp(t))+1/t)/2}function ke(t){return((t=Math.exp(t))-1/t)/2}function Ee(t){return((t=Math.exp(2*t))-1)/(t+1)}function Pe(t){return function(e,n){var r=t((e=$t(e)).h,(n=$t(n)).h),o=me(e.s,n.s),i=me(e.l,n.l),a=me(e.opacity,n.opacity);return function(t){return e.h=r(t),e.s=o(t),e.l=i(t),e.opacity=a(t),e+""}}}function Se(t,e){var n=me((t=te(t)).l,(e=te(e)).l),r=me(t.a,e.a),o=me(t.b,e.b),i=me(t.opacity,e.opacity);return function(e){return t.l=n(e),t.a=r(e),t.b=o(e),t.opacity=i(e),t+""}}function Me(t){return function(e,n){var r=t((e=se(e)).h,(n=se(n)).h),o=me(e.c,n.c),i=me(e.l,n.l),a=me(e.opacity,n.opacity);return function(t){return e.h=r(t),e.c=o(t),e.l=i(t),e.opacity=a(t),e+""}}}function Ne(t){return function e(n){function r(e,r){var o=t((e=ce(e)).h,(r=ce(r)).h),i=me(e.s,r.s),a=me(e.l,r.l),s=me(e.opacity,r.opacity);return function(t){return e.h=o(t),e.s=i(t),e.l=a(Math.pow(t,n)),e.opacity=s(t),e+""}}return n=+n,r.gamma=e,r}(1)}function Ae(){for(var t,e=0,n=arguments.length,r={};e<n;++e){if(!(t=arguments[e]+"")||t in r)throw new Error("illegal type: "+t);r[t]=[]}return new Oe(r)}function Oe(t){this._=t}function De(t,e){return t.trim().split(/^|\s+/).map(function(t){var n="",r=t.indexOf(".");if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t&&!e.hasOwnProperty(t))throw new Error("unknown type: "+t);return{type:t,name:n}})}function Ie(t,e){for(var n,r=0,o=t.length;r<o;++r)if((n=t[r]).name===e)return n.value}function Re(t,e,n){for(var r=0,o=t.length;r<o;++r)if(t[r].name===e){t[r]=jp,t=t.slice(0,r).concat(t.slice(r+1));break}return null!=n&&t.push({name:e,value:n}),t}function Le(t){return new Function("d","return {"+t.map(function(t,e){return JSON.stringify(t)+": d["+e+"]"}).join(",")+"}")}function Fe(t,e){var n=Le(t);return function(r,o){return e(n(r),o,t)}}function je(t){var e=Object.create(null),n=[];return t.forEach(function(t){for(var r in t)r in e||n.push(e[r]=r)}),n}function Be(t){return function(e,n){t(null==e?n:null)}}function Ue(t){var e=t.responseType;return e&&"text"!==e?t.response:t.responseText}function He(t,e){return function(n){return t(n.responseText,e)}}function ze(){return dh||(gh(We),dh=hh.now()+ph)}function We(){dh=0}function qe(){this._call=this._time=this._next=null}function Ve(t,e,n){var r=new qe;return r.restart(t,e,n),r}function Ke(){ze(),++sh;for(var t,e=Bp;e;)(t=dh-e._time)>=0&&e._call.call(null,t),e=e._next;--sh}function Ye(){dh=(fh=hh.now())+ph,sh=lh=0;try{Ke()}finally{sh=0,Xe(),dh=0}}function Ge(){var t=hh.now(),e=t-fh;e>ch&&(ph-=e,fh=t)}function Xe(){for(var t,e,n=Bp,r=1/0;n;)n._call?(r>n._time&&(r=n._time),t=n,n=n._next):(e=n._next,n._next=null,n=t?t._next=e:Bp=e);Up=t,$e(r)}function $e(t){if(!sh){lh&&(lh=clearTimeout(lh));var e=t-dh;e>24?(t<1/0&&(lh=setTimeout(Ye,e)),uh&&(uh=clearInterval(uh))):(uh||(uh=setInterval(Ge,ch)),sh=1,gh(Ye))}}function Ze(t,e,n,r){function o(e){return t(e=new Date(+e)),e}return o.floor=o,o.ceil=function(n){return t(n=new Date(n-1)),e(n,1),t(n),n},o.round=function(t){var e=o(t),n=o.ceil(t);return t-e<n-t?e:n},o.offset=function(t,n){return e(t=new Date(+t),null==n?1:Math.floor(n)),t},o.range=function(n,r,i){var a=[];if(n=o.ceil(n),i=null==i?1:Math.floor(i),!(n<r&&i>0))return a;do a.push(new Date(+n));while(e(n,i),t(n),n<r);return a},o.filter=function(n){return Ze(function(e){if(e>=e)for(;t(e),!n(e);)e.setTime(e-1)},function(t,r){if(t>=t)for(;--r>=0;)for(;e(t,1),!n(t););})},n&&(o.count=function(e,r){return yh.setTime(+e),bh.setTime(+r),t(yh),t(bh),Math.floor(n(yh,bh))},o.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?o.filter(r?function(e){return r(e)%t===0}:function(e){return o.count(0,e)%t===0}):o:null}),o}function Je(t){return Ze(function(e){e.setDate(e.getDate()-(e.getDay()+7-t)%7),e.setHours(0,0,0,0)},function(t,e){t.setDate(t.getDate()+7*e)},function(t,e){return(e-t-(e.getTimezoneOffset()-t.getTimezoneOffset())*Th)/Eh})}function Qe(t){return Ze(function(e){e.setUTCDate(e.getUTCDate()-(e.getUTCDay()+7-t)%7),e.setUTCHours(0,0,0,0)},function(t,e){t.setUTCDate(t.getUTCDate()+7*e)},function(t,e){return(e-t)/Eh})}function tn(t){if(!(e=Ag.exec(t)))throw new Error("invalid format: "+t);var e,n=e[1]||" ",r=e[2]||">",o=e[3]||"-",i=e[4]||"",a=!!e[5],s=e[6]&&+e[6],l=!!e[7],u=e[8]&&+e[8].slice(1),c=e[9]||"";"n"===c?(l=!0,c="g"):Ng[c]||(c=""),(a||"0"===n&&"="===r)&&(a=!0,n="0",r="="),this.fill=n,this.align=r,this.sign=o,this.symbol=i,this.zero=a,this.width=s,this.comma=l,this.precision=u,this.type=c}function en(t){return t}function nn(e){return Dg=Rg(e),t.format=Dg.format,t.formatPrefix=Dg.formatPrefix,Dg}function rn(t){if(0<=t.y&&t.y<100){var e=new Date(-1,t.m,t.d,t.H,t.M,t.S,t.L);return e.setFullYear(t.y),e}return new Date(t.y,t.m,t.d,t.H,t.M,t.S,t.L)}function on(t){if(0<=t.y&&t.y<100){var e=new Date(Date.UTC(-1,t.m,t.d,t.H,t.M,t.S,t.L));return e.setUTCFullYear(t.y),e}return new Date(Date.UTC(t.y,t.m,t.d,t.H,t.M,t.S,t.L))}function an(t){return{y:t,m:0,d:1,H:0,M:0,S:0,L:0}}function sn(t){function e(t,e){return function(n){var r,o,i,a=[],s=-1,l=0,u=t.length;for(n instanceof Date||(n=new Date(+n));++s<u;)37===t.charCodeAt(s)&&(a.push(t.slice(l,s)),null!=(o=Ug[r=t.charAt(++s)])?r=t.charAt(++s):o="e"===r?" ":"0",(i=e[r])&&(r=i(n,o)),a.push(r),l=s+1);return a.push(t.slice(l,s)),a.join("")}}function n(t,e){return function(n){var o=an(1900),i=r(o,t,n+="",0);if(i!=n.length)return null;if("p"in o&&(o.H=o.H%12+12*o.p),"W"in o||"U"in o){"w"in o||(o.w="W"in o?1:0);var a="Z"in o?on(an(o.y)).getUTCDay():e(an(o.y)).getDay();o.m=0,o.d="W"in o?(o.w+6)%7+7*o.W-(a+5)%7:o.w+7*o.U-(a+6)%7}return"Z"in o?(o.H+=o.Z/100|0,o.M+=o.Z%100,on(o)):e(o)}}function r(t,e,n,r){for(var o,i,a=0,s=e.length,l=n.length;a<s;){if(r>=l)return-1;if(o=e.charCodeAt(a++),37===o){if(o=e.charAt(a++),i=z[o in Ug?e.charAt(a++):o],!i||(r=i(t,n,r))<0)return-1}else if(o!=n.charCodeAt(r++))return-1}return r}function o(t,e,n){var r=N.exec(e.slice(n));return r?(t.p=A[r[0].toLowerCase()],n+r[0].length):-1}function i(t,e,n){var r=I.exec(e.slice(n));return r?(t.w=R[r[0].toLowerCase()],n+r[0].length):-1}function a(t,e,n){var r=O.exec(e.slice(n));return r?(t.w=D[r[0].toLowerCase()],n+r[0].length):-1}function s(t,e,n){var r=j.exec(e.slice(n));return r?(t.m=B[r[0].toLowerCase()],n+r[0].length):-1}function l(t,e,n){var r=L.exec(e.slice(n));return r?(t.m=F[r[0].toLowerCase()],n+r[0].length):-1}function u(t,e,n){return r(t,w,e,n)}function c(t,e,n){return r(t,T,e,n)}function f(t,e,n){return r(t,C,e,n)}function d(t){return P[t.getDay()]}function p(t){return E[t.getDay()]}function h(t){return M[t.getMonth()]}function g(t){return S[t.getMonth()]}function v(t){return k[+(t.getHours()>=12)]}function m(t){return P[t.getUTCDay()]}function y(t){return E[t.getUTCDay()]}function b(t){return M[t.getUTCMonth()]}function x(t){return S[t.getUTCMonth()]}function _(t){return k[+(t.getUTCHours()>=12)]}var w=t.dateTime,T=t.date,C=t.time,k=t.periods,E=t.days,P=t.shortDays,S=t.months,M=t.shortMonths,N=cn(k),A=fn(k),O=cn(E),D=fn(E),I=cn(P),R=fn(P),L=cn(S),F=fn(S),j=cn(M),B=fn(M),U={a:d,A:p,b:h,B:g,c:null,d:En,e:En,H:Pn,I:Sn,j:Mn,L:Nn,m:An,M:On,p:v,S:Dn,U:In,w:Rn,W:Ln,x:null,X:null,y:Fn,Y:jn,Z:Bn,"%":tr},H={a:m,A:y,b:b,B:x,c:null,d:Un,e:Un,H:Hn,I:zn,j:Wn,L:qn,m:Vn,M:Kn,p:_,S:Yn,U:Gn,w:Xn,W:$n,x:null,X:null,y:Zn,Y:Jn,Z:Qn,"%":tr},z={a:i,A:a,b:s,B:l,c:u,d:bn,e:bn,H:_n,I:_n,j:xn,L:Cn,m:yn,M:wn,p:o,S:Tn,U:pn,w:dn,W:hn,x:c,X:f,y:vn,Y:gn,Z:mn,"%":kn};return U.x=e(T,U),U.X=e(C,U),U.c=e(w,U),H.x=e(T,H),H.X=e(C,H),H.c=e(w,H),{format:function(t){var n=e(t+="",U);return n.toString=function(){return t},n},parse:function(t){var e=n(t+="",rn);
return e.toString=function(){return t},e},utcFormat:function(t){var n=e(t+="",H);return n.toString=function(){return t},n},utcParse:function(t){var e=n(t,on);return e.toString=function(){return t},e}}}function ln(t,e,n){var r=t<0?"-":"",o=(r?-t:t)+"",i=o.length;return r+(i<n?new Array(n-i+1).join(e)+o:o)}function un(t){return t.replace(Wg,"\\$&")}function cn(t){return new RegExp("^(?:"+t.map(un).join("|")+")","i")}function fn(t){for(var e={},n=-1,r=t.length;++n<r;)e[t[n].toLowerCase()]=n;return e}function dn(t,e,n){var r=Hg.exec(e.slice(n,n+1));return r?(t.w=+r[0],n+r[0].length):-1}function pn(t,e,n){var r=Hg.exec(e.slice(n));return r?(t.U=+r[0],n+r[0].length):-1}function hn(t,e,n){var r=Hg.exec(e.slice(n));return r?(t.W=+r[0],n+r[0].length):-1}function gn(t,e,n){var r=Hg.exec(e.slice(n,n+4));return r?(t.y=+r[0],n+r[0].length):-1}function vn(t,e,n){var r=Hg.exec(e.slice(n,n+2));return r?(t.y=+r[0]+(+r[0]>68?1900:2e3),n+r[0].length):-1}function mn(t,e,n){var r=/^(Z)|([+-]\d\d)(?:\:?(\d\d))?/.exec(e.slice(n,n+6));return r?(t.Z=r[1]?0:-(r[2]+(r[3]||"00")),n+r[0].length):-1}function yn(t,e,n){var r=Hg.exec(e.slice(n,n+2));return r?(t.m=r[0]-1,n+r[0].length):-1}function bn(t,e,n){var r=Hg.exec(e.slice(n,n+2));return r?(t.d=+r[0],n+r[0].length):-1}function xn(t,e,n){var r=Hg.exec(e.slice(n,n+3));return r?(t.m=0,t.d=+r[0],n+r[0].length):-1}function _n(t,e,n){var r=Hg.exec(e.slice(n,n+2));return r?(t.H=+r[0],n+r[0].length):-1}function wn(t,e,n){var r=Hg.exec(e.slice(n,n+2));return r?(t.M=+r[0],n+r[0].length):-1}function Tn(t,e,n){var r=Hg.exec(e.slice(n,n+2));return r?(t.S=+r[0],n+r[0].length):-1}function Cn(t,e,n){var r=Hg.exec(e.slice(n,n+3));return r?(t.L=+r[0],n+r[0].length):-1}function kn(t,e,n){var r=zg.exec(e.slice(n,n+1));return r?n+r[0].length:-1}function En(t,e){return ln(t.getDate(),e,2)}function Pn(t,e){return ln(t.getHours(),e,2)}function Sn(t,e){return ln(t.getHours()%12||12,e,2)}function Mn(t,e){return ln(1+Dh.count(Zh(t),t),e,3)}function Nn(t,e){return ln(t.getMilliseconds(),e,3)}function An(t,e){return ln(t.getMonth()+1,e,2)}function On(t,e){return ln(t.getMinutes(),e,2)}function Dn(t,e){return ln(t.getSeconds(),e,2)}function In(t,e){return ln(Rh.count(Zh(t),t),e,2)}function Rn(t){return t.getDay()}function Ln(t,e){return ln(Lh.count(Zh(t),t),e,2)}function Fn(t,e){return ln(t.getFullYear()%100,e,2)}function jn(t,e){return ln(t.getFullYear()%1e4,e,4)}function Bn(t){var e=t.getTimezoneOffset();return(e>0?"-":(e*=-1,"+"))+ln(e/60|0,"0",2)+ln(e%60,"0",2)}function Un(t,e){return ln(t.getUTCDate(),e,2)}function Hn(t,e){return ln(t.getUTCHours(),e,2)}function zn(t,e){return ln(t.getUTCHours()%12||12,e,2)}function Wn(t,e){return ln(1+rg.count(_g(t),t),e,3)}function qn(t,e){return ln(t.getUTCMilliseconds(),e,3)}function Vn(t,e){return ln(t.getUTCMonth()+1,e,2)}function Kn(t,e){return ln(t.getUTCMinutes(),e,2)}function Yn(t,e){return ln(t.getUTCSeconds(),e,2)}function Gn(t,e){return ln(ig.count(_g(t),t),e,2)}function Xn(t){return t.getUTCDay()}function $n(t,e){return ln(ag.count(_g(t),t),e,2)}function Zn(t,e){return ln(t.getUTCFullYear()%100,e,2)}function Jn(t,e){return ln(t.getUTCFullYear()%1e4,e,4)}function Qn(){return"+0000"}function tr(){return"%"}function er(e){return Lg=sn(e),t.timeFormat=Lg.format,t.timeParse=Lg.parse,t.utcFormat=Lg.utcFormat,t.utcParse=Lg.utcParse,Lg}function nr(t){return t.toISOString()}function rr(t){var e=new Date(t);return isNaN(e)?null:e}function or(t){function e(e){var i=e+"",a=n.get(i);if(!a){if(o!==$g)return o;n.set(i,a=r.push(e))}return t[(a-1)%t.length]}var n=i(),r=[],o=$g;return t=null==t?[]:Xg.call(t),e.domain=function(t){if(!arguments.length)return r.slice();r=[],n=i();for(var o,a,s=-1,l=t.length;++s<l;)n.has(a=(o=t[s])+"")||n.set(a,r.push(o));return e},e.range=function(n){return arguments.length?(t=Xg.call(n),e):t.slice()},e.unknown=function(t){return arguments.length?(o=t,e):o},e.copy=function(){return or().domain(r).range(t).unknown(o)},e}function ir(){function t(){var t=o().length,r=a[1]<a[0],f=a[r-0],d=a[1-r];e=(d-f)/Math.max(1,t-l+2*u),s&&(e=Math.floor(e)),f+=(d-f-e*(t-l))*c,n=e*(1-l),s&&(f=Math.round(f),n=Math.round(n));var p=ju(t).map(function(t){return f+e*t});return i(r?p.reverse():p)}var e,n,r=or().unknown(void 0),o=r.domain,i=r.range,a=[0,1],s=!1,l=0,u=0,c=.5;return delete r.unknown,r.domain=function(e){return arguments.length?(o(e),t()):o()},r.range=function(e){return arguments.length?(a=[+e[0],+e[1]],t()):a.slice()},r.rangeRound=function(e){return a=[+e[0],+e[1]],s=!0,t()},r.bandwidth=function(){return n},r.step=function(){return e},r.round=function(e){return arguments.length?(s=!!e,t()):s},r.padding=function(e){return arguments.length?(l=u=Math.max(0,Math.min(1,e)),t()):l},r.paddingInner=function(e){return arguments.length?(l=Math.max(0,Math.min(1,e)),t()):l},r.paddingOuter=function(e){return arguments.length?(u=Math.max(0,Math.min(1,e)),t()):u},r.align=function(e){return arguments.length?(c=Math.max(0,Math.min(1,e)),t()):c},r.copy=function(){return ir().domain(o()).range(a).round(s).paddingInner(l).paddingOuter(u).align(c)},t()}function ar(t){var e=t.copy;return t.padding=t.paddingOuter,delete t.paddingInner,delete t.paddingOuter,t.copy=function(){return ar(e())},t}function sr(){return ar(ir().paddingInner(1))}function lr(t,e){return(e-=t=+t)?function(n){return(n-t)/e}:Zg(e)}function ur(t){return function(e,n){var r=t(e=+e,n=+n);return function(t){return t<=e?0:t>=n?1:r(t)}}}function cr(t){return function(e,n){var r=t(e=+e,n=+n);return function(t){return t<=0?e:t>=1?n:r(t)}}}function fr(t,e,n,r){var o=t[0],i=t[1],a=e[0],s=e[1];return i<o?(o=n(i,o),a=r(s,a)):(o=n(o,i),a=r(a,s)),function(t){return a(o(t))}}function dr(t,e,n,r){var o=Math.min(t.length,e.length)-1,i=new Array(o),a=new Array(o),s=-1;for(t[o]<t[0]&&(t=t.slice().reverse(),e=e.slice().reverse());++s<o;)i[s]=n(t[s],t[s+1]),a[s]=r(e[s],e[s+1]);return function(e){var n=Eu(t,e,1,o)-1;return a[n](i[n](e))}}function pr(t,e){return e.domain(t.domain()).range(t.range()).interpolate(t.interpolate()).clamp(t.clamp())}function hr(t,e){function n(){return o=Math.min(s.length,l.length)>2?dr:fr,i=a=null,r}function r(e){return(i||(i=o(s,l,c?ur(t):t,u)))(+e)}var o,i,a,s=Qg,l=Qg,u=bp,c=!1;return r.invert=function(t){return(a||(a=o(l,s,lr,c?cr(e):e)))(+t)},r.domain=function(t){return arguments.length?(s=Gg.call(t,Jg),n()):s.slice()},r.range=function(t){return arguments.length?(l=Xg.call(t),n()):l.slice()},r.rangeRound=function(t){return l=Xg.call(t),u=xp,n()},r.clamp=function(t){return arguments.length?(c=!!t,n()):c},r.interpolate=function(t){return arguments.length?(u=t,n()):u},n()}function gr(t){var e=t.domain;return t.ticks=function(t){var n=e();return zu(n[0],n[n.length-1],null==t?10:t)},t.tickFormat=function(t,n){return tv(e(),t,n)},t.nice=function(r){var o=e(),i=o.length-1,a=null==r?10:r,s=o[0],l=o[i],u=n(s,l,a);return u&&(u=n(Math.floor(s/u)*u,Math.ceil(l/u)*u,a),o[0]=Math.floor(s/u)*u,o[i]=Math.ceil(l/u)*u,e(o)),t},t}function vr(){var t=hr(lr,hp);return t.copy=function(){return pr(t,vr())},gr(t)}function mr(){function t(t){return+t}var e=[0,1];return t.invert=t,t.domain=t.range=function(n){return arguments.length?(e=Gg.call(n,Jg),t):e.slice()},t.copy=function(){return mr().domain(e)},gr(t)}function yr(t,e){return(e=Math.log(e/t))?function(n){return Math.log(n/t)/e}:Zg(e)}function br(t,e){return t<0?function(n){return-Math.pow(-e,n)*Math.pow(-t,1-n)}:function(n){return Math.pow(e,n)*Math.pow(t,1-n)}}function xr(t){return isFinite(t)?+("1e"+t):t<0?0:t}function _r(t){return 10===t?xr:t===Math.E?Math.exp:function(e){return Math.pow(t,e)}}function wr(t){return t===Math.E?Math.log:10===t&&Math.log10||2===t&&Math.log2||(t=Math.log(t),function(e){return Math.log(e)/t})}function Tr(t){return function(e){return-t(-e)}}function Cr(){function e(){return i=wr(o),a=_r(o),r()[0]<0&&(i=Tr(i),a=Tr(a)),n}var n=hr(yr,br).domain([1,10]),r=n.domain,o=10,i=wr(10),a=_r(10);return n.base=function(t){return arguments.length?(o=+t,e()):o},n.domain=function(t){return arguments.length?(r(t),e()):r()},n.ticks=function(t){var e,n=r(),s=n[0],l=n[n.length-1];(e=l<s)&&(d=s,s=l,l=d);var u,c,f,d=i(s),p=i(l),h=null==t?10:+t,g=[];if(!(o%1)&&p-d<h){if(d=Math.round(d)-1,p=Math.round(p)+1,s>0){for(;d<p;++d)for(c=1,u=a(d);c<o;++c)if(f=u*c,!(f<s)){if(f>l)break;g.push(f)}}else for(;d<p;++d)for(c=o-1,u=a(d);c>=1;--c)if(f=u*c,!(f<s)){if(f>l)break;g.push(f)}}else g=zu(d,p,Math.min(p-d,h)).map(a);return e?g.reverse():g},n.tickFormat=function(e,r){if(null==r&&(r=10===o?".0e":","),"function"!=typeof r&&(r=t.format(r)),e===1/0)return r;null==e&&(e=10);var s=Math.max(1,o*e/n.ticks().length);return function(t){var e=t/a(Math.round(i(t)));return e*o<o-.5&&(e*=o),e<=s?r(t):""}},n.nice=function(){return r(ev(r(),{floor:function(t){return a(Math.floor(i(t)))},ceil:function(t){return a(Math.ceil(i(t)))}}))},n.copy=function(){return pr(n,Cr().base(o))},n}function kr(t,e){return t<0?-Math.pow(-t,e):Math.pow(t,e)}function Er(){function t(t,e){return(e=kr(e,n)-(t=kr(t,n)))?function(r){return(kr(r,n)-t)/e}:Zg(e)}function e(t,e){return e=kr(e,n)-(t=kr(t,n)),function(r){return kr(t+e*r,1/n)}}var n=1,r=hr(t,e),o=r.domain;return r.exponent=function(t){return arguments.length?(n=+t,o(o())):n},r.copy=function(){return pr(r,Er().exponent(n))},gr(r)}function Pr(){return Er().exponent(.5)}function Sr(){function t(){var t=0,i=Math.max(1,r.length);for(o=new Array(i-1);++t<i;)o[t-1]=Vu(n,t/i);return e}function e(t){if(!isNaN(t=+t))return r[Eu(o,t)]}var n=[],r=[],o=[];return e.invertExtent=function(t){var e=r.indexOf(t);return e<0?[NaN,NaN]:[e>0?o[e-1]:n[0],e<o.length?o[e]:n[n.length-1]]},e.domain=function(e){if(!arguments.length)return n.slice();n=[];for(var r,o=0,i=e.length;o<i;++o)r=e[o],null==r||isNaN(r=+r)||n.push(r);return n.sort(Tu),t()},e.range=function(e){return arguments.length?(r=Xg.call(e),t()):r.slice()},e.quantiles=function(){return o.slice()},e.copy=function(){return Sr().domain(n).range(r)},e}function Mr(){function t(t){if(t<=t)return a[Eu(i,t,0,o)]}function e(){var e=-1;for(i=new Array(o);++e<o;)i[e]=((e+1)*r-(e-o)*n)/(o+1);return t}var n=0,r=1,o=1,i=[.5],a=[0,1];return t.domain=function(t){return arguments.length?(n=+t[0],r=+t[1],e()):[n,r]},t.range=function(t){return arguments.length?(o=(a=Xg.call(t)).length-1,e()):a.slice()},t.invertExtent=function(t){var e=a.indexOf(t);return e<0?[NaN,NaN]:e<1?[n,i[0]]:e>=o?[i[o-1],r]:[i[e-1],i[e]]},t.copy=function(){return Mr().domain([n,r]).range(a)},gr(t)}function Nr(){function t(t){if(t<=t)return n[Eu(e,t,0,r)]}var e=[.5],n=[0,1],r=1;return t.domain=function(o){return arguments.length?(e=Xg.call(o),r=Math.min(e.length,n.length-1),t):e.slice()},t.range=function(o){return arguments.length?(n=Xg.call(o),r=Math.min(e.length,n.length-1),t):n.slice()},t.invertExtent=function(t){var r=n.indexOf(t);return[e[r-1],e[r]]},t.copy=function(){return Nr().domain(e).range(n)},t}function Ar(t){return new Date(t)}function Or(t){return t instanceof Date?+t:+new Date(+t)}function Dr(t,e,r,o,i,a,s,l,u){function c(n){return(s(n)<n?g:a(n)<n?v:i(n)<n?m:o(n)<n?y:e(n)<n?r(n)<n?b:x:t(n)<n?_:w)(n)}function f(e,r,o,i){if(null==e&&(e=10),"number"==typeof e){var a=Math.abs(o-r)/e,s=Cu(function(t){return t[2]}).right(T,a);s===T.length?(i=n(r/lv,o/lv,e),e=t):s?(s=T[a/T[s-1][2]<T[s][2]/a?s-1:s],i=s[1],e=s[0]):(i=n(r,o,e),e=l)}return null==i?e:e.every(i)}var d=hr(lr,hp),p=d.invert,h=d.domain,g=u(".%L"),v=u(":%S"),m=u("%I:%M"),y=u("%I %p"),b=u("%a %d"),x=u("%b %d"),_=u("%B"),w=u("%Y"),T=[[s,1,nv],[s,5,5*nv],[s,15,15*nv],[s,30,30*nv],[a,1,rv],[a,5,5*rv],[a,15,15*rv],[a,30,30*rv],[i,1,ov],[i,3,3*ov],[i,6,6*ov],[i,12,12*ov],[o,1,iv],[o,2,2*iv],[r,1,av],[e,1,sv],[e,3,3*sv],[t,1,lv]];return d.invert=function(t){return new Date(p(t))},d.domain=function(t){return arguments.length?h(Gg.call(t,Or)):h().map(Ar)},d.ticks=function(t,e){var n,r=h(),o=r[0],i=r[r.length-1],a=i<o;return a&&(n=o,o=i,i=n),n=f(t,o,i,e),n=n?n.range(o,i+1):[],a?n.reverse():n},d.tickFormat=function(t,e){return null==e?c:u(e)},d.nice=function(t,e){var n=h();return(t=f(t,n[0],n[n.length-1],e))?h(ev(n,t)):d},d.copy=function(){return pr(d,Dr(t,e,r,o,i,a,s,l,u))},d}function Ir(t){var e=t.length;return function(n){return t[Math.max(0,Math.min(e-1,Math.floor(n*e)))]}}function Rr(t){function e(e){var i=(e-n)/(r-n);return t(o?Math.max(0,Math.min(1,i)):i)}var n=0,r=1,o=!1;return e.domain=function(t){return arguments.length?(n=+t[0],r=+t[1],e):[n,r]},e.clamp=function(t){return arguments.length?(o=!!t,e):o},e.interpolator=function(n){return arguments.length?(t=n,e):t},e.copy=function(){return Rr(t).domain([n,r]).clamp(o)},gr(e)}function Lr(t){return function(){var e=this.ownerDocument,n=this.namespaceURI;return n===kv&&e.documentElement.namespaceURI===kv?e.createElement(t):e.createElementNS(n,t)}}function Fr(t){return function(){return this.ownerDocument.createElementNS(t.space,t.local)}}function jr(){return new Br}function Br(){this._="@"+(++Mv).toString(36)}function Ur(t,e,n){return t=Hr(t,e,n),function(e){var n=e.relatedTarget;n&&(n===this||8&n.compareDocumentPosition(this))||t.call(this,e)}}function Hr(e,n,r){return function(o){var i=t.event;t.event=o;try{e.call(this,this.__data__,n,r)}finally{t.event=i}}}function zr(t){return t.trim().split(/^|\s+/).map(function(t){var e="",n=t.indexOf(".");return n>=0&&(e=t.slice(n+1),t=t.slice(0,n)),{type:t,name:e}})}function Wr(t){return function(){var e=this.__on;if(e){for(var n,r=0,o=-1,i=e.length;r<i;++r)n=e[r],t.type&&n.type!==t.type||n.name!==t.name?e[++o]=n:this.removeEventListener(n.type,n.listener,n.capture);++o?e.length=o:delete this.__on}}}function qr(t,e,n){var r=Iv.hasOwnProperty(t.type)?Ur:Hr;return function(o,i,a){var s,l=this.__on,u=r(e,i,a);if(l)for(var c=0,f=l.length;c<f;++c)if((s=l[c]).type===t.type&&s.name===t.name)return this.removeEventListener(s.type,s.listener,s.capture),this.addEventListener(s.type,s.listener=u,s.capture=n),void(s.value=e);this.addEventListener(t.type,u,n),s={type:t.type,name:t.name,value:e,listener:u,capture:n},l?l.push(s):this.__on=[s]}}function Vr(e,n,r,o){var i=t.event;e.sourceEvent=t.event,t.event=e;try{return n.apply(r,o)}finally{t.event=i}}function Kr(){}function Yr(){return[]}function Gr(t,e){this.ownerDocument=t.ownerDocument,this.namespaceURI=t.namespaceURI,this._next=null,this._parent=t,this.__data__=e}function Xr(t,e,n,r,o,i){for(var a,s=0,l=e.length,u=i.length;s<u;++s)(a=e[s])?(a.__data__=i[s],r[s]=a):n[s]=new Gr(t,i[s]);for(;s<l;++s)(a=e[s])&&(o[s]=a)}function $r(t,e,n,r,o,i,a){var s,l,u,c={},f=e.length,d=i.length,p=new Array(f);for(s=0;s<f;++s)(l=e[s])&&(p[s]=u=Gv+a.call(l,l.__data__,s,e),u in c?o[s]=l:c[u]=l);for(s=0;s<d;++s)u=Gv+a.call(t,i[s],s,i),(l=c[u])?(r[s]=l,l.__data__=i[s],c[u]=null):n[s]=new Gr(t,i[s]);for(s=0;s<f;++s)(l=e[s])&&c[p[s]]===l&&(o[s]=l)}function Zr(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function Jr(t){return function(){this.removeAttribute(t)}}function Qr(t){return function(){this.removeAttributeNS(t.space,t.local)}}function to(t,e){return function(){this.setAttribute(t,e)}}function eo(t,e){return function(){this.setAttributeNS(t.space,t.local,e)}}function no(t,e){return function(){var n=e.apply(this,arguments);null==n?this.removeAttribute(t):this.setAttribute(t,n)}}function ro(t,e){return function(){var n=e.apply(this,arguments);null==n?this.removeAttributeNS(t.space,t.local):this.setAttributeNS(t.space,t.local,n)}}function oo(t){return function(){this.style.removeProperty(t)}}function io(t,e,n){return function(){this.style.setProperty(t,e,n)}}function ao(t,e,n){return function(){var r=e.apply(this,arguments);null==r?this.style.removeProperty(t):this.style.setProperty(t,r,n)}}function so(t){return function(){delete this[t]}}function lo(t,e){return function(){this[t]=e}}function uo(t,e){return function(){var n=e.apply(this,arguments);null==n?delete this[t]:this[t]=n}}function co(t){return t.trim().split(/^|\s+/)}function fo(t){return t.classList||new po(t)}function po(t){this._node=t,this._names=co(t.getAttribute("class")||"")}function ho(t,e){for(var n=fo(t),r=-1,o=e.length;++r<o;)n.add(e[r])}function go(t,e){for(var n=fo(t),r=-1,o=e.length;++r<o;)n.remove(e[r])}function vo(t){return function(){ho(this,t)}}function mo(t){return function(){go(this,t)}}function yo(t,e){return function(){(e.apply(this,arguments)?ho:go)(this,t)}}function bo(){this.textContent=""}function xo(t){return function(){this.textContent=t}}function _o(t){return function(){var e=t.apply(this,arguments);this.textContent=null==e?"":e}}function wo(){this.innerHTML=""}function To(t){return function(){this.innerHTML=t}}function Co(t){return function(){var e=t.apply(this,arguments);this.innerHTML=null==e?"":e}}function ko(){this.nextSibling&&this.parentNode.appendChild(this)}function Eo(){this.previousSibling&&this.parentNode.insertBefore(this,this.parentNode.firstChild)}function Po(){return null}function So(){var t=this.parentNode;t&&t.removeChild(this)}function Mo(t,e,n){var r=sm(t),o=r.CustomEvent;o?o=new o(e,n):(o=r.document.createEvent("Event"),n?(o.initEvent(e,n.bubbles,n.cancelable),o.detail=n.detail):o.initEvent(e,!1,!1)),t.dispatchEvent(o)}function No(t,e){return function(){return Mo(this,t,e)}}function Ao(t,e){return function(){return Mo(this,t,e.apply(this,arguments))}}function Oo(t,e){this._groups=t,this._parents=e}function Do(){return new Oo([[document.documentElement]],xm)}function Io(t,e){var n=t.__transition;if(!n||!(n=n[e])||n.state>Pm)throw new Error("too late");return n}function Ro(t,e){var n=t.__transition;if(!n||!(n=n[e])||n.state>Mm)throw new Error("too late");return n}function Lo(t,e){var n=t.__transition;if(!n||!(n=n[e]))throw new Error("too late");return n}function Fo(t,e,n){function r(t){n.state=Sm,n.timer.restart(o,n.delay,n.time),n.delay<=t&&o(t-n.delay)}function o(r){var u,c,f,d;if(n.state!==Sm)return a();for(u in l)if(d=l[u],d.name===n.name){if(d.state===Nm)return vh(o);d.state===Am?(d.state=Dm,d.timer.stop(),d.on.call("interrupt",t,t.__data__,d.index,d.group),delete l[u]):+u<e&&(d.state=Dm,d.timer.stop(),delete l[u])}if(vh(function(){n.state===Nm&&(n.state=Am,n.timer.restart(i,n.delay,n.time),i(r))}),n.state=Mm,n.on.call("start",t,t.__data__,n.index,n.group),n.state===Mm){for(n.state=Nm,s=new Array(f=n.tween.length),u=0,c=-1;u<f;++u)(d=n.tween[u].value.call(t,t.__data__,n.index,n.group))&&(s[++c]=d);s.length=c+1}}function i(e){for(var r=e<n.duration?n.ease.call(null,e/n.duration):(n.timer.restart(a),n.state=Om,1),o=-1,i=s.length;++o<i;)s[o].call(null,r);n.state===Om&&(n.on.call("end",t,t.__data__,n.index,n.group),a())}function a(){n.state=Dm,n.timer.stop(),delete l[e];for(var r in l)return;delete t.__transition}var s,l=t.__transition;l[e]=n,n.timer=Ve(r,0,n.time)}function jo(t,e){var n,r;return function(){var o=Ro(this,t),i=o.tween;if(i!==n){r=n=i;for(var a=0,s=r.length;a<s;++a)if(r[a].name===e){r=r.slice(),r.splice(a,1);break}}o.tween=r}}function Bo(t,e,n){var r,o;if("function"!=typeof n)throw new Error;return function(){var i=Ro(this,t),a=i.tween;if(a!==r){o=(r=a).slice();for(var s={name:e,value:n},l=0,u=o.length;l<u;++l)if(o[l].name===e){o[l]=s;break}l===u&&o.push(s)}i.tween=o}}function Uo(t,e,n){var r=t._id;return t.each(function(){var t=Ro(this,r);(t.value||(t.value={}))[e]=n.apply(this,arguments)}),function(t){return Lo(t,r).value[e]}}function Ho(t){return function(){this.removeAttribute(t)}}function zo(t){return function(){this.removeAttributeNS(t.space,t.local)}}function Wo(t,e,n){var r,o;return function(){var i=this.getAttribute(t);return i===n?null:i===r?o:o=e(r=i,n)}}function qo(t,e,n){var r,o;return function(){var i=this.getAttributeNS(t.space,t.local);return i===n?null:i===r?o:o=e(r=i,n)}}function Vo(t,e,n){var r,o,i;return function(){var a,s=n(this);return null==s?void this.removeAttribute(t):(a=this.getAttribute(t),a===s?null:a===r&&s===o?i:i=e(r=a,o=s))}}function Ko(t,e,n){var r,o,i;return function(){var a,s=n(this);return null==s?void this.removeAttributeNS(t.space,t.local):(a=this.getAttributeNS(t.space,t.local),a===s?null:a===r&&s===o?i:i=e(r=a,o=s))}}function Yo(t,e){function n(){var n=this,r=e.apply(n,arguments);return r&&function(e){n.setAttributeNS(t.space,t.local,r(e))}}return n._value=e,n}function Go(t,e){function n(){var n=this,r=e.apply(n,arguments);return r&&function(e){n.setAttribute(t,r(e))}}return n._value=e,n}function Xo(t,e){return function(){Io(this,t).delay=+e.apply(this,arguments)}}function $o(t,e){return e=+e,function(){Io(this,t).delay=e}}function Zo(t,e){return function(){Ro(this,t).duration=+e.apply(this,arguments)}}function Jo(t,e){return e=+e,function(){Ro(this,t).duration=e}}function Qo(t,e){if("function"!=typeof e)throw new Error;return function(){Ro(this,t).ease=e}}function ti(t){return(t+"").trim().split(/^|\s+/).every(function(t){var e=t.indexOf(".");return e>=0&&(t=t.slice(0,e)),!t||"start"===t})}function ei(t,e,n){var r,o,i=ti(e)?Io:Ro;return function(){var a=i(this,t),s=a.on;s!==r&&(o=(r=s).copy()).on(e,n),a.on=o}}function ni(t){return function(){var e=this.parentNode;for(var n in this.__transition)if(+n!==t)return;e&&e.removeChild(this)}}function ri(t,e){var n,r,o;return function(){var i=sm(this).getComputedStyle(this,null),a=i.getPropertyValue(t),s=(this.style.removeProperty(t),i.getPropertyValue(t));return a===s?null:a===n&&s===r?o:o=e(n=a,r=s)}}function oi(t){return function(){this.style.removeProperty(t)}}function ii(t,e,n){var r,o;return function(){var i=sm(this).getComputedStyle(this,null).getPropertyValue(t);return i===n?null:i===r?o:o=e(r=i,n)}}function ai(t,e,n){var r,o,i;return function(){var a=sm(this).getComputedStyle(this,null),s=a.getPropertyValue(t),l=n(this);return null==l&&(this.style.removeProperty(t),l=a.getPropertyValue(t)),s===l?null:s===r&&l===o?i:i=e(r=s,o=l)}}function si(t,e,n){function r(){var r=this,o=e.apply(r,arguments);return o&&function(e){r.style.setProperty(t,o(e),n)}}return r._value=e,r}function li(t){return function(){this.textContent=t}}function ui(t){return function(){var e=t(this);this.textContent=null==e?"":e}}function ci(t,e,n,r){this._groups=t,this._parents=e,this._name=n,this._id=r}function fi(t){return Do().transition(t)}function di(){return++ny}function pi(t,e){for(var n;!(n=t.__transition)||!(n=n[e]);)if(!(t=t.parentNode))return oy.time=ze(),oy;return n}function hi(t,e,n){var r=t(n);return"translate("+(isFinite(r)?r:e(n))+",0)"}function gi(t,e,n){var r=t(n);return"translate(0,"+(isFinite(r)?r:e(n))+")"}function vi(t){var e=t.bandwidth()/2;return t.round()&&(e=Math.round(e)),function(n){return t(n)+e}}function mi(){return!this.__axis}function yi(t,e){function n(n){var u,c=null==o?e.ticks?e.ticks.apply(e,r):e.domain():o,f=null==i?e.tickFormat?e.tickFormat.apply(e,r):uy:i,d=Math.max(a,0)+l,p=t===cy||t===dy?hi:gi,h=e.range(),g=h[0]+.5,v=h[h.length-1]+.5,m=(e.bandwidth?vi:uy)(e.copy()),y=n.selection?n.selection():n,b=y.selectAll(".domain").data([null]),x=y.selectAll(".tick").data(c,e).order(),_=x.exit(),w=x.enter().append("g").attr("class","tick"),T=x.select("line"),C=x.select("text"),k=t===cy||t===py?-1:1,E=t===py||t===fy?(u="x","y"):(u="y","x");b=b.merge(b.enter().insert("path",".tick").attr("class","domain").attr("stroke","#000")),x=x.merge(w),T=T.merge(w.append("line").attr("stroke","#000").attr(u+"2",k*a).attr(E+"1",.5).attr(E+"2",.5)),C=C.merge(w.append("text").attr("fill","#000").attr(u,k*d).attr(E,.5).attr("dy",t===cy?"0em":t===dy?"0.71em":"0.32em")),n!==y&&(b=b.transition(n),x=x.transition(n),T=T.transition(n),C=C.transition(n),_=_.transition(n).attr("opacity",hy).attr("transform",function(t){return p(m,this.parentNode.__axis||m,t)}),w.attr("opacity",hy).attr("transform",function(t){return p(this.parentNode.__axis||m,m,t)})),_.remove(),b.attr("d",t===py||t==fy?"M"+k*s+","+g+"H0.5V"+v+"H"+k*s:"M"+g+","+k*s+"V0.5H"+v+"V"+k*s),x.attr("opacity",1).attr("transform",function(t){return p(m,m,t)}),T.attr(u+"2",k*a),C.attr(u,k*d).text(f),y.filter(mi).attr("fill","none").attr("font-size",10).attr("font-family","sans-serif").attr("text-anchor",t===fy?"start":t===py?"end":"middle"),y.each(function(){this.__axis=m})}var r=[],o=null,i=null,a=6,s=6,l=3;return n.scale=function(t){return arguments.length?(e=t,n):e},n.ticks=function(){return r=ly.call(arguments),n},n.tickArguments=function(t){return arguments.length?(r=null==t?[]:ly.call(t),n):r.slice()},n.tickValues=function(t){return arguments.length?(o=null==t?null:ly.call(t),n):o&&o.slice()},n.tickFormat=function(t){return arguments.length?(i=t,n):i},n.tickSize=function(t){return arguments.length?(a=s=+t,n):a},n.tickSizeInner=function(t){return arguments.length?(a=+t,n):a},n.tickSizeOuter=function(t){return arguments.length?(s=+t,n):s},n.tickPadding=function(t){return arguments.length?(l=+t,n):l},n}function bi(t){return yi(cy,t)}function xi(t){return yi(fy,t)}function _i(t){return yi(dy,t)}function wi(t){return yi(py,t)}function Ti(t,e){return t.parent===e.parent?1:2}function Ci(t){return t.reduce(ki,0)/t.length}function ki(t,e){return t+e.x}function Ei(t){return 1+t.reduce(Pi,0)}function Pi(t,e){return Math.max(t,e.y)}function Si(t){for(var e;e=t.children;)t=e[0];return t}function Mi(t){for(var e;e=t.children;)t=e[e.length-1];return t}function Ni(t,e){if(t===e)return t;var n=t.ancestors(),r=e.ancestors(),o=null;for(t=n.pop(),e=r.pop();t===e;)o=t,t=n.pop(),e=r.pop();return o}function Ai(t,e){var n,r,o,i,a,s=new Li(t),l=+t.value&&(s.value=t.value),u=[s];for(null==e&&(e=Di);n=u.pop();)if(l&&(n.value=+n.data.value),(o=e(n.data))&&(a=o.length))for(n.children=new Array(a),i=a-1;i>=0;--i)u.push(r=n.children[i]=new Li(o[i])),r.parent=n,r.depth=n.depth+1;return s.eachBefore(Ri)}function Oi(){return Ai(this).eachBefore(Ii)}function Di(t){return t.children}function Ii(t){t.data=t.data.data}function Ri(t){var e=0;do t.height=e;while((t=t.parent)&&t.height<++e)}function Li(t){this.data=t,this.depth=this.height=0,this.parent=null}function Fi(t){this._=t,this.next=null}function ji(t,e){var n=e.x-t.x,r=e.y-t.y,o=t.r-e.r;return o*o+1e-6>n*n+r*r}function Bi(t,e){var n,r,o,i=null,a=t.head;switch(e.length){case 1:n=Ui(e[0]);break;case 2:n=Hi(e[0],e[1]);break;case 3:n=zi(e[0],e[1],e[2])}for(;a;)o=a._,r=a.next,n&&ji(n,o)?i=a:(i?(t.tail=i,i.next=null):t.head=t.tail=null,e.push(o),n=Bi(t,e),e.pop(),t.head?(a.next=t.head,t.head=a):(a.next=null,t.head=t.tail=a),i=t.tail,i.next=r),a=r;return t.tail=i,n}function Ui(t){return{x:t.x,y:t.y,r:t.r}}function Hi(t,e){var n=t.x,r=t.y,o=t.r,i=e.x,a=e.y,s=e.r,l=i-n,u=a-r,c=s-o,f=Math.sqrt(l*l+u*u);return{x:(n+i+l/f*c)/2,y:(r+a+u/f*c)/2,r:(f+o+s)/2}}function zi(t,e,n){var r=t.x,o=t.y,i=t.r,a=e.x,s=e.y,l=e.r,u=n.x,c=n.y,f=n.r,d=2*(r-a),p=2*(o-s),h=2*(l-i),g=r*r+o*o-i*i-a*a-s*s+l*l,v=2*(r-u),m=2*(o-c),y=2*(f-i),b=r*r+o*o-i*i-u*u-c*c+f*f,x=v*p-d*m,_=(p*b-m*g)/x-r,w=(m*h-p*y)/x,T=(v*g-d*b)/x-o,C=(d*y-v*h)/x,k=w*w+C*C-1,E=2*(_*w+T*C+i),P=_*_+T*T-i*i,S=(-E-Math.sqrt(E*E-4*k*P))/(2*k);return{x:_+w*S+r,y:T+C*S+o,r:S}}function Wi(t,e,n){var r=t.x,o=t.y,i=e.r+n.r,a=t.r+n.r,s=e.x-r,l=e.y-o,u=s*s+l*l;if(u){var c=.5+((a*=a)-(i*=i))/(2*u),f=Math.sqrt(Math.max(0,2*i*(a+u)-(a-=u)*a-i*i))/(2*u);n.x=r+c*s+f*l,n.y=o+c*l-f*s}else n.x=r+a,n.y=o}function qi(t,e){var n=e.x-t.x,r=e.y-t.y,o=t.r+e.r;return o*o>n*n+r*r}function Vi(t,e,n){var r=t.x-e,o=t.y-n;return r*r+o*o}function Ki(t){this._=t,this.next=null,this.previous=null}function Yi(t){if(!(o=t.length))return 0;var e,n,r,o;if(e=t[0],e.x=0,e.y=0,!(o>1))return e.r;if(n=t[1],e.x=-n.r,n.x=e.r,n.y=0,!(o>2))return e.r+n.r;Wi(n,e,r=t[2]);var i,a,s,l,u,c,f,d=e.r*e.r,p=n.r*n.r,h=r.r*r.r,g=d+p+h,v=d*e.x+p*n.x+h*r.x,m=d*e.y+p*n.y+h*r.y;e=new Ki(e),n=new Ki(n),r=new Ki(r),e.next=r.previous=n,n.next=e.previous=r,r.next=n.previous=e;t:for(s=3;s<o;++s){if(Wi(e._,n._,r=t[s]),r=new Ki(r),(u=e.previous)===(l=n.next)){if(qi(l._,r._)){e=n,n=l,--s;continue t}}else{c=l._.r,f=u._.r;do if(c<=f){if(qi(l._,r._)){n=l,e.next=n,n.previous=e,--s;continue t}l=l.next,c+=l._.r}else{if(qi(u._,r._)){e=u,e.next=n,n.previous=e,--s;continue t}u=u.previous,f+=u._.r}while(l!==u.next)}for(r.previous=e,r.next=n,e.next=n.previous=n=r,g+=h=r._.r*r._.r,v+=h*r._.x,m+=h*r._.y,d=Vi(e._,i=v/g,a=m/g);(r=r.next)!==n;)(h=Vi(r._,i,a))<d&&(e=r,d=h);n=e.next}for(e=[n._],r=n;(r=r.next)!==n;)e.push(r._);for(r=Py(e),s=0;s<o;++s)e=t[s],e.x-=r.x,e.y-=r.y;return r.r}function Gi(t){return null==t?null:Xi(t)}function Xi(t){if("function"!=typeof t)throw new Error;return t}function $i(){return 0}function Zi(t){return Math.sqrt(t.value)}function Ji(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function Qi(t,e){return function(n){if(r=n.children){var r,o,i,a=r.length,s=t(n)*e||0;if(s)for(o=0;o<a;++o)r[o].r+=s;if(i=Yi(r),s)for(o=0;o<a;++o)r[o].r-=s;n.r=i+s}}}function ta(t){return function(e){var n=e.parent;e.r*=t,n&&(e.x=n.x+t*e.x,e.y=n.y+t*e.y)}}function ea(t){return t.id}function na(t){return t.parentId}function ra(t,e){return t.parent===e.parent?1:2}function oa(t){var e=t.children;return e?e[0]:t.t}function ia(t){var e=t.children;return e?e[e.length-1]:t.t}function aa(t,e,n){var r=n/(e.i-t.i);e.c-=r,e.s+=n,t.c+=r,e.z+=n,e.m+=n}function sa(t){for(var e,n=0,r=0,o=t.children,i=o.length;--i>=0;)e=o[i],e.z+=n,e.m+=n,n+=e.s+(r+=e.c)}function la(t,e,n){return t.a.parent===e.parent?t.a:n}function ua(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function ca(t){for(var e,n,r,o,i,a=new ua(t,0),s=[a];e=s.pop();)if(r=e._.children)for(e.children=new Array(i=r.length),o=i-1;o>=0;--o)s.push(n=e.children[o]=new ua(r[o],o)),n.parent=e;return(a.parent=new ua(null,0)).children=[a],a}function fa(t,e,n,r,o,i){for(var a,s,l,u,c,f,d,p,h,g,v,m=[],y=e.children,b=0,x=0,_=y.length,w=e.value;b<_;){l=o-n,u=i-r;do c=y[x++].value;while(!c&&x<_);for(f=d=c,g=Math.max(u/l,l/u)/(w*t),v=c*c*g,h=Math.max(d/v,v/f);x<_;++x){if(c+=s=y[x].value,s<f&&(f=s),s>d&&(d=s),v=c*c*g,p=Math.max(d/v,v/f),p>h){c-=s;break}h=p}m.push(a={value:c,dice:l<u,children:y.slice(b,x)}),a.dice?Oy(a,n,r,o,w?r+=u*c/w:i):By(a,n,r,w?n+=l*c/w:o,i),w-=c,b=x}return m}function da(t){return t.x+t.vx}function pa(t){return t.y+t.vy}function ha(t){return t.index}function ga(t,e){var n=t.get(e);if(!n)throw new Error("missing: "+e);return n}function va(t){return t.x}function ma(t){return t.y}function ya(){t.event.stopImmediatePropagation()}function ba(t,e){var n=t.document.documentElement,r=_m(t).on("dragstart.drag",null);e&&(r.on("click.drag",rb,!0),setTimeout(function(){r.on("click.drag",null)},0)),"onselectstart"in n?r.on("selectstart.drag",null):(n.style.MozUserSelect=n.__noselect,delete n.__noselect)}function xa(t,e,n,r,o,i,a,s,l,u){this.target=t,this.type=e,this.subject=n,this.identifier=r,this.active=o,this.x=i,this.y=a,this.dx=s,this.dy=l,this._=u}function _a(){return!t.event.button}function wa(){return this.parentNode}function Ta(e){return null==e?{x:t.event.x,y:t.event.y}:e}function Ca(t){return t[0]}function ka(t){return t[1]}function Ea(){this._=null}function Pa(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Sa(t,e){var n=e,r=e.R,o=n.U;o?o.L===n?o.L=r:o.R=r:t._=r,r.U=o,n.U=r,n.R=r.L,n.R&&(n.R.U=n),r.L=n}function Ma(t,e){var n=e,r=e.L,o=n.U;o?o.L===n?o.L=r:o.R=r:t._=r,r.U=o,n.U=r,n.L=r.R,n.L&&(n.L.U=n),r.R=n}function Na(t){for(;t.L;)t=t.L;return t}function Aa(t,e,n,r){var o=[null,null],i=db.push(o)-1;return o.left=t,o.right=e,n&&Da(o,t,e,n),r&&Da(o,e,t,r),cb[t.index].halfedges.push(i),cb[e.index].halfedges.push(i),o}function Oa(t,e,n){var r=[e,n];return r.left=t,r}function Da(t,e,n,r){t[0]||t[1]?t.left===n?t[1]=r:t[0]=r:(t[0]=r,t.left=e,t.right=n)}function Ia(t,e,n,r,o){var i,a=t[0],s=t[1],l=a[0],u=a[1],c=s[0],f=s[1],d=0,p=1,h=c-l,g=f-u;if(i=e-l,h||!(i>0)){if(i/=h,h<0){if(i<d)return;i<p&&(p=i)}else if(h>0){if(i>p)return;i>d&&(d=i)}if(i=r-l,h||!(i<0)){if(i/=h,h<0){if(i>p)return;i>d&&(d=i)}else if(h>0){if(i<d)return;i<p&&(p=i)}if(i=n-u,g||!(i>0)){if(i/=g,g<0){if(i<d)return;i<p&&(p=i)}else if(g>0){if(i>p)return;i>d&&(d=i)}if(i=o-u,g||!(i<0)){if(i/=g,g<0){if(i>p)return;i>d&&(d=i)}else if(g>0){if(i<d)return;i<p&&(p=i)}return!(d>0||p<1)||(d>0&&(t[0]=[l+d*h,u+d*g]),p<1&&(t[1]=[l+p*h,u+p*g]),!0)}}}}}function Ra(t,e,n,r,o){var i=t[1];if(i)return!0;
var a,s,l=t[0],u=t.left,c=t.right,f=u[0],d=u[1],p=c[0],h=c[1],g=(f+p)/2,v=(d+h)/2;if(h===d){if(g<e||g>=r)return;if(f>p){if(l){if(l[1]>=o)return}else l=[g,n];i=[g,o]}else{if(l){if(l[1]<n)return}else l=[g,o];i=[g,n]}}else if(a=(f-p)/(h-d),s=v-a*g,a<-1||a>1)if(f>p){if(l){if(l[1]>=o)return}else l=[(n-s)/a,n];i=[(o-s)/a,o]}else{if(l){if(l[1]<n)return}else l=[(o-s)/a,o];i=[(n-s)/a,n]}else if(d<h){if(l){if(l[0]>=r)return}else l=[e,a*e+s];i=[r,a*r+s]}else{if(l){if(l[0]<e)return}else l=[r,a*r+s];i=[e,a*e+s]}return t[0]=l,t[1]=i,!0}function La(t,e,n,r){for(var o,i=db.length;i--;)Ra(o=db[i],t,e,n,r)&&Ia(o,t,e,n,r)&&(Math.abs(o[0][0]-o[1][0])>gb||Math.abs(o[0][1]-o[1][1])>gb)||delete db[i]}function Fa(t){return cb[t.index]={site:t,halfedges:[]}}function ja(t,e){var n=t.site,r=e.left,o=e.right;return n===o&&(o=r,r=n),o?Math.atan2(o[1]-r[1],o[0]-r[0]):(n===r?(r=e[1],o=e[0]):(r=e[0],o=e[1]),Math.atan2(r[0]-o[0],o[1]-r[1]))}function Ba(t,e){return e[+(e.left!==t.site)]}function Ua(t,e){return e[+(e.left===t.site)]}function Ha(){for(var t,e,n,r,o=0,i=cb.length;o<i;++o)if((t=cb[o])&&(r=(e=t.halfedges).length)){var a=new Array(r),s=new Array(r);for(n=0;n<r;++n)a[n]=n,s[n]=ja(t,db[e[n]]);for(a.sort(function(t,e){return s[e]-s[t]}),n=0;n<r;++n)s[n]=e[a[n]];for(n=0;n<r;++n)e[n]=s[n]}}function za(t,e,n,r){var o,i,a,s,l,u,c,f,d,p,h,g,v=cb.length,m=!0;for(o=0;o<v;++o)if(i=cb[o]){for(a=i.site,l=i.halfedges,s=l.length;s--;)db[l[s]]||l.splice(s,1);for(s=0,u=l.length;s<u;)p=Ua(i,db[l[s]]),h=p[0],g=p[1],c=Ba(i,db[l[++s%u]]),f=c[0],d=c[1],(Math.abs(h-f)>gb||Math.abs(g-d)>gb)&&(l.splice(s,0,db.push(Oa(a,p,Math.abs(h-t)<gb&&r-g>gb?[t,Math.abs(f-t)<gb?d:r]:Math.abs(g-r)<gb&&n-h>gb?[Math.abs(d-r)<gb?f:n,r]:Math.abs(h-n)<gb&&g-e>gb?[n,Math.abs(f-n)<gb?d:e]:Math.abs(g-e)<gb&&h-t>gb?[Math.abs(d-e)<gb?f:t,e]:null))-1),++u);u&&(m=!1)}if(m){var y,b,x,_=1/0;for(o=0,m=null;o<v;++o)(i=cb[o])&&(a=i.site,y=a[0]-t,b=a[1]-e,x=y*y+b*b,x<_&&(_=x,m=i));if(m){var w=[t,e],T=[t,r],C=[n,r],k=[n,e];m.halfedges.push(db.push(Oa(a=m.site,w,T))-1,db.push(Oa(a,T,C))-1,db.push(Oa(a,C,k))-1,db.push(Oa(a,k,w))-1)}}for(o=0;o<v;++o)(i=cb[o])&&(i.halfedges.length||delete cb[o])}function Wa(){Pa(this),this.x=this.y=this.arc=this.site=this.cy=null}function qa(t){var e=t.P,n=t.N;if(e&&n){var r=e.site,o=t.site,i=n.site;if(r!==i){var a=o[0],s=o[1],l=r[0]-a,u=r[1]-s,c=i[0]-a,f=i[1]-s,d=2*(l*f-u*c);if(!(d>=-vb)){var p=l*l+u*u,h=c*c+f*f,g=(f*p-u*h)/d,v=(l*h-c*p)/d,m=pb.pop()||new Wa;m.arc=t,m.site=o,m.x=g+a,m.y=(m.cy=v+s)+Math.sqrt(g*g+v*v),t.circle=m;for(var y=null,b=fb._;b;)if(m.y<b.y||m.y===b.y&&m.x<=b.x){if(!b.L){y=b.P;break}b=b.L}else{if(!b.R){y=b;break}b=b.R}fb.insert(y,m),y||(lb=m)}}}}function Va(t){var e=t.circle;e&&(e.P||(lb=e.N),fb.remove(e),pb.push(e),Pa(e),t.circle=null)}function Ka(){Pa(this),this.edge=this.site=this.circle=null}function Ya(t){var e=hb.pop()||new Ka;return e.site=t,e}function Ga(t){Va(t),ub.remove(t),hb.push(t),Pa(t)}function Xa(t){var e=t.circle,n=e.x,r=e.cy,o=[n,r],i=t.P,a=t.N,s=[t];Ga(t);for(var l=i;l.circle&&Math.abs(n-l.circle.x)<gb&&Math.abs(r-l.circle.cy)<gb;)i=l.P,s.unshift(l),Ga(l),l=i;s.unshift(l),Va(l);for(var u=a;u.circle&&Math.abs(n-u.circle.x)<gb&&Math.abs(r-u.circle.cy)<gb;)a=u.N,s.push(u),Ga(u),u=a;s.push(u),Va(u);var c,f=s.length;for(c=1;c<f;++c)u=s[c],l=s[c-1],Da(u.edge,l.site,u.site,o);l=s[0],u=s[f-1],u.edge=Aa(l.site,u.site,null,o),qa(l),qa(u)}function $a(t){for(var e,n,r,o,i=t[0],a=t[1],s=ub._;s;)if(r=Za(s,a)-i,r>gb)s=s.L;else{if(o=i-Ja(s,a),!(o>gb)){r>-gb?(e=s.P,n=s):o>-gb?(e=s,n=s.N):e=n=s;break}if(!s.R){e=s;break}s=s.R}Fa(t);var l=Ya(t);if(ub.insert(e,l),e||n){if(e===n)return Va(e),n=Ya(e.site),ub.insert(l,n),l.edge=n.edge=Aa(e.site,l.site),qa(e),void qa(n);if(!n)return void(l.edge=Aa(e.site,l.site));Va(e),Va(n);var u=e.site,c=u[0],f=u[1],d=t[0]-c,p=t[1]-f,h=n.site,g=h[0]-c,v=h[1]-f,m=2*(d*v-p*g),y=d*d+p*p,b=g*g+v*v,x=[(v*y-p*b)/m+c,(d*b-g*y)/m+f];Da(n.edge,u,h,x),l.edge=Aa(u,t,null,x),n.edge=Aa(t,h,null,x),qa(e),qa(n)}}function Za(t,e){var n=t.site,r=n[0],o=n[1],i=o-e;if(!i)return r;var a=t.P;if(!a)return-(1/0);n=a.site;var s=n[0],l=n[1],u=l-e;if(!u)return s;var c=s-r,f=1/i-1/u,d=c/u;return f?(-d+Math.sqrt(d*d-2*f*(c*c/(-2*u)-l+u/2+o-i/2)))/f+r:(r+s)/2}function Ja(t,e){var n=t.N;if(n)return Za(n,e);var r=t.site;return r[1]===e?r[0]:1/0}function Qa(t,e,n){return(t[0]-n[0])*(e[1]-t[1])-(t[0]-e[0])*(n[1]-t[1])}function ts(t,e){return e[1]-t[1]||e[0]-t[0]}function es(t,e){var n,r,o,i=t.sort(ts).pop();for(db=[],cb=new Array(t.length),ub=new Ea,fb=new Ea;;)if(o=lb,i&&(!o||i[1]<o.y||i[1]===o.y&&i[0]<o.x))i[0]===n&&i[1]===r||($a(i),n=i[0],r=i[1]),i=t.pop();else{if(!o)break;Xa(o.arc)}if(Ha(),e){var a=+e[0][0],s=+e[0][1],l=+e[1][0],u=+e[1][1];La(a,s,l,u),za(a,s,l,u)}this.edges=db,this.cells=cb,ub=fb=db=cb=null}function ns(t,e,n){this.target=t,this.type=e,this.transform=n}function rs(t,e,n){this.k=t,this.x=e,this.y=n}function os(t){return t.__zoom||bb}function is(){t.event.stopImmediatePropagation()}function as(){return!t.event.button}function ss(){var t,e,n=this;return n instanceof SVGElement?(n=n.ownerSVGElement||n,t=n.width.baseVal.value,e=n.height.baseVal.value):(t=n.clientWidth,e=n.clientHeight),[[0,0],[t,e]]}function ls(){return this.__zoom||bb}function us(){t.event.stopImmediatePropagation()}function cs(t){return{type:t}}function fs(){return!t.event.button}function ds(){var t=this.ownerSVGElement||this;return[[0,0],[t.width.baseVal.value,t.height.baseVal.value]]}function ps(t){for(;!t.__brush;)if(!(t=t.parentNode))return;return t.__brush}function hs(t){return t[0][0]===t[1][0]||t[0][1]===t[1][1]}function gs(t){var e=t.__brush;return e?e.dim.output(e.selection):null}function vs(){return ys(Mb)}function ms(){return ys(Nb)}function ys(e){function n(t){var n=t.property("__brush",s).selectAll(".overlay").data([cs("overlay")]);n.enter().append("rect").attr("class","overlay").attr("pointer-events","all").attr("cursor",Ob.overlay).merge(n).each(function(){var t=ps(this).extent;_m(this).attr("x",t[0][0]).attr("y",t[0][1]).attr("width",t[1][0]-t[0][0]).attr("height",t[1][1]-t[0][1])}),t.selectAll(".selection").data([cs("selection")]).enter().append("rect").attr("class","selection").attr("cursor",Ob.selection).attr("fill","#777").attr("fill-opacity",.3).attr("stroke","#fff").attr("shape-rendering","crispEdges");var o=t.selectAll(".handle").data(e.handles,function(t){return t.type});o.exit().remove(),o.enter().append("rect").attr("class",function(t){return"handle handle--"+t.type}).attr("cursor",function(t){return Ob[t.type]}),t.each(r).attr("fill","none").attr("pointer-events","all").style("-webkit-tap-highlight-color","rgba(0,0,0,0)").on("mousedown.brush touchstart.brush",a)}function r(){var t=_m(this),e=ps(this).selection;e?(t.selectAll(".selection").style("display",null).attr("x",e[0][0]).attr("y",e[0][1]).attr("width",e[1][0]-e[0][0]).attr("height",e[1][1]-e[0][1]),t.selectAll(".handle").style("display",null).attr("x",function(t){return"e"===t.type[t.type.length-1]?e[1][0]-d/2:e[0][0]-d/2}).attr("y",function(t){return"s"===t.type[0]?e[1][1]-d/2:e[0][1]-d/2}).attr("width",function(t){return"n"===t.type||"s"===t.type?e[1][0]-e[0][0]+d:d}).attr("height",function(t){return"e"===t.type||"w"===t.type?e[1][1]-e[0][1]+d:d})):t.selectAll(".selection,.handle").style("display","none").attr("x",null).attr("y",null).attr("width",null).attr("height",null)}function o(t,e){return t.__brush.emitter||new i(t,e)}function i(t,e){this.that=t,this.args=e,this.state=t.__brush,this.active=0}function a(){function n(){var t=Bv(C);!L||w||T||(Math.abs(t[0]-j[0])>Math.abs(t[1]-j[1])?T=!0:w=!0),j=t,_=!0,Cb(),i()}function i(){var t;switch(b=j[0]-F[0],x=j[1]-F[1],E){case Eb:case kb:P&&(b=Math.max(O-f,Math.min(I-g,b)),d=f+b,v=g+b),S&&(x=Math.max(D-p,Math.min(R-m,x)),h=p+x,y=m+x);break;case Pb:P<0?(b=Math.max(O-f,Math.min(I-f,b)),d=f+b,v=g):P>0&&(b=Math.max(O-g,Math.min(I-g,b)),d=f,v=g+b),S<0?(x=Math.max(D-p,Math.min(R-p,x)),h=p+x,y=m):S>0&&(x=Math.max(D-m,Math.min(R-m,x)),h=p,y=m+x);break;case Sb:P&&(d=Math.max(O,Math.min(I,f-b*P)),v=Math.max(O,Math.min(I,g+b*P))),S&&(h=Math.max(D,Math.min(R,p-x*S)),y=Math.max(D,Math.min(R,m+x*S)))}v<d&&(P*=-1,t=f,f=g,g=t,t=d,d=v,v=t,k in Db&&H.attr("cursor",Ob[k=Db[k]])),y<h&&(S*=-1,t=p,p=m,m=t,t=h,h=y,y=t,k in Ib&&H.attr("cursor",Ob[k=Ib[k]])),M.selection&&(A=M.selection),w&&(d=A[0][0],v=A[1][0]),T&&(h=A[0][1],y=A[1][1]),A[0][0]===d&&A[0][1]===h&&A[1][0]===v&&A[1][1]===y||(M.selection=[[d,h],[v,y]],r.call(C),B.brush())}function a(){if(us(),t.event.touches){if(t.event.touches.length)return;l&&clearTimeout(l),l=setTimeout(function(){l=null},500),U.on("touchmove.brush touchend.brush touchcancel.brush",null)}else ba(t.event.view,_),z.on("keydown.brush keyup.brush mousemove.brush mouseup.brush",null);U.attr("pointer-events","all"),H.attr("cursor",Ob.overlay),M.selection&&(A=M.selection),hs(A)&&(M.selection=null,r.call(C)),B.end()}function s(){switch(t.event.keyCode){case 16:L=P&&S;break;case 18:E===Pb&&(P&&(g=v-b*P,f=d+b*P),S&&(m=y-x*S,p=h+x*S),E=Sb,i());break;case 32:E!==Pb&&E!==Sb||(P<0?g=v-b:P>0&&(f=d-b),S<0?m=y-x:S>0&&(p=h-x),E=Eb,H.attr("cursor",Ob.selection),i());break;default:return}Cb()}function u(){switch(t.event.keyCode){case 16:L&&(w=T=L=!1,i());break;case 18:E===Sb&&(P<0?g=v:P>0&&(f=d),S<0?m=y:S>0&&(p=h),E=Pb,i());break;case 32:E===Eb&&(t.event.altKey?(P&&(g=v-b*P,f=d+b*P),S&&(m=y-x*S,p=h+x*S),E=Sb):(P<0?g=v:P>0&&(f=d),S<0?m=y:S>0&&(p=h),E=Pb),H.attr("cursor",Ob[k]),i());break;default:return}Cb()}if(t.event.touches){if(t.event.changedTouches.length<t.event.touches.length)return Cb()}else if(l)return;if(c.apply(this,arguments)){var f,d,p,h,g,v,m,y,b,x,_,w,T,C=this,k=t.event.target.__data__.type,E="selection"===(t.event.metaKey?k="overlay":k)?kb:t.event.altKey?Sb:Pb,P=e===Nb?null:Rb[k],S=e===Mb?null:Lb[k],M=ps(C),N=M.extent,A=M.selection,O=N[0][0],D=N[0][1],I=N[1][0],R=N[1][1],L=P&&S&&t.event.shiftKey,F=Bv(C),j=F,B=o(C,arguments).beforestart();"overlay"===k?M.selection=A=[[f=e===Nb?O:F[0],p=e===Mb?D:F[1]],[g=e===Nb?I:f,m=e===Mb?R:p]]:(f=A[0][0],p=A[0][1],g=A[1][0],m=A[1][1]),d=f,h=p,v=g,y=m;var U=_m(C).attr("pointer-events","none"),H=U.selectAll(".overlay").attr("cursor",Ob[k]);if(t.event.touches)U.on("touchmove.brush",n,!0).on("touchend.brush touchcancel.brush",a,!0);else{var z=_m(t.event.view).on("keydown.brush",s,!0).on("keyup.brush",u,!0).on("mousemove.brush",n,!0).on("mouseup.brush",a,!0);ob(t.event.view)}us(),Rm(C),r.call(C),B.start()}}function s(){var t=this.__brush||{selection:null};return t.extent=u.apply(this,arguments),t.dim=e,t}var l,u=ds,c=fs,f=Ae(n,"start","brush","end"),d=6;return n.move=function(t,n){t.selection?t.on("start.brush",function(){o(this,arguments).beforestart().start()}).on("interrupt.brush end.brush",function(){o(this,arguments).end()}).tween("brush",function(){function t(t){a.selection=1===t&&hs(u)?null:c(t),r.call(i),s.brush()}var i=this,a=i.__brush,s=o(i,arguments),l=a.selection,u=e.input("function"==typeof n?n.apply(this,arguments):n,a.extent),c=bp(l,u);return l&&u?t:t(1)}):t.each(function(){var t=this,i=arguments,a=t.__brush,s=e.input("function"==typeof n?n.apply(t,i):n,a.extent),l=o(t,i).beforestart();Rm(t),a.selection=null==s||hs(s)?null:s,r.call(t),l.start().brush().end()})},i.prototype={beforestart:function(){return 1===++this.active&&(this.state.emitter=this,this.starting=!0),this},start:function(){return this.starting&&(this.starting=!1,this.emit("start")),this},brush:function(){return this.emit("brush"),this},end:function(){return 0===--this.active&&(delete this.state.emitter,this.emit("end")),this},emit:function(t){Vr(new Tb(n,t,e.output(this.state.selection)),f.apply,f,[t,this.that,this.args])}},n.extent=function(t){return arguments.length?(u="function"==typeof t?t:wb([[+t[0][0],+t[0][1]],[+t[1][0],+t[1][1]]]),n):u},n.filter=function(t){return arguments.length?(c="function"==typeof t?t:wb(!!t),n):c},n.handleSize=function(t){return arguments.length?(d=+t,n):d},n.on=function(){var t=f.on.apply(f,arguments);return t===f?n:t},n}function bs(t){return function(e,n){return t(e.source.value+e.target.value,n.source.value+n.target.value)}}function xs(t){return t.source}function _s(t){return t.target}function ws(t){return t.radius}function Ts(t){return t.startAngle}function Cs(t){return t.endAngle}function ks(){this.reset()}function Es(t,e,n){var r=t.s=e+n,o=r-e,i=r-o;t.t=e-i+(n-o)}function Ps(t){return t>1?0:t<-1?Mx:Math.acos(t)}function Ss(t){return t>1?Nx:t<-1?-Nx:Math.asin(t)}function Ms(t){return(t=Wx(t/2))*t}function Ns(){}function As(t,e){t&&Gx.hasOwnProperty(t.type)&&Gx[t.type](t,e)}function Os(t,e,n){var r,o=-1,i=t.length-n;for(e.lineStart();++o<i;)r=t[o],e.point(r[0],r[1],r[2]);e.lineEnd()}function Ds(t,e){var n=-1,r=t.length;for(e.polygonStart();++n<r;)Os(t[n],e,1);e.polygonEnd()}function Is(){Jx.point=Ls}function Rs(){Fs(Xb,$b)}function Ls(t,e){Jx.point=Fs,Xb=t,$b=e,t*=Ix,e*=Ix,Zb=t,Jb=jx(e=e/2+Ax),Qb=Wx(e)}function Fs(t,e){t*=Ix,e*=Ix,e=e/2+Ax;var n=t-Zb,r=n>=0?1:-1,o=r*n,i=jx(e),a=Wx(e),s=Qb*a,l=Jb*i+s*jx(o),u=s*r*Wx(o);$x.add(Fx(u,l)),Zb=t,Jb=i,Qb=a}function js(t){return[Fx(t[1],t[0]),Ss(t[2])]}function Bs(t){var e=t[0],n=t[1],r=jx(n);return[r*jx(e),r*Wx(e),Wx(n)]}function Us(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function Hs(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function zs(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Ws(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function qs(t){var e=Vx(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Vs(t,e){lx.push(ux=[tx=t,nx=t]),e<ex&&(ex=e),e>rx&&(rx=e)}function Ks(t,e){var n=Bs([t*Ix,e*Ix]);if(sx){var r=Hs(sx,n),o=[r[1],-r[0],0],i=Hs(o,r);qs(i),i=js(i);var a,s=t-ox,l=s>0?1:-1,u=i[0]*Dx*l,c=Rx(s)>180;c^(l*ox<u&&u<l*t)?(a=i[1]*Dx,a>rx&&(rx=a)):(u=(u+360)%360-180,c^(l*ox<u&&u<l*t)?(a=-i[1]*Dx,a<ex&&(ex=a)):(e<ex&&(ex=e),e>rx&&(rx=e))),c?t<ox?Js(tx,t)>Js(tx,nx)&&(nx=t):Js(t,nx)>Js(tx,nx)&&(tx=t):nx>=tx?(t<tx&&(tx=t),t>nx&&(nx=t)):t>ox?Js(tx,t)>Js(tx,nx)&&(nx=t):Js(t,nx)>Js(tx,nx)&&(tx=t)}else Vs(t,e);sx=n,ox=t}function Ys(){e_.point=Ks}function Gs(){ux[0]=tx,ux[1]=nx,e_.point=Vs,sx=null}function Xs(t,e){if(sx){var n=t-ox;t_.add(Rx(n)>180?n+(n>0?360:-360):n)}else ix=t,ax=e;Jx.point(t,e),Ks(t,e)}function $s(){Jx.lineStart()}function Zs(){Xs(ix,ax),Jx.lineEnd(),Rx(t_)>Px&&(tx=-(nx=180)),ux[0]=tx,ux[1]=nx,sx=null}function Js(t,e){return(e-=t)<0?e+360:e}function Qs(t,e){return t[0]-e[0]}function tl(t,e){return t[0]<=t[1]?t[0]<=e&&e<=t[1]:e<t[0]||t[1]<e}function el(t,e){t*=Ix,e*=Ix;var n=jx(e);nl(n*jx(t),n*Wx(t),Wx(e))}function nl(t,e,n){++cx,dx+=(t-dx)/cx,px+=(e-px)/cx,hx+=(n-hx)/cx}function rl(){r_.point=ol}function ol(t,e){t*=Ix,e*=Ix;var n=jx(e);Tx=n*jx(t),Cx=n*Wx(t),kx=Wx(e),r_.point=il,nl(Tx,Cx,kx)}function il(t,e){t*=Ix,e*=Ix;var n=jx(e),r=n*jx(t),o=n*Wx(t),i=Wx(e),a=Fx(Vx((a=Cx*i-kx*o)*a+(a=kx*r-Tx*i)*a+(a=Tx*o-Cx*r)*a),Tx*r+Cx*o+kx*i);fx+=a,gx+=a*(Tx+(Tx=r)),vx+=a*(Cx+(Cx=o)),mx+=a*(kx+(kx=i)),nl(Tx,Cx,kx)}function al(){r_.point=el}function sl(){r_.point=ul}function ll(){cl(_x,wx),r_.point=el}function ul(t,e){_x=t,wx=e,t*=Ix,e*=Ix,r_.point=cl;var n=jx(e);Tx=n*jx(t),Cx=n*Wx(t),kx=Wx(e),nl(Tx,Cx,kx)}function cl(t,e){t*=Ix,e*=Ix;var n=jx(e),r=n*jx(t),o=n*Wx(t),i=Wx(e),a=Cx*i-kx*o,s=kx*r-Tx*i,l=Tx*o-Cx*r,u=Vx(a*a+s*s+l*l),c=Tx*r+Cx*o+kx*i,f=u&&-Ps(c)/u,d=Fx(u,c);yx+=f*a,bx+=f*s,xx+=f*l,fx+=d,gx+=d*(Tx+(Tx=r)),vx+=d*(Cx+(Cx=o)),mx+=d*(kx+(kx=i)),nl(Tx,Cx,kx)}function fl(t,e){return[t>Mx?t-Ox:t<-Mx?t+Ox:t,e]}function dl(t,e,n){return(t%=Ox)?e||n?a_(hl(t),gl(e,n)):hl(t):e||n?gl(e,n):fl}function pl(t){return function(e,n){return e+=t,[e>Mx?e-Ox:e<-Mx?e+Ox:e,n]}}function hl(t){var e=pl(t);return e.invert=pl(-t),e}function gl(t,e){function n(t,e){var n=jx(e),s=jx(t)*n,l=Wx(t)*n,u=Wx(e),c=u*r+s*o;return[Fx(l*i-c*a,s*r-u*o),Ss(c*i+l*a)]}var r=jx(t),o=Wx(t),i=jx(e),a=Wx(e);return n.invert=function(t,e){var n=jx(e),s=jx(t)*n,l=Wx(t)*n,u=Wx(e),c=u*i-l*a;return[Fx(l*i+u*a,s*r+c*o),Ss(c*r-s*o)]},n}function vl(t,e,n,r,o,i){if(n){var a=jx(e),s=Wx(e),l=r*n;null==o?(o=e+r*Ox,i=e-l/2):(o=ml(a,o),i=ml(a,i),(r>0?o<i:o>i)&&(o+=r*Ox));for(var u,c=o;r>0?c>i:c<i;c-=l)u=js([a,-s*jx(c),-s*Wx(c)]),t.point(u[0],u[1])}}function ml(t,e){e=Bs(e),e[0]-=t,qs(e);var n=Ps(-e[1]);return((-e[2]<0?-n:n)+Ox-Px)%Ox}function yl(t,e,n,r){this.x=t,this.z=e,this.o=n,this.e=r,this.v=!1,this.n=this.p=null}function bl(t){if(e=t.length){for(var e,n,r=0,o=t[0];++r<e;)o.n=n=t[r],n.p=o,o=n;o.n=n=t[0],n.p=o}}function xl(t,e,n,r){function o(o,i){return t<=o&&o<=n&&e<=i&&i<=r}function i(o,i,s,u){var c=0,f=0;if(null==o||(c=a(o,s))!==(f=a(i,s))||l(o,i)<0^s>0){do u.point(0===c||3===c?t:n,c>1?r:e);while((c=(c+s+4)%4)!==f)}else u.point(i[0],i[1])}function a(r,o){return Rx(r[0]-t)<Px?o>0?0:3:Rx(r[0]-n)<Px?o>0?2:1:Rx(r[1]-e)<Px?o>0?1:0:o>0?3:2}function s(t,e){return l(t.x,e.x)}function l(t,e){var n=a(t,1),r=a(e,1);return n!==r?n-r:0===n?e[1]-t[1]:1===n?t[0]-e[0]:2===n?t[1]-e[1]:e[0]-t[0]}return function(a){function l(t,e){o(t,e)&&E.point(t,e)}function u(){for(var e=0,n=0,o=v.length;n<o;++n)for(var i,a,s=v[n],l=1,u=s.length,c=s[0],f=c[0],d=c[1];l<u;++l)i=f,a=d,c=s[l],f=c[0],d=c[1],a<=r?d>r&&(f-i)*(r-a)>(d-a)*(t-i)&&++e:d<=r&&(f-i)*(r-a)<(d-a)*(t-i)&&--e;return e}function c(){E=P,g=[],v=[],k=!0}function f(){var t=u(),e=k&&t,n=(g=Zu(g)).length;(e||n)&&(a.polygonStart(),e&&(a.lineStart(),i(null,null,1,a),a.lineEnd()),n&&T_(g,s,t,i,a),a.polygonEnd()),E=a,g=v=m=null}function d(){S.point=h,v&&v.push(m=[]),C=!0,T=!1,_=w=NaN}function p(){g&&(h(y,b),x&&T&&P.rejoin(),g.push(P.result())),S.point=l,T&&E.lineEnd()}function h(i,a){var s=o(i,a);if(v&&m.push([i,a]),C)y=i,b=a,x=s,C=!1,s&&(E.lineStart(),E.point(i,a));else if(s&&T)E.point(i,a);else{var l=[_=Math.max(k_,Math.min(C_,_)),w=Math.max(k_,Math.min(C_,w))],u=[i=Math.max(k_,Math.min(C_,i)),a=Math.max(k_,Math.min(C_,a))];__(l,u,t,e,n,r)?(T||(E.lineStart(),E.point(l[0],l[1])),E.point(u[0],u[1]),s||E.lineEnd(),k=!1):s&&(E.lineStart(),E.point(i,a),k=!1)}_=i,w=a,T=s}var g,v,m,y,b,x,_,w,T,C,k,E=a,P=x_(),S={point:l,lineStart:d,lineEnd:p,polygonStart:c,polygonEnd:f};return S}}function _l(){S_.point=Tl,S_.lineEnd=wl}function wl(){S_.point=S_.lineEnd=Ns}function Tl(t,e){t*=Ix,e*=Ix,s_=t,l_=Wx(e),u_=jx(e),S_.point=Cl}function Cl(t,e){t*=Ix,e*=Ix;var n=Wx(e),r=jx(e),o=Rx(t-s_),i=jx(o),a=Wx(o),s=r*a,l=u_*n-l_*r*i,u=l_*n+u_*r*i;P_.add(Fx(Vx(s*s+l*l),u)),s_=t,l_=n,u_=r}function kl(t,e,n){var r=ju(t,e-Px,n).concat(e);return function(t){return r.map(function(e){return[t,e]})}}function El(t,e,n){var r=ju(t,e-Px,n).concat(e);return function(t){return r.map(function(e){return[e,t]})}}function Pl(){function t(){return{type:"MultiLineString",coordinates:e()}}function e(){return ju(Bx(i/v)*v,o,v).map(d).concat(ju(Bx(u/m)*m,l,m).map(p)).concat(ju(Bx(r/h)*h,n,h).filter(function(t){return Rx(t%v)>Px}).map(c)).concat(ju(Bx(s/g)*g,a,g).filter(function(t){return Rx(t%m)>Px}).map(f))}var n,r,o,i,a,s,l,u,c,f,d,p,h=10,g=h,v=90,m=360,y=2.5;return t.lines=function(){return e().map(function(t){return{type:"LineString",coordinates:t}})},t.outline=function(){return{type:"Polygon",coordinates:[d(i).concat(p(l).slice(1),d(o).reverse().slice(1),p(u).reverse().slice(1))]}},t.extent=function(e){return arguments.length?t.extentMajor(e).extentMinor(e):t.extentMinor()},t.extentMajor=function(e){return arguments.length?(i=+e[0][0],o=+e[1][0],u=+e[0][1],l=+e[1][1],i>o&&(e=i,i=o,o=e),u>l&&(e=u,u=l,l=e),t.precision(y)):[[i,u],[o,l]]},t.extentMinor=function(e){return arguments.length?(r=+e[0][0],n=+e[1][0],s=+e[0][1],a=+e[1][1],r>n&&(e=r,r=n,n=e),s>a&&(e=s,s=a,a=e),t.precision(y)):[[r,s],[n,a]]},t.step=function(e){return arguments.length?t.stepMajor(e).stepMinor(e):t.stepMinor()},t.stepMajor=function(e){return arguments.length?(v=+e[0],m=+e[1],t):[v,m]},t.stepMinor=function(e){return arguments.length?(h=+e[0],g=+e[1],t):[h,g]},t.precision=function(e){return arguments.length?(y=+e,c=kl(s,a,90),f=El(r,n,y),d=kl(u,l,90),p=El(i,o,y),t):y},t.extentMajor([[-180,-90+Px],[180,90-Px]]).extentMinor([[-180,-80-Px],[180,80+Px]])}function Sl(){return Pl()()}function Ml(){F_.point=Nl}function Nl(t,e){F_.point=Al,c_=d_=t,f_=p_=e}function Al(t,e){L_.add(p_*t-d_*e),d_=t,p_=e}function Ol(){Al(c_,f_)}function Dl(t,e){t<j_&&(j_=t),t>U_&&(U_=t),e<B_&&(B_=e),e>H_&&(H_=e)}function Il(t,e){W_+=t,q_+=e,++V_}function Rl(){J_.point=Ll}function Ll(t,e){J_.point=Fl,Il(v_=t,m_=e)}function Fl(t,e){var n=t-v_,r=e-m_,o=Vx(n*n+r*r);K_+=o*(v_+t)/2,Y_+=o*(m_+e)/2,G_+=o,Il(v_=t,m_=e)}function jl(){J_.point=Il}function Bl(){J_.point=Hl}function Ul(){zl(h_,g_)}function Hl(t,e){J_.point=zl,Il(h_=v_=t,g_=m_=e)}function zl(t,e){var n=t-v_,r=e-m_,o=Vx(n*n+r*r);K_+=o*(v_+t)/2,Y_+=o*(m_+e)/2,G_+=o,o=m_*t-v_*e,X_+=o*(v_+t),$_+=o*(m_+e),Z_+=3*o,Il(v_=t,m_=e)}function Wl(t){this._context=t}function ql(){this._string=[]}function Vl(t){return"m0,"+t+"a"+t+","+t+" 0 1,1 0,"+-2*t+"a"+t+","+t+" 0 1,1 0,"+2*t+"z"}function Kl(t){return t.length>1}function Yl(t,e){return((t=t.x)[0]<0?t[1]-Nx-Px:Nx-t[1])-((e=e.x)[0]<0?e[1]-Nx-Px:Nx-e[1])}function Gl(t){var e,n=NaN,r=NaN,o=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(i,a){var s=i>0?Mx:-Mx,l=Rx(i-n);Rx(l-Mx)<Px?(t.point(n,r=(r+a)/2>0?Nx:-Nx),t.point(o,r),t.lineEnd(),t.lineStart(),t.point(s,r),t.point(i,r),e=0):o!==s&&l>=Mx&&(Rx(n-o)<Px&&(n-=o*Px),Rx(i-s)<Px&&(i-=s*Px),r=Xl(n,r,i,a),t.point(o,r),t.lineEnd(),t.lineStart(),t.point(s,r),e=0),t.point(n=i,r=a),o=s},lineEnd:function(){t.lineEnd(),n=r=NaN},clean:function(){return 2-e}}}function Xl(t,e,n,r){var o,i,a=Wx(t-n);return Rx(a)>Px?Lx((Wx(e)*(i=jx(r))*Wx(n)-Wx(r)*(o=jx(e))*Wx(t))/(o*i*a)):(e+r)/2}function $l(t,e,n,r){var o;if(null==t)o=n*Nx,r.point(-Mx,o),r.point(0,o),r.point(Mx,o),r.point(Mx,0),r.point(Mx,-o),r.point(0,-o),r.point(-Mx,-o),r.point(-Mx,0),r.point(-Mx,o);else if(Rx(t[0]-e[0])>Px){var i=t[0]<e[0]?Mx:-Mx;o=n*i/2,r.point(-i,o),r.point(0,o),r.point(i,o)}else r.point(e[0],e[1])}function Zl(t){return function(e){var n=new Jl;for(var r in t)n[r]=t[r];return n.stream=e,n}}function Jl(){}function Ql(t,e,n){var r=e[1][0]-e[0][0],o=e[1][1]-e[0][1],i=t.clipExtent&&t.clipExtent();t.scale(150).translate([0,0]),null!=i&&t.clipExtent(null),Xx(n,t.stream(z_));var a=z_.result(),s=Math.min(r/(a[1][0]-a[0][0]),o/(a[1][1]-a[0][1])),l=+e[0][0]+(r-s*(a[1][0]+a[0][0]))/2,u=+e[0][1]+(o-s*(a[1][1]+a[0][1]))/2;return null!=i&&t.clipExtent(i),t.scale(150*s).translate([l,u])}function tu(t,e,n){return Ql(t,[[0,0],e],n)}function eu(t){return Zl({point:function(e,n){e=t(e,n),this.stream.point(e[0],e[1])}})}function nu(t,e){function n(r,o,i,a,s,l,u,c,f,d,p,h,g,v){var m=u-r,y=c-o,b=m*m+y*y;if(b>4*e&&g--){var x=a+d,_=s+p,w=l+h,T=Vx(x*x+_*_+w*w),C=Ss(w/=T),k=Rx(Rx(w)-1)<Px||Rx(i-f)<Px?(i+f)/2:Fx(_,x),E=t(k,C),P=E[0],S=E[1],M=P-r,N=S-o,A=y*M-m*N;(A*A/b>e||Rx((m*M+y*N)/b-.5)>.3||a*d+s*p+l*h<sw)&&(n(r,o,i,a,s,l,P,S,k,x/=T,_/=T,w,g,v),v.point(P,S),n(P,S,k,x,_,w,u,c,f,d,p,h,g,v))}}return function(e){function r(n,r){n=t(n,r),e.point(n[0],n[1])}function o(){m=NaN,w.point=i,e.lineStart()}function i(r,o){var i=Bs([r,o]),a=t(r,o);n(m,y,v,b,x,_,m=a[0],y=a[1],v=r,b=i[0],x=i[1],_=i[2],aw,e),e.point(m,y)}function a(){w.point=r,e.lineEnd()}function s(){o(),w.point=l,w.lineEnd=u}function l(t,e){i(c=t,e),f=m,d=y,p=b,h=x,g=_,w.point=i}function u(){n(m,y,v,b,x,_,f,d,c,p,h,g,aw,e),w.lineEnd=a,a()}var c,f,d,p,h,g,v,m,y,b,x,_,w={point:r,lineStart:o,lineEnd:a,polygonStart:function(){e.polygonStart(),w.lineStart=s},polygonEnd:function(){e.polygonEnd(),w.lineStart=o}};return w}}function ru(t){return ou(function(){return t})()}function ou(t){function e(t){return t=c(t[0]*Ix,t[1]*Ix),[t[0]*v+s,l-t[1]*v]}function n(t){return t=c.invert((t[0]-s)/v,(l-t[1])/v),t&&[t[0]*Dx,t[1]*Dx]}function r(t,e){return t=a(t,e),[t[0]*v+s,l-t[1]*v]}function o(){c=a_(u=dl(_,w,T),a);var t=a(b,x);return s=m-t[0]*v,l=y+t[1]*v,i()}function i(){return h=g=null,e}var a,s,l,u,c,f,d,p,h,g,v=150,m=480,y=250,b=0,x=0,_=0,w=0,T=0,C=null,k=rw,E=null,P=I_,S=.5,M=lw(r,S);return e.stream=function(t){return h&&g===t?h:h=uw(k(u,M(P(g=t))))},e.clipAngle=function(t){return arguments.length?(k=+t?ow(C=t*Ix,6*Ix):(C=null,rw),i()):C*Dx},e.clipExtent=function(t){return arguments.length?(P=null==t?(E=f=d=p=null,I_):xl(E=+t[0][0],f=+t[0][1],d=+t[1][0],p=+t[1][1]),i()):null==E?null:[[E,f],[d,p]]},e.scale=function(t){return arguments.length?(v=+t,o()):v},e.translate=function(t){return arguments.length?(m=+t[0],y=+t[1],o()):[m,y]},e.center=function(t){return arguments.length?(b=t[0]%360*Ix,x=t[1]%360*Ix,o()):[b*Dx,x*Dx]},e.rotate=function(t){return arguments.length?(_=t[0]%360*Ix,w=t[1]%360*Ix,T=t.length>2?t[2]%360*Ix:0,o()):[_*Dx,w*Dx,T*Dx]},e.precision=function(t){return arguments.length?(M=lw(r,S=t*t),i()):Vx(S)},e.fitExtent=function(t,n){return Ql(e,t,n)},e.fitSize=function(t,n){return tu(e,t,n)},function(){return a=t.apply(this,arguments),e.invert=a.invert&&n,o()}}function iu(t){var e=0,n=Mx/3,r=ou(t),o=r(e,n);return o.parallels=function(t){return arguments.length?r(e=t[0]*Ix,n=t[1]*Ix):[e*Dx,n*Dx]},o}function au(t){function e(t,e){return[t*n,Wx(e)/n]}var n=jx(t);return e.invert=function(t,e){return[t/n,Ss(e*n)]},e}function su(t,e){function n(t,e){var n=Vx(i-2*o*Wx(e))/o;return[n*Wx(t*=o),a-n*jx(t)]}var r=Wx(t),o=(r+Wx(e))/2;if(Rx(o)<Px)return au(t);var i=1+r*(2*o-r),a=Vx(i)/o;return n.invert=function(t,e){var n=a-e;return[Fx(t,Rx(n))/o*qx(n),Ss((i-(t*t+n*n)*o*o)/(2*o))]},n}function lu(t){var e=t.length;return{point:function(n,r){for(var o=-1;++o<e;)t[o].point(n,r)},sphere:function(){for(var n=-1;++n<e;)t[n].sphere()},lineStart:function(){for(var n=-1;++n<e;)t[n].lineStart()},lineEnd:function(){for(var n=-1;++n<e;)t[n].lineEnd()},polygonStart:function(){for(var n=-1;++n<e;)t[n].polygonStart()},polygonEnd:function(){for(var n=-1;++n<e;)t[n].polygonEnd()}}}function uu(t){return function(e,n){var r=jx(e),o=jx(n),i=t(r*o);return[i*o*Wx(e),i*Wx(n)]}}function cu(t){return function(e,n){var r=Vx(e*e+n*n),o=t(r),i=Wx(o),a=jx(o);return[Fx(e*i,r*a),Ss(r&&n*i/r)]}}function fu(t,e){return[t,Hx(Kx((Nx+e)/2))]}function du(t){var e,n=ru(t),r=n.scale,o=n.translate,i=n.clipExtent;return n.scale=function(t){return arguments.length?(r(t),e&&n.clipExtent(null),n):r()},n.translate=function(t){return arguments.length?(o(t),e&&n.clipExtent(null),n):o()},n.clipExtent=function(t){if(!arguments.length)return e?null:i();if(e=null==t){var a=Mx*r(),s=o();t=[[s[0]-a,s[1]-a],[s[0]+a,s[1]+a]]}return i(t),n},n.clipExtent(null)}function pu(t){return Kx((Nx+t)/2)}function hu(t,e){function n(t,e){i>0?e<-Nx+Px&&(e=-Nx+Px):e>Nx-Px&&(e=Nx-Px);var n=i/zx(pu(e),o);return[n*Wx(o*t),i-n*jx(o*t)]}var r=jx(t),o=t===e?Wx(t):Hx(r/jx(e))/Hx(pu(e)/pu(t)),i=r*zx(pu(t),o)/o;return o?(n.invert=function(t,e){var n=i-e,r=qx(o)*Vx(t*t+n*n);return[Fx(t,Rx(n))/o*qx(n),2*Lx(zx(i/r,1/o))-Nx]},n):fu}function gu(t,e){return[t,e]}function vu(t,e){function n(t,e){var n=i-e,r=o*t;return[n*Wx(r),i-n*jx(r)]}var r=jx(t),o=t===e?Wx(t):(r-jx(e))/(e-t),i=r/o+t;return Rx(o)<Px?gu:(n.invert=function(t,e){var n=i-e;return[Fx(t,Rx(n))/o*qx(n),i-qx(o)*Vx(t*t+n*n)]},n)}function mu(t,e){var n=jx(e),r=jx(t)*n;return[n*Wx(t)/r,Wx(e)/r]}function yu(t,e,n,r){return 1===t&&1===e&&0===n&&0===r?I_:Zl({point:function(o,i){this.stream.point(o*t+n,i*e+r)}})}function bu(t,e){return[jx(e)*Wx(t),Wx(e)]}function xu(t,e){var n=jx(e),r=1+jx(t)*n;return[n*Wx(t)/r,Wx(e)/r]}function _u(t,e){return[Hx(Kx((Nx+e)/2)),-t]}var wu="4.4.1",Tu=function(t,e){return t<e?-1:t>e?1:t>=e?0:NaN},Cu=function(t){return 1===t.length&&(t=e(t)),{left:function(e,n,r,o){for(null==r&&(r=0),null==o&&(o=e.length);r<o;){var i=r+o>>>1;t(e[i],n)<0?r=i+1:o=i}return r},right:function(e,n,r,o){for(null==r&&(r=0),null==o&&(o=e.length);r<o;){var i=r+o>>>1;t(e[i],n)>0?o=i:r=i+1}return r}}},ku=Cu(Tu),Eu=ku.right,Pu=ku.left,Su=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},Mu=function(t){return null===t?NaN:+t},Nu=function(t,e){var n,r,o=t.length,i=0,a=0,s=-1,l=0;if(null==e)for(;++s<o;)isNaN(n=Mu(t[s]))||(r=n-i,i+=r/++l,a+=r*(n-i));else for(;++s<o;)isNaN(n=Mu(e(t[s],s,t)))||(r=n-i,i+=r/++l,a+=r*(n-i));if(l>1)return a/(l-1)},Au=function(t,e){var n=Nu(t,e);return n?Math.sqrt(n):n},Ou=function(t,e){var n,r,o,i=-1,a=t.length;if(null==e){for(;++i<a;)if(null!=(r=t[i])&&r>=r){n=o=r;break}for(;++i<a;)null!=(r=t[i])&&(n>r&&(n=r),o<r&&(o=r))}else{for(;++i<a;)if(null!=(r=e(t[i],i,t))&&r>=r){n=o=r;break}for(;++i<a;)null!=(r=e(t[i],i,t))&&(n>r&&(n=r),o<r&&(o=r))}return[n,o]},Du=Array.prototype,Iu=Du.slice,Ru=Du.map,Lu=function(t){return function(){return t}},Fu=function(t){return t},ju=function(t,e,n){t=+t,e=+e,n=(o=arguments.length)<2?(e=t,t=0,1):o<3?1:+n;for(var r=-1,o=0|Math.max(0,Math.ceil((e-t)/n)),i=new Array(o);++r<o;)i[r]=t+r*n;return i},Bu=Math.sqrt(50),Uu=Math.sqrt(10),Hu=Math.sqrt(2),zu=function(t,e,r){var o=n(t,e,r);return ju(Math.ceil(t/o)*o,Math.floor(e/o)*o+o/2,o)},Wu=function(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1},qu=function(){function t(t){var o,i,a=t.length,s=new Array(a);for(o=0;o<a;++o)s[o]=e(t[o],o,t);var l=n(s),u=l[0],c=l[1],f=r(s,u,c);Array.isArray(f)||(f=zu(u,c,f));for(var d=f.length;f[0]<=u;)f.shift(),--d;for(;f[d-1]>=c;)f.pop(),--d;var p,h=new Array(d+1);for(o=0;o<=d;++o)p=h[o]=[],p.x0=o>0?f[o-1]:u,p.x1=o<d?f[o]:c;for(o=0;o<a;++o)i=s[o],u<=i&&i<=c&&h[Eu(f,i,0,d)].push(t[o]);return h}var e=Fu,n=Ou,r=Wu;return t.value=function(n){return arguments.length?(e="function"==typeof n?n:Lu(n),t):e},t.domain=function(e){return arguments.length?(n="function"==typeof e?e:Lu([e[0],e[1]]),t):n},t.thresholds=function(e){return arguments.length?(r="function"==typeof e?e:Lu(Array.isArray(e)?Iu.call(e):e),t):r},t},Vu=function(t,e,n){if(null==n&&(n=Mu),r=t.length){if((e=+e)<=0||r<2)return+n(t[0],0,t);if(e>=1)return+n(t[r-1],r-1,t);var r,o=(r-1)*e,i=Math.floor(o),a=+n(t[i],i,t),s=+n(t[i+1],i+1,t);return a+(s-a)*(o-i)}},Ku=function(t,e,n){return t=Ru.call(t,Mu).sort(Tu),Math.ceil((n-e)/(2*(Vu(t,.75)-Vu(t,.25))*Math.pow(t.length,-1/3)))},Yu=function(t,e,n){return Math.ceil((n-e)/(3.5*Au(t)*Math.pow(t.length,-1/3)))},Gu=function(t,e){var n,r,o=-1,i=t.length;if(null==e){for(;++o<i;)if(null!=(r=t[o])&&r>=r){n=r;break}for(;++o<i;)null!=(r=t[o])&&r>n&&(n=r)}else{for(;++o<i;)if(null!=(r=e(t[o],o,t))&&r>=r){n=r;break}for(;++o<i;)null!=(r=e(t[o],o,t))&&r>n&&(n=r)}return n},Xu=function(t,e){var n,r=0,o=t.length,i=-1,a=o;if(null==e)for(;++i<o;)isNaN(n=Mu(t[i]))?--a:r+=n;else for(;++i<o;)isNaN(n=Mu(e(t[i],i,t)))?--a:r+=n;if(a)return r/a},$u=function(t,e){var n,r=[],o=t.length,i=-1;if(null==e)for(;++i<o;)isNaN(n=Mu(t[i]))||r.push(n);else for(;++i<o;)isNaN(n=Mu(e(t[i],i,t)))||r.push(n);return Vu(r.sort(Tu),.5)},Zu=function(t){for(var e,n,r,o=t.length,i=-1,a=0;++i<o;)a+=t[i].length;for(n=new Array(a);--o>=0;)for(r=t[o],e=r.length;--e>=0;)n[--a]=r[e];return n},Ju=function(t,e){var n,r,o=-1,i=t.length;if(null==e){for(;++o<i;)if(null!=(r=t[o])&&r>=r){n=r;break}for(;++o<i;)null!=(r=t[o])&&n>r&&(n=r)}else{for(;++o<i;)if(null!=(r=e(t[o],o,t))&&r>=r){n=r;break}for(;++o<i;)null!=(r=e(t[o],o,t))&&n>r&&(n=r)}return n},Qu=function(t){for(var e=0,n=t.length-1,r=t[0],o=new Array(n<0?0:n);e<n;)o[e]=[r,r=t[++e]];return o},tc=function(t,e){for(var n=e.length,r=new Array(n);n--;)r[n]=t[e[n]];return r},ec=function(t,e){if(n=t.length){var n,r,o=0,i=0,a=t[i];for(e||(e=Tu);++o<n;)(e(r=t[o],a)<0||0!==e(a,a))&&(a=r,i=o);return 0===e(a,a)?i:void 0}},nc=function(t,e,n){for(var r,o,i=(null==n?t.length:n)-(e=null==e?0:+e);i;)o=Math.random()*i--|0,r=t[i+e],t[i+e]=t[o+e],t[o+e]=r;return t},rc=function(t,e){var n,r=0,o=t.length,i=-1;if(null==e)for(;++i<o;)(n=+t[i])&&(r+=n);else for(;++i<o;)(n=+e(t[i],i,t))&&(r+=n);return r},oc=function(t){if(!(i=t.length))return[];for(var e=-1,n=Ju(t,r),o=new Array(n);++e<n;)for(var i,a=-1,s=o[e]=new Array(i);++a<i;)s[a]=t[a][e];return o},ic=function(){return oc(arguments)},ac="$";o.prototype=i.prototype={constructor:o,has:function(t){return ac+t in this},get:function(t){return this[ac+t]},set:function(t,e){return this[ac+t]=e,this},remove:function(t){var e=ac+t;return e in this&&delete this[e]},clear:function(){for(var t in this)t[0]===ac&&delete this[t]},keys:function(){var t=[];for(var e in this)e[0]===ac&&t.push(e.slice(1));
return t},values:function(){var t=[];for(var e in this)e[0]===ac&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)e[0]===ac&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)e[0]===ac&&++t;return t},empty:function(){for(var t in this)if(t[0]===ac)return!1;return!0},each:function(t){for(var e in this)e[0]===ac&&t(this[e],e.slice(1),this)}};var sc=function(){function t(e,o,a,s){if(o>=c.length)return null!=r?r(e):null!=n?e.sort(n):e;for(var l,u,f,d=-1,p=e.length,h=c[o++],g=i(),v=a();++d<p;)(f=g.get(l=h(u=e[d])+""))?f.push(u):g.set(l,[u]);return g.each(function(e,n){s(v,n,t(e,o,a,s))}),v}function e(t,n){if(++n>c.length)return t;var o,i=f[n-1];return null!=r&&n>=c.length?o=t.entries():(o=[],t.each(function(t,r){o.push({key:r,values:e(t,n)})})),null!=i?o.sort(function(t,e){return i(t.key,e.key)}):o}var n,r,o,c=[],f=[];return o={object:function(e){return t(e,0,a,s)},map:function(e){return t(e,0,l,u)},entries:function(n){return e(t(n,0,l,u),0)},key:function(t){return c.push(t),o},sortKeys:function(t){return f[c.length-1]=t,o},sortValues:function(t){return n=t,o},rollup:function(t){return r=t,o}}},lc=i.prototype;c.prototype=f.prototype={constructor:c,has:lc.has,add:function(t){return t+="",this[ac+t]=t,this},remove:lc.remove,clear:lc.clear,values:lc.keys,size:lc.size,empty:lc.empty,each:lc.each};var uc=function(t){var e=[];for(var n in t)e.push(n);return e},cc=function(t){var e=[];for(var n in t)e.push(t[n]);return e},fc=function(t){var e=[];for(var n in t)e.push({key:n,value:t[n]});return e},dc=function(t,e){return t=null==t?0:+t,e=null==e?1:+e,1===arguments.length?(e=t,t=0):e-=t,function(){return Math.random()*e+t}},pc=function(t,e){var n,r;return t=null==t?0:+t,e=null==e?1:+e,function(){var o;if(null!=n)o=n,n=null;else do n=2*Math.random()-1,o=2*Math.random()-1,r=n*n+o*o;while(!r||r>1);return t+e*o*Math.sqrt(-2*Math.log(r)/r)}},hc=function(){var t=pc.apply(this,arguments);return function(){return Math.exp(t())}},gc=function(t){return function(){for(var e=0,n=0;n<t;++n)e+=Math.random();return e}},vc=function(t){var e=gc(t);return function(){return e()/t}},mc=function(t){return function(){return-Math.log(1-Math.random())/t}},yc=3,bc=function t(e){function n(t){return Math.pow(t,e)}return e=+e,n.exponent=t,n}(yc),xc=function t(e){function n(t){return 1-Math.pow(1-t,e)}return e=+e,n.exponent=t,n}(yc),_c=function t(e){function n(t){return((t*=2)<=1?Math.pow(t,e):2-Math.pow(2-t,e))/2}return e=+e,n.exponent=t,n}(yc),wc=Math.PI,Tc=wc/2,Cc=4/11,kc=6/11,Ec=8/11,Pc=.75,Sc=9/11,Mc=10/11,Nc=.9375,Ac=21/22,Oc=63/64,Dc=1/Cc/Cc,Ic=1.70158,Rc=function t(e){function n(t){return t*t*((e+1)*t-e)}return e=+e,n.overshoot=t,n}(Ic),Lc=function t(e){function n(t){return--t*t*((e+1)*t+e)+1}return e=+e,n.overshoot=t,n}(Ic),Fc=function t(e){function n(t){return((t*=2)<1?t*t*((e+1)*t-e):(t-=2)*t*((e+1)*t+e)+2)/2}return e=+e,n.overshoot=t,n}(Ic),jc=2*Math.PI,Bc=1,Uc=.3,Hc=function t(e,n){function r(t){return e*Math.pow(2,10*--t)*Math.sin((o-t)/n)}var o=Math.asin(1/(e=Math.max(1,e)))*(n/=jc);return r.amplitude=function(e){return t(e,n*jc)},r.period=function(n){return t(e,n)},r}(Bc,Uc),zc=function t(e,n){function r(t){return 1-e*Math.pow(2,-10*(t=+t))*Math.sin((t+o)/n)}var o=Math.asin(1/(e=Math.max(1,e)))*(n/=jc);return r.amplitude=function(e){return t(e,n*jc)},r.period=function(n){return t(e,n)},r}(Bc,Uc),Wc=function t(e,n){function r(t){return((t=2*t-1)<0?e*Math.pow(2,10*t)*Math.sin((o-t)/n):2-e*Math.pow(2,-10*t)*Math.sin((o+t)/n))/2}var o=Math.asin(1/(e=Math.max(1,e)))*(n/=jc);return r.amplitude=function(e){return t(e,n*jc)},r.period=function(n){return t(e,n)},r}(Bc,Uc),qc=function(t){for(var e,n=-1,r=t.length,o=t[r-1],i=0;++n<r;)e=o,o=t[n],i+=e[1]*o[0]-e[0]*o[1];return i/2},Vc=function(t){for(var e,n,r=-1,o=t.length,i=0,a=0,s=t[o-1],l=0;++r<o;)e=s,s=t[r],l+=n=e[0]*s[1]-s[0]*e[1],i+=(e[0]+s[0])*n,a+=(e[1]+s[1])*n;return l*=3,[i/l,a/l]},Kc=function(t,e,n){return(e[0]-t[0])*(n[1]-t[1])-(e[1]-t[1])*(n[0]-t[0])},Yc=function(t){if((n=t.length)<3)return null;var e,n,r=new Array(n),o=new Array(n);for(e=0;e<n;++e)r[e]=[+t[e][0],+t[e][1],e];for(r.sort(A),e=0;e<n;++e)o[e]=[r[e][0],-r[e][1]];var i=O(r),a=O(o),s=a[0]===i[0],l=a[a.length-1]===i[i.length-1],u=[];for(e=i.length-1;e>=0;--e)u.push(t[r[i[e]][2]]);for(e=+s;e<a.length-l;++e)u.push(t[r[a[e]][2]]);return u},Gc=function(t,e){for(var n,r,o=t.length,i=t[o-1],a=e[0],s=e[1],l=i[0],u=i[1],c=!1,f=0;f<o;++f)i=t[f],n=i[0],r=i[1],r>s!=u>s&&a<(l-n)*(s-r)/(u-r)+n&&(c=!c),l=n,u=r;return c},Xc=function(t){for(var e,n,r=-1,o=t.length,i=t[o-1],a=i[0],s=i[1],l=0;++r<o;)e=a,n=s,i=t[r],a=i[0],s=i[1],e-=a,n-=s,l+=Math.sqrt(e*e+n*n);return l},$c=Math.PI,Zc=2*$c,Jc=1e-6,Qc=Zc-Jc;D.prototype=I.prototype={constructor:D,moveTo:function(t,e){this._+="M"+(this._x0=this._x1=+t)+","+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+="Z")},lineTo:function(t,e){this._+="L"+(this._x1=+t)+","+(this._y1=+e)},quadraticCurveTo:function(t,e,n,r){this._+="Q"+ +t+","+ +e+","+(this._x1=+n)+","+(this._y1=+r)},bezierCurveTo:function(t,e,n,r,o,i){this._+="C"+ +t+","+ +e+","+ +n+","+ +r+","+(this._x1=+o)+","+(this._y1=+i)},arcTo:function(t,e,n,r,o){t=+t,e=+e,n=+n,r=+r,o=+o;var i=this._x1,a=this._y1,s=n-t,l=r-e,u=i-t,c=a-e,f=u*u+c*c;if(o<0)throw new Error("negative radius: "+o);if(null===this._x1)this._+="M"+(this._x1=t)+","+(this._y1=e);else if(f>Jc)if(Math.abs(c*s-l*u)>Jc&&o){var d=n-i,p=r-a,h=s*s+l*l,g=d*d+p*p,v=Math.sqrt(h),m=Math.sqrt(f),y=o*Math.tan(($c-Math.acos((h+f-g)/(2*v*m)))/2),b=y/m,x=y/v;Math.abs(b-1)>Jc&&(this._+="L"+(t+b*u)+","+(e+b*c)),this._+="A"+o+","+o+",0,0,"+ +(c*d>u*p)+","+(this._x1=t+x*s)+","+(this._y1=e+x*l)}else this._+="L"+(this._x1=t)+","+(this._y1=e);else;},arc:function(t,e,n,r,o,i){t=+t,e=+e,n=+n;var a=n*Math.cos(r),s=n*Math.sin(r),l=t+a,u=e+s,c=1^i,f=i?r-o:o-r;if(n<0)throw new Error("negative radius: "+n);null===this._x1?this._+="M"+l+","+u:(Math.abs(this._x1-l)>Jc||Math.abs(this._y1-u)>Jc)&&(this._+="L"+l+","+u),n&&(f>Qc?this._+="A"+n+","+n+",0,1,"+c+","+(t-a)+","+(e-s)+"A"+n+","+n+",0,1,"+c+","+(this._x1=l)+","+(this._y1=u):(f<0&&(f=f%Zc+Zc),this._+="A"+n+","+n+",0,"+ +(f>=$c)+","+c+","+(this._x1=t+n*Math.cos(o))+","+(this._y1=e+n*Math.sin(o))))},rect:function(t,e,n,r){this._+="M"+(this._x0=this._x1=+t)+","+(this._y0=this._y1=+e)+"h"+ +n+"v"+ +r+"h"+-n+"Z"},toString:function(){return this._}};var tf=function(t){var e=+this._x.call(null,t),n=+this._y.call(null,t);return R(this.cover(e,n),e,n,t)},ef=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var n=this._x0,r=this._y0,o=this._x1,i=this._y1;if(isNaN(n))o=(n=Math.floor(t))+1,i=(r=Math.floor(e))+1;else{if(!(n>t||t>o||r>e||e>i))return this;var a,s,l=o-n,u=this._root;switch(s=(e<(r+i)/2)<<1|t<(n+o)/2){case 0:do a=new Array(4),a[s]=u,u=a;while(l*=2,o=n+l,i=r+l,t>o||e>i);break;case 1:do a=new Array(4),a[s]=u,u=a;while(l*=2,n=o-l,i=r+l,n>t||e>i);break;case 2:do a=new Array(4),a[s]=u,u=a;while(l*=2,o=n+l,r=i-l,t>o||r>e);break;case 3:do a=new Array(4),a[s]=u,u=a;while(l*=2,n=o-l,r=i-l,n>t||r>e)}this._root&&this._root.length&&(this._root=u)}return this._x0=n,this._y0=r,this._x1=o,this._y1=i,this},nf=function(){var t=[];return this.visit(function(e){if(!e.length)do t.push(e.data);while(e=e.next)}),t},rf=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},of=function(t,e,n,r,o){this.node=t,this.x0=e,this.y0=n,this.x1=r,this.y1=o},af=function(t,e,n){var r,o,i,a,s,l,u,c=this._x0,f=this._y0,d=this._x1,p=this._y1,h=[],g=this._root;for(g&&h.push(new of(g,c,f,d,p)),null==n?n=1/0:(c=t-n,f=e-n,d=t+n,p=e+n,n*=n);l=h.pop();)if(!(!(g=l.node)||(o=l.x0)>d||(i=l.y0)>p||(a=l.x1)<c||(s=l.y1)<f))if(g.length){var v=(o+a)/2,m=(i+s)/2;h.push(new of(g[3],v,m,a,s),new of(g[2],o,m,v,s),new of(g[1],v,i,a,m),new of(g[0],o,i,v,m)),(u=(e>=m)<<1|t>=v)&&(l=h[h.length-1],h[h.length-1]=h[h.length-1-u],h[h.length-1-u]=l)}else{var y=t-+this._x.call(null,g.data),b=e-+this._y.call(null,g.data),x=y*y+b*b;if(x<n){var _=Math.sqrt(n=x);c=t-_,f=e-_,d=t+_,p=e+_,r=g.data}}return r},sf=function(t){if(isNaN(i=+this._x.call(null,t))||isNaN(a=+this._y.call(null,t)))return this;var e,n,r,o,i,a,s,l,u,c,f,d,p=this._root,h=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((u=i>=(s=(h+v)/2))?h=s:v=s,(c=a>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[f=c<<1|u]))return this;if(!p.length)break;(e[f+1&3]||e[f+2&3]||e[f+3&3])&&(n=e,d=f)}for(;p.data!==t;)if(r=p,!(p=p.next))return this;return(o=p.next)&&delete p.next,r?(o?r.next=o:delete r.next,this):e?(o?e[f]=o:delete e[f],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(n?n[d]=p:this._root=p),this):(this._root=o,this)},lf=function(){return this._root},uf=function(){var t=0;return this.visit(function(e){if(!e.length)do++t;while(e=e.next)}),t},cf=function(t){var e,n,r,o,i,a,s=[],l=this._root;for(l&&s.push(new of(l,this._x0,this._y0,this._x1,this._y1));e=s.pop();)if(!t(l=e.node,r=e.x0,o=e.y0,i=e.x1,a=e.y1)&&l.length){var u=(r+i)/2,c=(o+a)/2;(n=l[3])&&s.push(new of(n,u,c,i,a)),(n=l[2])&&s.push(new of(n,r,c,u,a)),(n=l[1])&&s.push(new of(n,u,o,i,c)),(n=l[0])&&s.push(new of(n,r,o,u,c))}return this},ff=function(t){var e,n=[],r=[];for(this._root&&n.push(new of(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var o=e.node;if(o.length){var i,a=e.x0,s=e.y0,l=e.x1,u=e.y1,c=(a+l)/2,f=(s+u)/2;(i=o[0])&&n.push(new of(i,a,s,c,f)),(i=o[1])&&n.push(new of(i,c,s,l,f)),(i=o[2])&&n.push(new of(i,a,f,c,u)),(i=o[3])&&n.push(new of(i,c,f,l,u))}r.push(e)}for(;e=r.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},df=function(t){return arguments.length?(this._x=t,this):this._x},pf=function(t){return arguments.length?(this._y=t,this):this._y},hf=U.prototype=H.prototype;hf.copy=function(){var t,e,n=new H(this._x,this._y,this._x0,this._y0,this._x1,this._y1),r=this._root;if(!r)return n;if(!r.length)return n._root=z(r),n;for(t=[{source:r,target:n._root=new Array(4)}];r=t.pop();)for(var o=0;o<4;++o)(e=r.source[o])&&(e.length?t.push({source:e,target:r.target[o]=new Array(4)}):r.target[o]=z(e));return n},hf.add=tf,hf.addAll=L,hf.cover=ef,hf.data=nf,hf.extent=rf,hf.find=af,hf.remove=sf,hf.removeAll=F,hf.root=lf,hf.size=uf,hf.visit=cf,hf.visitAfter=ff,hf.x=df,hf.y=pf;var gf=[].slice,vf={};W.prototype=X.prototype={constructor:W,defer:function(t){if("function"!=typeof t||this._call)throw new Error;if(null!=this._error)return this;var e=gf.call(arguments,1);return e.push(t),++this._waiting,this._tasks.push(e),q(this),this},abort:function(){return null==this._error&&Y(this,new Error("abort")),this},await:function(t){if("function"!=typeof t||this._call)throw new Error;return this._call=function(e,n){t.apply(null,[e].concat(n))},G(this),this},awaitAll:function(t){if("function"!=typeof t||this._call)throw new Error;return this._call=t,G(this),this}};var mf=function(t){return function(){return t}},yf=1e-12,bf=Math.PI,xf=bf/2,_f=2*bf,wf=function(){function t(){var t,u,c=+e.apply(this,arguments),f=+n.apply(this,arguments),d=i.apply(this,arguments)-xf,p=a.apply(this,arguments)-xf,h=Math.abs(p-d),g=p>d;if(l||(l=t=I()),f<c&&(u=f,f=c,c=u),f>yf)if(h>_f-yf)l.moveTo(f*Math.cos(d),f*Math.sin(d)),l.arc(0,0,f,d,p,!g),c>yf&&(l.moveTo(c*Math.cos(p),c*Math.sin(p)),l.arc(0,0,c,p,d,g));else{var v,m,y=d,b=p,x=d,_=p,w=h,T=h,C=s.apply(this,arguments)/2,k=C>yf&&(o?+o.apply(this,arguments):Math.sqrt(c*c+f*f)),E=Math.min(Math.abs(f-c)/2,+r.apply(this,arguments)),P=E,S=E;if(k>yf){var M=et(k/c*Math.sin(C)),N=et(k/f*Math.sin(C));(w-=2*M)>yf?(M*=g?1:-1,x+=M,_-=M):(w=0,x=_=(d+p)/2),(T-=2*N)>yf?(N*=g?1:-1,y+=N,b-=N):(T=0,y=b=(d+p)/2)}var A=f*Math.cos(y),O=f*Math.sin(y),D=c*Math.cos(_),R=c*Math.sin(_);if(E>yf){var L=f*Math.cos(b),F=f*Math.sin(b),j=c*Math.cos(x),B=c*Math.sin(x);if(h<bf){var U=w>yf?nt(A,O,j,B,L,F,D,R):[D,R],H=A-U[0],z=O-U[1],W=L-U[0],q=F-U[1],V=1/Math.sin(Math.acos((H*W+z*q)/(Math.sqrt(H*H+z*z)*Math.sqrt(W*W+q*q)))/2),K=Math.sqrt(U[0]*U[0]+U[1]*U[1]);P=Math.min(E,(c-K)/(V-1)),S=Math.min(E,(f-K)/(V+1))}}T>yf?S>yf?(v=rt(j,B,A,O,f,S,g),m=rt(L,F,D,R,f,S,g),l.moveTo(v.cx+v.x01,v.cy+v.y01),S<E?l.arc(v.cx,v.cy,S,Math.atan2(v.y01,v.x01),Math.atan2(m.y01,m.x01),!g):(l.arc(v.cx,v.cy,S,Math.atan2(v.y01,v.x01),Math.atan2(v.y11,v.x11),!g),l.arc(0,0,f,Math.atan2(v.cy+v.y11,v.cx+v.x11),Math.atan2(m.cy+m.y11,m.cx+m.x11),!g),l.arc(m.cx,m.cy,S,Math.atan2(m.y11,m.x11),Math.atan2(m.y01,m.x01),!g))):(l.moveTo(A,O),l.arc(0,0,f,y,b,!g)):l.moveTo(A,O),c>yf&&w>yf?P>yf?(v=rt(D,R,L,F,c,-P,g),m=rt(A,O,j,B,c,-P,g),l.lineTo(v.cx+v.x01,v.cy+v.y01),P<E?l.arc(v.cx,v.cy,P,Math.atan2(v.y01,v.x01),Math.atan2(m.y01,m.x01),!g):(l.arc(v.cx,v.cy,P,Math.atan2(v.y01,v.x01),Math.atan2(v.y11,v.x11),!g),l.arc(0,0,c,Math.atan2(v.cy+v.y11,v.cx+v.x11),Math.atan2(m.cy+m.y11,m.cx+m.x11),g),l.arc(m.cx,m.cy,P,Math.atan2(m.y11,m.x11),Math.atan2(m.y01,m.x01),!g))):l.arc(0,0,c,_,x,g):l.lineTo(D,R)}else l.moveTo(0,0);if(l.closePath(),t)return l=null,t+""||null}var e=$,n=Z,r=mf(0),o=null,i=J,a=Q,s=tt,l=null;return t.centroid=function(){var t=(+e.apply(this,arguments)+ +n.apply(this,arguments))/2,r=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-bf/2;return[Math.cos(r)*t,Math.sin(r)*t]},t.innerRadius=function(n){return arguments.length?(e="function"==typeof n?n:mf(+n),t):e},t.outerRadius=function(e){return arguments.length?(n="function"==typeof e?e:mf(+e),t):n},t.cornerRadius=function(e){return arguments.length?(r="function"==typeof e?e:mf(+e),t):r},t.padRadius=function(e){return arguments.length?(o=null==e?null:"function"==typeof e?e:mf(+e),t):o},t.startAngle=function(e){return arguments.length?(i="function"==typeof e?e:mf(+e),t):i},t.endAngle=function(e){return arguments.length?(a="function"==typeof e?e:mf(+e),t):a},t.padAngle=function(e){return arguments.length?(s="function"==typeof e?e:mf(+e),t):s},t.context=function(e){return arguments.length?(l=null==e?null:e,t):l},t};ot.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var Tf=function(t){return new ot(t)},Cf=function(){function t(t){var s,l,u,c=t.length,f=!1;for(null==o&&(a=i(u=I())),s=0;s<=c;++s)!(s<c&&r(l=t[s],s,t))===f&&((f=!f)?a.lineStart():a.lineEnd()),f&&a.point(+e(l,s,t),+n(l,s,t));if(u)return a=null,u+""||null}var e=it,n=at,r=mf(!0),o=null,i=Tf,a=null;return t.x=function(n){return arguments.length?(e="function"==typeof n?n:mf(+n),t):e},t.y=function(e){return arguments.length?(n="function"==typeof e?e:mf(+e),t):n},t.defined=function(e){return arguments.length?(r="function"==typeof e?e:mf(!!e),t):r},t.curve=function(e){return arguments.length?(i=e,null!=o&&(a=i(o)),t):i},t.context=function(e){return arguments.length?(null==e?o=a=null:a=i(o=e),t):o},t},kf=function(){function t(t){var e,c,f,d,p,h=t.length,g=!1,v=new Array(h),m=new Array(h);for(null==s&&(u=l(p=I())),e=0;e<=h;++e){if(!(e<h&&a(d=t[e],e,t))===g)if(g=!g)c=e,u.areaStart(),u.lineStart();else{for(u.lineEnd(),u.lineStart(),f=e-1;f>=c;--f)u.point(v[f],m[f]);u.lineEnd(),u.areaEnd()}g&&(v[e]=+n(d,e,t),m[e]=+o(d,e,t),u.point(r?+r(d,e,t):v[e],i?+i(d,e,t):m[e]))}if(p)return u=null,p+""||null}function e(){return Cf().defined(a).curve(l).context(s)}var n=it,r=null,o=mf(0),i=at,a=mf(!0),s=null,l=Tf,u=null;return t.x=function(e){return arguments.length?(n="function"==typeof e?e:mf(+e),r=null,t):n},t.x0=function(e){return arguments.length?(n="function"==typeof e?e:mf(+e),t):n},t.x1=function(e){return arguments.length?(r=null==e?null:"function"==typeof e?e:mf(+e),t):r},t.y=function(e){return arguments.length?(o="function"==typeof e?e:mf(+e),i=null,t):o},t.y0=function(e){return arguments.length?(o="function"==typeof e?e:mf(+e),t):o},t.y1=function(e){return arguments.length?(i=null==e?null:"function"==typeof e?e:mf(+e),t):i},t.lineX0=t.lineY0=function(){return e().x(n).y(o)},t.lineY1=function(){return e().x(n).y(i)},t.lineX1=function(){return e().x(r).y(o)},t.defined=function(e){return arguments.length?(a="function"==typeof e?e:mf(!!e),t):a},t.curve=function(e){return arguments.length?(l=e,null!=s&&(u=l(s)),t):l},t.context=function(e){return arguments.length?(null==e?s=u=null:u=l(s=e),t):s},t},Ef=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},Pf=function(t){return t},Sf=function(){function t(t){var s,l,u,c,f,d=t.length,p=0,h=new Array(d),g=new Array(d),v=+o.apply(this,arguments),m=Math.min(_f,Math.max(-_f,i.apply(this,arguments)-v)),y=Math.min(Math.abs(m)/d,a.apply(this,arguments)),b=y*(m<0?-1:1);for(s=0;s<d;++s)(f=g[h[s]=s]=+e(t[s],s,t))>0&&(p+=f);for(null!=n?h.sort(function(t,e){return n(g[t],g[e])}):null!=r&&h.sort(function(e,n){return r(t[e],t[n])}),s=0,u=p?(m-d*b)/p:0;s<d;++s,v=c)l=h[s],f=g[l],c=v+(f>0?f*u:0)+b,g[l]={data:t[l],index:s,value:f,startAngle:v,endAngle:c,padAngle:y};return g}var e=Pf,n=Ef,r=null,o=mf(0),i=mf(_f),a=mf(0);return t.value=function(n){return arguments.length?(e="function"==typeof n?n:mf(+n),t):e},t.sortValues=function(e){return arguments.length?(n=e,r=null,t):n},t.sort=function(e){return arguments.length?(r=e,n=null,t):r},t.startAngle=function(e){return arguments.length?(o="function"==typeof e?e:mf(+e),t):o},t.endAngle=function(e){return arguments.length?(i="function"==typeof e?e:mf(+e),t):i},t.padAngle=function(e){return arguments.length?(a="function"==typeof e?e:mf(+e),t):a},t},Mf=lt(Tf);st.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var Nf=function(){return ut(Cf().curve(Mf))},Af=function(){var t=kf().curve(Mf),e=t.curve,n=t.lineX0,r=t.lineX1,o=t.lineY0,i=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return ut(n())},delete t.lineX0,t.lineEndAngle=function(){return ut(r())},delete t.lineX1,t.lineInnerRadius=function(){return ut(o())},delete t.lineY0,t.lineOuterRadius=function(){return ut(i())},delete t.lineY1,t.curve=function(t){return arguments.length?e(lt(t)):e()._curve},t},Of={draw:function(t,e){var n=Math.sqrt(e/bf);t.moveTo(n,0),t.arc(0,0,n,0,_f)}},Df={draw:function(t,e){var n=Math.sqrt(e/5)/2;t.moveTo(-3*n,-n),t.lineTo(-n,-n),t.lineTo(-n,-3*n),t.lineTo(n,-3*n),t.lineTo(n,-n),t.lineTo(3*n,-n),t.lineTo(3*n,n),t.lineTo(n,n),t.lineTo(n,3*n),t.lineTo(-n,3*n),t.lineTo(-n,n),t.lineTo(-3*n,n),t.closePath()}},If=Math.sqrt(1/3),Rf=2*If,Lf={draw:function(t,e){var n=Math.sqrt(e/Rf),r=n*If;t.moveTo(0,-n),t.lineTo(r,0),t.lineTo(0,n),t.lineTo(-r,0),t.closePath()}},Ff=.8908130915292852,jf=Math.sin(bf/10)/Math.sin(7*bf/10),Bf=Math.sin(_f/10)*jf,Uf=-Math.cos(_f/10)*jf,Hf={draw:function(t,e){var n=Math.sqrt(e*Ff),r=Bf*n,o=Uf*n;t.moveTo(0,-n),t.lineTo(r,o);for(var i=1;i<5;++i){var a=_f*i/5,s=Math.cos(a),l=Math.sin(a);t.lineTo(l*n,-s*n),t.lineTo(s*r-l*o,l*r+s*o)}t.closePath()}},zf={draw:function(t,e){var n=Math.sqrt(e),r=-n/2;t.rect(r,r,n,n)}},Wf=Math.sqrt(3),qf={draw:function(t,e){var n=-Math.sqrt(e/(3*Wf));t.moveTo(0,2*n),t.lineTo(-Wf*n,-n),t.lineTo(Wf*n,-n),t.closePath()}},Vf=-.5,Kf=Math.sqrt(3)/2,Yf=1/Math.sqrt(12),Gf=3*(Yf/2+1),Xf={draw:function(t,e){var n=Math.sqrt(e/Gf),r=n/2,o=n*Yf,i=r,a=n*Yf+n,s=-i,l=a;t.moveTo(r,o),t.lineTo(i,a),t.lineTo(s,l),t.lineTo(Vf*r-Kf*o,Kf*r+Vf*o),t.lineTo(Vf*i-Kf*a,Kf*i+Vf*a),t.lineTo(Vf*s-Kf*l,Kf*s+Vf*l),t.lineTo(Vf*r+Kf*o,Vf*o-Kf*r),t.lineTo(Vf*i+Kf*a,Vf*a-Kf*i),t.lineTo(Vf*s+Kf*l,Vf*l-Kf*s),t.closePath()}},$f=[Of,Df,Lf,zf,Hf,qf,Xf],Zf=function(){function t(){var t;if(r||(r=t=I()),e.apply(this,arguments).draw(r,+n.apply(this,arguments)),t)return r=null,t+""||null}var e=mf(Of),n=mf(64),r=null;return t.type=function(n){return arguments.length?(e="function"==typeof n?n:mf(n),t):e},t.size=function(e){return arguments.length?(n="function"==typeof e?e:mf(+e),t):n},t.context=function(e){return arguments.length?(r=null==e?null:e,t):r},t},Jf=function(){};ft.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:ct(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}};var Qf=function(t){return new ft(t)};dt.prototype={areaStart:Jf,areaEnd:Jf,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}};var td=function(t){return new dt(t)};pt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var n=(this._x0+4*this._x1+t)/6,r=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(n,r):this._context.moveTo(n,r);break;case 3:this._point=4;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}};var ed=function(t){return new pt(t)};ht.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,n=t.length-1;if(n>0)for(var r,o=t[0],i=e[0],a=t[n]-o,s=e[n]-i,l=-1;++l<=n;)r=l/n,this._basis.point(this._beta*t[l]+(1-this._beta)*(o+r*a),this._beta*e[l]+(1-this._beta)*(i+r*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var nd=function t(e){function n(t){return 1===e?new ft(t):new ht(t,e)}return n.beta=function(e){return t(+e)},n}(.85);vt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:gt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var rd=function t(e){function n(t){return new vt(t,e)}return n.tension=function(e){return t(+e)},n}(0);mt.prototype={areaStart:Jf,areaEnd:Jf,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var od=function t(e){function n(t){return new mt(t,e)}return n.tension=function(e){return t(+e)},n}(0);yt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var id=function t(e){function n(t){return new yt(t,e)}return n.tension=function(e){return t(+e)},n}(0);xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var n=this._x2-t,r=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(n*n+r*r,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:bt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var ad=function t(e){function n(t){return e?new xt(t,e):new vt(t,0)}return n.alpha=function(e){return t(+e)},n}(.5);_t.prototype={areaStart:Jf,areaEnd:Jf,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var n=this._x2-t,r=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(n*n+r*r,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:bt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var sd=function t(e){function n(t){return e?new _t(t,e):new mt(t,0)}return n.alpha=function(e){return t(+e)},n}(.5);wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var n=this._x2-t,r=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(n*n+r*r,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:bt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var ld=function t(e){function n(t){return e?new wt(t,e):new yt(t,0)}return n.alpha=function(e){return t(+e)},n}(.5);Tt.prototype={areaStart:Jf,areaEnd:Jf,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}};var ud=function(t){return new Tt(t)};St.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Pt(this,this._t0,Et(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var n=NaN;if(t=+t,e=+e,t!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Pt(this,Et(this,n=kt(this,t,e)),n);break;default:Pt(this,this._t0,n=kt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=n}}},(Mt.prototype=Object.create(St.prototype)).point=function(t,e){St.prototype.point.call(this,e,t)},Nt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,n,r,o,i){this._context.bezierCurveTo(e,t,r,n,i,o)}},Dt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,n=t.length;if(n)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===n)this._context.lineTo(t[1],e[1]);else for(var r=It(t),o=It(e),i=0,a=1;a<n;++i,++a)this._context.bezierCurveTo(r[0][i],o[0][i],r[1][i],o[1][i],t[a],e[a]);(this._line||0!==this._line&&1===n)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var cd=function(t){return new Dt(t)};Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var n=this._x*(1-this._t)+t*this._t;this._context.lineTo(n,this._y),this._context.lineTo(n,e)}}this._x=t,this._y=e}};var fd=function(t){return new Rt(t,.5)},dd=Array.prototype.slice,pd=function(t,e){if((r=t.length)>1)for(var n,r,o=1,i=t[e[0]],a=i.length;o<r;++o){
n=i,i=t[e[o]];for(var s=0;s<a;++s)i[s][1]+=i[s][0]=isNaN(n[s][1])?n[s][0]:n[s][1]}},hd=function(t){for(var e=t.length,n=new Array(e);--e>=0;)n[e]=e;return n},gd=function(){function t(t){var i,a,s=e.apply(this,arguments),l=t.length,u=s.length,c=new Array(u);for(i=0;i<u;++i){for(var f,d=s[i],p=c[i]=new Array(l),h=0;h<l;++h)p[h]=f=[0,+o(t[h],d,h,t)],f.data=t[h];p.key=d}for(i=0,a=n(c);i<u;++i)c[a[i]].index=i;return r(c,a),c}var e=mf([]),n=hd,r=pd,o=jt;return t.keys=function(n){return arguments.length?(e="function"==typeof n?n:mf(dd.call(n)),t):e},t.value=function(e){return arguments.length?(o="function"==typeof e?e:mf(+e),t):o},t.order=function(e){return arguments.length?(n=null==e?hd:"function"==typeof e?e:mf(dd.call(e)),t):n},t.offset=function(e){return arguments.length?(r=null==e?pd:e,t):r},t},vd=function(t,e){if((r=t.length)>0){for(var n,r,o,i=0,a=t[0].length;i<a;++i){for(o=n=0;n<r;++n)o+=t[n][i][1]||0;if(o)for(n=0;n<r;++n)t[n][i][1]/=o}pd(t,e)}},md=function(t,e){if((n=t.length)>0){for(var n,r=0,o=t[e[0]],i=o.length;r<i;++r){for(var a=0,s=0;a<n;++a)s+=t[a][r][1]||0;o[r][1]+=o[r][0]=-s/2}pd(t,e)}},yd=function(t,e){if((o=t.length)>0&&(r=(n=t[e[0]]).length)>0){for(var n,r,o,i=0,a=1;a<r;++a){for(var s=0,l=0,u=0;s<o;++s){for(var c=t[e[s]],f=c[a][1]||0,d=c[a-1][1]||0,p=(f-d)/2,h=0;h<s;++h){var g=t[e[h]],v=g[a][1]||0,m=g[a-1][1]||0;p+=v-m}l+=f,u+=p*f}n[a-1][1]+=n[a-1][0]=i,l&&(i-=u/l)}n[a-1][1]+=n[a-1][0]=i,pd(t,e)}},bd=function(t){var e=t.map(Bt);return hd(t).sort(function(t,n){return e[t]-e[n]})},xd=function(t){return bd(t).reverse()},_d=function(t){var e,n,r=t.length,o=t.map(Bt),i=hd(t).sort(function(t,e){return o[e]-o[t]}),a=0,s=0,l=[],u=[];for(e=0;e<r;++e)n=i[e],a<s?(a+=o[n],l.push(n)):(s+=o[n],u.push(n));return u.reverse().concat(l)},wd=function(t){return hd(t).reverse()},Td=function(t,e,n){t.prototype=e.prototype=n,n.constructor=t},Cd=.7,kd=1/Cd,Ed="\\s*([+-]?\\d+)\\s*",Pd="\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)\\s*",Sd="\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*",Md=/^#([0-9a-f]{3})$/,Nd=/^#([0-9a-f]{6})$/,Ad=new RegExp("^rgb\\("+[Ed,Ed,Ed]+"\\)$"),Od=new RegExp("^rgb\\("+[Sd,Sd,Sd]+"\\)$"),Dd=new RegExp("^rgba\\("+[Ed,Ed,Ed,Pd]+"\\)$"),Id=new RegExp("^rgba\\("+[Sd,Sd,Sd,Pd]+"\\)$"),Rd=new RegExp("^hsl\\("+[Pd,Sd,Sd]+"\\)$"),Ld=new RegExp("^hsla\\("+[Pd,Sd,Sd,Pd]+"\\)$"),Fd={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};Td(Ht,zt,{displayable:function(){return this.rgb().displayable()},toString:function(){return this.rgb()+""}}),Td(Yt,Kt,Ut(Ht,{brighter:function(t){return t=null==t?kd:Math.pow(kd,t),new Yt(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?Cd:Math.pow(Cd,t),new Yt(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},toString:function(){var t=this.opacity;return t=isNaN(t)?1:Math.max(0,Math.min(1,t)),(1===t?"rgb(":"rgba(")+Math.max(0,Math.min(255,Math.round(this.r)||0))+", "+Math.max(0,Math.min(255,Math.round(this.g)||0))+", "+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?")":", "+t+")")}})),Td(Zt,$t,Ut(Ht,{brighter:function(t){return t=null==t?kd:Math.pow(kd,t),new Zt(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?Cd:Math.pow(Cd,t),new Zt(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,n=this.l,r=n+(n<.5?n:1-n)*e,o=2*n-r;return new Yt(Jt(t>=240?t-240:t+120,o,r),Jt(t,o,r),Jt(t<120?t+240:t-120,o,r),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var jd=Math.PI/180,Bd=180/Math.PI,Ud=18,Hd=.95047,zd=1,Wd=1.08883,qd=4/29,Vd=6/29,Kd=3*Vd*Vd,Yd=Vd*Vd*Vd;Td(ee,te,Ut(Ht,{brighter:function(t){return new ee(this.l+Ud*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new ee(this.l-Ud*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,n=isNaN(this.b)?t:t-this.b/200;return t=zd*re(t),e=Hd*re(e),n=Wd*re(n),new Yt(oe(3.2404542*e-1.5371385*t-.4985314*n),oe(-.969266*e+1.8760108*t+.041556*n),oe(.0556434*e-.2040259*t+1.0572252*n),this.opacity)}})),Td(le,se,Ut(Ht,{brighter:function(t){return new le(this.h,this.c,this.l+Ud*(null==t?1:t),this.opacity)},darker:function(t){return new le(this.h,this.c,this.l-Ud*(null==t?1:t),this.opacity)},rgb:function(){return Qt(this).rgb()}}));var Gd=-.14861,Xd=1.78277,$d=-.29227,Zd=-.90649,Jd=1.97294,Qd=Jd*Zd,tp=Jd*Xd,ep=Xd*$d-Zd*Gd;Td(fe,ce,Ut(Ht,{brighter:function(t){return t=null==t?kd:Math.pow(kd,t),new fe(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?Cd:Math.pow(Cd,t),new fe(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*jd,e=+this.l,n=isNaN(this.s)?0:this.s*e*(1-e),r=Math.cos(t),o=Math.sin(t);return new Yt(255*(e+n*(Gd*r+Xd*o)),255*(e+n*($d*r+Zd*o)),255*(e+n*(Jd*r)),this.opacity)}}));var np,rp,op,ip,ap=function(t){var e=t.length-1;return function(n){var r=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),o=t[r],i=t[r+1],a=r>0?t[r-1]:2*o-i,s=r<e-1?t[r+2]:2*i-o;return de((n-r/e)*e,a,o,i,s)}},sp=function(t){var e=t.length;return function(n){var r=Math.floor(((n%=1)<0?++n:n)*e),o=t[(r+e-1)%e],i=t[r%e],a=t[(r+1)%e],s=t[(r+2)%e];return de((n-r/e)*e,o,i,a,s)}},lp=function(t){return function(){return t}},up=function t(e){function n(t,e){var n=r((t=Kt(t)).r,(e=Kt(e)).r),o=r(t.g,e.g),i=r(t.b,e.b),a=r(t.opacity,e.opacity);return function(e){return t.r=n(e),t.g=o(e),t.b=i(e),t.opacity=a(e),t+""}}var r=ve(e);return n.gamma=t,n}(1),cp=ye(ap),fp=ye(sp),dp=function(t,e){var n,r=e?e.length:0,o=t?Math.min(r,t.length):0,i=new Array(r),a=new Array(r);for(n=0;n<o;++n)i[n]=bp(t[n],e[n]);for(;n<r;++n)a[n]=e[n];return function(t){for(n=0;n<o;++n)a[n]=i[n](t);return a}},pp=function(t,e){var n=new Date;return t=+t,e-=t,function(r){return n.setTime(t+e*r),n}},hp=function(t,e){return t=+t,e-=t,function(n){return t+e*n}},gp=function(t,e){var n,r={},o={};null!==t&&"object"==typeof t||(t={}),null!==e&&"object"==typeof e||(e={});for(n in e)n in t?r[n]=bp(t[n],e[n]):o[n]=e[n];return function(t){for(n in r)o[n]=r[n](t);return o}},vp=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,mp=new RegExp(vp.source,"g"),yp=function(t,e){var n,r,o,i=vp.lastIndex=mp.lastIndex=0,a=-1,s=[],l=[];for(t+="",e+="";(n=vp.exec(t))&&(r=mp.exec(e));)(o=r.index)>i&&(o=e.slice(i,o),s[a]?s[a]+=o:s[++a]=o),(n=n[0])===(r=r[0])?s[a]?s[a]+=r:s[++a]=r:(s[++a]=null,l.push({i:a,x:hp(n,r)})),i=mp.lastIndex;return i<e.length&&(o=e.slice(i),s[a]?s[a]+=o:s[++a]=o),s.length<2?l[0]?xe(l[0].x):be(e):(e=l.length,function(t){for(var n,r=0;r<e;++r)s[(n=l[r]).i]=n.x(t);return s.join("")})},bp=function(t,e){var n,r=typeof e;return null==e||"boolean"===r?lp(e):("number"===r?hp:"string"===r?(n=zt(e))?(e=n,up):yp:e instanceof zt?up:e instanceof Date?pp:Array.isArray(e)?dp:isNaN(e)?gp:hp)(t,e)},xp=function(t,e){return t=+t,e-=t,function(n){return Math.round(t+e*n)}},_p=180/Math.PI,wp={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1},Tp=function(t,e,n,r,o,i){var a,s,l;return(a=Math.sqrt(t*t+e*e))&&(t/=a,e/=a),(l=t*n+e*r)&&(n-=t*l,r-=e*l),(s=Math.sqrt(n*n+r*r))&&(n/=s,r/=s,l/=s),t*r<e*n&&(t=-t,e=-e,l=-l,a=-a),{translateX:o,translateY:i,rotate:Math.atan2(e,t)*_p,skewX:Math.atan(l)*_p,scaleX:a,scaleY:s}},Cp=Te(_e,"px, ","px)","deg)"),kp=Te(we,", ",")",")"),Ep=Math.SQRT2,Pp=2,Sp=4,Mp=1e-12,Np=function(t,e){var n,r,o=t[0],i=t[1],a=t[2],s=e[0],l=e[1],u=e[2],c=s-o,f=l-i,d=c*c+f*f;if(d<Mp)r=Math.log(u/a)/Ep,n=function(t){return[o+t*c,i+t*f,a*Math.exp(Ep*t*r)]};else{var p=Math.sqrt(d),h=(u*u-a*a+Sp*d)/(2*a*Pp*p),g=(u*u-a*a-Sp*d)/(2*u*Pp*p),v=Math.log(Math.sqrt(h*h+1)-h),m=Math.log(Math.sqrt(g*g+1)-g);r=(m-v)/Ep,n=function(t){var e=t*r,n=Ce(v),s=a/(Pp*p)*(n*Ee(Ep*e+v)-ke(v));return[o+s*c,i+s*f,a*n/Ce(Ep*e+v)]}}return n.duration=1e3*r,n},Ap=Pe(ge),Op=Pe(me),Dp=Me(ge),Ip=Me(me),Rp=Ne(ge),Lp=Ne(me),Fp=function(t,e){for(var n=new Array(e),r=0;r<e;++r)n[r]=t(r/(e-1));return n},jp={value:function(){}};Oe.prototype=Ae.prototype={constructor:Oe,on:function(t,e){var n,r=this._,o=De(t+"",r),i=-1,a=o.length;{if(!(arguments.length<2)){if(null!=e&&"function"!=typeof e)throw new Error("invalid callback: "+e);for(;++i<a;)if(n=(t=o[i]).type)r[n]=Re(r[n],t.name,e);else if(null==e)for(n in r)r[n]=Re(r[n],t.name,null);return this}for(;++i<a;)if((n=(t=o[i]).type)&&(n=Ie(r[n],t.name)))return n}},copy:function(){var t={},e=this._;for(var n in e)t[n]=e[n].slice();return new Oe(t)},call:function(t,e){if((n=arguments.length-2)>0)for(var n,r,o=new Array(n),i=0;i<n;++i)o[i]=arguments[i+2];if(!this._.hasOwnProperty(t))throw new Error("unknown type: "+t);for(r=this._[t],i=0,n=r.length;i<n;++i)r[i].value.apply(e,o)},apply:function(t,e,n){if(!this._.hasOwnProperty(t))throw new Error("unknown type: "+t);for(var r=this._[t],o=0,i=r.length;o<i;++o)r[o].value.apply(e,n)}};var Bp,Up,Hp=function(t){function e(t,e){var r,o,i=n(t,function(t,n){return r?r(t,n-1):(o=t,void(r=e?Fe(t,e):Le(t)))});return i.columns=o,i}function n(t,e){function n(){if(c>=u)return a;if(o)return o=!1,i;var e,n=c;if(34===t.charCodeAt(n)){for(var r=n;r++<u;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,e=t.charCodeAt(r+1),13===e?(o=!0,10===t.charCodeAt(r+2)&&++c):10===e&&(o=!0),t.slice(n+1,r).replace(/""/g,'"')}for(;c<u;){var s=1;if(e=t.charCodeAt(c++),10===e)o=!0;else if(13===e)o=!0,10===t.charCodeAt(c)&&(++c,++s);else if(e!==l)continue;return t.slice(n,c-s)}return t.slice(n)}for(var r,o,i={},a={},s=[],u=t.length,c=0,f=0;(r=n())!==a;){for(var d=[];r!==i&&r!==a;)d.push(r),r=n();e&&null==(d=e(d,f++))||s.push(d)}return s}function r(e,n){return null==n&&(n=je(e)),[n.map(a).join(t)].concat(e.map(function(e){return n.map(function(t){return a(e[t])}).join(t)})).join("\n")}function o(t){return t.map(i).join("\n")}function i(e){return e.map(a).join(t)}function a(t){return null==t?"":s.test(t+="")?'"'+t.replace(/\"/g,'""')+'"':t}var s=new RegExp('["'+t+"\n]"),l=t.charCodeAt(0);return{parse:e,parseRows:n,format:r,formatRows:o}},zp=Hp(","),Wp=zp.parse,qp=zp.parseRows,Vp=zp.format,Kp=zp.formatRows,Yp=Hp("\t"),Gp=Yp.parse,Xp=Yp.parseRows,$p=Yp.format,Zp=Yp.formatRows,Jp=function(t,e){function n(t){var e,n=c.status;if(!n&&Ue(c)||n>=200&&n<300||304===n){if(a)try{e=a.call(r,c)}catch(t){return void l.call("error",r,t)}else e=c;l.call("load",r,e)}else l.call("error",r,t)}var r,o,a,s,l=Ae("beforesend","progress","load","error"),u=i(),c=new XMLHttpRequest,f=null,d=null,p=0;if("undefined"==typeof XDomainRequest||"withCredentials"in c||!/^(http(s)?:)?\/\//.test(t)||(c=new XDomainRequest),"onload"in c?c.onload=c.onerror=c.ontimeout=n:c.onreadystatechange=function(t){c.readyState>3&&n(t)},c.onprogress=function(t){l.call("progress",r,t)},r={header:function(t,e){return t=(t+"").toLowerCase(),arguments.length<2?u.get(t):(null==e?u.remove(t):u.set(t,e+""),r)},mimeType:function(t){return arguments.length?(o=null==t?null:t+"",r):o},responseType:function(t){return arguments.length?(s=t,r):s},timeout:function(t){return arguments.length?(p=+t,r):p},user:function(t){return arguments.length<1?f:(f=null==t?null:t+"",r)},password:function(t){return arguments.length<1?d:(d=null==t?null:t+"",r)},response:function(t){return a=t,r},get:function(t,e){return r.send("GET",t,e)},post:function(t,e){return r.send("POST",t,e)},send:function(e,n,i){return c.open(e,t,!0,f,d),null==o||u.has("accept")||u.set("accept",o+",*/*"),c.setRequestHeader&&u.each(function(t,e){c.setRequestHeader(e,t)}),null!=o&&c.overrideMimeType&&c.overrideMimeType(o),null!=s&&(c.responseType=s),p>0&&(c.timeout=p),null==i&&"function"==typeof n&&(i=n,n=null),null!=i&&1===i.length&&(i=Be(i)),null!=i&&r.on("error",i).on("load",function(t){i(null,t)}),l.call("beforesend",r,c),c.send(null==n?null:n),r},abort:function(){return c.abort(),r},on:function(){var t=l.on.apply(l,arguments);return t===l?r:t}},null!=e){if("function"!=typeof e)throw new Error("invalid callback: "+e);return r.get(e)}return r},Qp=function(t,e){return function(n,r){var o=Jp(n).mimeType(t).response(e);if(null!=r){if("function"!=typeof r)throw new Error("invalid callback: "+r);return o.get(r)}return o}},th=Qp("text/html",function(t){return document.createRange().createContextualFragment(t.responseText)}),eh=Qp("application/json",function(t){return JSON.parse(t.responseText)}),nh=Qp("text/plain",function(t){return t.responseText}),rh=Qp("application/xml",function(t){var e=t.responseXML;if(!e)throw new Error("parse error");return e}),oh=function(t,e){return function(n,r,o){arguments.length<3&&(o=r,r=null);var i=Jp(n).mimeType(t);return i.row=function(t){return arguments.length?i.response(He(e,r=t)):r},i.row(r),o?i.get(o):i}},ih=oh("text/csv",Wp),ah=oh("text/tab-separated-values",Gp),sh=0,lh=0,uh=0,ch=1e3,fh=0,dh=0,ph=0,hh="object"==typeof performance&&performance.now?performance:Date,gh="function"==typeof requestAnimationFrame?requestAnimationFrame:function(t){setTimeout(t,17)};qe.prototype=Ve.prototype={constructor:qe,restart:function(t,e,n){if("function"!=typeof t)throw new TypeError("callback is not a function");n=(null==n?ze():+n)+(null==e?0:+e),this._next||Up===this||(Up?Up._next=this:Bp=this,Up=this),this._call=t,this._time=n,$e()},stop:function(){this._call&&(this._call=null,this._time=1/0,$e())}};var vh=function(t,e,n){var r=new qe;return e=null==e?0:+e,r.restart(function(n){r.stop(),t(n+e)},e,n),r},mh=function(t,e,n){var r=new qe,o=e;return null==e?(r.restart(t,e,n),r):(e=+e,n=null==n?ze():+n,r.restart(function i(a){a+=o,r.restart(i,o+=e,n),t(a)},e,n),r)},yh=new Date,bh=new Date,xh=Ze(function(){},function(t,e){t.setTime(+t+e)},function(t,e){return e-t});xh.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?Ze(function(e){e.setTime(Math.floor(e/t)*t)},function(e,n){e.setTime(+e+n*t)},function(e,n){return(n-e)/t}):xh:null};var _h=xh.range,wh=1e3,Th=6e4,Ch=36e5,kh=864e5,Eh=6048e5,Ph=Ze(function(t){t.setTime(Math.floor(t/wh)*wh)},function(t,e){t.setTime(+t+e*wh)},function(t,e){return(e-t)/wh},function(t){return t.getUTCSeconds()}),Sh=Ph.range,Mh=Ze(function(t){t.setTime(Math.floor(t/Th)*Th)},function(t,e){t.setTime(+t+e*Th)},function(t,e){return(e-t)/Th},function(t){return t.getMinutes()}),Nh=Mh.range,Ah=Ze(function(t){var e=t.getTimezoneOffset()*Th%Ch;e<0&&(e+=Ch),t.setTime(Math.floor((+t-e)/Ch)*Ch+e)},function(t,e){t.setTime(+t+e*Ch)},function(t,e){return(e-t)/Ch},function(t){return t.getHours()}),Oh=Ah.range,Dh=Ze(function(t){t.setHours(0,0,0,0)},function(t,e){t.setDate(t.getDate()+e)},function(t,e){return(e-t-(e.getTimezoneOffset()-t.getTimezoneOffset())*Th)/kh},function(t){return t.getDate()-1}),Ih=Dh.range,Rh=Je(0),Lh=Je(1),Fh=Je(2),jh=Je(3),Bh=Je(4),Uh=Je(5),Hh=Je(6),zh=Rh.range,Wh=Lh.range,qh=Fh.range,Vh=jh.range,Kh=Bh.range,Yh=Uh.range,Gh=Hh.range,Xh=Ze(function(t){t.setDate(1),t.setHours(0,0,0,0)},function(t,e){t.setMonth(t.getMonth()+e)},function(t,e){return e.getMonth()-t.getMonth()+12*(e.getFullYear()-t.getFullYear())},function(t){return t.getMonth()}),$h=Xh.range,Zh=Ze(function(t){t.setMonth(0,1),t.setHours(0,0,0,0)},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t,e){return e.getFullYear()-t.getFullYear()},function(t){return t.getFullYear()});Zh.every=function(t){return isFinite(t=Math.floor(t))&&t>0?Ze(function(e){e.setFullYear(Math.floor(e.getFullYear()/t)*t),e.setMonth(0,1),e.setHours(0,0,0,0)},function(e,n){e.setFullYear(e.getFullYear()+n*t)}):null};var Jh=Zh.range,Qh=Ze(function(t){t.setUTCSeconds(0,0)},function(t,e){t.setTime(+t+e*Th)},function(t,e){return(e-t)/Th},function(t){return t.getUTCMinutes()}),tg=Qh.range,eg=Ze(function(t){t.setUTCMinutes(0,0,0)},function(t,e){t.setTime(+t+e*Ch)},function(t,e){return(e-t)/Ch},function(t){return t.getUTCHours()}),ng=eg.range,rg=Ze(function(t){t.setUTCHours(0,0,0,0)},function(t,e){t.setUTCDate(t.getUTCDate()+e)},function(t,e){return(e-t)/kh},function(t){return t.getUTCDate()-1}),og=rg.range,ig=Qe(0),ag=Qe(1),sg=Qe(2),lg=Qe(3),ug=Qe(4),cg=Qe(5),fg=Qe(6),dg=ig.range,pg=ag.range,hg=sg.range,gg=lg.range,vg=ug.range,mg=cg.range,yg=fg.range,bg=Ze(function(t){t.setUTCDate(1),t.setUTCHours(0,0,0,0)},function(t,e){t.setUTCMonth(t.getUTCMonth()+e)},function(t,e){return e.getUTCMonth()-t.getUTCMonth()+12*(e.getUTCFullYear()-t.getUTCFullYear())},function(t){return t.getUTCMonth()}),xg=bg.range,_g=Ze(function(t){t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)},function(t,e){t.setUTCFullYear(t.getUTCFullYear()+e)},function(t,e){return e.getUTCFullYear()-t.getUTCFullYear()},function(t){return t.getUTCFullYear()});_g.every=function(t){return isFinite(t=Math.floor(t))&&t>0?Ze(function(e){e.setUTCFullYear(Math.floor(e.getUTCFullYear()/t)*t),e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)},function(e,n){e.setUTCFullYear(e.getUTCFullYear()+n*t)}):null};var wg,Tg=_g.range,Cg=function(t,e){if((n=(t=e?t.toExponential(e-1):t.toExponential()).indexOf("e"))<0)return null;var n,r=t.slice(0,n);return[r.length>1?r[0]+r.slice(2):r,+t.slice(n+1)]},kg=function(t){return t=Cg(Math.abs(t)),t?t[1]:NaN},Eg=function(t,e){return function(n,r){for(var o=n.length,i=[],a=0,s=t[0],l=0;o>0&&s>0&&(l+s+1>r&&(s=Math.max(1,r-l)),i.push(n.substring(o-=s,o+s)),!((l+=s+1)>r));)s=t[a=(a+1)%t.length];return i.reverse().join(e)}},Pg=function(t,e){t=t.toPrecision(e);t:for(var n,r=t.length,o=1,i=-1;o<r;++o)switch(t[o]){case".":i=n=o;break;case"0":0===i&&(i=o),n=o;break;case"e":break t;default:i>0&&(i=0)}return i>0?t.slice(0,i)+t.slice(n+1):t},Sg=function(t,e){var n=Cg(t,e);if(!n)return t+"";var r=n[0],o=n[1],i=o-(wg=3*Math.max(-8,Math.min(8,Math.floor(o/3))))+1,a=r.length;return i===a?r:i>a?r+new Array(i-a+1).join("0"):i>0?r.slice(0,i)+"."+r.slice(i):"0."+new Array(1-i).join("0")+Cg(t,Math.max(0,e+i-1))[0]},Mg=function(t,e){var n=Cg(t,e);if(!n)return t+"";var r=n[0],o=n[1];return o<0?"0."+new Array(-o).join("0")+r:r.length>o+1?r.slice(0,o+1)+"."+r.slice(o+1):r+new Array(o-r.length+2).join("0")},Ng={"":Pg,"%":function(t,e){return(100*t).toFixed(e)},b:function(t){return Math.round(t).toString(2)},c:function(t){return t+""},d:function(t){return Math.round(t).toString(10)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},g:function(t,e){return t.toPrecision(e)},o:function(t){return Math.round(t).toString(8)},p:function(t,e){return Mg(100*t,e)},r:Mg,s:Sg,X:function(t){return Math.round(t).toString(16).toUpperCase()},x:function(t){return Math.round(t).toString(16)}},Ag=/^(?:(.)?([<>=^]))?([+\-\( ])?([$#])?(0)?(\d+)?(,)?(\.\d+)?([a-z%])?$/i,Og=function(t){return new tn(t)};tn.prototype.toString=function(){return this.fill+this.align+this.sign+this.symbol+(this.zero?"0":"")+(null==this.width?"":Math.max(1,0|this.width))+(this.comma?",":"")+(null==this.precision?"":"."+Math.max(0,0|this.precision))+this.type};var Dg,Ig=["y","z","a","f","p","n","µ","m","","k","M","G","T","P","E","Z","Y"],Rg=function(t){function e(t){function e(t){var e,o,l,y=h,b=g;if("c"===p)b=v(t)+b,t="";else{t=+t;var x=(t<0||1/t<0)&&(t*=-1,!0);if(t=v(t,d),x)for(e=-1,o=t.length,x=!1;++e<o;)if(l=t.charCodeAt(e),48<l&&l<58||"x"===p&&96<l&&l<103||"X"===p&&64<l&&l<71){x=!0;break}if(y=(x?"("===s?s:"-":"-"===s||"("===s?"":s)+y,b=b+("s"===p?Ig[8+wg/3]:"")+(x&&"("===s?")":""),m)for(e=-1,o=t.length;++e<o;)if(l=t.charCodeAt(e),48>l||l>57){b=(46===l?i+t.slice(e+1):t.slice(e))+b,t=t.slice(0,e);break}}f&&!u&&(t=r(t,1/0));var _=y.length+t.length+b.length,w=_<c?new Array(c-_+1).join(n):"";switch(f&&u&&(t=r(w+t,w.length?c-b.length:1/0),w=""),a){case"<":return y+t+b+w;case"=":return y+w+t+b;case"^":return w.slice(0,_=w.length>>1)+y+t+b+w.slice(_)}return w+y+t+b}t=Og(t);var n=t.fill,a=t.align,s=t.sign,l=t.symbol,u=t.zero,c=t.width,f=t.comma,d=t.precision,p=t.type,h="$"===l?o[0]:"#"===l&&/[boxX]/.test(p)?"0"+p.toLowerCase():"",g="$"===l?o[1]:/[%p]/.test(p)?"%":"",v=Ng[p],m=!p||/[defgprs%]/.test(p);return d=null==d?p?6:12:/[gprs]/.test(p)?Math.max(1,Math.min(21,d)):Math.max(0,Math.min(20,d)),e.toString=function(){return t+""},e}function n(t,n){var r=e((t=Og(t),t.type="f",t)),o=3*Math.max(-8,Math.min(8,Math.floor(kg(n)/3))),i=Math.pow(10,-o),a=Ig[8+o/3];return function(t){return r(i*t)+a}}var r=t.grouping&&t.thousands?Eg(t.grouping,t.thousands):en,o=t.currency,i=t.decimal;return{format:e,formatPrefix:n}};nn({decimal:".",thousands:",",grouping:[3],currency:["$",""]});var Lg,Fg=function(t){return Math.max(0,-kg(Math.abs(t)))},jg=function(t,e){return Math.max(0,3*Math.max(-8,Math.min(8,Math.floor(kg(e)/3)))-kg(Math.abs(t)))},Bg=function(t,e){return t=Math.abs(t),e=Math.abs(e)-t,Math.max(0,kg(e)-kg(t))+1},Ug={"-":"",_:" ",0:"0"},Hg=/^\s*\d+/,zg=/^%/,Wg=/[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g;er({dateTime:"%x, %X",date:"%-m/%-d/%Y",time:"%-I:%M:%S %p",periods:["AM","PM"],days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]});var qg="%Y-%m-%dT%H:%M:%S.%LZ",Vg=Date.prototype.toISOString?nr:t.utcFormat(qg),Kg=+new Date("2000-01-01T00:00:00.000Z")?rr:t.utcParse(qg),Yg=Array.prototype,Gg=Yg.map,Xg=Yg.slice,$g={name:"implicit"},Zg=function(t){return function(){return t}},Jg=function(t){return+t},Qg=[0,1],tv=function(e,r,o){var i,a=e[0],s=e[e.length-1],l=n(a,s,null==r?10:r);switch(o=Og(null==o?",f":o),o.type){case"s":var u=Math.max(Math.abs(a),Math.abs(s));return null!=o.precision||isNaN(i=jg(l,u))||(o.precision=i),t.formatPrefix(o,u);case"":case"e":case"g":case"p":case"r":null!=o.precision||isNaN(i=Bg(l,Math.max(Math.abs(a),Math.abs(s))))||(o.precision=i-("e"===o.type));break;case"f":case"%":null!=o.precision||isNaN(i=Fg(l))||(o.precision=i-2*("%"===o.type))}return t.format(o)},ev=function(t,e){t=t.slice();var n,r=0,o=t.length-1,i=t[r],a=t[o];return a<i&&(n=r,r=o,o=n,n=i,i=a,a=n),t[r]=e.floor(i),t[o]=e.ceil(a),t},nv=1e3,rv=60*nv,ov=60*rv,iv=24*ov,av=7*iv,sv=30*iv,lv=365*iv,uv=function(){return Dr(Zh,Xh,Rh,Dh,Ah,Mh,Ph,xh,t.timeFormat).domain([new Date(2e3,0,1),new Date(2e3,0,2)])},cv=function(){return Dr(_g,bg,ig,rg,eg,Qh,Ph,xh,t.utcFormat).domain([Date.UTC(2e3,0,1),Date.UTC(2e3,0,2)])},fv=function(t){return t.match(/.{6}/g).map(function(t){return"#"+t})},dv=fv("1f77b4ff7f0e2ca02cd627289467bd8c564be377c27f7f7fbcbd2217becf"),pv=fv("393b795254a36b6ecf9c9ede6379398ca252b5cf6bcedb9c8c6d31bd9e39e7ba52e7cb94843c39ad494ad6616be7969c7b4173a55194ce6dbdde9ed6"),hv=fv("3182bd6baed69ecae1c6dbefe6550dfd8d3cfdae6bfdd0a231a35474c476a1d99bc7e9c0756bb19e9ac8bcbddcdadaeb636363969696bdbdbdd9d9d9"),gv=fv("1f77b4aec7e8ff7f0effbb782ca02c98df8ad62728ff98969467bdc5b0d58c564bc49c94e377c2f7b6d27f7f7fc7c7c7bcbd22dbdb8d17becf9edae5"),vv=Lp(ce(300,.5,0),ce(-240,.5,1)),mv=Lp(ce(-100,.75,.35),ce(80,1.5,.8)),yv=Lp(ce(260,.75,.35),ce(80,1.5,.8)),bv=ce(),xv=function(t){(t<0||t>1)&&(t-=Math.floor(t));var e=Math.abs(t-.5);return bv.h=360*t-100,bv.s=1.5-1.5*e,bv.l=.8-.9*e,bv+""},_v=Ir(fv("44015444025645045745055946075a46085c460a5d460b5e470d60470e6147106347116447136548146748166848176948186a481a6c481b6d481c6e481d6f481f70482071482173482374482475482576482677482878482979472a7a472c7a472d7b472e7c472f7d46307e46327e46337f463480453581453781453882443983443a83443b84433d84433e85423f854240864241864142874144874045884046883f47883f48893e49893e4a893e4c8a3d4d8a3d4e8a3c4f8a3c508b3b518b3b528b3a538b3a548c39558c39568c38588c38598c375a8c375b8d365c8d365d8d355e8d355f8d34608d34618d33628d33638d32648e32658e31668e31678e31688e30698e306a8e2f6b8e2f6c8e2e6d8e2e6e8e2e6f8e2d708e2d718e2c718e2c728e2c738e2b748e2b758e2a768e2a778e2a788e29798e297a8e297b8e287c8e287d8e277e8e277f8e27808e26818e26828e26828e25838e25848e25858e24868e24878e23888e23898e238a8d228b8d228c8d228d8d218e8d218f8d21908d21918c20928c20928c20938c1f948c1f958b1f968b1f978b1f988b1f998a1f9a8a1e9b8a1e9c891e9d891f9e891f9f881fa0881fa1881fa1871fa28720a38620a48621a58521a68522a78522a88423a98324aa8325ab8225ac8226ad8127ad8128ae8029af7f2ab07f2cb17e2db27d2eb37c2fb47c31b57b32b67a34b67935b77937b87838b9773aba763bbb753dbc743fbc7340bd7242be7144bf7046c06f48c16e4ac16d4cc26c4ec36b50c46a52c56954c56856c66758c7655ac8645cc8635ec96260ca6063cb5f65cb5e67cc5c69cd5b6ccd5a6ece5870cf5773d05675d05477d1537ad1517cd2507fd34e81d34d84d44b86d54989d5488bd6468ed64590d74393d74195d84098d83e9bd93c9dd93ba0da39a2da37a5db36a8db34aadc32addc30b0dd2fb2dd2db5de2bb8de29bade28bddf26c0df25c2df23c5e021c8e020cae11fcde11dd0e11cd2e21bd5e21ad8e219dae319dde318dfe318e2e418e5e419e7e419eae51aece51befe51cf1e51df4e61ef6e620f8e621fbe723fde725")),wv=Ir(fv("00000401000501010601010802010902020b02020d03030f03031204041405041606051806051a07061c08071e0907200a08220b09240c09260d0a290e0b2b100b2d110c2f120d31130d34140e36150e38160f3b180f3d19103f1a10421c10441d11471e114920114b21114e22115024125325125527125829115a2a115c2c115f2d11612f116331116533106734106936106b38106c390f6e3b0f703d0f713f0f72400f74420f75440f764510774710784910784a10794c117a4e117b4f127b51127c52137c54137d56147d57157e59157e5a167e5c167f5d177f5f187f601880621980641a80651a80671b80681c816a1c816b1d816d1d816e1e81701f81721f817320817521817621817822817922827b23827c23827e24828025828125818326818426818627818827818928818b29818c29818e2a81902a81912b81932b80942c80962c80982d80992d809b2e7f9c2e7f9e2f7fa02f7fa1307ea3307ea5317ea6317da8327daa337dab337cad347cae347bb0357bb2357bb3367ab5367ab73779b83779ba3878bc3978bd3977bf3a77c03a76c23b75c43c75c53c74c73d73c83e73ca3e72cc3f71cd4071cf4070d0416fd2426fd3436ed5446dd6456cd8456cd9466bdb476adc4869de4968df4a68e04c67e24d66e34e65e44f64e55064e75263e85362e95462ea5661eb5760ec5860ed5a5fee5b5eef5d5ef05f5ef1605df2625df2645cf3655cf4675cf4695cf56b5cf66c5cf66e5cf7705cf7725cf8745cf8765cf9785df9795df97b5dfa7d5efa7f5efa815ffb835ffb8560fb8761fc8961fc8a62fc8c63fc8e64fc9065fd9266fd9467fd9668fd9869fd9a6afd9b6bfe9d6cfe9f6dfea16efea36ffea571fea772fea973feaa74feac76feae77feb078feb27afeb47bfeb67cfeb77efeb97ffebb81febd82febf84fec185fec287fec488fec68afec88cfeca8dfecc8ffecd90fecf92fed194fed395fed597fed799fed89afdda9cfddc9efddea0fde0a1fde2a3fde3a5fde5a7fde7a9fde9aafdebacfcecaefceeb0fcf0b2fcf2b4fcf4b6fcf6b8fcf7b9fcf9bbfcfbbdfcfdbf")),Tv=Ir(fv("00000401000501010601010802010a02020c02020e03021004031204031405041706041907051b08051d09061f0a07220b07240c08260d08290e092b10092d110a30120a32140b34150b37160b39180c3c190c3e1b0c411c0c431e0c451f0c48210c4a230c4c240c4f260c51280b53290b552b0b572d0b592f0a5b310a5c320a5e340a5f3609613809623909633b09643d09653e0966400a67420a68440a68450a69470b6a490b6a4a0c6b4c0c6b4d0d6c4f0d6c510e6c520e6d540f6d550f6d57106e59106e5a116e5c126e5d126e5f136e61136e62146e64156e65156e67166e69166e6a176e6c186e6d186e6f196e71196e721a6e741a6e751b6e771c6d781c6d7a1d6d7c1d6d7d1e6d7f1e6c801f6c82206c84206b85216b87216b88226a8a226a8c23698d23698f24699025689225689326679526679727669827669a28659b29649d29649f2a63a02a63a22b62a32c61a52c60a62d60a82e5fa92e5eab2f5ead305dae305cb0315bb1325ab3325ab43359b63458b73557b93556ba3655bc3754bd3853bf3952c03a51c13a50c33b4fc43c4ec63d4dc73e4cc83f4bca404acb4149cc4248ce4347cf4446d04545d24644d34743d44842d54a41d74b3fd84c3ed94d3dda4e3cdb503bdd513ade5238df5337e05536e15635e25734e35933e45a31e55c30e65d2fe75e2ee8602de9612bea632aeb6429eb6628ec6726ed6925ee6a24ef6c23ef6e21f06f20f1711ff1731df2741cf3761bf37819f47918f57b17f57d15f67e14f68013f78212f78410f8850ff8870ef8890cf98b0bf98c0af98e09fa9008fa9207fa9407fb9606fb9706fb9906fb9b06fb9d07fc9f07fca108fca309fca50afca60cfca80dfcaa0ffcac11fcae12fcb014fcb216fcb418fbb61afbb81dfbba1ffbbc21fbbe23fac026fac228fac42afac62df9c72ff9c932f9cb35f8cd37f8cf3af7d13df7d340f6d543f6d746f5d949f5db4cf4dd4ff4df53f4e156f3e35af3e55df2e661f2e865f2ea69f1ec6df1ed71f1ef75f1f179f2f27df2f482f3f586f3f68af4f88ef5f992f6fa96f8fb9af9fc9dfafda1fcffa4")),Cv=Ir(fv("0d088710078813078916078a19068c1b068d1d068e20068f2206902406912605912805922a05932c05942e05952f059631059733059735049837049938049a3a049a3c049b3e049c3f049c41049d43039e44039e46039f48039f4903a04b03a14c02a14e02a25002a25102a35302a35502a45601a45801a45901a55b01a55c01a65e01a66001a66100a76300a76400a76600a76700a86900a86a00a86c00a86e00a86f00a87100a87201a87401a87501a87701a87801a87a02a87b02a87d03a87e03a88004a88104a78305a78405a78606a68707a68808a68a09a58b0aa58d0ba58e0ca48f0da4910ea3920fa39410a29511a19613a19814a099159f9a169f9c179e9d189d9e199da01a9ca11b9ba21d9aa31e9aa51f99a62098a72197a82296aa2395ab2494ac2694ad2793ae2892b02991b12a90b22b8fb32c8eb42e8db52f8cb6308bb7318ab83289ba3388bb3488bc3587bd3786be3885bf3984c03a83c13b82c23c81c33d80c43e7fc5407ec6417dc7427cc8437bc9447aca457acb4679cc4778cc4977cd4a76ce4b75cf4c74d04d73d14e72d24f71d35171d45270d5536fd5546ed6556dd7566cd8576bd9586ada5a6ada5b69db5c68dc5d67dd5e66de5f65de6164df6263e06363e16462e26561e26660e3685fe4695ee56a5de56b5de66c5ce76e5be76f5ae87059e97158e97257ea7457eb7556eb7655ec7754ed7953ed7a52ee7b51ef7c51ef7e50f07f4ff0804ef1814df1834cf2844bf3854bf3874af48849f48948f58b47f58c46f68d45f68f44f79044f79143f79342f89441f89540f9973ff9983ef99a3efa9b3dfa9c3cfa9e3bfb9f3afba139fba238fca338fca537fca636fca835fca934fdab33fdac33fdae32fdaf31fdb130fdb22ffdb42ffdb52efeb72dfeb82cfeba2cfebb2bfebd2afebe2afec029fdc229fdc328fdc527fdc627fdc827fdca26fdcb26fccd25fcce25fcd025fcd225fbd324fbd524fbd724fad824fada24f9dc24f9dd25f8df25f8e125f7e225f7e425f6e626f6e826f5e926f5eb27f4ed27f3ee27f3f027f2f227f1f426f1f525f0f724f0f921")),kv="http://www.w3.org/1999/xhtml",Ev={svg:"http://www.w3.org/2000/svg",xhtml:kv,xlink:"http://www.w3.org/1999/xlink",
xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"},Pv=function(t){var e=t+="",n=e.indexOf(":");return n>=0&&"xmlns"!==(e=t.slice(0,n))&&(t=t.slice(n+1)),Ev.hasOwnProperty(e)?{space:Ev[e],local:t}:t},Sv=function(t){var e=Pv(t);return(e.local?Fr:Lr)(e)},Mv=0;Br.prototype=jr.prototype={constructor:Br,get:function(t){for(var e=this._;!(e in t);)if(!(t=t.parentNode))return;return t[e]},set:function(t,e){return t[this._]=e},remove:function(t){return this._ in t&&delete t[this._]},toString:function(){return this._}};var Nv=function(t){return function(){return this.matches(t)}};if("undefined"!=typeof document){var Av=document.documentElement;if(!Av.matches){var Ov=Av.webkitMatchesSelector||Av.msMatchesSelector||Av.mozMatchesSelector||Av.oMatchesSelector;Nv=function(t){return function(){return Ov.call(this,t)}}}}var Dv=Nv,Iv={};if(t.event=null,"undefined"!=typeof document){var Rv=document.documentElement;"onmouseenter"in Rv||(Iv={mouseenter:"mouseover",mouseleave:"mouseout"})}var Lv=function(t,e,n){var r,o,i=zr(t+""),a=i.length;{if(!(arguments.length<2)){for(s=e?qr:Wr,null==n&&(n=!1),r=0;r<a;++r)this.each(s(i[r],e,n));return this}var s=this.node().__on;if(s)for(var l,u=0,c=s.length;u<c;++u)for(r=0,l=s[u];r<a;++r)if((o=i[r]).type===l.type&&o.name===l.name)return l.value}},Fv=function(){for(var e,n=t.event;e=n.sourceEvent;)n=e;return n},jv=function(t,e){var n=t.ownerSVGElement||t;if(n.createSVGPoint){var r=n.createSVGPoint();return r.x=e.clientX,r.y=e.clientY,r=r.matrixTransform(t.getScreenCTM().inverse()),[r.x,r.y]}var o=t.getBoundingClientRect();return[e.clientX-o.left-t.clientLeft,e.clientY-o.top-t.clientTop]},Bv=function(t){var e=Fv();return e.changedTouches&&(e=e.changedTouches[0]),jv(t,e)},Uv=function(t){return null==t?Kr:function(){return this.querySelector(t)}},Hv=function(t){"function"!=typeof t&&(t=Uv(t));for(var e=this._groups,n=e.length,r=new Array(n),o=0;o<n;++o)for(var i,a,s=e[o],l=s.length,u=r[o]=new Array(l),c=0;c<l;++c)(i=s[c])&&(a=t.call(i,i.__data__,c,s))&&("__data__"in i&&(a.__data__=i.__data__),u[c]=a);return new Oo(r,this._parents)},zv=function(t){return null==t?Yr:function(){return this.querySelectorAll(t)}},Wv=function(t){"function"!=typeof t&&(t=zv(t));for(var e=this._groups,n=e.length,r=[],o=[],i=0;i<n;++i)for(var a,s=e[i],l=s.length,u=0;u<l;++u)(a=s[u])&&(r.push(t.call(a,a.__data__,u,s)),o.push(a));return new Oo(r,o)},qv=function(t){"function"!=typeof t&&(t=Dv(t));for(var e=this._groups,n=e.length,r=new Array(n),o=0;o<n;++o)for(var i,a=e[o],s=a.length,l=r[o]=[],u=0;u<s;++u)(i=a[u])&&t.call(i,i.__data__,u,a)&&l.push(i);return new Oo(r,this._parents)},Vv=function(t){return new Array(t.length)},Kv=function(){return new Oo(this._enter||this._groups.map(Vv),this._parents)};Gr.prototype={constructor:Gr,appendChild:function(t){return this._parent.insertBefore(t,this._next)},insertBefore:function(t,e){return this._parent.insertBefore(t,e)},querySelector:function(t){return this._parent.querySelector(t)},querySelectorAll:function(t){return this._parent.querySelectorAll(t)}};var Yv=function(t){return function(){return t}},Gv="$",Xv=function(t,e){if(!t)return p=new Array(this.size()),u=-1,this.each(function(t){p[++u]=t}),p;var n=e?$r:Xr,r=this._parents,o=this._groups;"function"!=typeof t&&(t=Yv(t));for(var i=o.length,a=new Array(i),s=new Array(i),l=new Array(i),u=0;u<i;++u){var c=r[u],f=o[u],d=f.length,p=t.call(c,c&&c.__data__,u,r),h=p.length,g=s[u]=new Array(h),v=a[u]=new Array(h),m=l[u]=new Array(d);n(c,f,g,v,m,p,e);for(var y,b,x=0,_=0;x<h;++x)if(y=g[x]){for(x>=_&&(_=x+1);!(b=v[_])&&++_<h;);y._next=b||null}}return a=new Oo(a,r),a._enter=s,a._exit=l,a},$v=function(){return new Oo(this._exit||this._groups.map(Vv),this._parents)},Zv=function(t){for(var e=this._groups,n=t._groups,r=e.length,o=n.length,i=Math.min(r,o),a=new Array(r),s=0;s<i;++s)for(var l,u=e[s],c=n[s],f=u.length,d=a[s]=new Array(f),p=0;p<f;++p)(l=u[p]||c[p])&&(d[p]=l);for(;s<r;++s)a[s]=e[s];return new Oo(a,this._parents)},Jv=function(){for(var t=this._groups,e=-1,n=t.length;++e<n;)for(var r,o=t[e],i=o.length-1,a=o[i];--i>=0;)(r=o[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},Qv=function(t){function e(e,n){return e&&n?t(e.__data__,n.__data__):!e-!n}t||(t=Zr);for(var n=this._groups,r=n.length,o=new Array(r),i=0;i<r;++i){for(var a,s=n[i],l=s.length,u=o[i]=new Array(l),c=0;c<l;++c)(a=s[c])&&(u[c]=a);u.sort(e)}return new Oo(o,this._parents).order()},tm=function(){var t=arguments[0];return arguments[0]=this,t.apply(null,arguments),this},em=function(){var t=new Array(this.size()),e=-1;return this.each(function(){t[++e]=this}),t},nm=function(){for(var t=this._groups,e=0,n=t.length;e<n;++e)for(var r=t[e],o=0,i=r.length;o<i;++o){var a=r[o];if(a)return a}return null},rm=function(){var t=0;return this.each(function(){++t}),t},om=function(){return!this.node()},im=function(t){for(var e=this._groups,n=0,r=e.length;n<r;++n)for(var o,i=e[n],a=0,s=i.length;a<s;++a)(o=i[a])&&t.call(o,o.__data__,a,i);return this},am=function(t,e){var n=Pv(t);if(arguments.length<2){var r=this.node();return n.local?r.getAttributeNS(n.space,n.local):r.getAttribute(n)}return this.each((null==e?n.local?Qr:Jr:"function"==typeof e?n.local?ro:no:n.local?eo:to)(n,e))},sm=function(t){return t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView},lm=function(t,e,n){var r;return arguments.length>1?this.each((null==e?oo:"function"==typeof e?ao:io)(t,e,null==n?"":n)):sm(r=this.node()).getComputedStyle(r,null).getPropertyValue(t)},um=function(t,e){return arguments.length>1?this.each((null==e?so:"function"==typeof e?uo:lo)(t,e)):this.node()[t]};po.prototype={add:function(t){var e=this._names.indexOf(t);e<0&&(this._names.push(t),this._node.setAttribute("class",this._names.join(" ")))},remove:function(t){var e=this._names.indexOf(t);e>=0&&(this._names.splice(e,1),this._node.setAttribute("class",this._names.join(" ")))},contains:function(t){return this._names.indexOf(t)>=0}};var cm=function(t,e){var n=co(t+"");if(arguments.length<2){for(var r=fo(this.node()),o=-1,i=n.length;++o<i;)if(!r.contains(n[o]))return!1;return!0}return this.each(("function"==typeof e?yo:e?vo:mo)(n,e))},fm=function(t){return arguments.length?this.each(null==t?bo:("function"==typeof t?_o:xo)(t)):this.node().textContent},dm=function(t){return arguments.length?this.each(null==t?wo:("function"==typeof t?Co:To)(t)):this.node().innerHTML},pm=function(){return this.each(ko)},hm=function(){return this.each(Eo)},gm=function(t){var e="function"==typeof t?t:Sv(t);return this.select(function(){return this.appendChild(e.apply(this,arguments))})},vm=function(t,e){var n="function"==typeof t?t:Sv(t),r=null==e?Po:"function"==typeof e?e:Uv(e);return this.select(function(){return this.insertBefore(n.apply(this,arguments),r.apply(this,arguments)||null)})},mm=function(){return this.each(So)},ym=function(t){return arguments.length?this.property("__data__",t):this.node().__data__},bm=function(t,e){return this.each(("function"==typeof e?Ao:No)(t,e))},xm=[null];Oo.prototype=Do.prototype={constructor:Oo,select:Hv,selectAll:Wv,filter:qv,data:Xv,enter:Kv,exit:$v,merge:Zv,order:Jv,sort:Qv,call:tm,nodes:em,node:nm,size:rm,empty:om,each:im,attr:am,style:lm,property:um,classed:cm,text:fm,html:dm,raise:pm,lower:hm,append:gm,insert:vm,remove:mm,datum:ym,on:Lv,dispatch:bm};var _m=function(t){return"string"==typeof t?new Oo([[document.querySelector(t)]],[document.documentElement]):new Oo([[t]],xm)},wm=function(t){return"string"==typeof t?new Oo([document.querySelectorAll(t)],[document.documentElement]):new Oo([null==t?[]:t],xm)},Tm=function(t,e,n){arguments.length<3&&(n=e,e=Fv().changedTouches);for(var r,o=0,i=e?e.length:0;o<i;++o)if((r=e[o]).identifier===n)return jv(t,r);return null},Cm=function(t,e){null==e&&(e=Fv().touches);for(var n=0,r=e?e.length:0,o=new Array(r);n<r;++n)o[n]=jv(t,e[n]);return o},km=Ae("start","end","interrupt"),Em=[],Pm=0,Sm=1,Mm=2,Nm=3,Am=4,Om=5,Dm=6,Im=function(t,e,n,r,o,i){var a=t.__transition;if(a){if(n in a)return}else t.__transition={};Fo(t,n,{name:e,index:r,group:o,on:km,tween:Em,time:i.time,delay:i.delay,duration:i.duration,ease:i.ease,timer:null,state:Pm})},Rm=function(t,e){var n,r,o,i=t.__transition,a=!0;if(i){e=null==e?null:e+"";for(o in i)(n=i[o]).name===e?(r=n.state>Mm&&n.state<Om,n.state=Dm,n.timer.stop(),r&&n.on.call("interrupt",t,t.__data__,n.index,n.group),delete i[o]):a=!1;a&&delete t.__transition}},Lm=function(t){return this.each(function(){Rm(this,t)})},Fm=function(t,e){var n=this._id;if(t+="",arguments.length<2){for(var r,o=Lo(this.node(),n).tween,i=0,a=o.length;i<a;++i)if((r=o[i]).name===t)return r.value;return null}return this.each((null==e?jo:Bo)(n,t,e))},jm=function(t,e){var n;return("number"==typeof e?hp:e instanceof zt?up:(n=zt(e))?(e=n,up):yp)(t,e)},Bm=function(t,e){var n=Pv(t),r="transform"===n?kp:jm;return this.attrTween(t,"function"==typeof e?(n.local?Ko:Vo)(n,r,Uo(this,"attr."+t,e)):null==e?(n.local?zo:Ho)(n):(n.local?qo:Wo)(n,r,e))},Um=function(t,e){var n="attr."+t;if(arguments.length<2)return(n=this.tween(n))&&n._value;if(null==e)return this.tween(n,null);if("function"!=typeof e)throw new Error;var r=Pv(t);return this.tween(n,(r.local?Yo:Go)(r,e))},Hm=function(t){var e=this._id;return arguments.length?this.each(("function"==typeof t?Xo:$o)(e,t)):Lo(this.node(),e).delay},zm=function(t){var e=this._id;return arguments.length?this.each(("function"==typeof t?Zo:Jo)(e,t)):Lo(this.node(),e).duration},Wm=function(t){var e=this._id;return arguments.length?this.each(Qo(e,t)):Lo(this.node(),e).ease},qm=function(t){"function"!=typeof t&&(t=Dv(t));for(var e=this._groups,n=e.length,r=new Array(n),o=0;o<n;++o)for(var i,a=e[o],s=a.length,l=r[o]=[],u=0;u<s;++u)(i=a[u])&&t.call(i,i.__data__,u,a)&&l.push(i);return new ci(r,this._parents,this._name,this._id)},Vm=function(t){if(t._id!==this._id)throw new Error;for(var e=this._groups,n=t._groups,r=e.length,o=n.length,i=Math.min(r,o),a=new Array(r),s=0;s<i;++s)for(var l,u=e[s],c=n[s],f=u.length,d=a[s]=new Array(f),p=0;p<f;++p)(l=u[p]||c[p])&&(d[p]=l);for(;s<r;++s)a[s]=e[s];return new ci(a,this._parents,this._name,this._id)},Km=function(t,e){var n=this._id;return arguments.length<2?Lo(this.node(),n).on.on(t):this.each(ei(n,t,e))},Ym=function(){return this.on("end.remove",ni(this._id))},Gm=function(t){var e=this._name,n=this._id;"function"!=typeof t&&(t=Uv(t));for(var r=this._groups,o=r.length,i=new Array(o),a=0;a<o;++a)for(var s,l,u=r[a],c=u.length,f=i[a]=new Array(c),d=0;d<c;++d)(s=u[d])&&(l=t.call(s,s.__data__,d,u))&&("__data__"in s&&(l.__data__=s.__data__),f[d]=l,Im(f[d],e,n,d,f,Lo(s,n)));return new ci(i,this._parents,e,n)},Xm=function(t){var e=this._name,n=this._id;"function"!=typeof t&&(t=zv(t));for(var r=this._groups,o=r.length,i=[],a=[],s=0;s<o;++s)for(var l,u=r[s],c=u.length,f=0;f<c;++f)if(l=u[f]){for(var d,p=t.call(l,l.__data__,f,u),h=Lo(l,n),g=0,v=p.length;g<v;++g)(d=p[g])&&Im(d,e,n,g,p,h);i.push(p),a.push(l)}return new ci(i,a,e,n)},$m=Do.prototype.constructor,Zm=function(){return new $m(this._groups,this._parents)},Jm=function(t,e,n){var r="transform"==(t+="")?Cp:jm;return null==e?this.styleTween(t,ri(t,r)).on("end.style."+t,oi(t)):this.styleTween(t,"function"==typeof e?ai(t,r,Uo(this,"style."+t,e)):ii(t,r,e),n)},Qm=function(t,e,n){var r="style."+(t+="");if(arguments.length<2)return(r=this.tween(r))&&r._value;if(null==e)return this.tween(r,null);if("function"!=typeof e)throw new Error;return this.tween(r,si(t,e,null==n?"":n))},ty=function(t){return this.tween("text","function"==typeof t?ui(Uo(this,"text",t)):li(null==t?"":t+""))},ey=function(){for(var t=this._name,e=this._id,n=di(),r=this._groups,o=r.length,i=0;i<o;++i)for(var a,s=r[i],l=s.length,u=0;u<l;++u)if(a=s[u]){var c=Lo(a,e);Im(a,t,n,u,s,{time:c.time+c.delay+c.duration,delay:0,duration:c.duration,ease:c.ease})}return new ci(r,this._parents,t,n)},ny=0,ry=Do.prototype;ci.prototype=fi.prototype={constructor:ci,select:Gm,selectAll:Xm,filter:qm,merge:Vm,selection:Zm,transition:ey,call:ry.call,nodes:ry.nodes,node:ry.node,size:ry.size,empty:ry.empty,each:ry.each,on:Km,attr:Bm,attrTween:Um,style:Jm,styleTween:Qm,text:ty,remove:Ym,tween:Fm,delay:Hm,duration:zm,ease:Wm};var oy={time:null,delay:0,duration:250,ease:y},iy=function(t){var e,n;t instanceof ci?(e=t._id,t=t._name):(e=di(),(n=oy).time=ze(),t=null==t?null:t+"");for(var r=this._groups,o=r.length,i=0;i<o;++i)for(var a,s=r[i],l=s.length,u=0;u<l;++u)(a=s[u])&&Im(a,t,e,u,s,n||pi(a,e));return new ci(r,this._parents,t,e)};Do.prototype.interrupt=Lm,Do.prototype.transition=iy;var ay=[null],sy=function(t,e){var n,r,o=t.__transition;if(o){e=null==e?null:e+"";for(r in o)if((n=o[r]).state>Sm&&n.name===e)return new ci([[t]],ay,e,+r)}return null},ly=Array.prototype.slice,uy=function(t){return t},cy=1,fy=2,dy=3,py=4,hy=1e-6,gy=function(){function t(t){var i,a=0;t.eachAfter(function(t){var n=t.children;n?(t.x=Ci(n),t.y=Ei(n)):(t.x=i?a+=e(t,i):0,t.y=0,i=t)});var s=Si(t),l=Mi(t),u=s.x-e(s,l)/2,c=l.x+e(l,s)/2;return t.eachAfter(o?function(e){e.x=(e.x-t.x)*n,e.y=(t.y-e.y)*r}:function(e){e.x=(e.x-u)/(c-u)*n,e.y=(1-(t.y?e.y/t.y:1))*r})}var e=Ti,n=1,r=1,o=!1;return t.separation=function(n){return arguments.length?(e=n,t):e},t.size=function(e){return arguments.length?(o=!1,n=+e[0],r=+e[1],t):o?null:[n,r]},t.nodeSize=function(e){return arguments.length?(o=!0,n=+e[0],r=+e[1],t):o?[n,r]:null},t},vy=function(t){var e,n,r,o,i=this,a=[i];do for(e=a.reverse(),a=[];i=e.pop();)if(t(i),n=i.children)for(r=0,o=n.length;r<o;++r)a.push(n[r]);while(a.length);return this},my=function(t){for(var e,n,r=this,o=[r];r=o.pop();)if(t(r),e=r.children)for(n=e.length-1;n>=0;--n)o.push(e[n]);return this},yy=function(t){for(var e,n,r,o=this,i=[o],a=[];o=i.pop();)if(a.push(o),e=o.children)for(n=0,r=e.length;n<r;++n)i.push(e[n]);for(;o=a.pop();)t(o);return this},by=function(t){return this.eachAfter(function(e){for(var n=+t(e.data)||0,r=e.children,o=r&&r.length;--o>=0;)n+=r[o].value;e.value=n})},xy=function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},_y=function(t){for(var e=this,n=Ni(e,t),r=[e];e!==n;)e=e.parent,r.push(e);for(var o=r.length;t!==n;)r.splice(o,0,t),t=t.parent;return r},wy=function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},Ty=function(){var t=[];return this.each(function(e){t.push(e)}),t},Cy=function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},ky=function(){var t=this,e=[];return t.each(function(n){n!==t&&e.push({source:n.parent,target:n})}),e};Li.prototype=Ai.prototype={constructor:Li,each:vy,eachAfter:yy,eachBefore:my,sum:by,sort:xy,path:_y,ancestors:wy,descendants:Ty,leaves:Cy,links:ky,copy:Oi};var Ey=function(t){for(var e,n=(t=t.slice()).length,r=null,o=r;n;){var i=new Fi(t[n-1]);o=o?o.next=i:r=i,t[e]=t[--n]}return{head:r,tail:o}},Py=function(t){return Bi(Ey(t),[])},Sy=function(t){return Yi(t),t},My=function(t){return function(){return t}},Ny=function(){function t(t){return t.x=n/2,t.y=r/2,e?t.eachBefore(Ji(e)).eachAfter(Qi(o,.5)).eachBefore(ta(1)):t.eachBefore(Ji(Zi)).eachAfter(Qi($i,1)).eachAfter(Qi(o,t.r/Math.min(n,r))).eachBefore(ta(Math.min(n,r)/(2*t.r))),t}var e=null,n=1,r=1,o=$i;return t.radius=function(n){return arguments.length?(e=Gi(n),t):e},t.size=function(e){return arguments.length?(n=+e[0],r=+e[1],t):[n,r]},t.padding=function(e){return arguments.length?(o="function"==typeof e?e:My(+e),t):o},t},Ay=function(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)},Oy=function(t,e,n,r,o){for(var i,a=t.children,s=-1,l=a.length,u=t.value&&(r-e)/t.value;++s<l;)i=a[s],i.y0=n,i.y1=o,i.x0=e,i.x1=e+=i.value*u},Dy=function(){function t(t){var a=t.height+1;return t.x0=t.y0=o,t.x1=n,t.y1=r/a,t.eachBefore(e(r,a)),i&&t.eachBefore(Ay),t}function e(t,e){return function(n){n.children&&Oy(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var r=n.x0,i=n.y0,a=n.x1-o,s=n.y1-o;a<r&&(r=a=(r+a)/2),s<i&&(i=s=(i+s)/2),n.x0=r,n.y0=i,n.x1=a,n.y1=s}}var n=1,r=1,o=0,i=!1;return t.round=function(e){return arguments.length?(i=!!e,t):i},t.size=function(e){return arguments.length?(n=+e[0],r=+e[1],t):[n,r]},t.padding=function(e){return arguments.length?(o=+e,t):o},t},Iy="$",Ry={depth:-1},Ly={},Fy=function(){function t(t){var r,o,i,a,s,l,u,c=t.length,f=new Array(c),d={};for(o=0;o<c;++o)r=t[o],s=f[o]=new Li(r),null!=(l=e(r,o,t))&&(l+="")&&(u=Iy+(s.id=l),d[u]=u in d?Ly:s);for(o=0;o<c;++o)if(s=f[o],l=n(t[o],o,t),null!=l&&(l+="")){if(a=d[Iy+l],!a)throw new Error("missing: "+l);if(a===Ly)throw new Error("ambiguous: "+l);a.children?a.children.push(s):a.children=[s],s.parent=a}else{if(i)throw new Error("multiple roots");i=s}if(!i)throw new Error("no root");if(i.parent=Ry,i.eachBefore(function(t){t.depth=t.parent.depth+1,--c}).eachBefore(Ri),i.parent=null,c>0)throw new Error("cycle");return i}var e=ea,n=na;return t.id=function(n){return arguments.length?(e=Xi(n),t):e},t.parentId=function(e){return arguments.length?(n=Xi(e),t):n},t};ua.prototype=Object.create(Li.prototype);var jy=function(){function t(t){var r=ca(t);if(r.eachAfter(e),r.parent.m=-r.z,r.eachBefore(n),l)t.eachBefore(o);else{var u=t,c=t,f=t;t.eachBefore(function(t){t.x<u.x&&(u=t),t.x>c.x&&(c=t),t.depth>f.depth&&(f=t)});var d=u===c?1:i(u,c)/2,p=d-u.x,h=a/(c.x+d+p),g=s/(f.depth||1);t.eachBefore(function(t){t.x=(t.x+p)*h,t.y=t.depth*g})}return t}function e(t){var e=t.children,n=t.parent.children,o=t.i?n[t.i-1]:null;if(e){sa(t);var a=(e[0].z+e[e.length-1].z)/2;o?(t.z=o.z+i(t._,o._),t.m=t.z-a):t.z=a}else o&&(t.z=o.z+i(t._,o._));t.parent.A=r(t,o,t.parent.A||n[0])}function n(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function r(t,e,n){if(e){for(var r,o=t,a=t,s=e,l=o.parent.children[0],u=o.m,c=a.m,f=s.m,d=l.m;s=ia(s),o=oa(o),s&&o;)l=oa(l),a=ia(a),a.a=t,r=s.z+f-o.z-u+i(s._,o._),r>0&&(aa(la(s,t,n),t,r),u+=r,c+=r),f+=s.m,u+=o.m,d+=l.m,c+=a.m;s&&!ia(a)&&(a.t=s,a.m+=f-c),o&&!oa(l)&&(l.t=o,l.m+=u-d,n=t)}return n}function o(t){t.x*=a,t.y=t.depth*s}var i=ra,a=1,s=1,l=null;return t.separation=function(e){return arguments.length?(i=e,t):i},t.size=function(e){return arguments.length?(l=!1,a=+e[0],s=+e[1],t):l?null:[a,s]},t.nodeSize=function(e){return arguments.length?(l=!0,a=+e[0],s=+e[1],t):l?[a,s]:null},t},By=function(t,e,n,r,o){for(var i,a=t.children,s=-1,l=a.length,u=t.value&&(o-n)/t.value;++s<l;)i=a[s],i.x0=e,i.x1=r,i.y0=n,i.y1=n+=i.value*u},Uy=(1+Math.sqrt(5))/2,Hy=function t(e){function n(t,n,r,o,i){fa(e,t,n,r,o,i)}return n.ratio=function(e){return t((e=+e)>1?e:1)},n}(Uy),zy=function(){function t(t){return t.x0=t.y0=0,t.x1=o,t.y1=i,t.eachBefore(e),a=[0],r&&t.eachBefore(Ay),t}function e(t){var e=a[t.depth],r=t.x0+e,o=t.y0+e,i=t.x1-e,d=t.y1-e;i<r&&(r=i=(r+i)/2),d<o&&(o=d=(o+d)/2),t.x0=r,t.y0=o,t.x1=i,t.y1=d,t.children&&(e=a[t.depth+1]=s(t)/2,r+=f(t)-e,o+=l(t)-e,i-=u(t)-e,d-=c(t)-e,i<r&&(r=i=(r+i)/2),d<o&&(o=d=(o+d)/2),n(t,r,o,i,d))}var n=Hy,r=!1,o=1,i=1,a=[0],s=$i,l=$i,u=$i,c=$i,f=$i;return t.round=function(e){return arguments.length?(r=!!e,t):r},t.size=function(e){return arguments.length?(o=+e[0],i=+e[1],t):[o,i]},t.tile=function(e){return arguments.length?(n=Xi(e),t):n},t.padding=function(e){return arguments.length?t.paddingInner(e).paddingOuter(e):t.paddingInner()},t.paddingInner=function(e){return arguments.length?(s="function"==typeof e?e:My(+e),t):s},t.paddingOuter=function(e){return arguments.length?t.paddingTop(e).paddingRight(e).paddingBottom(e).paddingLeft(e):t.paddingTop()},t.paddingTop=function(e){return arguments.length?(l="function"==typeof e?e:My(+e),t):l},t.paddingRight=function(e){return arguments.length?(u="function"==typeof e?e:My(+e),t):u},t.paddingBottom=function(e){return arguments.length?(c="function"==typeof e?e:My(+e),t):c},t.paddingLeft=function(e){return arguments.length?(f="function"==typeof e?e:My(+e),t):f},t},Wy=function(t,e,n,r,o){function i(t,e,n,r,o,a,s){if(t>=e-1){var u=l[t];return u.x0=r,u.y0=o,u.x1=a,u.y1=s,void 0}for(var f=c[t],d=n/2+f,p=t+1,h=e-1;p<h;){var g=p+h>>>1;c[g]<d?p=g+1:h=g}var v=c[p]-f,m=n-v;if(s-o>a-r){var y=(o*m+s*v)/n;i(t,p,v,r,o,a,y),i(p,e,m,r,y,a,s)}else{var b=(r*m+a*v)/n;i(t,p,v,r,o,b,s),i(p,e,m,b,o,a,s)}}var a,s,l=t.children,u=l.length,c=new Array(u+1);for(c[0]=s=a=0;a<u;++a)c[a+1]=s+=l[a].value;i(0,u,t.value,e,n,r,o)},qy=function(t,e,n,r,o){(1&t.depth?By:Oy)(t,e,n,r,o)},Vy=function t(e){function n(t,n,r,o,i){if((a=t._squarify)&&a.ratio===e)for(var a,s,l,u,c,f=-1,d=a.length,p=t.value;++f<d;){for(s=a[f],l=s.children,u=s.value=0,c=l.length;u<c;++u)s.value+=l[u].value;s.dice?Oy(s,n,r,o,r+=(i-r)*s.value/p):By(s,n,r,n+=(o-n)*s.value/p,i),p-=s.value}else t._squarify=a=fa(e,t,n,r,o,i),a.ratio=e}return n.ratio=function(e){return t((e=+e)>1?e:1)},n}(Uy),Ky=function(t,e){function n(){var n,o,i=r.length,a=0,s=0;for(n=0;n<i;++n)o=r[n],a+=o.x,s+=o.y;for(a=a/i-t,s=s/i-e,n=0;n<i;++n)o=r[n],o.x-=a,o.y-=s}var r;return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},Yy=function(t){return function(){return t}},Gy=function(){return 1e-6*(Math.random()-.5)},Xy=function(t){function e(){function t(t,e,n,r,o){var i=t.data,s=t.r,p=f+s;{if(!i)return e>u+p||r<u-p||n>c+p||o<c-p;if(i.index>l.index){var h=u-i.x-i.vx,g=c-i.y-i.vy,v=h*h+g*g;v<p*p&&(0===h&&(h=Gy(),v+=h*h),0===g&&(g=Gy(),v+=g*g),v=(p-(v=Math.sqrt(v)))/v*a,l.vx+=(h*=v)*(p=(s*=s)/(d+s)),l.vy+=(g*=v)*p,i.vx-=h*(p=1-p),i.vy-=g*p)}}}for(var e,r,l,u,c,f,d,p=o.length,h=0;h<s;++h)for(r=U(o,da,pa).visitAfter(n),e=0;e<p;++e)l=o[e],f=i[l.index],d=f*f,u=l.x+l.vx,c=l.y+l.vy,r.visit(t)}function n(t){if(t.data)return t.r=i[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function r(){if(o){var e,n,r=o.length;for(i=new Array(r),e=0;e<r;++e)n=o[e],i[n.index]=+t(n,e,o)}}var o,i,a=1,s=1;return"function"!=typeof t&&(t=Yy(null==t?1:+t)),e.initialize=function(t){o=t,r()},e.iterations=function(t){return arguments.length?(s=+t,e):s},e.strength=function(t){return arguments.length?(a=+t,e):a},e.radius=function(n){return arguments.length?(t="function"==typeof n?n:Yy(+n),r(),e):t},e},$y=function(t){function e(t){return 1/Math.min(c[t.source.index],c[t.target.index])}function n(e){for(var n=0,r=t.length;n<g;++n)for(var o,i,a,u,c,d,p,h=0;h<r;++h)o=t[h],i=o.source,a=o.target,u=a.x+a.vx-i.x-i.vx||Gy(),c=a.y+a.vy-i.y-i.vy||Gy(),d=Math.sqrt(u*u+c*c),d=(d-l[h])/d*e*s[h],u*=d,c*=d,a.vx-=u*(p=f[h]),a.vy-=c*p,i.vx+=u*(p=1-p),i.vy+=c*p}function r(){if(u){var e,n,r=u.length,p=t.length,h=i(u,d);for(e=0,c=new Array(r);e<p;++e)n=t[e],n.index=e,"object"!=typeof n.source&&(n.source=ga(h,n.source)),"object"!=typeof n.target&&(n.target=ga(h,n.target)),c[n.source.index]=(c[n.source.index]||0)+1,c[n.target.index]=(c[n.target.index]||0)+1;for(e=0,f=new Array(p);e<p;++e)n=t[e],f[e]=c[n.source.index]/(c[n.source.index]+c[n.target.index]);s=new Array(p),o(),l=new Array(p),a()}}function o(){if(u)for(var e=0,n=t.length;e<n;++e)s[e]=+p(t[e],e,t)}function a(){if(u)for(var e=0,n=t.length;e<n;++e)l[e]=+h(t[e],e,t)}var s,l,u,c,f,d=ha,p=e,h=Yy(30),g=1;return null==t&&(t=[]),n.initialize=function(t){u=t,r()},n.links=function(e){return arguments.length?(t=e,r(),n):t},n.id=function(t){return arguments.length?(d=t,n):d},n.iterations=function(t){return arguments.length?(g=+t,n):g},n.strength=function(t){return arguments.length?(p="function"==typeof t?t:Yy(+t),o(),n):p},n.distance=function(t){return arguments.length?(h="function"==typeof t?t:Yy(+t),a(),n):h},n},Zy=10,Jy=Math.PI*(3-Math.sqrt(5)),Qy=function(t){function e(){n(),h.call("tick",a),s<l&&(p.stop(),h.call("end",a))}function n(){var e,n,r=t.length;for(s+=(c-s)*u,d.each(function(t){t(s)}),e=0;e<r;++e)n=t[e],null==n.fx?n.x+=n.vx*=f:(n.x=n.fx,n.vx=0),null==n.fy?n.y+=n.vy*=f:(n.y=n.fy,n.vy=0)}function r(){for(var e,n=0,r=t.length;n<r;++n){if(e=t[n],e.index=n,isNaN(e.x)||isNaN(e.y)){var o=Zy*Math.sqrt(n),i=n*Jy;e.x=o*Math.cos(i),e.y=o*Math.sin(i)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function o(e){return e.initialize&&e.initialize(t),e}var a,s=1,l=.001,u=1-Math.pow(l,1/300),c=0,f=.6,d=i(),p=Ve(e),h=Ae("tick","end");return null==t&&(t=[]),r(),a={tick:n,restart:function(){return p.restart(e),a},stop:function(){return p.stop(),a},nodes:function(e){return arguments.length?(t=e,r(),d.each(o),a):t},alpha:function(t){return arguments.length?(s=+t,a):s},alphaMin:function(t){return arguments.length?(l=+t,a):l},alphaDecay:function(t){return arguments.length?(u=+t,a):+u},alphaTarget:function(t){return arguments.length?(c=+t,a):c},velocityDecay:function(t){return arguments.length?(f=1-t,a):1-f},force:function(t,e){return arguments.length>1?(null==e?d.remove(t):d.set(t,o(e)),a):d.get(t)},find:function(e,n,r){var o,i,a,s,l,u=0,c=t.length;for(null==r?r=1/0:r*=r,u=0;u<c;++u)s=t[u],o=e-s.x,i=n-s.y,a=o*o+i*i,a<r&&(l=s,r=a);return l},on:function(t,e){return arguments.length>1?(h.on(t,e),a):h.on(t)}}},tb=function(){function t(t){var e,s=o.length,l=U(o,va,ma).visitAfter(n);for(a=t,e=0;e<s;++e)i=o[e],l.visit(r)}function e(){if(o){var t,e,n=o.length;for(s=new Array(n),t=0;t<n;++t)e=o[t],s[e.index]=+l(e,t,o)}}function n(t){var e,n,r,o,i,a=0;if(t.length){for(r=o=i=0;i<4;++i)(e=t[i])&&(n=e.value)&&(a+=n,r+=n*e.x,o+=n*e.y);t.x=r/a,t.y=o/a}else{e=t,e.x=e.data.x,e.y=e.data.y;do a+=s[e.data.index];while(e=e.next)}t.value=a}function r(t,e,n,r){if(!t.value)return!0;var o=t.x-i.x,l=t.y-i.y,d=r-e,p=o*o+l*l;if(d*d/f<p)return p<c&&(0===o&&(o=Gy(),p+=o*o),0===l&&(l=Gy(),p+=l*l),p<u&&(p=Math.sqrt(u*p)),i.vx+=o*t.value*a/p,i.vy+=l*t.value*a/p),!0;if(!(t.length||p>=c)){(t.data!==i||t.next)&&(0===o&&(o=Gy(),p+=o*o),0===l&&(l=Gy(),p+=l*l),p<u&&(p=Math.sqrt(u*p)));do t.data!==i&&(d=s[t.data.index]*a/p,i.vx+=o*d,i.vy+=l*d);while(t=t.next)}}var o,i,a,s,l=Yy(-30),u=1,c=1/0,f=.81;return t.initialize=function(t){o=t,e()},t.strength=function(n){return arguments.length?(l="function"==typeof n?n:Yy(+n),e(),t):l},t.distanceMin=function(e){return arguments.length?(u=e*e,t):Math.sqrt(u)},t.distanceMax=function(e){return arguments.length?(c=e*e,t):Math.sqrt(c)},t.theta=function(e){return arguments.length?(f=e*e,t):Math.sqrt(f)},t},eb=function(t){function e(t){for(var e,n=0,a=r.length;n<a;++n)e=r[n],e.vx+=(i[n]-e.x)*o[n]*t}function n(){if(r){var e,n=r.length;for(o=new Array(n),i=new Array(n),e=0;e<n;++e)o[e]=isNaN(i[e]=+t(r[e],e,r))?0:+a(r[e],e,r)}}var r,o,i,a=Yy(.1);return"function"!=typeof t&&(t=Yy(null==t?0:+t)),e.initialize=function(t){r=t,n()},e.strength=function(t){return arguments.length?(a="function"==typeof t?t:Yy(+t),n(),e):a},e.x=function(r){return arguments.length?(t="function"==typeof r?r:Yy(+r),n(),e):t},e},nb=function(t){function e(t){for(var e,n=0,a=r.length;n<a;++n)e=r[n],e.vy+=(i[n]-e.y)*o[n]*t}function n(){if(r){var e,n=r.length;for(o=new Array(n),i=new Array(n),e=0;e<n;++e)o[e]=isNaN(i[e]=+t(r[e],e,r))?0:+a(r[e],e,r)}}var r,o,i,a=Yy(.1);return"function"!=typeof t&&(t=Yy(null==t?0:+t)),e.initialize=function(t){r=t,n()},e.strength=function(t){return arguments.length?(a="function"==typeof t?t:Yy(+t),n(),e):a},e.y=function(r){return arguments.length?(t="function"==typeof r?r:Yy(+r),n(),e):t},e},rb=function(){t.event.preventDefault(),t.event.stopImmediatePropagation()},ob=function(t){var e=t.document.documentElement,n=_m(t).on("dragstart.drag",rb,!0);"onselectstart"in e?n.on("selectstart.drag",rb,!0):(e.__noselect=e.style.MozUserSelect,e.style.MozUserSelect="none")},ib=function(t){return function(){return t}};xa.prototype.on=function(){var t=this._.on.apply(this._,arguments);return t===this._?this:t};var ab=function(){function e(t){t.on("mousedown.drag",n).on("touchstart.drag",i).on("touchmove.drag",a).on("touchend.drag touchcancel.drag",s).style("-webkit-tap-highlight-color","rgba(0,0,0,0)")}function n(){if(!c&&f.apply(this,arguments)){var e=l("mouse",d.apply(this,arguments),Bv,this,arguments);e&&(_m(t.event.view).on("mousemove.drag",r,!0).on("mouseup.drag",o,!0),ob(t.event.view),ya(),u=!1,e("start"))}}function r(){rb(),u=!0,h.mouse("drag")}function o(){_m(t.event.view).on("mousemove.drag mouseup.drag",null),ba(t.event.view,u),rb(),h.mouse("end")}function i(){if(f.apply(this,arguments)){var e,n,r=t.event.changedTouches,o=d.apply(this,arguments),i=r.length;for(e=0;e<i;++e)(n=l(r[e].identifier,o,Tm,this,arguments))&&(ya(),n("start"))}}function a(){var e,n,r=t.event.changedTouches,o=r.length;for(e=0;e<o;++e)(n=h[r[e].identifier])&&(rb(),n("drag"))}function s(){var e,n,r=t.event.changedTouches,o=r.length;for(c&&clearTimeout(c),c=setTimeout(function(){c=null},500),e=0;e<o;++e)(n=h[r[e].identifier])&&(ya(),n("end"))}function l(n,r,o,i,a){var s,l,u,c=o(r,n),f=g.copy();if(Vr(new xa(e,"beforestart",s,n,v,c[0],c[1],0,0,f),function(){return null!=(t.event.subject=s=p.apply(i,a))&&(l=s.x-c[0]||0,u=s.y-c[1]||0,!0)}))return function t(d){var p,g=c;switch(d){case"start":h[n]=t,p=v++;break;case"end":delete h[n],--v;case"drag":c=o(r,n),p=v}Vr(new xa(e,d,s,n,p,c[0]+l,c[1]+u,c[0]-g[0],c[1]-g[1],f),f.apply,f,[d,i,a])}}var u,c,f=_a,d=wa,p=Ta,h={},g=Ae("start","drag","end"),v=0;return e.filter=function(t){return arguments.length?(f="function"==typeof t?t:ib(!!t),e):f},e.container=function(t){return arguments.length?(d="function"==typeof t?t:ib(t),e):d},e.subject=function(t){return arguments.length?(p="function"==typeof t?t:ib(t),e):p},e.on=function(){var t=g.on.apply(g,arguments);return t===g?e:t},e},sb=function(t){return function(){return t}};Ea.prototype={constructor:Ea,insert:function(t,e){var n,r,o;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;n=t}else this._?(t=Na(this._),e.P=null,e.N=t,t.P=t.L=e,n=t):(e.P=e.N=null,this._=e,n=null);for(e.L=e.R=null,e.U=n,e.C=!0,t=e;n&&n.C;)r=n.U,n===r.L?(o=r.R,o&&o.C?(n.C=o.C=!1,r.C=!0,t=r):(t===n.R&&(Sa(this,n),t=n,n=t.U),n.C=!1,r.C=!0,Ma(this,r))):(o=r.L,o&&o.C?(n.C=o.C=!1,r.C=!0,t=r):(t===n.L&&(Ma(this,n),t=n,n=t.U),n.C=!1,r.C=!0,Sa(this,r))),n=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,n,r,o=t.U,i=t.L,a=t.R;if(n=i?a?Na(a):i:a,o?o.L===t?o.L=n:o.R=n:this._=n,i&&a?(r=n.C,n.C=t.C,n.L=i,i.U=n,n!==a?(o=n.U,n.U=t.U,t=n.R,o.L=t,n.R=a,a.U=n):(n.U=o,o=n,t=n.R)):(r=t.C,t=n),t&&(t.U=o),!r){if(t&&t.C)return void(t.C=!1);do{if(t===this._)break;if(t===o.L){if(e=o.R,e.C&&(e.C=!1,o.C=!0,Sa(this,o),e=o.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ma(this,e),e=o.R),e.C=o.C,o.C=e.R.C=!1,Sa(this,o),t=this._;break}}else if(e=o.L,e.C&&(e.C=!1,o.C=!0,Ma(this,o),e=o.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Sa(this,e),e=o.L),e.C=o.C,o.C=e.L.C=!1,Ma(this,o),t=this._;break}e.C=!0,t=o,o=o.U}while(!t.C);t&&(t.C=!1)}}};var lb,ub,cb,fb,db,pb=[],hb=[],gb=1e-6,vb=1e-12;es.prototype={constructor:es,polygons:function(){var t=this.edges;return this.cells.map(function(e){var n=e.halfedges.map(function(n){return Ba(e,t[n])});return n.data=e.site.data,n})},triangles:function(){var t=[],e=this.edges;return this.cells.forEach(function(n,r){if(i=(o=n.halfedges).length)for(var o,i,a,s=n.site,l=-1,u=e[o[i-1]],c=u.left===s?u.right:u.left;++l<i;)a=c,u=e[o[l]],c=u.left===s?u.right:u.left,a&&c&&r<a.index&&r<c.index&&Qa(s,a,c)<0&&t.push([s.data,a.data,c.data])}),t},links:function(){return this.edges.filter(function(t){return t.right}).map(function(t){return{source:t.left.data,target:t.right.data}})},find:function(t,e,n){for(var r,o,i=this,a=i._found||0,s=i.cells.length;!(o=i.cells[a]);)if(++a>=s)return null;var l=t-o.site[0],u=e-o.site[1],c=l*l+u*u;do o=i.cells[r=a],a=null,o.halfedges.forEach(function(n){var r=i.edges[n],s=r.left;if(s!==o.site&&s||(s=r.right)){var l=t-s[0],u=e-s[1],f=l*l+u*u;f<c&&(c=f,a=s.index)}});while(null!==a);return i._found=r,null==n||c<=n*n?o.site:null}};var mb=function(){function t(t){return new es(t.map(function(r,o){var i=[Math.round(e(r,o,t)/gb)*gb,Math.round(n(r,o,t)/gb)*gb];return i.index=o,i.data=r,i}),r)}var e=Ca,n=ka,r=null;return t.polygons=function(e){return t(e).polygons()},t.links=function(e){return t(e).links()},t.triangles=function(e){return t(e).triangles()},t.x=function(n){return arguments.length?(e="function"==typeof n?n:sb(+n),t):e},t.y=function(e){return arguments.length?(n="function"==typeof e?e:sb(+e),
t):n},t.extent=function(e){return arguments.length?(r=null==e?null:[[+e[0][0],+e[0][1]],[+e[1][0],+e[1][1]]],t):r&&[[r[0][0],r[0][1]],[r[1][0],r[1][1]]]},t.size=function(e){return arguments.length?(r=null==e?null:[[0,0],[+e[0],+e[1]]],t):r&&[r[1][0]-r[0][0],r[1][1]-r[0][1]]},t},yb=function(t){return function(){return t}};rs.prototype={constructor:rs,scale:function(t){return 1===t?this:new rs(this.k*t,this.x,this.y)},translate:function(t,e){return 0===t&0===e?this:new rs(this.k,this.x+this.k*t,this.y+this.k*e)},apply:function(t){return[t[0]*this.k+this.x,t[1]*this.k+this.y]},applyX:function(t){return t*this.k+this.x},applyY:function(t){return t*this.k+this.y},invert:function(t){return[(t[0]-this.x)/this.k,(t[1]-this.y)/this.k]},invertX:function(t){return(t-this.x)/this.k},invertY:function(t){return(t-this.y)/this.k},rescaleX:function(t){return t.copy().domain(t.range().map(this.invertX,this).map(t.invert,t))},rescaleY:function(t){return t.copy().domain(t.range().map(this.invertY,this).map(t.invert,t))},toString:function(){return"translate("+this.x+","+this.y+") scale("+this.k+")"}};var bb=new rs(1,0,0);os.prototype=rs.prototype;var xb=function(){t.event.preventDefault(),t.event.stopImmediatePropagation()},_b=function(){function e(t){t.on("wheel.zoom",u).on("mousedown.zoom",c).on("dblclick.zoom",f).on("touchstart.zoom",d).on("touchmove.zoom",p).on("touchend.zoom touchcancel.zoom",h).style("-webkit-tap-highlight-color","rgba(0,0,0,0)").property("__zoom",ls)}function n(t,e){return e=Math.max(b,Math.min(x,e)),e===t.k?t:new rs(e,t.x,t.y)}function r(t,e,n){var r=e[0]-n[0]*t.k,o=e[1]-n[1]*t.k;return r===t.x&&o===t.y?t:new rs(t.k,r,o)}function o(t,e){var n=t.invertX(e[0][0])-_,r=t.invertX(e[1][0])-w,o=t.invertY(e[0][1])-T,i=t.invertY(e[1][1])-C;return t.translate(r>n?(n+r)/2:Math.min(0,n)||Math.max(0,r),i>o?(o+i)/2:Math.min(0,o)||Math.max(0,i))}function i(t){return[(+t[0][0]+ +t[1][0])/2,(+t[0][1]+ +t[1][1])/2]}function a(t,e,n){t.on("start.zoom",function(){s(this,arguments).start()}).on("interrupt.zoom end.zoom",function(){s(this,arguments).end()}).tween("zoom",function(){var t=this,r=arguments,o=s(t,r),a=y.apply(t,r),l=n||i(a),u=Math.max(a[1][0]-a[0][0],a[1][1]-a[0][1]),c=t.__zoom,f="function"==typeof e?e.apply(t,r):e,d=E(c.invert(l).concat(u/c.k),f.invert(l).concat(u/f.k));return function(t){if(1===t)t=f;else{var e=d(t),n=u/e[2];t=new rs(n,l[0]-e[0]*n,l[1]-e[1]*n)}o.zoom(null,t)}})}function s(t,e){for(var n,r=0,o=P.length;r<o;++r)if((n=P[r]).that===t)return n;return new l(t,e)}function l(t,e){this.that=t,this.args=e,this.index=-1,this.active=0,this.extent=y.apply(t,e)}function u(){function e(){i.wheel=null,i.end()}if(m.apply(this,arguments)){var i=s(this,arguments),a=this.__zoom,l=Math.max(b,Math.min(x,a.k*Math.pow(2,-t.event.deltaY*(t.event.deltaMode?120:1)/500))),u=Bv(this);if(i.wheel)i.mouse[0][0]===u[0]&&i.mouse[0][1]===u[1]||(i.mouse[1]=a.invert(i.mouse[0]=u)),clearTimeout(i.wheel);else{if(a.k===l)return;i.mouse=[u,a.invert(u)],Rm(this),i.start()}xb(),i.wheel=setTimeout(e,N),i.zoom("mouse",o(r(n(a,l),i.mouse[0],i.mouse[1]),i.extent))}}function c(){function e(){xb(),i.moved=!0,i.zoom("mouse",o(r(i.that.__zoom,i.mouse[0]=Bv(i.that),i.mouse[1]),i.extent))}function n(){a.on("mousemove.zoom mouseup.zoom",null),ba(t.event.view,i.moved),xb(),i.end()}if(!v&&m.apply(this,arguments)){var i=s(this,arguments),a=_m(t.event.view).on("mousemove.zoom",e,!0).on("mouseup.zoom",n,!0),l=Bv(this);ob(t.event.view),is(),i.mouse=[l,this.__zoom.invert(l)],Rm(this),i.start()}}function f(){if(m.apply(this,arguments)){var i=this.__zoom,s=Bv(this),l=i.invert(s),u=i.k*(t.event.shiftKey?.5:2),c=o(r(n(i,u),s,l),y.apply(this,arguments));xb(),k>0?_m(this).transition().duration(k).call(a,c,s):_m(this).call(e.transform,c)}}function d(){if(m.apply(this,arguments)){var e,n,r,o,i=s(this,arguments),a=t.event.changedTouches,l=a.length;for(is(),n=0;n<l;++n)r=a[n],o=Tm(this,a,r.identifier),o=[o,this.__zoom.invert(o),r.identifier],i.touch0?i.touch1||(i.touch1=o):(i.touch0=o,e=!0);return g&&(g=clearTimeout(g),!i.touch1)?(i.end(),o=_m(this).on("dblclick.zoom"),void(o&&o.apply(this,arguments))):void(e&&(g=setTimeout(function(){g=null},M),Rm(this),i.start()))}}function p(){var e,i,a,l,u=s(this,arguments),c=t.event.changedTouches,f=c.length;for(xb(),g&&(g=clearTimeout(g)),e=0;e<f;++e)i=c[e],a=Tm(this,c,i.identifier),u.touch0&&u.touch0[2]===i.identifier?u.touch0[0]=a:u.touch1&&u.touch1[2]===i.identifier&&(u.touch1[0]=a);if(i=u.that.__zoom,u.touch1){var d=u.touch0[0],p=u.touch0[1],h=u.touch1[0],v=u.touch1[1],m=(m=h[0]-d[0])*m+(m=h[1]-d[1])*m,y=(y=v[0]-p[0])*y+(y=v[1]-p[1])*y;i=n(i,Math.sqrt(m/y)),a=[(d[0]+h[0])/2,(d[1]+h[1])/2],l=[(p[0]+v[0])/2,(p[1]+v[1])/2]}else{if(!u.touch0)return;a=u.touch0[0],l=u.touch0[1]}u.zoom("touch",o(r(i,a,l),u.extent))}function h(){var e,n,r=s(this,arguments),o=t.event.changedTouches,i=o.length;for(is(),v&&clearTimeout(v),v=setTimeout(function(){v=null},M),e=0;e<i;++e)n=o[e],r.touch0&&r.touch0[2]===n.identifier?delete r.touch0:r.touch1&&r.touch1[2]===n.identifier&&delete r.touch1;r.touch1&&!r.touch0&&(r.touch0=r.touch1,delete r.touch1),r.touch0||r.end()}var g,v,m=as,y=ss,b=0,x=1/0,_=-x,w=x,T=_,C=w,k=250,E=Np,P=[],S=Ae("start","zoom","end"),M=500,N=150;return e.transform=function(t,e){var n=t.selection?t.selection():t;n.property("__zoom",ls),t!==n?a(t,e):n.interrupt().each(function(){s(this,arguments).start().zoom(null,"function"==typeof e?e.apply(this,arguments):e).end()})},e.scaleBy=function(t,n){e.scaleTo(t,function(){var t=this.__zoom.k,e="function"==typeof n?n.apply(this,arguments):n;return t*e})},e.scaleTo=function(t,a){e.transform(t,function(){var t=y.apply(this,arguments),e=this.__zoom,s=i(t),l=e.invert(s),u="function"==typeof a?a.apply(this,arguments):a;return o(r(n(e,u),s,l),t)})},e.translateBy=function(t,n,r){e.transform(t,function(){return o(this.__zoom.translate("function"==typeof n?n.apply(this,arguments):n,"function"==typeof r?r.apply(this,arguments):r),y.apply(this,arguments))})},l.prototype={start:function(){return 1===++this.active&&(this.index=P.push(this)-1,this.emit("start")),this},zoom:function(t,e){return this.mouse&&"mouse"!==t&&(this.mouse[1]=e.invert(this.mouse[0])),this.touch0&&"touch"!==t&&(this.touch0[1]=e.invert(this.touch0[0])),this.touch1&&"touch"!==t&&(this.touch1[1]=e.invert(this.touch1[0])),this.that.__zoom=e,this.emit("zoom"),this},end:function(){return 0===--this.active&&(P.splice(this.index,1),this.index=-1,this.emit("end")),this},emit:function(t){Vr(new ns(e,t,this.that.__zoom),S.apply,S,[t,this.that,this.args])}},e.filter=function(t){return arguments.length?(m="function"==typeof t?t:yb(!!t),e):m},e.extent=function(t){return arguments.length?(y="function"==typeof t?t:yb([[+t[0][0],+t[0][1]],[+t[1][0],+t[1][1]]]),e):y},e.scaleExtent=function(t){return arguments.length?(b=+t[0],x=+t[1],e):[b,x]},e.translateExtent=function(t){return arguments.length?(_=+t[0][0],w=+t[1][0],T=+t[0][1],C=+t[1][1],e):[[_,T],[w,C]]},e.duration=function(t){return arguments.length?(k=+t,e):k},e.interpolate=function(t){return arguments.length?(E=t,e):E},e.on=function(){var t=S.on.apply(S,arguments);return t===S?e:t},e},wb=function(t){return function(){return t}},Tb=function(t,e,n){this.target=t,this.type=e,this.selection=n},Cb=function(){t.event.preventDefault(),t.event.stopImmediatePropagation()},kb={name:"drag"},Eb={name:"space"},Pb={name:"handle"},Sb={name:"center"},Mb={name:"x",handles:["e","w"].map(cs),input:function(t,e){return t&&[[t[0],e[0][1]],[t[1],e[1][1]]]},output:function(t){return t&&[t[0][0],t[1][0]]}},Nb={name:"y",handles:["n","s"].map(cs),input:function(t,e){return t&&[[e[0][0],t[0]],[e[1][0],t[1]]]},output:function(t){return t&&[t[0][1],t[1][1]]}},Ab={name:"xy",handles:["n","e","s","w","nw","ne","se","sw"].map(cs),input:function(t){return t},output:function(t){return t}},Ob={overlay:"crosshair",selection:"move",n:"ns-resize",e:"ew-resize",s:"ns-resize",w:"ew-resize",nw:"nwse-resize",ne:"nesw-resize",se:"nwse-resize",sw:"nesw-resize"},Db={e:"w",w:"e",nw:"ne",ne:"nw",se:"sw",sw:"se"},Ib={n:"s",s:"n",nw:"sw",ne:"se",se:"ne",sw:"nw"},Rb={overlay:1,selection:1,n:null,e:1,s:null,w:-1,nw:-1,ne:1,se:1,sw:-1},Lb={overlay:1,selection:1,n:-1,e:null,s:1,w:null,nw:-1,ne:-1,se:1,sw:1},Fb=function(){return ys(Ab)},jb=Math.cos,Bb=Math.sin,Ub=Math.PI,Hb=Ub/2,zb=2*Ub,Wb=Math.max,qb=function(){function t(t){var i,a,s,l,u,c,f=t.length,d=[],p=ju(f),h=[],g=[],v=g.groups=new Array(f),m=new Array(f*f);for(i=0,u=-1;++u<f;){for(a=0,c=-1;++c<f;)a+=t[u][c];d.push(a),h.push(ju(f)),i+=a}for(n&&p.sort(function(t,e){return n(d[t],d[e])}),r&&h.forEach(function(e,n){e.sort(function(e,o){return r(t[n][e],t[n][o])})}),i=Wb(0,zb-e*f)/i,l=i?e:zb/f,a=0,u=-1;++u<f;){for(s=a,c=-1;++c<f;){var y=p[u],b=h[y][c],x=t[y][b],_=a,w=a+=x*i;m[b*f+y]={index:y,subindex:b,startAngle:_,endAngle:w,value:x}}v[y]={index:y,startAngle:s,endAngle:a,value:d[y]},a+=l}for(u=-1;++u<f;)for(c=u-1;++c<f;){var T=m[c*f+u],C=m[u*f+c];(T.value||C.value)&&g.push(T.value<C.value?{source:C,target:T}:{source:T,target:C})}return o?g.sort(o):g}var e=0,n=null,r=null,o=null;return t.padAngle=function(n){return arguments.length?(e=Wb(0,n),t):e},t.sortGroups=function(e){return arguments.length?(n=e,t):n},t.sortSubgroups=function(e){return arguments.length?(r=e,t):r},t.sortChords=function(e){return arguments.length?(null==e?o=null:(o=bs(e))._=e,t):o&&o._},t},Vb=Array.prototype.slice,Kb=function(t){return function(){return t}},Yb=function(){function t(){var t,s=Vb.call(arguments),l=e.apply(this,s),u=n.apply(this,s),c=+r.apply(this,(s[0]=l,s)),f=o.apply(this,s)-Hb,d=i.apply(this,s)-Hb,p=c*jb(f),h=c*Bb(f),g=+r.apply(this,(s[0]=u,s)),v=o.apply(this,s)-Hb,m=i.apply(this,s)-Hb;if(a||(a=t=I()),a.moveTo(p,h),a.arc(0,0,c,f,d),f===v&&d===m||(a.quadraticCurveTo(0,0,g*jb(v),g*Bb(v)),a.arc(0,0,g,v,m)),a.quadraticCurveTo(0,0,p,h),a.closePath(),t)return a=null,t+""||null}var e=xs,n=_s,r=ws,o=Ts,i=Cs,a=null;return t.radius=function(e){return arguments.length?(r="function"==typeof e?e:Kb(+e),t):r},t.startAngle=function(e){return arguments.length?(o="function"==typeof e?e:Kb(+e),t):o},t.endAngle=function(e){return arguments.length?(i="function"==typeof e?e:Kb(+e),t):i},t.source=function(n){return arguments.length?(e=n,t):e},t.target=function(e){return arguments.length?(n=e,t):n},t.context=function(e){return arguments.length?(a=null==e?null:e,t):a},t},Gb=function(){return new ks};ks.prototype={constructor:ks,reset:function(){this.s=this.t=0},add:function(t){Es(Ex,t,this.t),Es(this,Ex.s,this.s),this.s?this.t+=Ex.t:this.s=Ex.t},valueOf:function(){return this.s}};var Xb,$b,Zb,Jb,Qb,tx,ex,nx,rx,ox,ix,ax,sx,lx,ux,cx,fx,dx,px,hx,gx,vx,mx,yx,bx,xx,_x,wx,Tx,Cx,kx,Ex=new ks,Px=1e-6,Sx=1e-12,Mx=Math.PI,Nx=Mx/2,Ax=Mx/4,Ox=2*Mx,Dx=180/Mx,Ix=Mx/180,Rx=Math.abs,Lx=Math.atan,Fx=Math.atan2,jx=Math.cos,Bx=Math.ceil,Ux=Math.exp,Hx=Math.log,zx=Math.pow,Wx=Math.sin,qx=Math.sign||function(t){return t>0?1:t<0?-1:0},Vx=Math.sqrt,Kx=Math.tan,Yx={Feature:function(t,e){As(t.geometry,e)},FeatureCollection:function(t,e){for(var n=t.features,r=-1,o=n.length;++r<o;)As(n[r].geometry,e)}},Gx={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var n=t.coordinates,r=-1,o=n.length;++r<o;)t=n[r],e.point(t[0],t[1],t[2])},LineString:function(t,e){Os(t.coordinates,e,0)},MultiLineString:function(t,e){for(var n=t.coordinates,r=-1,o=n.length;++r<o;)Os(n[r],e,0)},Polygon:function(t,e){Ds(t.coordinates,e)},MultiPolygon:function(t,e){for(var n=t.coordinates,r=-1,o=n.length;++r<o;)Ds(n[r],e)},GeometryCollection:function(t,e){for(var n=t.geometries,r=-1,o=n.length;++r<o;)As(n[r],e)}},Xx=function(t,e){t&&Yx.hasOwnProperty(t.type)?Yx[t.type](t,e):As(t,e)},$x=Gb(),Zx=Gb(),Jx={point:Ns,lineStart:Ns,lineEnd:Ns,polygonStart:function(){$x.reset(),Jx.lineStart=Is,Jx.lineEnd=Rs},polygonEnd:function(){var t=+$x;Zx.add(t<0?Ox+t:t),this.lineStart=this.lineEnd=this.point=Ns},sphere:function(){Zx.add(Ox)}},Qx=function(t){return Zx.reset(),Xx(t,Jx),2*Zx},t_=Gb(),e_={point:Vs,lineStart:Ys,lineEnd:Gs,polygonStart:function(){e_.point=Xs,e_.lineStart=$s,e_.lineEnd=Zs,t_.reset(),Jx.polygonStart()},polygonEnd:function(){Jx.polygonEnd(),e_.point=Vs,e_.lineStart=Ys,e_.lineEnd=Gs,$x<0?(tx=-(nx=180),ex=-(rx=90)):t_>Px?rx=90:t_<-Px&&(ex=-90),ux[0]=tx,ux[1]=nx}},n_=function(t){var e,n,r,o,i,a,s;if(rx=nx=-(tx=ex=1/0),lx=[],Xx(t,e_),n=lx.length){for(lx.sort(Qs),e=1,r=lx[0],i=[r];e<n;++e)o=lx[e],tl(r,o[0])||tl(r,o[1])?(Js(r[0],o[1])>Js(r[0],r[1])&&(r[1]=o[1]),Js(o[0],r[1])>Js(r[0],r[1])&&(r[0]=o[0])):i.push(r=o);for(a=-(1/0),n=i.length-1,e=0,r=i[n];e<=n;r=o,++e)o=i[e],(s=Js(r[1],o[0]))>a&&(a=s,tx=o[0],nx=r[1])}return lx=ux=null,tx===1/0||ex===1/0?[[NaN,NaN],[NaN,NaN]]:[[tx,ex],[nx,rx]]},r_={sphere:Ns,point:el,lineStart:rl,lineEnd:al,polygonStart:function(){r_.lineStart=sl,r_.lineEnd=ll},polygonEnd:function(){r_.lineStart=rl,r_.lineEnd=al}},o_=function(t){cx=fx=dx=px=hx=gx=vx=mx=yx=bx=xx=0,Xx(t,r_);var e=yx,n=bx,r=xx,o=e*e+n*n+r*r;return o<Sx&&(e=gx,n=vx,r=mx,fx<Px&&(e=dx,n=px,r=hx),o=e*e+n*n+r*r,o<Sx)?[NaN,NaN]:[Fx(n,e)*Dx,Ss(r/Vx(o))*Dx]},i_=function(t){return function(){return t}},a_=function(t,e){function n(n,r){return n=t(n,r),e(n[0],n[1])}return t.invert&&e.invert&&(n.invert=function(n,r){return n=e.invert(n,r),n&&t.invert(n[0],n[1])}),n};fl.invert=fl;var s_,l_,u_,c_,f_,d_,p_,h_,g_,v_,m_,y_=function(t){function e(e){return e=t(e[0]*Ix,e[1]*Ix),e[0]*=Dx,e[1]*=Dx,e}return t=dl(t[0]*Ix,t[1]*Ix,t.length>2?t[2]*Ix:0),e.invert=function(e){return e=t.invert(e[0]*Ix,e[1]*Ix),e[0]*=Dx,e[1]*=Dx,e},e},b_=function(){function t(t,e){n.push(t=r(t,e)),t[0]*=Dx,t[1]*=Dx}function e(){var t=o.apply(this,arguments),e=i.apply(this,arguments)*Ix,l=a.apply(this,arguments)*Ix;return n=[],r=dl(-t[0]*Ix,-t[1]*Ix,0).invert,vl(s,e,l,1),t={type:"Polygon",coordinates:[n]},n=r=null,t}var n,r,o=i_([0,0]),i=i_(90),a=i_(6),s={point:t};return e.center=function(t){return arguments.length?(o="function"==typeof t?t:i_([+t[0],+t[1]]),e):o},e.radius=function(t){return arguments.length?(i="function"==typeof t?t:i_(+t),e):i},e.precision=function(t){return arguments.length?(a="function"==typeof t?t:i_(+t),e):a},e},x_=function(){var t,e=[];return{point:function(e,n){t.push([e,n])},lineStart:function(){e.push(t=[])},lineEnd:Ns,rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))},result:function(){var n=e;return e=[],t=null,n}}},__=function(t,e,n,r,o,i){var a,s=t[0],l=t[1],u=e[0],c=e[1],f=0,d=1,p=u-s,h=c-l;if(a=n-s,p||!(a>0)){if(a/=p,p<0){if(a<f)return;a<d&&(d=a)}else if(p>0){if(a>d)return;a>f&&(f=a)}if(a=o-s,p||!(a<0)){if(a/=p,p<0){if(a>d)return;a>f&&(f=a)}else if(p>0){if(a<f)return;a<d&&(d=a)}if(a=r-l,h||!(a>0)){if(a/=h,h<0){if(a<f)return;a<d&&(d=a)}else if(h>0){if(a>d)return;a>f&&(f=a)}if(a=i-l,h||!(a<0)){if(a/=h,h<0){if(a>d)return;a>f&&(f=a)}else if(h>0){if(a<f)return;a<d&&(d=a)}return f>0&&(t[0]=s+f*p,t[1]=l+f*h),d<1&&(e[0]=s+d*p,e[1]=l+d*h),!0}}}}},w_=function(t,e){return Rx(t[0]-e[0])<Px&&Rx(t[1]-e[1])<Px},T_=function(t,e,n,r,o){var i,a,s=[],l=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,n,r=t[0],a=t[e];if(w_(r,a)){for(o.lineStart(),i=0;i<e;++i)o.point((r=t[i])[0],r[1]);return void o.lineEnd()}s.push(n=new yl(r,t,null,!0)),l.push(n.o=new yl(r,null,n,!1)),s.push(n=new yl(a,t,null,!1)),l.push(n.o=new yl(a,null,n,!0))}}),s.length){for(l.sort(e),bl(s),bl(l),i=0,a=l.length;i<a;++i)l[i].e=n=!n;for(var u,c,f=s[0];;){for(var d=f,p=!0;d.v;)if((d=d.n)===f)return;u=d.z,o.lineStart();do{if(d.v=d.o.v=!0,d.e){if(p)for(i=0,a=u.length;i<a;++i)o.point((c=u[i])[0],c[1]);else r(d.x,d.n.x,1,o);d=d.n}else{if(p)for(u=d.p.z,i=u.length-1;i>=0;--i)o.point((c=u[i])[0],c[1]);else r(d.x,d.p.x,-1,o);d=d.p}d=d.o,u=d.z,p=!p}while(!d.v);o.lineEnd()}}},C_=1e9,k_=-C_,E_=function(){var t,e,n,r=0,o=0,i=960,a=500;return n={stream:function(n){return t&&e===n?t:t=xl(r,o,i,a)(e=n)},extent:function(s){return arguments.length?(r=+s[0][0],o=+s[0][1],i=+s[1][0],a=+s[1][1],t=e=null,n):[[r,o],[i,a]]}}},P_=Gb(),S_={sphere:Ns,point:Ns,lineStart:_l,lineEnd:Ns,polygonStart:Ns,polygonEnd:Ns},M_=function(t){return P_.reset(),Xx(t,S_),+P_},N_=[null,null],A_={type:"LineString",coordinates:N_},O_=function(t,e){return N_[0]=t,N_[1]=e,M_(A_)},D_=function(t,e){var n=t[0]*Ix,r=t[1]*Ix,o=e[0]*Ix,i=e[1]*Ix,a=jx(r),s=Wx(r),l=jx(i),u=Wx(i),c=a*jx(n),f=a*Wx(n),d=l*jx(o),p=l*Wx(o),h=2*Ss(Vx(Ms(i-r)+a*l*Ms(o-n))),g=Wx(h),v=h?function(t){var e=Wx(t*=h)/g,n=Wx(h-t)/g,r=n*c+e*d,o=n*f+e*p,i=n*s+e*u;return[Fx(o,r)*Dx,Fx(i,Vx(r*r+o*o))*Dx]}:function(){return[n*Dx,r*Dx]};return v.distance=h,v},I_=function(t){return t},R_=Gb(),L_=Gb(),F_={point:Ns,lineStart:Ns,lineEnd:Ns,polygonStart:function(){F_.lineStart=Ml,F_.lineEnd=Ol},polygonEnd:function(){F_.lineStart=F_.lineEnd=F_.point=Ns,R_.add(Rx(L_)),L_.reset()},result:function(){var t=R_/2;return R_.reset(),t}},j_=1/0,B_=j_,U_=-j_,H_=U_,z_={point:Dl,lineStart:Ns,lineEnd:Ns,polygonStart:Ns,polygonEnd:Ns,result:function(){var t=[[j_,B_],[U_,H_]];return U_=H_=-(B_=j_=1/0),t}},W_=0,q_=0,V_=0,K_=0,Y_=0,G_=0,X_=0,$_=0,Z_=0,J_={point:Il,lineStart:Rl,lineEnd:jl,polygonStart:function(){J_.lineStart=Bl,J_.lineEnd=Ul},polygonEnd:function(){J_.point=Il,J_.lineStart=Rl,J_.lineEnd=jl},result:function(){var t=Z_?[X_/Z_,$_/Z_]:G_?[K_/G_,Y_/G_]:V_?[W_/V_,q_/V_]:[NaN,NaN];return W_=q_=V_=K_=Y_=G_=X_=$_=Z_=0,t}};Wl.prototype={_radius:4.5,pointRadius:function(t){return this._radius=t,this},polygonStart:function(){this._line=0},polygonEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){0===this._line&&this._context.closePath(),this._point=NaN},point:function(t,e){switch(this._point){case 0:this._context.moveTo(t,e),this._point=1;break;case 1:this._context.lineTo(t,e);break;default:this._context.moveTo(t+this._radius,e),this._context.arc(t,e,this._radius,0,Ox)}},result:Ns},ql.prototype={_circle:Vl(4.5),pointRadius:function(t){return this._circle=Vl(t),this},polygonStart:function(){this._line=0},polygonEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){0===this._line&&this._string.push("Z"),this._point=NaN},point:function(t,e){switch(this._point){case 0:this._string.push("M",t,",",e),this._point=1;break;case 1:this._string.push("L",t,",",e);break;default:this._string.push("M",t,",",e,this._circle)}},result:function(){if(this._string.length){var t=this._string.join("");return this._string=[],t}}};var Q_=function(t,e){function n(t){return t&&("function"==typeof i&&o.pointRadius(+i.apply(this,arguments)),Xx(t,r(o))),o.result()}var r,o,i=4.5;return n.area=function(t){return Xx(t,r(F_)),F_.result()},n.bounds=function(t){return Xx(t,r(z_)),z_.result()},n.centroid=function(t){return Xx(t,r(J_)),J_.result()},n.projection=function(e){return arguments.length?(r=null==e?(t=null,I_):(t=e).stream,n):t},n.context=function(t){return arguments.length?(o=null==t?(e=null,new ql):new Wl(e=t),"function"!=typeof i&&o.pointRadius(i),n):e},n.pointRadius=function(t){return arguments.length?(i="function"==typeof t?t:(o.pointRadius(+t),+t),n):i},n.projection(t).context(e)},tw=Gb(),ew=function(t,e){var n=e[0],r=e[1],o=[Wx(n),-jx(n),0],i=0,a=0;tw.reset();for(var s=0,l=t.length;s<l;++s)if(c=(u=t[s]).length)for(var u,c,f=u[c-1],d=f[0],p=f[1]/2+Ax,h=Wx(p),g=jx(p),v=0;v<c;++v,d=y,h=x,g=_,f=m){var m=u[v],y=m[0],b=m[1]/2+Ax,x=Wx(b),_=jx(b),w=y-d,T=w>=0?1:-1,C=T*w,k=C>Mx,E=h*x;if(tw.add(Fx(E*T*Wx(C),g*_+E*jx(C))),i+=k?w+T*Ox:w,k^d>=n^y>=n){var P=Hs(Bs(f),Bs(m));qs(P);var S=Hs(o,P);qs(S);var M=(k^w>=0?-1:1)*Ss(S[2]);(r>M||r===M&&(P[0]||P[1]))&&(a+=k^w>=0?1:-1)}}return(i<-Px||i<Px&&tw<-Px)^1&a},nw=function(t,e,n,r){return function(o,i){function a(e,n){var r=o(e,n);t(e=r[0],n=r[1])&&i.point(e,n)}function s(t,e){var n=o(t,e);v.point(n[0],n[1])}function l(){_.point=s,v.lineStart()}function u(){_.point=a,v.lineEnd()}function c(t,e){g.push([t,e]);var n=o(t,e);b.point(n[0],n[1])}function f(){b.lineStart(),g=[]}function d(){c(g[0][0],g[0][1]),b.lineEnd();var t,e,n,r,o=b.clean(),a=y.result(),s=a.length;if(g.pop(),p.push(g),g=null,s)if(1&o){if(n=a[0],(e=n.length-1)>0){for(x||(i.polygonStart(),x=!0),i.lineStart(),t=0;t<e;++t)i.point((r=n[t])[0],r[1]);i.lineEnd()}}else s>1&&2&o&&a.push(a.pop().concat(a.shift())),h.push(a.filter(Kl))}var p,h,g,v=e(i),m=o.invert(r[0],r[1]),y=x_(),b=e(y),x=!1,_={point:a,lineStart:l,lineEnd:u,polygonStart:function(){_.point=c,_.lineStart=f,_.lineEnd=d,h=[],p=[]},polygonEnd:function(){_.point=a,_.lineStart=l,_.lineEnd=u,h=Zu(h);var t=ew(p,m);h.length?(x||(i.polygonStart(),x=!0),T_(h,Yl,t,n,i)):t&&(x||(i.polygonStart(),x=!0),i.lineStart(),n(null,null,1,i),i.lineEnd()),x&&(i.polygonEnd(),x=!1),h=p=null},sphere:function(){i.polygonStart(),i.lineStart(),n(null,null,1,i),i.lineEnd(),i.polygonEnd()}};return _}},rw=nw(function(){return!0},Gl,$l,[-Mx,-Nx]),ow=function(t,e){function n(n,r,o,i){vl(i,t,e,o,n,r)}function r(t,e){return jx(t)*jx(e)>s}function o(t){var e,n,o,s,c;return{lineStart:function(){s=o=!1,c=1},point:function(f,d){var p,h=[f,d],g=r(f,d),v=l?g?0:a(f,d):g?a(f+(f<0?Mx:-Mx),d):0;if(!e&&(s=o=g)&&t.lineStart(),g!==o&&(p=i(e,h),(w_(e,p)||w_(h,p))&&(h[0]+=Px,h[1]+=Px,g=r(h[0],h[1]))),g!==o)c=0,g?(t.lineStart(),p=i(h,e),t.point(p[0],p[1])):(p=i(e,h),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(u&&e&&l^g){var m;v&n||!(m=i(h,e,!0))||(c=0,l?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&w_(e,h)||t.point(h[0],h[1]),e=h,o=g,n=v},lineEnd:function(){o&&t.lineEnd(),e=null},clean:function(){return c|(s&&o)<<1}}}function i(t,e,n){var r=Bs(t),o=Bs(e),i=[1,0,0],a=Hs(r,o),l=Us(a,a),u=a[0],c=l-u*u;if(!c)return!n&&t;var f=s*l/c,d=-s*u/c,p=Hs(i,a),h=Ws(i,f),g=Ws(a,d);zs(h,g);var v=p,m=Us(h,v),y=Us(v,v),b=m*m-y*(Us(h,h)-1);if(!(b<0)){var x=Vx(b),_=Ws(v,(-m-x)/y);if(zs(_,h),_=js(_),!n)return _;var w,T=t[0],C=e[0],k=t[1],E=e[1];C<T&&(w=T,T=C,C=w);var P=C-T,S=Rx(P-Mx)<Px,M=S||P<Px;if(!S&&E<k&&(w=k,k=E,E=w),M?S?k+E>0^_[1]<(Rx(_[0]-T)<Px?k:E):k<=_[1]&&_[1]<=E:P>Mx^(T<=_[0]&&_[0]<=C)){var N=Ws(v,(-m+x)/y);return zs(N,h),[_,js(N)]}}}function a(e,n){var r=l?t:Mx-t,o=0;return e<-r?o|=1:e>r&&(o|=2),n<-r?o|=4:n>r&&(o|=8),o}var s=jx(t),l=s>0,u=Rx(s)>Px;return nw(r,o,n,l?[0,-t]:[-Mx,t-Mx])},iw=function(t){return{stream:Zl(t)}};Jl.prototype={constructor:Jl,point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}};var aw=16,sw=jx(30*Ix),lw=function(t,e){return+e?nu(t,e):eu(t)},uw=Zl({point:function(t,e){this.stream.point(t*Ix,e*Ix)}}),cw=function(){return iu(su).scale(155.424).center([0,33.6442])},fw=function(){return cw().parallels([29.5,45.5]).scale(1070).translate([480,250]).rotate([96,0]).center([-.6,38.7])},dw=function(){function t(t){var e=t[0],n=t[1];return s=null,o.point(e,n),s||(i.point(e,n),s)||(a.point(e,n),s)}function e(){return n=r=null,t}var n,r,o,i,a,s,l=fw(),u=cw().rotate([154,0]).center([-2,58.5]).parallels([55,65]),c=cw().rotate([157,0]).center([-3,19.9]).parallels([8,18]),f={point:function(t,e){s=[t,e]}};return t.invert=function(t){var e=l.scale(),n=l.translate(),r=(t[0]-n[0])/e,o=(t[1]-n[1])/e;return(o>=.12&&o<.234&&r>=-.425&&r<-.214?u:o>=.166&&o<.234&&r>=-.214&&r<-.115?c:l).invert(t)},t.stream=function(t){return n&&r===t?n:n=lu([l.stream(r=t),u.stream(t),c.stream(t)])},t.precision=function(t){return arguments.length?(l.precision(t),u.precision(t),c.precision(t),e()):l.precision()},t.scale=function(e){return arguments.length?(l.scale(e),u.scale(.35*e),c.scale(e),t.translate(l.translate())):l.scale()},t.translate=function(t){if(!arguments.length)return l.translate();var n=l.scale(),r=+t[0],s=+t[1];return o=l.translate(t).clipExtent([[r-.455*n,s-.238*n],[r+.455*n,s+.238*n]]).stream(f),i=u.translate([r-.307*n,s+.201*n]).clipExtent([[r-.425*n+Px,s+.12*n+Px],[r-.214*n-Px,s+.234*n-Px]]).stream(f),a=c.translate([r-.205*n,s+.212*n]).clipExtent([[r-.214*n+Px,s+.166*n+Px],[r-.115*n-Px,s+.234*n-Px]]).stream(f),e()},t.fitExtent=function(e,n){return Ql(t,e,n)},t.fitSize=function(e,n){return tu(t,e,n)},t.scale(1070)},pw=uu(function(t){return Vx(2/(1+t))});pw.invert=cu(function(t){return 2*Ss(t/2)});var hw=function(){return ru(pw).scale(124.75).clipAngle(179.999)},gw=uu(function(t){return(t=Ps(t))&&t/Wx(t)});gw.invert=cu(function(t){return t});var vw=function(){return ru(gw).scale(79.4188).clipAngle(179.999)};fu.invert=function(t,e){return[t,2*Lx(Ux(e))-Nx]};var mw=function(){return du(fu).scale(961/Ox)},yw=function(){return iu(hu).scale(109.5).parallels([30,30])};gu.invert=gu;var bw=function(){return ru(gu).scale(152.63)},xw=function(){return iu(vu).scale(131.154).center([0,13.9389])};mu.invert=cu(Lx);var _w=function(){return ru(mu).scale(144.049).clipAngle(60)},ww=function(){function t(){return o=i=null,a}var e,n,r,o,i,a,s=1,l=0,u=0,c=1,f=1,d=I_,p=null,h=I_;return a={stream:function(t){return o&&i===t?o:o=d(h(i=t))},clipExtent:function(o){return arguments.length?(h=null==o?(p=e=n=r=null,I_):xl(p=+o[0][0],e=+o[0][1],n=+o[1][0],r=+o[1][1]),t()):null==p?null:[[p,e],[n,r]]},scale:function(e){return arguments.length?(d=yu((s=+e)*c,s*f,l,u),t()):s},translate:function(e){return arguments.length?(d=yu(s*c,s*f,l=+e[0],u=+e[1]),t()):[l,u]},reflectX:function(e){return arguments.length?(d=yu(s*(c=e?-1:1),s*f,l,u),t()):c<0},reflectY:function(e){return arguments.length?(d=yu(s*c,s*(f=e?-1:1),l,u),t()):f<0},fitExtent:function(t,e){return Ql(a,t,e)},fitSize:function(t,e){return tu(a,t,e)}}};bu.invert=cu(Ss);var Tw=function(){return ru(bu).scale(249.5).clipAngle(90+Px)};xu.invert=cu(function(t){return 2*Lx(t)});var Cw=function(){return ru(xu).scale(250).clipAngle(142)};_u.invert=function(t,e){return[-e,2*Lx(Ux(t))-Nx]};var kw=function(){var t=du(_u),e=t.center,n=t.rotate;return t.center=function(t){return arguments.length?e([-t[1],t[0]]):(t=e(),[t[1],-t[0]])},t.rotate=function(t){return arguments.length?n([t[0],t[1],t.length>2?t[2]+90:90]):(t=n(),[t[0],t[1],t[2]-90])},n([0,0,90]).scale(159.155)};t.version=wu,t.bisect=Eu,t.bisectRight=Eu,t.bisectLeft=Pu,t.ascending=Tu,t.bisector=Cu,t.descending=Su,t.deviation=Au,t.extent=Ou,t.histogram=qu,t.thresholdFreedmanDiaconis=Ku,t.thresholdScott=Yu,t.thresholdSturges=Wu,t.max=Gu,t.mean=Xu,t.median=$u,t.merge=Zu,t.min=Ju,t.pairs=Qu,t.permute=tc,t.quantile=Vu,t.range=ju,t.scan=ec,t.shuffle=nc,t.sum=rc,t.ticks=zu,t.tickStep=n,t.transpose=oc,t.variance=Nu,t.zip=ic,t.entries=fc,t.keys=uc,t.values=cc,t.map=i,t.set=f,t.nest=sc,t.randomUniform=dc,t.randomNormal=pc,t.randomLogNormal=hc,t.randomBates=vc,t.randomIrwinHall=gc,t.randomExponential=mc,t.easeLinear=d,t.easeQuad=g,t.easeQuadIn=p,t.easeQuadOut=h,t.easeQuadInOut=g,t.easeCubic=y,t.easeCubicIn=v,t.easeCubicOut=m,t.easeCubicInOut=y,t.easePoly=_c,t.easePolyIn=bc,t.easePolyOut=xc,t.easePolyInOut=_c,t.easeSin=_,t.easeSinIn=b,t.easeSinOut=x,t.easeSinInOut=_,t.easeExp=C,t.easeExpIn=w,t.easeExpOut=T,t.easeExpInOut=C,t.easeCircle=P,t.easeCircleIn=k,t.easeCircleOut=E,t.easeCircleInOut=P,t.easeBounce=M,t.easeBounceIn=S,t.easeBounceOut=M,t.easeBounceInOut=N,t.easeBack=Fc,t.easeBackIn=Rc,t.easeBackOut=Lc,t.easeBackInOut=Fc,t.easeElastic=zc,t.easeElasticIn=Hc,t.easeElasticOut=zc,t.easeElasticInOut=Wc,t.polygonArea=qc,t.polygonCentroid=Vc,t.polygonHull=Yc,t.polygonContains=Gc,t.polygonLength=Xc,t.path=I,t.quadtree=U,t.queue=X,t.arc=wf,t.area=kf,t.line=Cf,t.pie=Sf,t.radialArea=Af,t.radialLine=Nf,t.symbol=Zf,t.symbols=$f,t.symbolCircle=Of,t.symbolCross=Df,t.symbolDiamond=Lf,t.symbolSquare=zf,t.symbolStar=Hf,t.symbolTriangle=qf,t.symbolWye=Xf,t.curveBasisClosed=td,t.curveBasisOpen=ed,t.curveBasis=Qf,t.curveBundle=nd,t.curveCardinalClosed=od,t.curveCardinalOpen=id,t.curveCardinal=rd,t.curveCatmullRomClosed=sd,t.curveCatmullRomOpen=ld,t.curveCatmullRom=ad,t.curveLinearClosed=ud,t.curveLinear=Tf,t.curveMonotoneX=At,t.curveMonotoneY=Ot,t.curveNatural=cd,t.curveStep=fd,t.curveStepAfter=Ft,t.curveStepBefore=Lt,t.stack=gd,t.stackOffsetExpand=vd,t.stackOffsetNone=pd,t.stackOffsetSilhouette=md,t.stackOffsetWiggle=yd,t.stackOrderAscending=bd,t.stackOrderDescending=xd,t.stackOrderInsideOut=_d,t.stackOrderNone=hd,t.stackOrderReverse=wd,t.color=zt,t.rgb=Kt,t.hsl=$t,t.lab=te,t.hcl=se,t.cubehelix=ce,t.interpolate=bp,t.interpolateArray=dp,t.interpolateDate=pp,t.interpolateNumber=hp,t.interpolateObject=gp,t.interpolateRound=xp,t.interpolateString=yp,t.interpolateTransformCss=Cp,t.interpolateTransformSvg=kp,t.interpolateZoom=Np,t.interpolateRgb=up,t.interpolateRgbBasis=cp,t.interpolateRgbBasisClosed=fp,t.interpolateHsl=Ap,t.interpolateHslLong=Op,t.interpolateLab=Se,t.interpolateHcl=Dp,t.interpolateHclLong=Ip,t.interpolateCubehelix=Rp,t.interpolateCubehelixLong=Lp,t.interpolateBasis=ap,t.interpolateBasisClosed=sp,t.quantize=Fp,t.dispatch=Ae,t.dsvFormat=Hp,t.csvParse=Wp,t.csvParseRows=qp,t.csvFormat=Vp,t.csvFormatRows=Kp,t.tsvParse=Gp,t.tsvParseRows=Xp,t.tsvFormat=$p,t.tsvFormatRows=Zp,t.request=Jp,t.html=th,t.json=eh,t.text=nh,t.xml=rh,t.csv=ih,t.tsv=ah,t.now=ze,t.timer=Ve,t.timerFlush=Ke,t.timeout=vh,t.interval=mh,t.timeInterval=Ze,t.timeMillisecond=xh,t.timeMilliseconds=_h,t.timeSecond=Ph,t.timeSeconds=Sh,t.timeMinute=Mh,t.timeMinutes=Nh,t.timeHour=Ah,t.timeHours=Oh,t.timeDay=Dh,t.timeDays=Ih,t.timeWeek=Rh,t.timeWeeks=zh,t.timeSunday=Rh,t.timeSundays=zh,t.timeMonday=Lh,t.timeMondays=Wh,t.timeTuesday=Fh,t.timeTuesdays=qh;t.timeWednesday=jh;t.timeWednesdays=Vh,t.timeThursday=Bh,t.timeThursdays=Kh,t.timeFriday=Uh,t.timeFridays=Yh,t.timeSaturday=Hh,t.timeSaturdays=Gh,t.timeMonth=Xh,t.timeMonths=$h,t.timeYear=Zh,t.timeYears=Jh,t.utcMillisecond=xh,t.utcMilliseconds=_h,t.utcSecond=Ph,t.utcSeconds=Sh,t.utcMinute=Qh,t.utcMinutes=tg,t.utcHour=eg,t.utcHours=ng,t.utcDay=rg,t.utcDays=og,t.utcWeek=ig,t.utcWeeks=dg,t.utcSunday=ig,t.utcSundays=dg,t.utcMonday=ag,t.utcMondays=pg,t.utcTuesday=sg,t.utcTuesdays=hg,t.utcWednesday=lg,t.utcWednesdays=gg,t.utcThursday=ug,t.utcThursdays=vg,t.utcFriday=cg,t.utcFridays=mg,t.utcSaturday=fg,t.utcSaturdays=yg,t.utcMonth=bg,t.utcMonths=xg,t.utcYear=_g,t.utcYears=Tg,t.formatLocale=Rg,t.formatDefaultLocale=nn,t.formatSpecifier=Og,t.precisionFixed=Fg,t.precisionPrefix=jg,t.precisionRound=Bg,t.isoFormat=Vg,t.isoParse=Kg,t.timeFormatLocale=sn,t.timeFormatDefaultLocale=er,t.scaleBand=ir,t.scalePoint=sr,t.scaleIdentity=mr,t.scaleLinear=vr,t.scaleLog=Cr,t.scaleOrdinal=or,t.scaleImplicit=$g,t.scalePow=Er,t.scaleSqrt=Pr,t.scaleQuantile=Sr,t.scaleQuantize=Mr,t.scaleThreshold=Nr,t.scaleTime=uv,t.scaleUtc=cv,t.schemeCategory10=dv,t.schemeCategory20b=pv,t.schemeCategory20c=hv,t.schemeCategory20=gv,t.scaleSequential=Rr,t.interpolateCubehelixDefault=vv,t.interpolateRainbow=xv,t.interpolateWarm=mv,t.interpolateCool=yv,t.interpolateViridis=_v,t.interpolateMagma=wv,t.interpolateInferno=Tv,t.interpolatePlasma=Cv,t.creator=Sv,t.customEvent=Vr,t.local=jr,t.matcher=Dv,t.mouse=Bv,t.namespace=Pv,t.namespaces=Ev,t.select=_m,t.selectAll=wm,t.selection=Do,t.selector=Uv,t.selectorAll=zv,t.touch=Tm,t.touches=Cm,t.window=sm,t.active=sy,t.interrupt=Rm,t.transition=fi,t.axisTop=bi,t.axisRight=xi,t.axisBottom=_i,t.axisLeft=wi,t.cluster=gy,t.hierarchy=Ai,t.pack=Ny,t.packSiblings=Sy,t.packEnclose=Py,t.partition=Dy,t.stratify=Fy,t.tree=jy,t.treemap=zy,t.treemapBinary=Wy,t.treemapDice=Oy,t.treemapSlice=By,t.treemapSliceDice=qy,t.treemapSquarify=Hy,t.treemapResquarify=Vy,t.forceCenter=Ky,t.forceCollide=Xy,t.forceLink=$y,t.forceManyBody=tb,t.forceSimulation=Qy,t.forceX=eb,t.forceY=nb,t.drag=ab,t.dragDisable=ob,t.dragEnable=ba,t.voronoi=mb,t.zoom=_b,t.zoomIdentity=bb,t.zoomTransform=os,t.brush=Fb,t.brushX=vs,t.brushY=ms,t.brushSelection=gs,t.chord=qb,t.ribbon=Yb,t.geoAlbers=fw,t.geoAlbersUsa=dw,t.geoArea=Qx,t.geoAzimuthalEqualArea=hw,t.geoAzimuthalEqualAreaRaw=pw,t.geoAzimuthalEquidistant=vw,t.geoAzimuthalEquidistantRaw=gw,t.geoBounds=n_,t.geoCentroid=o_,t.geoCircle=b_,t.geoClipExtent=E_,t.geoConicConformal=yw,t.geoConicConformalRaw=hu,t.geoConicEqualArea=cw,t.geoConicEqualAreaRaw=su,
t.geoConicEquidistant=xw,t.geoConicEquidistantRaw=vu,t.geoDistance=O_,t.geoEquirectangular=bw,t.geoEquirectangularRaw=gu,t.geoGnomonic=_w,t.geoGnomonicRaw=mu,t.geoGraticule=Pl,t.geoGraticule10=Sl,t.geoIdentity=ww,t.geoInterpolate=D_,t.geoLength=M_,t.geoMercator=mw,t.geoMercatorRaw=fu,t.geoOrthographic=Tw,t.geoOrthographicRaw=bu,t.geoPath=Q_,t.geoProjection=ru,t.geoProjectionMutator=ou,t.geoRotation=y_,t.geoStereographic=Cw,t.geoStereographicRaw=xu,t.geoStream=Xx,t.geoTransform=iw,t.geoTransverseMercator=kw,t.geoTransverseMercatorRaw=_u,Object.defineProperty(t,"__esModule",{value:!0})})},function(t,e,n){!function(){function e(t,e,n){"undefined"==typeof n&&(n=e,optionsValues=void 0);var r="undefined"!=typeof t?t:e;if("undefined"==typeof r)return null;if("function"==typeof r){var o=[n];return n.geography&&(o=[n.geography,n.data]),r.apply(null,o)}return r}function r(t,e,n){return this.svg=g.select(t).append("svg").attr("width",n||t.offsetWidth).attr("data-width",n||t.offsetWidth).attr("class","datamap").attr("height",e||t.offsetHeight).style("overflow","hidden"),this.options.responsive&&(g.select(this.options.element).style({position:"relative","padding-bottom":100*this.options.aspectRatio+"%"}),g.select(this.options.element).select("svg").style({position:"absolute",width:"100%",height:"100%"}),g.select(this.options.element).select("svg").select("g").selectAll("path").style("vector-effect","non-scaling-stroke")),this.svg}function o(t,e){var n,r,o=e.width||t.offsetWidth,i=e.height||t.offsetHeight,a=this.svg;return e&&"undefined"==typeof e.scope&&(e.scope="world"),"usa"===e.scope?n=g.geo.albersUsa().scale(o).translate([o/2,i/2]):"world"===e.scope&&(n=g.geo[e.projection]().scale((o+1)/2/Math.PI).translate([o/2,i/("mercator"===e.projection?1.45:1.8)])),"orthographic"===e.projection&&(a.append("defs").append("path").datum({type:"Sphere"}).attr("id","sphere").attr("d",r),a.append("use").attr("class","stroke").attr("xlink:href","#sphere"),a.append("use").attr("class","fill").attr("xlink:href","#sphere"),n.scale(250).clipAngle(90).rotate(e.projectionConfig.rotation)),r=g.geo.path().projection(n),{path:r,projection:n}}function i(){g.select(".datamaps-style-block").empty()&&g.select("head").append("style").attr("class","datamaps-style-block").html('.datamap path.datamaps-graticule { fill: none; stroke: #777; stroke-width: 0.5px; stroke-opacity: .5; pointer-events: none; } .datamap .labels {pointer-events: none;} .datamap path:not(.datamaps-arc), .datamap circle, .datamap line {stroke: #FFFFFF; vector-effect: non-scaling-stroke; stroke-width: 1px;} .datamaps-legend dt, .datamaps-legend dd { float: left; margin: 0 3px 0 0;} .datamaps-legend dd {width: 20px; margin-right: 6px; border-radius: 3px;} .datamaps-legend {padding-bottom: 20px; z-index: 1001; position: absolute; left: 4px; font-size: 12px; font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;} .datamaps-hoverover {display: none; font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; } .hoverinfo {padding: 4px; border-radius: 1px; background-color: #FFF; box-shadow: 1px 1px 5px #CCC; font-size: 12px; border: 1px solid #CCC; } .hoverinfo hr {border:1px dotted #CCC; }')}function a(t){var n=this.options.fills,r=this.options.data||{},o=this.options.geographyConfig,i=this.svg.select("g.datamaps-subunits");i.empty()&&(i=this.addLayer("datamaps-subunits",null,!0));var a=v.feature(t,t.objects[this.options.scope]).features;o.hideAntarctica&&(a=a.filter(function(t){return"ATA"!==t.id})),o.hideHawaiiAndAlaska&&(a=a.filter(function(t){return"HI"!==t.id&&"AK"!==t.id}));var s=i.selectAll("path.datamaps-subunit").data(a);s.enter().append("path").attr("d",this.path).attr("class",function(t){return"datamaps-subunit "+t.id}).attr("data-info",function(t){return JSON.stringify(r[t.id])}).style("fill",function(t){var o,i=r[t.id];return i&&i.fillKey&&(o=n[e(i.fillKey,{data:r[t.id],geography:t})]),"undefined"==typeof o&&(o=e(i&&i.fillColor,n.defaultFill,{data:r[t.id],geography:t})),o}).style("stroke-width",o.borderWidth).style("stroke-opacity",o.borderOpacity).style("stroke",o.borderColor)}function s(){function t(){this.parentNode.appendChild(this)}var n=this.svg,r=this,o=this.options.geographyConfig;(o.highlightOnHover||o.popupOnHover)&&n.selectAll(".datamaps-subunit").on("mouseover",function(i){var a=g.select(this),s=r.options.data[i.id]||{};if(o.highlightOnHover){var l={fill:a.style("fill"),stroke:a.style("stroke"),"stroke-width":a.style("stroke-width"),"fill-opacity":a.style("fill-opacity")};a.style("fill",e(s.highlightFillColor,o.highlightFillColor,s)).style("stroke",e(s.highlightBorderColor,o.highlightBorderColor,s)).style("stroke-width",e(s.highlightBorderWidth,o.highlightBorderWidth,s)).style("stroke-opacity",e(s.highlightBorderOpacity,o.highlightBorderOpacity,s)).style("fill-opacity",e(s.highlightFillOpacity,o.highlightFillOpacity,s)).attr("data-previousAttributes",JSON.stringify(l)),/((MSIE)|(Trident))/.test(navigator.userAgent)||t.call(this)}o.popupOnHover&&r.updatePopup(a,i,o,n)}).on("mouseout",function(){var t=g.select(this);if(o.highlightOnHover){var e=JSON.parse(t.attr("data-previousAttributes"));for(var n in e)t.style(n,e[n])}t.on("mousemove",null),g.selectAll(".datamaps-hoverover").style("display","none")})}function l(t,e,n){if(e=e||{},this.options.fills){var r="<dl>",o="";e.legendTitle&&(r="<h2>"+e.legendTitle+"</h2>"+r);for(var i in this.options.fills){if("defaultFill"===i){if(!e.defaultFillName)continue;o=e.defaultFillName}else o=e.labels&&e.labels[i]?e.labels[i]:i+": ";r+="<dt>"+o+"</dt>",r+='<dd style="background-color:'+this.options.fills[i]+'">&nbsp;</dd>'}r+="</dl>";g.select(this.options.element).append("div").attr("class","datamaps-legend").html(r)}}function u(t,e){var n=g.geo.graticule();this.svg.insert("path",".datamaps-subunits").datum(n).attr("class","datamaps-graticule").attr("d",this.path)}function c(t,n,r){var o=this,i=this.svg;if(!n||n&&!n.slice)throw"Datamaps Error - arcs must be an array";for(var a=0;a<n.length;a++)n[a]=p(n[a],n[a].options),delete n[a].options;"undefined"==typeof r&&(r=m.arcConfig);var s=t.selectAll("path.datamaps-arc").data(n,JSON.stringify),l=g.geo.path().projection(o.projection);s.enter().append("svg:path").attr("class","datamaps-arc").style("stroke-linecap","round").style("stroke",function(t){return e(t.strokeColor,r.strokeColor,t)}).style("fill","none").style("stroke-width",function(t){return e(t.strokeWidth,r.strokeWidth,t)}).attr("d",function(t){var n,a;if("string"==typeof t.origin)switch(t.origin){case"CAN":n=o.latLngToXY(56.624472,-114.665293);break;case"CHL":n=o.latLngToXY(-33.44889,-70.669265);break;case"IDN":n=o.latLngToXY(-6.208763,106.845599);break;case"JPN":n=o.latLngToXY(35.689487,139.691706);break;case"MYS":n=o.latLngToXY(3.139003,101.686855);break;case"NOR":n=o.latLngToXY(59.913869,10.752245);break;case"USA":n=o.latLngToXY(41.140276,-100.760145);break;case"VNM":n=o.latLngToXY(21.027764,105.83416);break;default:n=o.path.centroid(i.select("path."+t.origin).data()[0])}else n=o.latLngToXY(e(t.origin.latitude,t),e(t.origin.longitude,t));if("string"==typeof t.destination)switch(t.destination){case"CAN":a=o.latLngToXY(56.624472,-114.665293);break;case"CHL":a=o.latLngToXY(-33.44889,-70.669265);break;case"IDN":a=o.latLngToXY(-6.208763,106.845599);break;case"JPN":a=o.latLngToXY(35.689487,139.691706);break;case"MYS":a=o.latLngToXY(3.139003,101.686855);break;case"NOR":a=o.latLngToXY(59.913869,10.752245);break;case"USA":a=o.latLngToXY(41.140276,-100.760145);break;case"VNM":a=o.latLngToXY(21.027764,105.83416);break;default:a=o.path.centroid(i.select("path."+t.destination).data()[0])}else a=o.latLngToXY(e(t.destination.latitude,t),e(t.destination.longitude,t));var s=[(n[0]+a[0])/2,(n[1]+a[1])/2];if(r.greatArc){var u=g.geo.greatArc().source(function(t){return[e(t.origin.longitude,t),e(t.origin.latitude,t)]}).target(function(t){return[e(t.destination.longitude,t),e(t.destination.latitude,t)]});return l(u(t))}var c=e(t.arcSharpness,r.arcSharpness,t);return"M"+n[0]+","+n[1]+"S"+(s[0]+50*c)+","+(s[1]-75*c)+","+a[0]+","+a[1]}).attr("data-info",function(t){return JSON.stringify(t)}).on("mouseover",function(t){var e=g.select(this);r.popupOnHover&&o.updatePopup(e,t,r,i)}).on("mouseout",function(t){g.select(this);g.selectAll(".datamaps-hoverover").style("display","none")}).transition().delay(100).style("fill",function(t){var n=this.getTotalLength();return this.style.transition=this.style.WebkitTransition="none",this.style.strokeDasharray=n+" "+n,this.style.strokeDashoffset=n,this.getBoundingClientRect(),this.style.transition=this.style.WebkitTransition="stroke-dashoffset "+e(t.animationSpeed,r.animationSpeed,t)+"ms ease-out",this.style.strokeDashoffset="0","none"}),s.exit().transition().style("opacity",0).remove()}function f(t,e){var n=this;e=e||{};var r=this.projection([-67.707617,42.722131]);this.svg.selectAll(".datamaps-subunit").attr("data-foo",function(o){var i=n.path.centroid(o),a=7.5,s=5;["FL","KY","MI"].indexOf(o.id)>-1&&(a=-2.5),"NY"===o.id&&(a=-1),"MI"===o.id&&(s=18),"LA"===o.id&&(a=13);var l,u;l=i[0]-a,u=i[1]+s;var c=["VT","NH","MA","RI","CT","NJ","DE","MD","DC"].indexOf(o.id);if(c>-1){var f=r[1];l=r[0],u=f+c*(2+(e.fontSize||12)),t.append("line").attr("x1",l-3).attr("y1",u-5).attr("x2",i[0]).attr("y2",i[1]).style("stroke",e.labelColor||"#000").style("stroke-width",e.lineWidth||1)}return t.append("text").attr("x",l).attr("y",u).style("font-size",(e.fontSize||10)+"px").style("font-family",e.fontFamily||"Verdana").style("fill",e.labelColor||"#000").text(function(){return e.customLabelText&&e.customLabelText[o.id]?e.customLabelText[o.id]:o.id}),"bar"})}function d(t,n,r){function o(t){return"undefined"!=typeof t&&"undefined"!=typeof t.latitude&&"undefined"!=typeof t.longitude}var i=this,a=this.options.fills,s=this.options.filters,l=this.svg;if(!n||n&&!n.slice)throw"Datamaps Error - bubbles must be an array";var u=t.selectAll("circle.datamaps-bubble").data(n,r.key);u.enter().append("svg:circle").attr("class","datamaps-bubble").attr("cx",function(t){var e;if(o(t)?e=i.latLngToXY(t.latitude,t.longitude):t.centered&&(e="USA"===t.centered?i.projection([-98.58333,39.83333]):i.path.centroid(l.select("path."+t.centered).data()[0])),e)return e[0]}).attr("cy",function(t){var e;if(o(t)?e=i.latLngToXY(t.latitude,t.longitude):t.centered&&(e="USA"===t.centered?i.projection([-98.58333,39.83333]):i.path.centroid(l.select("path."+t.centered).data()[0])),e)return e[1]}).attr("r",function(t){return r.animate?0:e(t.radius,r.radius,t)}).attr("data-info",function(t){return JSON.stringify(t)}).attr("filter",function(t){var n=s[e(t.filterKey,r.filterKey,t)];if(n)return n}).style("stroke",function(t){return e(t.borderColor,r.borderColor,t)}).style("stroke-width",function(t){return e(t.borderWidth,r.borderWidth,t)}).style("stroke-opacity",function(t){return e(t.borderOpacity,r.borderOpacity,t)}).style("fill-opacity",function(t){return e(t.fillOpacity,r.fillOpacity,t)}).style("fill",function(t){var n=a[e(t.fillKey,r.fillKey,t)];return n||a.defaultFill}).on("mouseover",function(t){var n=g.select(this);if(r.highlightOnHover){var o={fill:n.style("fill"),stroke:n.style("stroke"),"stroke-width":n.style("stroke-width"),"fill-opacity":n.style("fill-opacity")};n.style("fill",e(t.highlightFillColor,r.highlightFillColor,t)).style("stroke",e(t.highlightBorderColor,r.highlightBorderColor,t)).style("stroke-width",e(t.highlightBorderWidth,r.highlightBorderWidth,t)).style("stroke-opacity",e(t.highlightBorderOpacity,r.highlightBorderOpacity,t)).style("fill-opacity",e(t.highlightFillOpacity,r.highlightFillOpacity,t)).attr("data-previousAttributes",JSON.stringify(o))}r.popupOnHover&&i.updatePopup(n,t,r,l)}).on("mouseout",function(t){var e=g.select(this);if(r.highlightOnHover){var n=JSON.parse(e.attr("data-previousAttributes"));for(var o in n)e.style(o,n[o])}g.selectAll(".datamaps-hoverover").style("display","none")}),u.transition().duration(400).attr("r",function(t){return e(t.radius,r.radius,t)}).transition().duration(0).attr("data-info",function(t){return JSON.stringify(t)}),u.exit().transition().delay(r.exitDelay).attr("r",0).remove()}function p(t){return Array.prototype.slice.call(arguments,1).forEach(function(e){if(e)for(var n in e)null==t[n]&&("function"==typeof e[n]?t[n]=e[n]:t[n]=JSON.parse(JSON.stringify(e[n])))}),t}function h(t){if("undefined"==typeof g||"undefined"==typeof v)throw new Error("Include d3.js (v3.0.3 or greater) and topojson on this page before creating a new map");return this.options=p(t,m),this.options.geographyConfig=p(t.geographyConfig,m.geographyConfig),this.options.projectionConfig=p(t.projectionConfig,m.projectionConfig),this.options.bubblesConfig=p(t.bubblesConfig,m.bubblesConfig),this.options.arcConfig=p(t.arcConfig,m.arcConfig),g.select(this.options.element).select("svg").length>0&&r.call(this,this.options.element,this.options.height,this.options.width),this.addPlugin("bubbles",d),this.addPlugin("legend",l),this.addPlugin("arc",c),this.addPlugin("labels",f),this.addPlugin("graticule",u),this.options.disableDefaultStyles||i(),this.draw()}var g=window.d3,v=window.topojson,m={scope:"world",responsive:!1,aspectRatio:.5625,setProjection:o,projection:"equirectangular",dataType:"json",data:{},done:function(){},fills:{defaultFill:"#ABDDA4"},filters:{},geographyConfig:{dataUrl:null,hideAntarctica:!0,hideHawaiiAndAlaska:!1,borderWidth:1,borderOpacity:1,borderColor:"#FDFDFD",popupTemplate:function(t,e){return'<div class="hoverinfo"><strong>'+t.properties.name+"</strong></div>"},popupOnHover:!0,highlightOnHover:!0,highlightFillColor:"#FC8D59",highlightBorderColor:"rgba(250, 15, 160, 0.2)",highlightBorderWidth:2,highlightBorderOpacity:1},projectionConfig:{rotation:[97,0]},bubblesConfig:{borderWidth:2,borderOpacity:1,borderColor:"#FFFFFF",popupOnHover:!0,radius:null,popupTemplate:function(t,e){return'<div class="hoverinfo"><strong>'+e.name+"</strong></div>"},fillOpacity:.75,animate:!0,highlightOnHover:!0,highlightFillColor:"#FC8D59",highlightBorderColor:"rgba(250, 15, 160, 0.2)",highlightBorderWidth:2,highlightBorderOpacity:1,highlightFillOpacity:.85,exitDelay:100,key:JSON.stringify},arcConfig:{strokeColor:"#DD1C77",strokeWidth:1,arcSharpness:1,animationSpeed:600,popupOnHover:!1,popupTemplate:function(t,e){return e.origin&&e.destination&&e.origin.latitude&&e.origin.longitude&&e.destination.latitude&&e.destination.longitude?'<div class="hoverinfo"><strong>Arc</strong><br>Origin: '+JSON.stringify(e.origin)+"<br>Destination: "+JSON.stringify(e.destination)+"</div>":e.origin&&e.destination?'<div class="hoverinfo"><strong>Arc</strong><br>'+e.origin+" -> "+e.destination+"</div>":""}}};h.prototype.resize=function(){var t=this,e=t.options;if(e.responsive){var n=e.element.clientWidth,r=g.select(e.element).select("svg").attr("data-width");g.select(e.element).select("svg").selectAll("g").attr("transform","scale("+n/r+")")}},h.prototype.draw=function(){function t(t){e.options.dataUrl&&g[e.options.dataType](e.options.dataUrl,function(t){if("csv"===e.options.dataType&&t&&t.slice){for(var n={},r=0;r<t.length;r++)n[t[r].id]=t[r];t=n}Datamaps.prototype.updateChoropleth.call(e,t)}),a.call(e,t),s.call(e),(e.options.geographyConfig.popupOnHover||e.options.bubblesConfig.popupOnHover)&&(hoverover=g.select(e.options.element).append("div").attr("class","datamaps-hoverover").style("z-index",10001).style("position","absolute")),e.options.done(e)}var e=this,n=e.options,r=n.setProjection.apply(this,[n.element,n]);return this.path=r.path,this.projection=r.projection,n.geographyConfig.dataUrl?g.json(n.geographyConfig.dataUrl,function(n,r){if(n)throw new Error(n);e.customTopo=r,t(r)}):t(this[n.scope+"Topo"]||n.geographyConfig.dataJson),this},h.prototype.worldTopo={type:"Topology",objects:{world:{type:"GeometryCollection",geometries:[{type:"Polygon",properties:{name:"Afghanistan"},id:"AFG",arcs:[[0,1,2,3,4,5]]},{type:"MultiPolygon",properties:{name:"Angola"},id:"AGO",arcs:[[[6,7,8,9]],[[10,11,12]]]},{type:"Polygon",properties:{name:"Albania"},id:"ALB",arcs:[[13,14,15,16,17]]},{type:"Polygon",properties:{name:"United Arab Emirates"},id:"ARE",arcs:[[18,19,20,21,22]]},{type:"MultiPolygon",properties:{name:"Argentina"},id:"ARG",arcs:[[[23,24]],[[25,26,27,28,29,30]]]},{type:"Polygon",properties:{name:"Armenia"},id:"ARM",arcs:[[31,32,33,34,35]]},{type:"MultiPolygon",properties:{name:"Antarctica"},id:"ATA",arcs:[[[36]],[[37]],[[38]],[[39]],[[40]],[[41]],[[42]],[[43]]]},{type:"Polygon",properties:{name:"French Southern and Antarctic Lands"},id:"ATF",arcs:[[44]]},{type:"MultiPolygon",properties:{name:"Australia"},id:"AUS",arcs:[[[45]],[[46]]]},{type:"Polygon",properties:{name:"Austria"},id:"AUT",arcs:[[47,48,49,50,51,52,53]]},{type:"MultiPolygon",properties:{name:"Azerbaijan"},id:"AZE",arcs:[[[54,-35]],[[55,56,-33,57,58]]]},{type:"Polygon",properties:{name:"Burundi"},id:"BDI",arcs:[[59,60,61]]},{type:"Polygon",properties:{name:"Belgium"},id:"BEL",arcs:[[62,63,64,65,66]]},{type:"Polygon",properties:{name:"Benin"},id:"BEN",arcs:[[67,68,69,70,71]]},{type:"Polygon",properties:{name:"Burkina Faso"},id:"BFA",arcs:[[72,73,74,-70,75,76]]},{type:"Polygon",properties:{name:"Bangladesh"},id:"BGD",arcs:[[77,78,79]]},{type:"Polygon",properties:{name:"Bulgaria"},id:"BGR",arcs:[[80,81,82,83,84,85]]},{type:"MultiPolygon",properties:{name:"The Bahamas"},id:"BHS",arcs:[[[86]],[[87]],[[88]]]},{type:"Polygon",properties:{name:"Bosnia and Herzegovina"},id:"BIH",arcs:[[89,90,91]]},{type:"Polygon",properties:{name:"Belarus"},id:"BLR",arcs:[[92,93,94,95,96]]},{type:"Polygon",properties:{name:"Belize"},id:"BLZ",arcs:[[97,98,99]]},{type:"Polygon",properties:{name:"Bolivia"},id:"BOL",arcs:[[100,101,102,103,-31]]},{type:"Polygon",properties:{name:"Brazil"},id:"BRA",arcs:[[-27,104,-103,105,106,107,108,109,110,111,112]]},{type:"Polygon",properties:{name:"Brunei"},id:"BRN",arcs:[[113,114]]},{type:"Polygon",properties:{name:"Bhutan"},id:"BTN",arcs:[[115,116]]},{type:"Polygon",properties:{name:"Botswana"},id:"BWA",arcs:[[117,118,119,120]]},{type:"Polygon",properties:{name:"Central African Republic"},id:"CAF",arcs:[[121,122,123,124,125,126,127]]},{type:"MultiPolygon",properties:{name:"Canada"},id:"CAN",arcs:[[[128]],[[129]],[[130]],[[131]],[[132]],[[133]],[[134]],[[135]],[[136]],[[137]],[[138,139,140,141]],[[142]],[[143]],[[144]],[[145]],[[146]],[[147]],[[148]],[[149]],[[150]],[[151]],[[152]],[[153]],[[154]],[[155]],[[156]],[[157]],[[158]],[[159]],[[160]]]},{type:"Polygon",properties:{name:"Switzerland"},id:"CHE",arcs:[[-51,161,162,163]]},{type:"MultiPolygon",properties:{name:"Chile"},id:"CHL",arcs:[[[-24,164]],[[-30,165,166,-101]]]},{type:"MultiPolygon",properties:{name:"China"},id:"CHN",arcs:[[[167]],[[168,169,170,171,172,173,-117,174,175,176,177,-4,178,179,180,181,182,183]]]},{type:"Polygon",properties:{name:"Ivory Coast"},id:"CIV",arcs:[[184,185,186,187,-73,188]]},{type:"Polygon",properties:{name:"Cameroon"},id:"CMR",arcs:[[189,190,191,192,193,194,-128,195]]},{type:"Polygon",properties:{name:"Democratic Republic of the Congo"},id:"COD",arcs:[[196,197,-60,198,199,-10,200,-13,201,-126,202]]},{type:"Polygon",properties:{name:"Republic of the Congo"},id:"COG",arcs:[[-12,203,204,-196,-127,-202]]},{type:"Polygon",properties:{name:"Colombia"},id:"COL",arcs:[[205,206,207,208,209,-107,210]]},{type:"Polygon",properties:{name:"Costa Rica"},id:"CRI",arcs:[[211,212,213,214]]},{type:"Polygon",properties:{name:"Cuba"},id:"CUB",arcs:[[215]]},{type:"Polygon",properties:{name:"Northern Cyprus"},id:"-99",arcs:[[216,217]]},{type:"Polygon",properties:{name:"Cyprus"},id:"CYP",arcs:[[218,-218]]},{type:"Polygon",properties:{name:"Czech Republic"},id:"CZE",arcs:[[-53,219,220,221]]},{type:"Polygon",properties:{name:"Germany"},id:"DEU",arcs:[[222,223,-220,-52,-164,224,225,-64,226,227,228]]},{type:"Polygon",properties:{name:"Djibouti"},id:"DJI",arcs:[[229,230,231,232]]},{type:"MultiPolygon",properties:{name:"Denmark"},id:"DNK",arcs:[[[233]],[[-229,234]]]},{type:"Polygon",properties:{name:"Dominican Republic"},id:"DOM",arcs:[[235,236]]},{type:"Polygon",properties:{name:"Algeria"},id:"DZA",arcs:[[237,238,239,240,241,242,243,244]]},{type:"Polygon",properties:{name:"Ecuador"},id:"ECU",arcs:[[245,-206,246]]},{type:"Polygon",properties:{name:"Egypt"},id:"EGY",arcs:[[247,248,249,250,251]]},{type:"Polygon",properties:{name:"Eritrea"},id:"ERI",arcs:[[252,253,254,-233]]},{type:"Polygon",properties:{name:"Spain"},id:"ESP",arcs:[[255,256,257,258]]},{type:"Polygon",properties:{name:"Estonia"},id:"EST",arcs:[[259,260,261]]},{type:"Polygon",properties:{name:"Ethiopia"},id:"ETH",arcs:[[-232,262,263,264,265,266,267,-253]]},{type:"Polygon",properties:{name:"Finland"},id:"FIN",arcs:[[268,269,270,271]]},{type:"MultiPolygon",properties:{name:"Fiji"},id:"FJI",arcs:[[[272]],[[273,274]],[[275,-275]]]},{type:"Polygon",properties:{name:"Falkland Islands"},id:"FLK",arcs:[[276]]},{type:"MultiPolygon",properties:{name:"France"},id:"FRA",arcs:[[[277]],[[278,-225,-163,279,280,-257,281,-66]]]},{type:"Polygon",properties:{name:"French Guiana"},id:"GUF",arcs:[[282,283,284,285,-111]]},{type:"Polygon",properties:{name:"Gabon"},id:"GAB",arcs:[[286,287,-190,-205]]},{type:"MultiPolygon",properties:{name:"United Kingdom"},id:"GBR",arcs:[[[288,289]],[[290]]]},{type:"Polygon",properties:{name:"Georgia"},id:"GEO",arcs:[[291,292,-58,-32,293]]},{type:"Polygon",properties:{name:"Ghana"},id:"GHA",arcs:[[294,-189,-77,295]]},{type:"Polygon",properties:{name:"Guinea"},id:"GIN",arcs:[[296,297,298,299,300,301,-187]]},{type:"Polygon",properties:{name:"Gambia"},id:"GMB",arcs:[[302,303]]},{type:"Polygon",properties:{name:"Guinea Bissau"},id:"GNB",arcs:[[304,305,-300]]},{type:"Polygon",properties:{name:"Equatorial Guinea"},id:"GNQ",arcs:[[306,-191,-288]]},{type:"MultiPolygon",properties:{name:"Greece"},id:"GRC",arcs:[[[307]],[[308,-15,309,-84,310]]]},{type:"Polygon",properties:{name:"Greenland"},id:"GRL",arcs:[[311]]},{type:"Polygon",properties:{name:"Guatemala"},id:"GTM",arcs:[[312,313,-100,314,315,316]]},{type:"Polygon",properties:{name:"Guyana"},id:"GUY",arcs:[[317,318,-109,319]]},{type:"Polygon",properties:{name:"Honduras"},id:"HND",arcs:[[320,321,-316,322,323]]},{type:"Polygon",properties:{name:"Croatia"},id:"HRV",arcs:[[324,-92,325,326,327,328]]},{type:"Polygon",properties:{name:"Haiti"},id:"HTI",arcs:[[-237,329]]},{type:"Polygon",properties:{name:"Hungary"},id:"HUN",arcs:[[-48,330,331,332,333,-329,334]]},{type:"MultiPolygon",properties:{name:"Indonesia"},id:"IDN",arcs:[[[335]],[[336,337]],[[338]],[[339]],[[340]],[[341]],[[342]],[[343]],[[344,345]],[[346]],[[347]],[[348,349]],[[350]]]},{type:"Polygon",properties:{name:"India"},id:"IND",arcs:[[-177,351,-175,-116,-174,352,-80,353,354]]},{type:"Polygon",properties:{name:"Ireland"},id:"IRL",arcs:[[355,-289]]},{type:"Polygon",properties:{name:"Iran"},id:"IRN",arcs:[[356,-6,357,358,359,360,-55,-34,-57,361]]},{type:"Polygon",properties:{name:"Iraq"},id:"IRQ",arcs:[[362,363,364,365,366,367,-360]]},{type:"Polygon",properties:{name:"Iceland"},id:"ISL",arcs:[[368]]},{type:"Polygon",properties:{name:"Israel"},id:"ISR",arcs:[[369,370,371,-252,372,373,374]]},{type:"MultiPolygon",properties:{name:"Italy"},id:"ITA",arcs:[[[375]],[[376]],[[377,378,-280,-162,-50]]]},{type:"Polygon",properties:{name:"Jamaica"},id:"JAM",arcs:[[379]]},{type:"Polygon",properties:{name:"Jordan"},id:"JOR",arcs:[[-370,380,-366,381,382,-372,383]]},{type:"MultiPolygon",properties:{name:"Japan"},id:"JPN",arcs:[[[384]],[[385]],[[386]]]},{type:"Polygon",properties:{name:"Kazakhstan"},id:"KAZ",arcs:[[387,388,389,390,-181,391]]},{type:"Polygon",properties:{name:"Kenya"},id:"KEN",arcs:[[392,393,394,395,-265,396]]},{type:"Polygon",properties:{name:"Kyrgyzstan"},id:"KGZ",arcs:[[-392,-180,397,398]]},{type:"Polygon",properties:{name:"Cambodia"},id:"KHM",arcs:[[399,400,401,402]]},{type:"Polygon",properties:{name:"South Korea"},id:"KOR",arcs:[[403,404]]},{type:"Polygon",properties:{name:"Kosovo"},id:"-99",arcs:[[-18,405,406,407]]},{type:"Polygon",properties:{name:"Kuwait"},id:"KWT",arcs:[[408,409,-364]]},{type:"Polygon",properties:{name:"Laos"},id:"LAO",arcs:[[410,411,-172,412,-401]]},{type:"Polygon",properties:{name:"Lebanon"},id:"LBN",arcs:[[-374,413,414]]},{type:"Polygon",properties:{name:"Liberia"},id:"LBR",arcs:[[415,416,-297,-186]]},{type:"Polygon",properties:{name:"Libya"},id:"LBY",arcs:[[417,-245,418,419,-250,420,421]]},{type:"Polygon",properties:{name:"Sri Lanka"},id:"LKA",arcs:[[422]]},{type:"Polygon",properties:{name:"Lesotho"},id:"LSO",arcs:[[423]]},{type:"Polygon",properties:{name:"Lithuania"},id:"LTU",arcs:[[424,425,426,-93,427]]},{type:"Polygon",properties:{name:"Luxembourg"},id:"LUX",arcs:[[-226,-279,-65]]},{type:"Polygon",properties:{name:"Latvia"},id:"LVA",arcs:[[428,-262,429,-94,-427]]},{type:"Polygon",properties:{name:"Morocco"},id:"MAR",arcs:[[-242,430,431]]},{type:"Polygon",properties:{name:"Moldova"},id:"MDA",arcs:[[432,433]]},{type:"Polygon",properties:{name:"Madagascar"},id:"MDG",arcs:[[434]]},{type:"Polygon",properties:{name:"Mexico"},id:"MEX",arcs:[[435,-98,-314,436,437]]},{type:"Polygon",properties:{name:"Macedonia"},id:"MKD",arcs:[[-408,438,-85,-310,-14]]},{type:"Polygon",properties:{name:"Mali"},id:"MLI",arcs:[[439,-239,440,-74,-188,-302,441]]},{type:"Polygon",properties:{name:"Myanmar"},id:"MMR",arcs:[[442,-78,-353,-173,-412,443]]},{type:"Polygon",properties:{name:"Montenegro"},id:"MNE",arcs:[[444,-326,-91,445,-406,-17]]},{type:"Polygon",properties:{name:"Mongolia"},id:"MNG",arcs:[[446,-183]]},{type:"Polygon",properties:{name:"Mozambique"},id:"MOZ",arcs:[[447,448,449,450,451,452,453,454]]},{type:"Polygon",properties:{name:"Mauritania"},id:"MRT",arcs:[[455,456,457,-240,-440]]},{type:"Polygon",properties:{name:"Malawi"},id:"MWI",arcs:[[-455,458,459]]},{type:"MultiPolygon",properties:{name:"Malaysia"},id:"MYS",arcs:[[[460,461]],[[-349,462,-115,463]]]},{type:"Polygon",properties:{name:"Namibia"},id:"NAM",arcs:[[464,-8,465,-119,466]]},{type:"Polygon",properties:{name:"New Caledonia"},id:"NCL",arcs:[[467]]},{type:"Polygon",properties:{name:"Niger"},id:"NER",arcs:[[-75,-441,-238,-418,468,-194,469,-71]]},{type:"Polygon",properties:{name:"Nigeria"},id:"NGA",arcs:[[470,-72,-470,-193]]},{type:"Polygon",properties:{name:"Nicaragua"},id:"NIC",arcs:[[471,-324,472,-213]]},{type:"Polygon",properties:{name:"Netherlands"},id:"NLD",arcs:[[-227,-63,473]]},{type:"MultiPolygon",properties:{name:"Norway"},id:"NOR",arcs:[[[474,-272,475,476]],[[477]],[[478]],[[479]]]},{type:"Polygon",properties:{name:"Nepal"},id:"NPL",arcs:[[-352,-176]]},{type:"MultiPolygon",properties:{name:"New Zealand"},id:"NZL",arcs:[[[480]],[[481]]]},{type:"MultiPolygon",properties:{name:"Oman"},id:"OMN",arcs:[[[482,483,-22,484]],[[-20,485]]]},{type:"Polygon",properties:{name:"Pakistan"},id:"PAK",arcs:[[-178,-355,486,-358,-5]]},{type:"Polygon",properties:{name:"Panama"},id:"PAN",arcs:[[487,-215,488,-208]]},{type:"Polygon",properties:{name:"Peru"},id:"PER",arcs:[[-167,489,-247,-211,-106,-102]]},{type:"MultiPolygon",properties:{name:"Philippines"},id:"PHL",arcs:[[[490]],[[491]],[[492]],[[493]],[[494]],[[495]],[[496]]]},{type:"MultiPolygon",properties:{name:"Papua New Guinea"},id:"PNG",arcs:[[[497]],[[498]],[[-345,499]],[[500]]]},{type:"Polygon",properties:{name:"Poland"},id:"POL",arcs:[[-224,501,502,-428,-97,503,504,-221]]},{type:"Polygon",properties:{name:"Puerto Rico"},id:"PRI",arcs:[[505]]},{type:"Polygon",properties:{name:"North Korea"},id:"PRK",arcs:[[506,507,-405,508,-169]]},{type:"Polygon",properties:{name:"Portugal"},id:"PRT",arcs:[[-259,509]]},{type:"Polygon",properties:{name:"Paraguay"},id:"PRY",arcs:[[-104,-105,-26]]},{type:"Polygon",properties:{name:"Qatar"},id:"QAT",arcs:[[510,511]]},{type:"Polygon",properties:{name:"Romania"},id:"ROU",arcs:[[512,-434,513,514,-81,515,-333]]},{type:"MultiPolygon",properties:{name:"Russia"},id:"RUS",arcs:[[[516]],[[-503,517,-425]],[[518,519]],[[520]],[[521]],[[522]],[[523]],[[524]],[[525]],[[526,-507,-184,-447,-182,-391,527,-59,-293,528,529,-95,-430,-261,530,-269,-475,531,-520]],[[532]],[[533]],[[534]]]},{type:"Polygon",properties:{name:"Rwanda"},id:"RWA",arcs:[[535,-61,-198,536]]},{type:"Polygon",properties:{name:"Western Sahara"},id:"ESH",arcs:[[-241,-458,537,-431]]},{type:"Polygon",properties:{name:"Saudi Arabia"},id:"SAU",arcs:[[538,-382,-365,-410,539,-512,540,-23,-484,541]]},{type:"Polygon",properties:{name:"Sudan"},id:"SDN",arcs:[[542,543,-123,544,-421,-249,545,-254,-268,546]]},{type:"Polygon",properties:{name:"South Sudan"},id:"SSD",arcs:[[547,-266,-396,548,-203,-125,549,-543]]},{type:"Polygon",properties:{name:"Senegal"},id:"SEN",arcs:[[550,-456,-442,-301,-306,551,-304]]},{type:"MultiPolygon",properties:{name:"Solomon Islands"},id:"SLB",arcs:[[[552]],[[553]],[[554]],[[555]],[[556]]]},{type:"Polygon",properties:{name:"Sierra Leone"},id:"SLE",arcs:[[557,-298,-417]]},{type:"Polygon",properties:{name:"El Salvador"},id:"SLV",arcs:[[558,-317,-322]]},{type:"Polygon",properties:{name:"Somaliland"},id:"-99",arcs:[[-263,-231,559,560]]},{type:"Polygon",properties:{name:"Somalia"},id:"SOM",arcs:[[-397,-264,-561,561]]},{type:"Polygon",properties:{name:"Republic of Serbia"},id:"SRB",arcs:[[-86,-439,-407,-446,-90,-325,-334,-516]]},{type:"Polygon",properties:{name:"Suriname"},id:"SUR",arcs:[[562,-285,563,-283,-110,-319]]},{type:"Polygon",properties:{name:"Slovakia"},id:"SVK",arcs:[[-505,564,-331,-54,-222]]},{type:"Polygon",properties:{name:"Slovenia"},id:"SVN",arcs:[[-49,-335,-328,565,-378]]},{type:"Polygon",properties:{name:"Sweden"},id:"SWE",arcs:[[-476,-271,566]]},{type:"Polygon",properties:{name:"Swaziland"},id:"SWZ",arcs:[[567,-451]]},{type:"Polygon",properties:{name:"Syria"},id:"SYR",arcs:[[-381,-375,-415,568,569,-367]]},{type:"Polygon",properties:{name:"Chad"},id:"TCD",arcs:[[-469,-422,-545,-122,-195]]},{type:"Polygon",properties:{name:"Togo"},id:"TGO",arcs:[[570,-296,-76,-69]]},{type:"Polygon",properties:{name:"Thailand"},id:"THA",arcs:[[571,-462,572,-444,-411,-400]]},{type:"Polygon",properties:{name:"Tajikistan"},id:"TJK",arcs:[[-398,-179,-3,573]]},{type:"Polygon",properties:{name:"Turkmenistan"},id:"TKM",arcs:[[-357,574,-389,575,-1]]},{type:"Polygon",properties:{name:"East Timor"},id:"TLS",arcs:[[576,-337]]},{type:"Polygon",properties:{name:"Trinidad and Tobago"},id:"TTO",arcs:[[577]]},{type:"Polygon",properties:{name:"Tunisia"},id:"TUN",arcs:[[-244,578,-419]]},{type:"MultiPolygon",properties:{name:"Turkey"},id:"TUR",arcs:[[[-294,-36,-361,-368,-570,579]],[[-311,-83,580]]]},{type:"Polygon",properties:{name:"Taiwan"},id:"TWN",arcs:[[581]]},{type:"Polygon",properties:{name:"United Republic of Tanzania"},id:"TZA",arcs:[[-394,582,-448,-460,583,-199,-62,-536,584]]},{type:"Polygon",properties:{name:"Uganda"},id:"UGA",arcs:[[-537,-197,-549,-395,-585]]},{type:"Polygon",properties:{name:"Ukraine"},id:"UKR",arcs:[[-530,585,-514,-433,-513,-332,-565,-504,-96]]},{type:"Polygon",properties:{name:"Uruguay"},id:"URY",arcs:[[-113,586,-28]]},{type:"MultiPolygon",properties:{name:"United States of America"},id:"USA",arcs:[[[587]],[[588]],[[589]],[[590]],[[591]],[[592,-438,593,-139]],[[594]],[[595]],[[596]],[[-141,597]]]},{type:"Polygon",properties:{name:"Uzbekistan"},id:"UZB",arcs:[[-576,-388,-399,-574,-2]]},{type:"Polygon",properties:{name:"Venezuela"},id:"VEN",arcs:[[598,-320,-108,-210]]},{type:"Polygon",properties:{name:"Vietnam"},id:"VNM",arcs:[[599,-402,-413,-171]]},{type:"MultiPolygon",properties:{name:"Vanuatu"},id:"VUT",arcs:[[[600]],[[601]]]},{type:"Polygon",properties:{name:"West Bank"},id:"PSE",arcs:[[-384,-371]]},{type:"Polygon",properties:{name:"Yemen"},id:"YEM",arcs:[[602,-542,-483]]},{type:"Polygon",properties:{name:"South Africa"},id:"ZAF",arcs:[[-467,-118,603,-452,-568,-450,604],[-424]]},{type:"Polygon",properties:{name:"Zambia"},id:"ZMB",arcs:[[-459,-454,605,-120,-466,-7,-200,-584]]},{type:"Polygon",properties:{name:"Zimbabwe"},id:"ZWE",arcs:[[-604,-121,-606,-453]]}]}},arcs:[[[6700,7164],[28,-23],[21,8],[6,27],[22,9],[15,18],[6,47],[23,11],[5,21],[13,-15],[8,-2]],[[6847,7265],[16,-1],[20,-12]],[[6883,7252],[9,-7],[20,19],[9,-12],[9,27],[17,-1],[4,9],[3,24],[12,20],[15,-13],[-3,-18],[9,-3],[-3,-50],[11,-19],[10,12],[12,6],[17,27],[19,-5],[29,0]],[[7082,7268],[5,-17]],[[7087,7251],[-16,-6],[-14,-11],[-32,-7],[-30,-13],[-16,-25],[6,-25],[4,-30],[-14,-25],[1,-22],[-8,-22],[-26,2],[11,-39],[-18,-15],[-12,-35],[2,-36],[-11,-16],[-10,5],[-22,-8],[-3,-16],[-20,0],[-16,-34],[-1,-50],[-36,-24],[-19,5],[-6,-13],[-16,7],[-28,-8],[-47,30]],[[6690,6820],[25,53],[-2,38],[-21,10],[-2,38],[-9,47],[12,32],[-12,9],[7,43],[12,74]],[[5664,4412],[3,-18],[-4,-29],[5,-28],[-4,-22],[3,-20],[-58,1],[-2,-188],[19,-49],[18,-37]],[[5644,4022],[-51,-24],[-67,9],[-19,28],[-113,-3],[-4,-4],[-17,27],[-18,2],[-16,-10],[-14,-12]],[[5325,4035],[-2,38],[4,51],[9,55],[2,25],[9,53],[6,24],[16,39],[9,26],[3,44],[-1,34],[-9,21],[-7,36],[-7,35],[2,12],[8,24],[-8,57],[-6,39],[-14,38],[3,11]],[[5342,4697],[11,8],[8,-1],[10,7],[82,-1],[7,-44],[8,-35],[6,-19],[11,-31],[18,5],[9,8],[16,-8],[4,14],[7,35],[17,2],[2,10],[14,1],[-3,-22],[34,1],[1,-37],[5,-23],[-4,-36],[2,-36],[9,-22],[-1,-70],[7,5],[12,-1],[17,8],[13,-3]],[[5338,4715],[-8,45]],[[5330,4760],[12,25],[8,10],[10,-20]],[[5360,4775],[-10,-12],[-4,-16],[-1,-25],[-7,-7]],[[5571,7530],[-3,-20],[4,-25],[11,-15]],[[5583,7470],[0,-15],[-9,-9],[-2,-19],[-13,-29]],[[5559,7398],[-5,5],[0,13],[-15,19],[-3,29],[2,40],[4,18],[-4,10]],[[5538,7532],[-2,18],[12,29],[1,-11],[8,6]],[[5557,7574],[6,-16],[7,-6],[1,-22]],[[6432,6490],[5,3],[1,-16],[22,9],[23,-2],[17,-1],[19,39],[20,38],[18,37]],[[6557,6597],[5,-20]],[[6562,6577],[4,-47]],[[6566,6530],[-14,0],[-3,-39],[5,-8],[-12,-12],[0,-24],[-8,-24],[-1,-24]],[[6533,6399],[-6,-12],[-83,29],[-11,60],[-1,14]],[[3140,1814],[-17,2],[-30,0],[0,132]],[[3093,1948],[11,-27],[14,-45],[36,-35],[39,-15],[-13,-30],[-26,-2],[-14,20]],[[3258,3743],[51,-96],[23,-9],[34,-44],[29,-23],[4,-26],[-28,-90],[28,-16],[32,-9],[22,10],[25,45],[4,52]],[[3482,3537],[14,11],[14,-34],[-1,-47],[-23,-33],[-19,-24],[-31,-57],[-37,-81]],[[3399,3272],[-7,-47],[-7,-61],[0,-58],[-6,-14],[-2,-38]],[[3377,3054],[-2,-31],[35,-50],[-4,-41],[18,-26],[-2,-29],[-26,-75],[-42,-32],[-55,-12],[-31,6],[6,-36],[-6,-44],[5,-30],[-16,-20],[-29,-8],[-26,21],[-11,-15],[4,-59],[18,-18],[16,19],[8,-31],[-26,-18],[-22,-37],[-4,-59],[-7,-32],[-26,0],[-22,-31],[-8,-44],[28,-43],[26,-12],[-9,-53],[-33,-33],[-18,-70],[-25,-23],[-12,-28],[9,-61],[19,-34],[-12,3]],[[3095,1968],[-26,9],[-67,8],[-11,34],[0,45],[-18,-4],[-10,21],[-3,63],[22,26],[9,37],[-4,30],[15,51],[10,78],[-3,35],[12,11],[-3,22],[-13,12],[10,25],[-13,22],[-6,68],[11,12],[-5,72],[7,61],[7,52],[17,22],[-9,58],[0,54],[21,38],[-1,50],[16,57],[0,55],[-7,11],[-13,102],[17,60],[-2,58],[10,53],[18,56],[20,36],[-9,24],[6,19],[-1,98],[30,29],[10,62],[-3,14]],[[3136,3714],[23,54],[36,-15],[16,-42],[11,47],[32,-2],[4,-13]],[[6210,7485],[39,9]],[[6249,7494],[5,-15],[11,-10],[-6,-15],[15,-21],[-8,-18],[12,-16],[13,-10],[0,-41]],[[6291,7348],[-10,-2]],[[6281,7346],[-11,34],[0,10],[-12,-1],[-9,16],[-5,-1]],[[6244,7404],[-11,17],[-21,15],[3,28],[-5,21]],[[3345,329],[-8,-30],[-8,-27],[-59,8],[-62,-3],[-34,20],[0,2],[-16,17],[63,-2],[60,-6],[20,24],[15,21],[29,-24]],[[577,361],[-53,-8],[-36,21],[-17,21],[-1,3],[-18,16],[17,22],[52,-9],[28,-18],[21,-21],[7,-27]],[[3745,447],[35,-26],[12,-36],[3,-25],[1,-30],[-43,-19],[-45,-15],[-52,-14],[-59,-11],[-65,3],[-37,20],[5,24],[59,16],[24,20],[18,26],[12,22],[17,20],[18,25],[14,0],[41,12],[42,-12]],[[1633,715],[36,-9],[33,10],[-16,-20],[-26,-15],[-39,4],[-27,21],[6,20],[33,-11]],[[1512,716],[43,-23],[-17,3],[-36,5],[-38,17],[20,12],[28,-14]],[[2250,808],[31,-8],[30,7],[17,-34],[-22,5],[-34,-2],[-34,2],[-38,-4],[-28,12],[-15,24],[18,11],[35,-8],[40,-5]],[[3098,866],[4,-27],[-5,-23],[-8,-22],[-33,-8],[-31,-12],[-36,1],[14,24],[-33,-9],[-31,-8],[-21,18],[-2,24],[30,23],[20,7],[32,-2],[8,30],[1,22],[0,47],[16,28],[25,9],[15,-22],[6,-22],[12,-26],[10,-26],[7,-26]],[[3371,1268],[-11,-13],[-21,9],[-23,-6],[-19,-14],[-20,-15],[-14,-17],[-4,-23],[2,-22],[13,-20],[-19,-14],[-26,-4],[-15,-20],[-17,-19],[-17,-25],[-4,-22],[9,-24],[15,-19],[23,-14],[21,-18],[12,-23],[6,-22],[8,-24],[13,-19],[8,-22],[4,-55],[8,-22],[2,-23],[9,-23],[-4,-31],[-15,-24],[-17,-20],[-37,-8],[-12,-21],[-17,-20],[-42,-22],[-37,-9],[-35,-13],[-37,-13],[-22,-24],[-45,-2],[-49,2],[-44,-4],[-47,0],[9,-24],[42,-10],[31,-16],[18,-21],[-31,-19],[-48,6],[-40,-15],[-2,-24],[-1,-23],[33,-20],[6,-22],[35,-22],[59,-9],[50,-16],[40,-19],[50,-18],[70,-10],[68,-16],[47,-17],[52,-20],[27,-28],[13,-22],[34,21],[46,17],[48,19],[58,15],[49,16],[69,1],[68,-8],[56,-14],[18,26],[39,17],[70,1],[55,13],[52,13],[58,8],[62,10],[43,15],[-20,21],[-12,21],[0,22],[-54,-2],[-57,-10],[-54,0],[-8,22],[4,44],[12,13],[40,14],[47,14],[34,17],[33,18],[25,23],[38,10],[38,8],[19,5],[43,2],[41,8],[34,12],[34,14],[30,14],[39,18],[24,20],[26,17],[9,24],[-30,13],[10,25],[18,18],[29,12],[31,14],[28,18],[22,23],[13,28],[21,16],[33,-3],[13,-20],[34,-2],[1,22],[14,23],[30,-6],[7,-22],[33,-3],[36,10],[35,7],[31,-3],[12,-25],[31,20],[28,10],[31,9],[31,8],[29,14],[31,9],[24,13],[17,20],[20,-15],[29,8],[20,-27],[16,-21],[32,11],[12,24],[28,16],[37,-4],[11,-22],[22,22],[30,7],[33,3],[29,-2],[31,-7],[30,-3],[13,-20],[18,-17],[31,10],[32,3],[32,0],[31,1],[28,8],[29,7],[25,16],[26,11],[28,5],[21,17],[15,32],[16,20],[29,-10],[11,-21],[24,-13],[29,4],[19,-21],[21,-15],[28,14],[10,26],[25,10],[29,20],[27,8],[33,11],[22,13],[22,14],[22,13],[26,-7],[25,21],[18,16],[26,-1],[23,14],[6,21],[23,16],[23,11],[28,10],[25,4],[25,-3],[26,-6],[22,-16],[3,-26],[24,-19],[17,-17],[33,-7],[19,-16],[23,-16],[26,-3],[23,11],[24,24],[26,-12],[27,-7],[26,-7],[27,-5],[28,0],[23,-61],[-1,-15],[-4,-27],[-26,-15],[-22,-22],[4,-23],[31,1],[-4,-23],[-14,-22],[-13,-24],[21,-19],[32,-6],[32,11],[15,23],[10,22],[15,18],[17,18],[7,21],[15,29],[18,5],[31,3],[28,7],[28,9],[14,23],[8,22],[19,22],[27,15],[23,12],[16,19],[15,11],[21,9],[27,-6],[25,6],[28,7],[30,-4],[20,17],[14,39],[11,-16],[13,-28],[23,-12],[27,-4],[26,7],[29,-5],[26,-1],[17,6],[24,-4],[21,-12],[25,8],[30,0],[25,8],[29,-8],[19,19],[14,20],[19,16],[35,44],[18,-8],[21,-16],[18,-21],[36,-36],[27,-1],[25,0],[30,7],[30,8],[23,16],[19,18],[31,2],[21,13],[22,-12],[14,-18],[19,-19],[31,2],[19,-15],[33,-15],[35,-5],[29,4],[21,19],[19,18],[25,5],[25,-8],[29,-6],[26,9],[25,0],[24,-6],[26,-5],[25,10],[30,9],[28,3],[32,0],[25,5],[25,5],[8,29],[1,24],[17,-16],[5,-27],[10,-24],[11,-20],[23,-10],[32,4],[36,1],[25,3],[37,0],[26,1],[36,-2],[31,-5],[20,-18],[-5,-22],[18,-18],[30,-13],[31,-15],[35,-11],[38,-9],[28,-9],[32,-2],[18,20],[24,-16],[21,-19],[25,-13],[34,-6],[32,-7],[13,-23],[32,-14],[21,-21],[31,-9],[32,1],[30,-4],[33,1],[34,-4],[31,-8],[28,-14],[29,-12],[20,-17],[-3,-23],[-15,-21],[-13,-27],[-9,-21],[-14,-24],[-36,-9],[-16,-21],[-36,-13],[-13,-23],[-19,-22],[-20,-18],[-11,-25],[-7,-22],[-3,-26],[0,-22],[16,-23],[6,-22],[13,-21],[52,-8],[11,-26],[-50,-9],[-43,-13],[-52,-2],[-24,-34],[-5,-27],[-12,-22],[-14,-22],[37,-20],[14,-24],[24,-22],[33,-20],[39,-19],[42,-18],[64,-19],[14,-29],[80,-12],[5,-5],[21,-17],[77,15],[63,-19],[48,-14],[-9997,-1],[24,35],[50,-19],[3,2],[30,19],[4,0],[3,-1],[40,-25],[35,25],[7,3],[81,11],[27,-14],[13,-7],[41,-20],[79,-15],[63,-18],[107,-14],[80,16],[118,-11],[67,-19],[73,17],[78,17],[6,27],[-110,3],[-89,14],[-24,23],[-74,12],[5,27],[10,24],[10,22],[-5,25],[-46,16],[-22,21],[-43,18],[68,-3],[64,9],[40,-20],[50,18],[45,22],[23,19],[-10,25],[-36,16],[-41,17],[-57,4],[-50,8],[-54,6],[-18,22],[-36,18],[-21,21],[-9,67],[14,-6],[25,-18],[45,6],[44,8],[23,-26],[44,6],[37,13],[35,16],[32,20],[41,5],[-1,22],[-9,22],[8,21],[36,11],[16,-20],[42,12],[32,15],[40,1],[38,6],[37,13],[30,13],[34,13],[22,-4],[19,-4],[41,8],[37,-10],[38,1],[37,8],[37,-6],[41,-6],[39,3],[40,-2],[42,-1],[38,3],[28,17],[34,9],[35,-13],[33,11],[30,21],[18,-19],[9,-21],[18,-19],[29,17],[33,-22],[38,-7],[32,-16],[39,3],[36,11],[41,-3],[38,-8],[38,-10],[15,25],[-18,20],[-14,21],[-36,5],[-15,22],[-6,22],[-10,43],[21,-8],[36,-3],[36,3],[33,-9],[28,-17],[12,-21],[38,-4],[36,9],[38,11],[34,7],[28,-14],[37,5],[24,45],[23,-27],[32,-10],[34,6],[23,-23],[37,-3],[33,-7],[34,-12],[21,22],[11,20],[28,-23],[38,6],[28,-13],[19,-19],[37,5],[29,13],[29,15],[33,8],[39,7],[36,8],[27,13],[16,19],[7,25],[-3,24],[-9,24],[-10,23],[-9,23],[-7,21],[-1,23],[2,23],[13,22],[11,24],[5,23],[-6,26],[-3,23],[14,27],[15,17],[18,22],[19,19],[22,17],[11,25],[15,17],[18,15],[26,3],[18,19],[19,11],[23,7],[20,15],[16,19],[22,7],[16,-15],[-10,-20],[-29,-17]],[[6914,2185],[18,-19],[26,-7],[1,-11],[-7,-27],[-43,-4],[-1,31],[4,25],[2,12]],[[9038,2648],[27,-21],[15,8],[22,12],[16,-4],[2,-70],[-9,-21],[-3,-47],[-10,16],[-19,-41],[-6,3],[-17,2],[-17,50],[-4,39],[-16,52],[1,27],[18,-5]],[[8987,4244],[10,-46],[18,22],[9,-25],[13,-23],[-3,-26],[6,-51],[5,-29],[7,-7],[7,-51],[-3,-30],[9,-40],[31,-31],[19,-28],[19,-26],[-4,-14],[16,-37],[11,-64],[11,13],[11,-26],[7,9],[5,-63],[19,-36],[13,-22],[22,-48],[8,-48],[1,-33],[-2,-37],[13,-50],[-2,-52],[-5,-28],[-7,-52],[1,-34],[-6,-43],[-12,-53],[-21,-29],[-10,-46],[-9,-29],[-8,-51],[-11,-30],[-7,-44],[-4,-41],[2,-18],[-16,-21],[-31,-2],[-26,-24],[-13,-23],[-17,-26],[-23,27],[-17,10],[5,31],[-15,-11],[-25,-43],[-24,16],[-15,9],[-16,4],[-27,17],[-18,37],[-5,45],[-7,30],[-13,24],[-27,7],[9,28],[-7,44],[-13,-41],[-25,-11],[14,33],[5,34],[10,29],[-2,44],[-22,-50],[-18,-21],[-10,-47],[-22,25],[1,31],[-18,43],[-14,22],[5,14],[-36,35],[-19,2],[-27,29],[-50,-6],[-36,-21],[-31,-20],[-27,4],[-29,-30],[-24,-14],[-6,-31],[-10,-24],[-23,-1],[-18,-5],[-24,10],[-20,-6],[-19,-3],[-17,-31],[-8,2],[-14,-16],[-13,-19],[-21,2],[-18,0],[-30,38],[-15,11],[1,34],[14,8],[4,14],[-1,21],[4,41],[-3,35],[-15,60],[-4,33],[1,34],[-11,38],[-1,18],[-12,23],[-4,47],[-16,46],[-4,26],[13,-26],[-10,55],[14,-17],[8,-23],[0,30],[-14,47],[-3,18],[-6,18],[3,34],[6,15],[4,29],[-3,35],[11,42],[2,-45],[12,41],[22,20],[14,25],[21,22],[13,4],[7,-7],[22,22],[17,6],[4,13],[8,6],[15,-2],[29,18],[15,26],[7,31],[17,30],[1,24],[1,32],[19,50],[12,-51],[12,12],[-10,28],[9,29],[12,-13],[3,45],[15,29],[7,23],[14,10],[0,17],[13,-7],[0,15],[12,8],[14,8],[20,-27],[16,-35],[17,0],[18,-6],[-6,33],[13,47],[13,15],[-5,15],[12,34],[17,21],[14,-7],[24,11],[-1,30],[-20,19],[15,9],[18,-15],[15,-24],[23,-15],[8,6],[17,-18],[17,17],[10,-5],[7,11],[12,-29],[-7,-32],[-11,-24],[-9,-2],[3,-23],[-8,-30],[-10,-29],[2,-17],[22,-32],[21,-19],[15,-20],[20,-35],[8,0],[14,-15],[4,-19],[27,-20],[18,20],[6,32],[5,26],[4,33],[8,47],[-4,28],[2,17],[-3,34],[4,45],[5,12],[-4,20],[7,31],[5,32],[1,17],[10,22],[8,-29],[2,-37],[7,-7],[1,-25],[10,-30],[2,-33],[-1,-22]],[[5471,7900],[-2,-24],[-16,0],[6,-13],[-9,-38]],[[5450,7825],[-6,-10],[-24,-1],[-14,-13],[-23,4]],[[5383,7805],[-40,15],[-6,21],[-27,-10],[-4,-12],[-16,9]],[[5290,7828],[-15,1],[-12,11],[4,15],[-1,10]],[[5266,7865],[8,3],[14,-16],[4,16],[25,-3],[20,11],[13,-2],[9,-12],[2,10],[-4,38],[10,8],[10,27]],[[5377,7945],[21,-19],[15,24],[10,5],[22,-18],[13,3],[13,-12]],[[5471,7928],[-3,-7],[3,-21]],[[6281,7346],[-19,8],[-14,27],[-4,23]],[[6349,7527],[15,-31],[14,-42],[13,-2],[8,-16],[-23,-5],[-5,-46],[-4,-21],[-11,-13],[1,-30]],[[6357,7321],[-7,-3],[-17,31],[10,30],[-9,17],[-10,-4],[-33,-44]],[[6249,7494],[6,10],[21,-17],[15,-4],[4,7],[-14,32],[7,9]],[[6288,7531],[8,-2],[19,-36],[13,-4],[4,15],[17,23]],[[5814,4792],[-1,71],[-7,27]],[[5806,4890],[17,-5],[8,34],[15,-4]],[[5846,4915],[1,-23],[6,-14],[1,-19],[-7,-12],[-11,-31],[-10,-22],[-12,-2]],[[5092,8091],[20,-5],[26,12],[17,-25],[16,-14]],[[5171,8059],[-4,-40]],[[5167,8019],[-7,-2],[-3,-33]],[[5157,7984],[-24,26],[-14,-4],[-20,28],[-13,23],[-13,1],[-4,21]],[[5069,8079],[23,12]],[[5074,5427],[-23,-7]],[[5051,5420],[-7,41],[2,136],[-6,12],[-1,29],[-10,21],[-8,17],[3,31]],[[5024,5707],[10,7],[6,26],[13,5],[6,18]],[[5059,5763],[10,17],[10,0],[21,-34]],[[5100,5746],[-1,-19],[6,-35],[-6,-24],[3,-16],[-13,-37],[-9,-18],[-5,-37],[1,-38],[-2,-95]],[[4921,5627],[-19,15],[-13,-2],[-10,-15],[-12,13],[-5,19],[-13,13]],[[4849,5670],[-1,34],[7,26],[-1,20],[23,48],[4,41],[7,14],[14,-8],[11,12],[4,16],[22,26],[5,19],[26,24],[15,9],[7,-12],[18,0]],[[5010,5939],[-2,-28],[3,-27],[16,-39],[1,-28],[32,-14],[-1,-40]],[[5024,5707],[-24,1]],[[5e3,5708],[-13,5],[-9,-9],[-12,4],[-48,-3],[-1,-33],[4,-45]],[[7573,6360],[0,-43],[-10,9],[2,-47]],[[7565,6279],[-8,30],[-1,31],[-6,28],[-11,34],[-26,3],[3,-25],[-9,-32],[-12,12],[-4,-11],[-8,6],[-11,5]],[[7472,6360],[-4,49],[-10,45],[5,35],[-17,16],[6,22],[18,22],[-20,31],[9,40],[22,-26],[14,-3],[2,-41],[26,-8],[26,1],[16,-10],[-13,-50],[-12,-3],[-9,-34],[16,-31],[4,38],[8,0],[14,-93]],[[5629,7671],[8,-25],[11,5],[21,-9],[41,-4],[13,16],[33,13],[20,-21],[17,-6]],[[5793,7640],[-15,-25],[-10,-42],[9,-34]],[[5777,7539],[-24,8],[-28,-18]],[[5725,7529],[0,-30],[-26,-5],[-19,20],[-22,-16],[-21,2]],[[5637,7500],[-2,39],[-14,19]],[[5621,7558],[5,8],[-3,7],[4,19],[11,18],[-14,26],[-2,21],[7,14]],[[2846,6461],[-7,-3],[-7,34],[-10,17],[6,38],[8,-3],[10,-49],[0,-34]],[[2838,6628],[-30,-10],[-2,22],[13,5],[18,-2],[1,-15]],[[2861,6628],[-5,-42],[-5,8],[0,31],[-12,23],[0,7],[22,-27]],[[5527,7708],[10,0],[-7,-26],[14,-23],[-4,-28],[-7,-2]],[[5533,7629],[-5,-6],[-9,-13],[-4,-33]],[[5515,7577],[-25,23],[-10,24],[-11,13],[-12,22],[-6,19],[-14,27],[6,25],[10,-14],[6,12],[13,2],[24,-10],[19,1],[12,-13]],[[5652,8242],[27,0],[30,22],[6,34],[23,19],[-3,26]],[[5735,8343],[17,10],[30,23]],[[5782,8376],[29,-15],[4,-15],[15,7],[27,-14],[3,-27],[-6,-16],[17,-39],[12,-11],[-2,-11],[19,-10],[8,-16],[-11,-13],[-23,2],[-5,-5],[7,-20],[6,-37]],[[5882,8136],[-23,-4],[-9,-13],[-2,-30],[-11,6],[-25,-3],[-7,14],[-11,-10],[-10,8],[-22,1],[-31,15],[-28,4],[-22,-1],[-15,-16],[-13,-2]],[[5653,8105],[-1,26],[-8,27],[17,12],[0,24],[-8,22],[-1,26]],[[2524,6110],[-1,8],[4,3],[5,-7],[10,36],[5,0]],[[2547,6150],[0,-8],[5,-1],[0,-16],[-5,-25],[3,-9],[-3,-21],[2,-6],[-4,-30],[-5,-16],[-5,-1],[-6,-21]],[[2529,5996],[-8,0],[2,67],[1,47]],[[3136,3714],[-20,-8],[-11,82],[-15,66],[9,57],[-15,25],[-4,43],[-13,40]],[[3067,4019],[17,64],[-12,49],[7,20],[-5,22],[10,30],[1,50],[1,41],[6,20],[-24,96]],[[3068,4411],[21,-5],[14,1],[6,18],[25,24],[14,22],[37,10],[-3,-44],[3,-23],[-2,-40],[30,-53],[31,-9],[11,-23],[19,-11],[11,-17],[18,0],[16,-17],[1,-34],[6,-18],[0,-25],[-8,-1],[11,-69],[53,-2],[-4,-35],[3,-23],[15,-16],[6,-37],[-4,-47],[-8,-26],[3,-33],[-9,-12]],[[3384,3866],[-1,18],[-25,30],[-26,1],[-49,-17],[-13,-52],[-1,-32],[-11,-71]],[[3482,3537],[6,34],[3,35],[1,32],[-10,11],[-11,-9],[-10,2],[-4,23],[-2,54],[-5,18],[-19,16],[-11,-12],[-30,11],[2,81],[-8,33]],[[3068,4411],[-15,-11],[-13,7],[2,90],[-23,-35],[-24,2],[-11,31],[-18,4],[5,25],[-15,36],[-11,53],[7,11],[0,25],[17,17],[-3,32],[7,20],[2,28],[32,40],[22,11],[4,9],[25,-2]],[[3058,4804],[13,162],[0,25],[-4,34],[-12,22],[0,42],[15,10],[6,-6],[1,23],[-16,6],[-1,37],[54,-2],[10,21],[7,-19],[6,-35],[5,8]],[[3142,5132],[15,-32],[22,4],[5,18],[21,14],[11,10],[4,25],[19,17],[-1,12],[-24,5],[-3,37],[1,40],[-13,15],[5,6],[21,-8],[22,-15],[8,14],[20,9],[31,23],[10,22],[-3,17]],[[3313,5365],[14,2],[7,-13],[-4,-26],[9,-9],[7,-28],[-8,-20],[-4,-51],[7,-30],[2,-27],[17,-28],[14,-3],[3,12],[8,3],[13,10],[9,16],[15,-5],[7,2]],[[3429,5170],[15,-5],[3,12],[-5,12],[3,17],[11,-5],[13,6],[16,-13]],[[3485,5194],[12,-12],[9,16],[6,-3],[4,-16],[13,4],[11,22],[8,44],[17,54]],[[3565,5303],[9,3],[7,-33],[16,-103],[14,-10],[1,-41],[-21,-48],[9,-18],[49,-9],[1,-60],[21,39],[35,-21],[46,-36],[14,-35],[-5,-32],[33,18],[54,-32],[41,3],[41,-49],[36,-66],[21,-17],[24,-3],[10,-18],[9,-76],[5,-35],[-11,-98],[-14,-39],[-39,-82],[-18,-67],[-21,-51],[-7,-1],[-7,-43],[2,-111],[-8,-91],[-3,-39],[-9,-23],[-5,-79],[-28,-77],[-5,-61],[-22,-26],[-7,-35],[-30,0],[-44,-23],[-19,-26],[-31,-18],[-33,-47],[-23,-58],[-5,-44],[5,-33],[-5,-60],[-6,-28],[-20,-33],[-31,-104],[-24,-47],[-19,-27],[-13,-57],[-18,-33]],[[3517,3063],[-8,33],[13,28],[-16,40],[-22,33],[-29,38],[-10,-2],[-28,46],[-18,-7]],[[8172,5325],[11,22],[23,32]],[[8206,5379],[-1,-29],[-2,-37],[-13,1],[-6,-20],[-12,31]],[[7546,6698],[12,-19],[-2,-36],[-23,-2],[-23,4],[-18,-9],[-25,22],[-1,12]],[[7466,6670],[19,44],[15,15],[20,-14],[14,-1],[12,-16]],[[5817,3752],[-39,-43],[-25,-44],[-10,-40],[-8,-22],[-15,-4],[-5,-29],[-3,-18],[-17,-14],[-23,3],[-13,17],[-12,7],[-14,-14],[-6,-28],[-14,-18],[-13,-26],[-20,-6],[-6,20],[2,36],[-16,56],[-8,9]],[[5552,3594],[0,173],[27,2],[1,210],[21,2],[43,21],[10,-24],[18,23],[9,0],[15,13]],[[5696,4014],[5,-4]],[[5701,4010],[11,-48],[5,-10],[9,-34],[32,-65],[12,-7],[0,-20],[8,-38],[21,-9],[18,-27]],[[5424,5496],[23,4],[5,16],[5,-2],[7,-13],[34,23],[12,23],[15,20],[-3,21],[8,6],[27,-4],[26,27],[20,65],[14,24],[18,10]],[[5635,5716],[3,-26],[16,-36],[0,-25],[-5,-24],[2,-18],[10,-18]],[[5661,5569],[21,-25]],[[5682,5544],[15,-24],[0,-19],[19,-31],[12,-26],[7,-35],[20,-24],[5,-18]],[[5760,5367],[-9,-7],[-18,2],[-21,6],[-10,-5],[-5,-14],[-9,-2],[-10,12],[-31,-29],[-13,6],[-4,-5],[-8,-35],[-21,11],[-20,6],[-18,22],[-23,20],[-15,-19],[-10,-30],[-3,-41]],[[5512,5265],[-18,3],[-19,10],[-16,-32],[-15,-55]],[[5444,5191],[-3,18],[-1,27],[-13,19],[-10,30],[-2,21],[-13,31],[2,18],[-3,25],[2,45],[7,11],[14,60]],[[3231,7808],[20,-8],[26,1],[-14,-24],[-10,-4],[-35,25],[-7,20],[10,18],[10,-28]],[[3283,7958],[-14,-1],[-36,19],[-26,28],[10,5],[37,-15],[28,-25],[1,-11]],[[1569,7923],[-14,-8],[-46,27],[-8,21],[-25,21],[-5,16],[-28,11],[-11,32],[2,14],[30,-13],[17,-9],[26,-6],[9,-21],[14,-28],[28,-24],[11,-33]],[[3440,8052],[-18,-52],[18,20],[19,-12],[-10,-21],[25,-16],[12,14],[28,-18],[-8,-43],[19,10],[4,-32],[8,-36],[-11,-52],[-13,-2],[-18,11],[6,48],[-8,8],[-32,-52],[-17,2],[20,28],[-27,14],[-30,-3],[-54,2],[-4,17],[17,21],[-12,16],[24,36],[28,94],[18,33],[24,21],[13,-3],[-6,-16],[-15,-37]],[[1313,8250],[27,5],[-8,-67],[24,-48],[-11,0],[-17,27],[-10,27],[-14,19],[-5,26],[1,19],[13,-8]],[[2798,8730],[-11,-31],[-12,5],[-8,17],[2,4],[10,18],[12,-1],[7,-12]],[[2725,8762],[-33,-32],[-19,1],[-6,16],[20,27],[38,0],[0,-12]],[[2634,8936],[5,-26],[15,9],[16,-15],[30,-20],[32,-19],[2,-28],[21,5],[20,-20],[-25,-18],[-43,14],[-16,26],[-27,-31],[-40,-31],[-9,35],[-38,-6],[24,30],[4,46],[9,54],[20,-5]],[[2892,9024],[-31,-3],[-7,29],[12,34],[26,8],[21,-17],[1,-25],[-4,-8],[-18,-18]],[[2343,9140],[-17,-21],[-38,18],[-22,-6],[-38,26],[24,19],[19,25],[30,-16],[17,-11],[8,-11],[17,-23]],[[3135,7724],[-18,33],[0,81],[-13,17],[-18,-10],[-10,16],[-21,-45],[-8,-46],[-10,-27],[-12,-9],[-9,-3],[-3,-15],[-51,0],[-42,0],[-12,-11],[-30,-42],[-3,-5],[-9,-23],[-26,0],[-27,0],[-12,-10],[4,-11],[2,-18],[0,-6],[-36,-30],[-29,-9],[-32,-31],[-7,0],[-10,9],[-3,8],[1,6],[6,21],[13,33],[8,35],[-5,51],[-6,53],[-29,28],[3,11],[-4,7],[-8,0],[-5,9],[-2,14],[-5,-6],[-7,2],[1,6],[-6,6],[-3,15],[-21,19],[-23,20],[-27,23],[-26,21],[-25,-17],[-9,0],[-34,15],[-23,-8],[-27,19],[-28,9],[-19,4],[-9,10],[-5,32],[-9,0],[-1,-23],[-57,0],[-95,0],[-94,0],[-84,0],[-83,0],[-82,0],[-85,0],[-27,0],[-82,0],[-79,0]],[[1588,7952],[-4,0],[-54,58],[-20,26],[-50,24],[-15,53],[3,36],[-35,25],[-5,48],[-34,43],[0,30]],[[1374,8295],[15,29],[0,37],[-48,37],[-28,68],[-17,42],[-26,27],[-19,24],[-14,31],[-28,-20],[-27,-33],[-25,39],[-19,26],[-27,16],[-28,2],[0,337],[1,219]],[[1084,9176],[51,-14],[44,-29],[29,-5],[24,24],[34,19],[41,-7],[42,26],[45,14],[20,-24],[20,14],[6,27],[20,-6],[47,-53],[37,40],[3,-45],[34,10],[11,17],[34,-3],[42,-25],[65,-22],[38,-10],[28,4],[37,-30],[-39,-29],[50,-13],[75,7],[24,11],[29,-36],[31,30],[-29,25],[18,20],[34,3],[22,6],[23,-14],[28,-32],[31,5],[49,-27],[43,9],[40,-1],[-3,37],[25,10],[43,-20],[0,-56],[17,47],[23,-1],[12,59],[-30,36],[-32,24],[2,65],[33,43],[37,-9],[28,-26],[38,-67],[-25,-29],[52,-12],[-1,-60],[38,46],[33,-38],[-9,-44],[27,-40],[29,43],[21,51],[1,65],[40,-5],[41,-8],[37,-30],[2,-29],[-21,-31],[20,-32],[-4,-29],[-54,-41],[-39,-9],[-29,18],[-8,-30],[-27,-50],[-8,-26],[-32,-40],[-40,-4],[-22,-25],[-2,-38],[-32,-7],[-34,-48],[-30,-67],[-11,-46],[-1,-69],[40,-10],[13,-55],[13,-45],[39,12],[51,-26],[28,-22],[20,-28],[35,-17],[29,-24],[46,-4],[30,-6],[-4,-51],[8,-59],[21,-66],[41,-56],[21,19],[15,61],[-14,93],[-20,31],[45,28],[31,41],[16,41],[-3,40],[-19,50],[-33,44],[32,62],[-12,54],[-9,92],[19,14],[48,-16],[29,-6],[23,15],[25,-20],[35,-34],[8,-23],[50,-4],[-1,-50],[9,-74],[25,-10],[21,-35],[40,33],[26,65],[19,28],[21,-53],[36,-75],[31,-71],[-11,-37],[37,-33],[25,-34],[44,-15],[18,-19],[11,-50],[22,-8],[11,-22],[2,-67],[-20,-22],[-20,-21],[-46,-21],[-35,-48],[-47,-10],[-59,13],[-42,0],[-29,-4],[-23,-43],[-35,-26],[-40,-78],[-32,-54],[23,9],[45,78],[58,49],[42,6],[24,-29],[-26,-40],[9,-63],[9,-45],[36,-29],[46,8],[28,67],[2,-43],[17,-22],[-34,-38],[-61,-36],[-28,-23],[-31,-43],[-21,4],[-1,50],[48,49],[-44,-2],[-31,-7]],[[1829,9377],[-14,-27],[61,17],[39,-29],[31,30],[26,-20],[23,-58],[14,25],[-20,60],[24,9],[28,-9],[31,-24],[17,-58],[9,-41],[47,-30],[50,-28],[-3,-26],[-46,-4],[18,-23],[-9,-22],[-51,9],[-48,16],[-32,-3],[-52,-20],[-70,-9],[-50,-6],[-15,28],[-38,16],[-24,-6],[-35,47],[19,6],[43,10],[39,-3],[36,11],[-54,13],[-59,-4],[-39,1],[-15,22],[64,23],[-42,-1],[-49,16],[23,44],[20,24],[74,36],[29,-12]],[[2097,9395],[-24,-39],[-44,41],[10,9],[37,2],[21,-13]],[[2879,9376],[3,-16],[-30,2],[-30,1],[-30,-8],[-8,3],[-31,32],[1,21],[14,4],[63,-6],[48,-33]],[[2595,9379],[22,-36],[26,47],[70,24],[48,-61],[-4,-38],[55,17],[26,23],[62,-30],[38,-28],[3,-25],[52,13],[29,-38],[67,-23],[24,-24],[26,-55],[-51,-28],[66,-38],[44,-13],[40,-55],[44,-3],[-9,-42],[-49,-69],[-34,26],[-44,57],[-36,-8],[-3,-34],[29,-34],[38,-27],[11,-16],[18,-58],[-9,-43],[-35,16],[-70,47],[39,-51],[29,-35],[5,-21],[-76,24],[-59,34],[-34,29],[10,17],[-42,30],[-40,29],[0,-18],[-80,-9],[-23,20],[18,44],[52,1],[57,7],[-9,21],[10,30],[36,57],[-8,27],[-11,20],[-42,29],[-57,20],[18,15],[-29,36],[-25,4],[-22,20],[-14,-18],[-51,-7],[-101,13],[-59,17],[-45,9],[-23,21],[29,27],[-39,0],[-9,60],[21,53],[29,24],[72,16],[-21,-39]],[[2212,9420],[33,-12],[50,7],[7,-17],[-26,-28],[42,-26],[-5,-53],[-45,-23],[-27,5],[-19,23],[-69,45],[0,19],[57,-7],[-31,38],[33,29]],[[2411,9357],[-30,-45],[-32,3],[-17,52],[1,29],[14,25],[28,16],[58,-2],[53,-14],[-42,-53],[-33,-11]],[[1654,9275],[-73,-29],[-15,26],[-64,31],[12,25],[19,43],[24,39],[-27,36],[94,10],[39,-13],[71,-3],[27,-17],[30,-25],[-35,-15],[-68,-41],[-34,-42],[0,-25]],[[2399,9487],[-15,-23],[-40,5],[-34,15],[15,27],[40,16],[24,-21],[10,-19]],[[2264,9590],[21,-27],[1,-31],[-13,-44],[-46,-6],[-30,10],[1,34],[-45,-4],[-2,45],[30,-2],[41,21],[40,-4],[2,8]],[[1994,9559],[11,-21],[25,10],[29,-2],[5,-29],[-17,-28],[-94,-10],[-70,-25],[-43,-2],[-3,20],[57,26],[-125,-7],[-39,10],[38,58],[26,17],[78,-20],[50,-35],[48,-5],[-40,57],[26,21],[29,-7],[9,-28]],[[2370,9612],[30,-19],[55,0],[24,-19],[-6,-22],[32,-14],[17,-14],[38,-2],[40,-5],[44,13],[57,5],[45,-5],[30,-22],[6,-24],[-17,-16],[-42,-13],[-35,8],[-80,-10],[-57,-1],[-45,8],[-74,19],[-9,32],[-4,29],[-27,26],[-58,7],[-32,19],[10,24],[58,-4]],[[1772,9645],[-4,-46],[-21,-20],[-26,-3],[-52,-26],[-44,-9],[-38,13],[47,44],[57,39],[43,-1],[38,9]],[[2393,9637],[-13,-2],[-52,4],[-7,17],[56,-1],[19,-11],[-3,-7]],[[1939,9648],[-52,-17],[-41,19],[23,19],[40,6],[39,-10],[-9,-17]],[[1954,9701],[-34,-11],[-46,0],[0,8],[29,18],[14,-3],[37,-12]],[[2338,9669],[-41,-12],[-23,13],[-12,23],[-2,24],[36,-2],[16,-4],[33,-21],[-7,-21]],[[2220,9685],[11,-25],[-45,7],[-46,19],[-62,2],[27,18],[-34,14],[-2,22],[55,-8],[75,-21],[21,-28]],[[2583,9764],[33,-20],[-38,-17],[-51,-45],[-50,-4],[-57,8],[-30,24],[0,21],[22,16],[-50,0],[-31,19],[-18,27],[20,26],[19,18],[28,4],[-12,14],[65,3],[35,-32],[47,-12],[46,-11],[22,-39]],[[3097,9967],[74,-4],[60,-8],[51,-16],[-2,-16],[-67,-25],[-68,-12],[-25,-14],[61,1],[-66,-36],[-45,-17],[-48,-48],[-57,-10],[-18,-12],[-84,-6],[39,-8],[-20,-10],[23,-29],[-26,-21],[-43,-16],[-13,-24],[-39,-17],[4,-14],[48,3],[0,-15],[-74,-35],[-73,16],[-81,-9],[-42,7],[-52,3],[-4,29],[52,13],[-14,43],[17,4],[74,-26],[-38,38],[-45,11],[23,23],[49,14],[8,21],[-39,23],[-12,31],[76,-3],[22,-6],[43,21],[-62,7],[-98,-4],[-49,20],[-23,24],[-32,17],[-6,21],[41,11],[32,2],[55,9],[41,22],[34,-3],[30,-16],[21,32],[37,9],[50,7],[85,2],[14,-6],[81,10],[60,-4],[60,-4]],[[5290,7828],[-3,-24],[-12,-10],[-20,7],[-6,-24],[-14,-2],[-5,10],[-15,-20],[-13,-3],[-12,13]],[[5190,7775],[-10,25],[-13,-9],[0,27],[21,33],[-1,15],[12,-5],[8,10]],[[5207,7871],[24,-1],[5,13],[30,-18]],[[3140,1814],[-10,-24],[-23,-18],[-14,2],[-16,5],[-21,18],[-29,8],[-35,33],[-28,32],[-38,66],[23,-12],[39,-40],[36,-21],[15,27],[9,41],[25,24],[20,-7]],[[3095,1968],[-25,0],[-13,-14],[-25,-22],[-5,-55],[-11,-1],[-32,19],[-32,41],[-34,34],[-9,37],[8,35],[-14,39],[-4,101],[12,57],[30,45],[-43,18],[27,52],[9,98],[31,-21],[15,123],[-19,15],[-9,-73],[-17,8],[9,84],[9,110],[13,40],[-8,58],[-2,66],[11,2],[17,96],[20,94],[11,88],[-6,89],[8,49],[-3,72],[16,73],[5,114],[9,123],[9,132],[-2,96],[-6,84]],[[3045,3974],[14,15],[8,30]],[[8064,6161],[-24,-28],[-23,18],[0,51],[13,26],[31,17],[16,-1],[6,-23],[-12,-26],[-7,-34]],[[8628,7562],[-18,35],[-11,-33],[-43,-26],[4,-31],[-24,2],[-13,19],[-19,-42],[-30,-32],[-23,-38]],[[8451,7416],[-39,-17],[-20,-27],[-30,-17],[15,28],[-6,23],[22,40],[-15,30],[-24,-20],[-32,-41],[-17,-39],[-27,-2],[-14,-28],[15,-40],[22,-10],[1,-26],[22,-17],[31,42],[25,-23],[18,-2],[4,-31],[-39,-16],[-13,-32],[-27,-30],[-14,-41],[30,-33],[11,-58],[17,-54],[18,-45],[0,-44],[-17,-16],[6,-32],[17,-18],[-5,-48],[-7,-47],[-15,-5],[-21,-64],[-22,-78],[-26,-70],[-38,-55],[-39,-50],[-31,-6],[-17,-27],[-10,20],[-15,-30],[-39,-29],[-29,-9],[-10,-63],[-15,-3],[-8,43],[7,22],[-37,19],[-13,-9]],[[8001,6331],[-28,15],[-14,24],[5,34],[-26,11],[-13,22],[-24,-31],[-27,-7],[-22,0],[-15,-14]],[[7837,6385],[-14,-9],[4,-68],[-15,2],[-2,14]],[[7810,6324],[-1,24],[-20,-17],[-12,11],[-21,22],[8,49],[-18,12],[-6,54],[-30,-10],[4,70],[26,50],[1,48],[-1,46],[-12,14],[-9,35],[-16,-5]],[[7703,6727],[-30,9],[9,25],[-13,36],[-20,-24],[-23,14],[-32,-37],[-25,-44],[-23,-8]],[[7466,6670],[-2,47],[-17,-13]],[[7447,6704],[-32,6],[-32,14],[-22,26],[-22,11],[-9,29],[-16,8],[-28,39],[-22,18],[-12,-14]],[[7252,6841],[-38,41],[-28,37],[-7,65],[20,-7],[1,30],[-12,30],[3,48],[-30,69]],[[7161,7154],[-45,24],[-8,46],[-21,27]],[[7082,7268],[-4,34],[1,23],[-17,13],[-9,-6],[-7,55]],[[7046,7387],[8,13],[-4,14],[26,28],[20,12],[29,-8],[11,38],[35,7],[10,23],[44,32],[4,13]],[[7229,7559],[-2,34],[19,15],[-25,103],[55,24],[14,13],[20,106],[55,-20],[15,27],[2,59],[23,6],[21,39]],[[7426,7965],[11,5]],[[7437,7970],[7,-41],[23,-32],[40,-22],[19,-47],[-10,-70],[10,-25],[33,-10],[37,-8],[33,-37],[18,-7],[12,-54],[17,-35],[30,1],[58,-13],[36,8],[28,-9],[41,-36],[34,0],[12,-18],[32,32],[45,20],[42,2],[32,21],[20,32],[20,20],[-5,19],[-9,23],[15,38],[15,-5],[29,-12],[28,31],[42,23],[20,39],[20,17],[40,8],[22,-7],[3,21],[-25,41],[-22,19],[-22,-22],[-27,10],[-16,-8],[-7,24],[20,59],[13,45]],[[8240,8005],[34,-23],[39,38],[-1,26],[26,62],[15,19],[0,33],[-16,14],[23,29],[35,11],[37,2],[41,-18],[25,-22],[17,-59],[10,-26],[10,-36],[10,-58],[49,-19],[32,-42],[12,-55],[42,0],[24,23],[46,17],[-15,-53],[-11,-21],[-9,-65],[-19,-58],[-33,11],[-24,-21],[7,-51],[-4,-69],[-14,-2],[0,-30]],[[4920,5353],[-12,-1],[-20,12],[-18,-1],[-33,-10],[-19,-18],[-27,-21],[-6,1]],[[4785,5315],[2,49],[3,7],[-1,24],[-12,24],[-8,4],[-8,17],[6,26],[-3,28],[1,18]],[[4765,5512],[5,0],[1,25],[-2,12],[3,8],[10,7],[-7,47],[-6,25],[2,20],[5,4]],[[4776,5660],[4,6],[8,-9],[21,-1],[5,18],[5,-1],[8,6],[4,-25],[7,7],[11,9]],[[4921,5627],[7,-84],[-11,-50],[-8,-66],[12,-51],[-1,-23]],[[5363,5191],[-4,4],[-16,-8],[-17,8],[-13,-4]],[[5313,5191],[-45,1]],[[5268,5192],[4,47],[-11,39],[-13,10],[-6,27],[-7,8],[1,16]],[[5236,5339],[7,42],[13,57],[8,1],[17,34],[10,1],[16,-24],[19,20],[2,25],[7,23],[4,30],[15,25],[5,41],[6,13],[4,31],[7,37],[24,46],[1,20],[3,10],[-11,24]],[[5393,5795],[1,19],[8,3]],[[5402,5817],[11,-38],[2,-39],[-1,-39],[15,-54],[-15,1],[-8,-4],[-13,6],[-6,-28],[16,-35],[13,-10],[3,-24],[9,-41],[-4,-16]],[[5444,5191],[-2,-31],[-22,14],[-22,15],[-35,2]],[[5856,5265],[-2,-69],[11,-8],[-9,-21],[-10,-16],[-11,-31],[-6,-27],[-1,-48],[-7,-22],[0,-45]],[[5821,4978],[-8,-16],[-1,-35],[-4,-5],[-2,-32]],[[5814,4792],[5,-55],[-2,-30],[5,-35],[16,-33],[15,-74]],[[5853,4565],[-11,6],[-37,-10],[-7,-7],[-8,-38],[6,-26],[-5,-70],[-3,-59],[7,-11],[19,-23],[8,11],[2,-64],[-21,1],[-11,32],[-10,25],[-22,9],[-6,31],[-17,-19],[-22,8],[-10,27],[-17,6],[-13,-2],[-2,19],[-9,1]],[[5342,4697],[-4,18]],[[5360,4775],[8,-6],[9,23],[15,-1],[2,-17],[11,-10],[16,37],[16,29],[7,19],[-1,48],[12,58],[13,30],[18,29],[3,18],[1,22],[5,21],[-2,33],[4,52],[5,37],[8,32],[2,36]],[[5760,5367],[17,-49],[12,-7],[8,10],[12,-4],[16,12],[6,-25],[25,-39]],[[5330,4760],[-22,62]],[[5308,4822],[21,33],[-11,39],[10,15],[19,7],[2,26],[15,-28],[24,-2],[9,27],[3,40],[-3,46],[-13,35],[12,68],[-7,12],[-21,-5],[-7,31],[2,25]],[[2906,5049],[-12,14],[-14,19],[-7,-9],[-24,8],[-7,25],[-5,-1],[-28,34]],[[2809,5139],[-3,18],[10,5],[-1,29],[6,22],[14,4],[12,37],[10,31],[-10,14],[5,34],[-6,54],[6,16],[-4,50],[-12,31]],[[2836,5484],[4,29],[9,-4],[5,17],[-6,35],[3,9]],[[2851,5570],[14,-2],[21,41],[12,6],[0,20],[5,50],[16,27],[17,1],[3,13],[21,-5],[22,30],[11,13],[14,28],[9,-3],[8,-16],[-6,-20]],[[3018,5753],[-18,-10],[-7,-29],[-10,-17],[-8,-22],[-4,-42],[-8,-35],[15,-4],[3,-27],[6,-13],[3,-24],[-4,-22],[1,-12],[7,-5],[7,-20],[36,5],[16,-7],[19,-51],[11,6],[20,-3],[16,7],[10,-10],[-5,-32],[-6,-20],[-2,-42],[5,-40],[8,-17],[1,-13],[-14,-30],[10,-13],[8,-21],[8,-58]],[[3058,4804],[-14,31],[-8,1],[18,61],[-21,27],[-17,-5],[-10,10],[-15,-15],[-21,7],[-16,62],[-13,15],[-9,28],[-19,28],[-7,-5]],[[2695,5543],[-15,14],[-6,12],[4,10],[-1,13],[-8,14],[-11,12],[-10,8],[-1,17],[-8,10],[2,-17],[-5,-14],[-7,17],[-9,5],[-4,12],[1,18],[3,19],[-8,8],[7,12]],[[2619,5713],[4,7],[18,-15],[7,7],[9,-5],[4,-12],[8,-4],[7,13]],[[2676,5704],[7,-32],[11,-24],[13,-25]],[[2707,5623],[-11,-6],[0,-23],[6,-9],[-4,-7],[1,-11],[-2,-12],[-2,-12]],[[2715,6427],[23,-4],[22,0],[26,-21],[11,-21],[26,6],[10,-13],[24,-37],[17,-27],[9,1],[17,-12],[-2,-17],[20,-2],[21,-24],[-3,-14],[-19,-7],[-18,-3],[-19,4],[-40,-5],[18,32],[-11,16],[-18,4],[-9,17],[-7,33],[-16,-2],[-26,16],[-8,12],[-36,10],[-10,11],[11,15],[-28,3],[-20,-31],[-11,-1],[-4,-14],[-14,-7],[-12,6],[15,18],[6,22],[13,13],[14,11],[21,6],[7,6]],[[5909,7133],[2,1],[4,14],[20,-1],[25,18],[-19,-25],[2,-11]],[[5943,7129],[-3,2],[-5,-5],[-4,1],[-2,-2],[0,6],[-2,4],[-6,0],[-7,-5],[-5,3]],[[5943,7129],[1,-5],[-28,-24],[-14,8],[-7,23],[14,2]],[[5377,7945],[-16,25],[-14,15],[-3,25],[-5,17],[21,13],[10,15],[20,11],[7,11],[7,-6],[13,6]],[[5417,8077],[13,-19],[21,-5],[-2,-17],[15,-12],[4,15],[19,-6],[3,-19],[20,-3],[13,-29]],[[5523,7982],[-8,0],[-4,-11],[-7,-3],[-2,-13],[-5,-3],[-1,-5],[-9,-7],[-12,1],[-4,-13]],[[5275,8306],[1,-23],[28,-14],[-1,-21],[29,11],[15,16],[32,-23],[13,-19]],[[5392,8233],[6,-30],[-8,-16],[11,-21],[6,-31],[-2,-21],[12,-37]],[[5207,7871],[3,42],[14,40],[-40,11],[-13,16]],[[5171,7980],[2,26],[-6,13]],[[5171,8059],[-5,62],[17,0],[7,22],[6,54],[-5,20]],[[5191,8217],[6,13],[23,3],[5,-13],[19,29],[-6,22],[-2,34]],[[5236,8305],[21,-8],[18,9]],[[6196,5808],[7,-19],[-1,-24],[-16,-14],[12,-16]],[[6198,5735],[-10,-32]],[[6188,5703],[-7,11],[-6,-5],[-16,1],[0,18],[-2,17],[9,27],[10,26]],[[6176,5798],[12,-5],[8,15]],[[5352,8343],[-17,-48],[-29,33],[-4,25],[41,19],[9,-29]],[[5236,8305],[-11,32],[-1,61],[5,16],[8,17],[24,4],[10,16],[22,17],[-1,-30],[-8,-20],[4,-16],[15,-9],[-7,-22],[-8,6],[-20,-42],[7,-29]],[[3008,6222],[3,10],[22,0],[16,-15],[8,1],[5,-21],[15,1],[-1,-17],[12,-2],[14,-22],[-10,-24],[-14,13],[-12,-3],[-9,3],[-5,-11],[-11,-3],[-4,14],[-10,-8],[-11,-41],[-7,10],[-1,17]],[[3008,6124],[0,16],[-7,17],[7,10],[2,23],[-2,32]],[[5333,6444],[-95,-112],[-81,-117],[-39,-26]],[[5118,6189],[-31,-6],[0,38],[-13,10],[-17,16],[-7,28],[-94,129],[-93,129]],[[4863,6533],[-105,143]],[[4758,6676],[1,11],[0,4]],[[4759,6691],[0,70],[44,44],[28,9],[23,16],[11,29],[32,24],[1,44],[16,5],[13,22],[36,9],[5,23],[-7,13],[-10,62],[-1,36],[-11,38]],[[4939,7135],[27,32],[30,11],[17,24],[27,18],[47,11],[46,4],[14,-8],[26,23],[30,0],[11,-13],[19,3]],[[5233,7240],[-5,-30],[4,-56],[-6,-49],[-18,-33],[3,-45],[23,-35],[0,-14],[17,-24],[12,-106]],[[5263,6848],[9,-52],[1,-28],[-5,-48],[2,-27],[-3,-32],[2,-37],[-11,-25],[17,-43],[1,-25],[10,-33],[13,11],[22,-28],[12,-37]],[[2769,4856],[15,45],[-6,25],[-11,-27],[-16,26],[5,16],[-4,54],[9,9],[5,37],[11,38],[-2,24],[15,13],[19,23]],[[2906,5049],[4,-45],[-9,-39],[-30,-62],[-33,-23],[-17,-51],[-6,-40],[-15,-24],[-12,29],[-11,7],[-12,-5],[-1,22],[8,14],[-3,24]],[[5969,6800],[-7,-23],[-6,-45],[-8,-31],[-6,-10],[-10,19],[-12,26],[-20,85],[-3,-5],[12,-63],[17,-59],[21,-92],[10,-32],[9,-34],[25,-65],[-6,-10],[1,-39],[33,-53],[4,-12]],[[6023,6357],[-110,0],[-107,0],[-112,0]],[[5694,6357],[0,218],[0,210],[-8,47],[7,37],[-5,25],[10,29]],[[5698,6923],[37,0],[27,-15],[28,-18],[13,-9],[21,19],[11,17],[25,5],[20,-8],[7,-29],[7,19],[22,-14],[22,-3],[13,15]],[[5951,6902],[18,-102]],[[6176,5798],[-10,20],[-11,34],[-12,19],[-8,21],[-24,23],[-19,1],[-7,12],[-16,-14],[-17,27],[-8,-44],[-33,13]],[[6011,5910],[-3,23],[12,87],[3,39],[9,18],[20,10],[14,34]],[[6066,6121],[16,-69],[8,-54],[15,-29],[38,-55],[16,-34],[15,-34],[8,-20],[14,-18]],[[4749,7532],[1,42],[-11,25],[39,43],[34,-11],[37,1],[30,-10],[23,3],[45,-2]],[[4947,7623],[11,-23],[51,-27],[10,13],[31,-27],[32,8]],[[5082,7567],[2,-35],[-26,-39],[-36,-12],[-2,-20],[-18,-33],[-10,-48],[11,-34],[-16,-26],[-6,-39],[-21,-11],[-20,-46],[-35,-1],[-27,1],[-17,-21],[-11,-22],[-13,5],[-11,20],[-8,34],[-26,9]],[[4792,7249],[-2,20],[10,22],[4,16],[-9,17],[7,39],[-11,36],[12,5],[1,27],[5,9],[0,46],[13,16],[-8,30],[-16,2],[-5,-8],[-16,0],[-7,29],[-11,-8],[-10,-15]],[[5675,8472],[3,35],[-10,-8],[-18,21],[-2,34],[35,17],[35,8],[30,-10],[29,2]],[[5777,8571],[4,-10],[-20,-34],[8,-55],[-12,-19]],[[5757,8453],[-22,0],[-24,22],[-13,7],[-23,-10]],[[6188,5703],[-6,-21],[10,-32],[10,-29],[11,-21],[90,-70],[24,0]],[[6327,5530],[-79,-177],[-36,-3],[-25,-41],[-17,-1],[-8,-19]],[[6162,5289],[-19,0],[-11,20],[-26,-25],[-8,-24],[-18,4],[-6,7],[-7,-1],[-9,0],[-35,50],[-19,0],[-10,20],[0,33],[-14,10]],[[5980,5383],[-17,64],[-12,14],[-5,23],[-14,29],[-17,4],[9,34],[15,2],[4,18]],[[5943,5571],[0,53]],[[5943,5624],[8,62],[13,16],[3,24],[12,45],[17,30],[11,58],[4,51]],[[5794,9138],[-4,-42],[42,-39],[-26,-45],[33,-67],[-19,-51],[25,-43],[-11,-39],[41,-40],[-11,-31],[-25,-34],[-60,-75]],[[5779,8632],[-50,-5],[-49,-21],[-45,-13],[-16,32],[-27,20],[6,58],[-14,53],[14,35],[25,37],[63,64],[19,12],[-3,25],[-39,28]],[[5663,8957],[-9,23],[-1,91],[-43,40],[-37,29]],[[5573,9140],[17,16],[30,-32],[37,3],[30,-14],[26,26],[14,44],[43,20],[35,-24],[-11,-41]],[[9954,4033],[9,-17],[-4,-31],[-17,-8],[-16,7],[-2,26],[10,21],[13,-8],[7,10]],[[0,4079],[9981,-14],[-17,-13],[-4,23],[14,12],[9,3],[-9983,18]],[[0,4108],[0,-29]],[[0,4108],[6,3],[-4,-28],[-2,-4]],[[3300,1994],[33,36],[24,-15],[16,24],[22,-27],[-8,-21],[-37,-17],[-13,20],[-23,-26],[-14,26]],[[5265,7548],[-9,-46],[-13,12],[-6,40],[5,22],[18,22],[5,-50]],[[5157,7984],[6,-6],[8,2]],[[5190,7775],[-2,-17],[9,-22],[-10,-18],[7,-46],[15,-8],[-3,-25]],[[5206,7639],[-25,-34],[-55,16],[-40,-19],[-4,-35]],[[4947,7623],[14,35],[5,118],[-28,62],[-21,30],[-42,23],[-3,43],[36,12],[47,-15],[-9,67],[26,-25],[65,46],[8,48],[24,12]],[[3485,5194],[7,25],[3,27]],[[3495,5246],[4,26],[-10,34]],[[3489,5306],[-3,41],[15,51]],[[3501,5398],[9,-7],[21,-14],[29,-50],[5,-24]],[[5308,4822],[-29,60],[-18,49],[-17,61],[1,19],[6,19],[7,43],[5,44]],[[5263,5117],[10,4],[40,-1],[0,71]],[[4827,8240],[-21,12],[-17,-1],[6,32],[-6,32]],[[4789,8315],[23,2],[30,-37],[-15,-40]],[[4916,8521],[-30,-63],[29,8],[30,-1],[-7,-48],[-25,-53],[29,-4],[2,-6],[25,-69],[19,-10],[17,-67],[8,-24],[33,-11],[-3,-38],[-14,-17],[11,-30],[-25,-31],[-37,0],[-48,-16],[-13,12],[-18,-28],[-26,7],[-19,-23],[-15,12],[41,62],[25,13],[-1,0],[-43,9],[-8,24],[29,18],[-15,32],[5,39],[42,-6],[4,35],[-19,36],[0,1],[-34,10],[-7,16],[10,27],[-9,16],[-15,-28],[-1,57],[-14,30],[10,61],[21,48],[23,-4],[33,4]],[[6154,7511],[4,26],[-7,40],[-16,22],[-16,6],[-10,19]],[[6109,7624],[4,6],[23,-10],[41,-9],[38,-28],[5,-11],[17,9],[25,-13],[9,-24],[17,-13]],[[6210,7485],[-27,29],[-29,-3]],[[5029,5408],[-44,-35],[-15,-20],[-25,-17],[-25,17]],[[5e3,5708],[-2,-18],[12,-30],[0,-43],[2,-47],[7,-21],[-6,-54],[2,-29],[8,-37],[6,-21]],[[4765,5512],[-8,1],[-5,-24],[-8,1],[-6,12],[2,24],[-11,36],[-8,-7],[-6,-1]],[[4715,5554],[-7,-3],[0,21],[-4,16],[0,17],[-6,25],[-7,21],[-23,0],[-6,-11],[-8,-1],[-4,-13],[-4,-17],[-14,-26]],[[4632,5583],[-13,35],[-10,24],[-8,7],[-6,12],[-4,26],[-4,13],[-8,10]],[[4579,5710],[13,29],[8,-2],[7,10],[6,0],[5,8],[-3,20],[3,6],[1,20]],[[4619,5801],[13,-1],[20,-14],[6,1],[3,7],[15,-5],[4,4]],[[4680,5793],[1,-22],[5,0],[7,8],[5,-2],[7,-15],[12,-5],[8,13],[9,8],[6,8],[6,-1],[6,-13],[3,-17],[12,-24],[-6,-16],[-1,-19],[6,6],[3,-7],[-1,-17],[8,-18]],[[4532,5834],[3,27]],[[4535,5861],[31,1],[6,14],[9,1],[11,-14],[8,-1],[9,10],[6,-17],[-12,-13],[-12,1],[-12,13],[-10,-14],[-5,-1],[-7,-8],[-25,1]],[[4579,5710],[-15,24],[-11,4],[-7,17],[1,9],[-9,13],[-2,12]],[[4536,5789],[15,10],[9,-2],[8,7],[51,-3]],[[5263,5117],[-5,9],[10,66]],[[5658,7167],[15,-20],[22,3],[20,-4],[0,-10],[15,7],[-4,-18],[-40,-5],[1,10],[-34,12],[5,25]],[[5723,7469],[-17,2],[-14,6],[-34,-16],[19,-33],[-14,-10],[-15,0],[-15,31],[-5,-13],[6,-36],[14,-27],[-10,-13],[15,-27],[14,-18],[0,-33],[-25,16],[8,-30],[-18,-7],[11,-52],[-19,-1],[-23,26],[-10,47],[-5,40],[-11,27],[-14,34],[-2,16]],[[5583,7470],[18,6],[11,13],[15,-2],[5,11],[5,2]],[[5725,7529],[13,-16],[-8,-37],[-7,-7]],[[3701,9939],[93,35],[97,-2],[36,21],[98,6],[222,-7],[174,-47],[-52,-23],[-106,-3],[-150,-5],[14,-11],[99,7],[83,-21],[54,18],[23,-21],[-30,-34],[71,22],[135,23],[83,-12],[15,-25],[-113,-42],[-16,-14],[-88,-10],[64,-3],[-32,-43],[-23,-38],[1,-66],[33,-38],[-43,-3],[-46,-19],[52,-31],[6,-50],[-30,-6],[36,-50],[-61,-5],[32,-24],[-9,-20],[-39,-10],[-39,0],[35,-40],[0,-26],[-55,24],[-14,-15],[37,-15],[37,-36],[10,-48],[-49,-11],[-22,22],[-34,34],[10,-40],[-33,-31],[73,-2],[39,-3],[-75,-52],[-75,-46],[-81,-21],[-31,0],[-29,-23],[-38,-62],[-60,-42],[-19,-2],[-37,-15],[-40,-13],[-24,-37],[0,-41],[-15,-39],[-45,-47],[11,-47],[-12,-48],[-14,-58],[-39,-4],[-41,49],[-56,0],[-27,32],[-18,58],[-49,73],[-14,39],[-3,53],[-39,54],[10,44],[-18,21],[27,69],[42,22],[11,25],[6,46],[-32,-21],[-15,-9],[-25,-8],[-34,19],[-2,40],[11,31],[25,1],[57,-15],[-48,37],[-24,20],[-28,-8],[-23,15],[31,55],[-17,22],[-22,41],[-34,62],[-35,23],[0,25],[-74,34],[-59,5],[-74,-3],[-68,-4],[-32,19],[-49,37],[73,19],[56,3],[-119,15],[-62,24],[3,23],[106,28],[101,29],[11,21],[-75,22],[24,23],[97,41],[40,7],[-12,26],[66,16],[86,9],[85,1],[30,-19],[74,33],[66,-22],[39,-5],[58,-19],[-66,32],[4,25]],[[2497,5869],[-14,10],[-17,1],[-13,12],[-15,24]],[[2438,5916],[1,18],[3,13],[-4,12],[13,48],[36,0],[1,20],[-5,4],[-3,12],[-10,14],[-11,20],[13,0],[0,33],[26,0],[26,0]],[[2529,5996],[10,-11],[2,9],[8,-7]],[[2549,5987],[-13,-23],[-13,-16],[-2,-12],[2,-11],[-5,-15]],[[2518,5910],[-7,-4],[2,-7],[-6,-6],[-9,-15],[-1,-9]],[[3340,5552],[18,-22],[17,-38],[1,-31],[10,-1],[15,-29],[11,-21]],[[3412,5410],[-4,-53],[-17,-15],[1,-14],[-5,-31],[13,-42],[9,-1],[3,-33],[17,-51]],[[3313,5365],[-19,45],[7,16],[0,27],[17,10],[7,11],[-10,22],[3,21],[22,35]],[[2574,5825],[-5,18],[-8,5]],[[2561,5848],[2,24],[-4,6],[-6,4],[-12,-7],[-1,8],[-8,10],[-6,12],[-8,5]],[[2549,5987],[3,-3],[6,11],[8,1],[3,-5],[4,3],[13,-6],[13,2],[9,6],[3,7],[9,-3],[6,-4],[8,1],[5,5],[13,-8],[4,-1],[9,-11],[8,-13],[10,-9],[7,-17]],[[2690,5943],[-9,2],[-4,-8],[-10,-8],[-7,0],[-6,-8],[-6,3],[-4,9],[-3,-2],[-4,-14],[-3,1],[0,-12],[-10,-17],[-5,-7],[-3,-7],[-8,12],[-6,-16],[-6,1],[-6,-2],[0,-29],[-4,0],[-3,-14],[-9,-2]],[[5522,7770],[7,-23],[9,-17],[-11,-22]],[[5515,7577],[-3,-10]],[[5512,7567],[-26,22],[-16,21],[-26,18],[-23,43],[6,5],[-13,25],[-1,19],[-17,10],[-9,-26],[-8,20],[0,21],[1,1]],[[5380,7746],[20,-2],[5,9],[9,-9],[11,-1],[0,16],[10,6],[2,24],[23,16]],[[5460,7805],[8,-7],[21,-26],[23,-11],[10,9]],[[3008,6124],[-19,10],[-13,-5],[-17,5],[-13,-11],[-15,18],[3,19],[25,-8],[21,-5],[10,13],[-12,26],[0,23],[-18,9],[7,16],[17,-3],[24,-9]],[[5471,7900],[14,-15],[10,-6],[24,7],[2,12],[11,2],[14,9],[3,-4],[13,8],[6,13],[9,4],[30,-18],[6,6]],[[5613,7918],[15,-16],[2,-16]],[[5630,7886],[-17,-12],[-13,-40],[-17,-40],[-22,-11]],[[5561,7783],[-17,2],[-22,-15]],[[5460,7805],[-6,20],[-4,0]],[[8352,4453],[-11,-2],[-37,42],[26,11],[14,-18],[10,-17],[-2,-16]],[[8471,4532],[2,-11],[1,-18]],[[8474,4503],[-18,-45],[-24,-13],[-3,8],[2,20],[12,36],[28,23]],[[8274,4579],[10,-16],[17,5],[7,-25],[-32,-12],[-19,-8],[-15,1],[10,34],[15,0],[7,21]],[[8413,4579],[-4,-32],[-42,-17],[-37,7],[0,22],[22,12],[18,-18],[18,5],[25,21]],[[8017,4657],[53,-6],[6,25],[51,-29],[10,-38],[42,-11],[34,-35],[-31,-23],[-31,24],[-25,-1],[-29,4],[-26,11],[-32,22],[-21,6],[-11,-7],[-51,24],[-5,25],[-25,5],[19,56],[34,-3],[22,-23],[12,-5],[4,-21]],[[8741,4690],[-14,-40],[-3,45],[5,21],[6,20],[7,-17],[-1,-29]],[[8534,4853],[-11,-19],[-19,10],[-5,26],[28,3],[7,-20]],[[8623,4875],[10,-45],[-23,24],[-23,5],[-16,-4],[-19,2],[6,33],[35,2],[30,-17]],[[8916,4904],[0,-193],[1,-192]],[[8917,4519],[-25,48],[-28,12],[-7,-17],[-35,-1],[12,48],[17,16],[-7,64],[-14,50],[-53,50],[-23,5],[-42,54],[-8,-28],[-11,-5],[-6,21],[0,26],[-21,29],[29,21],[20,-1],[-2,16],[-41,0],[-11,35],[-25,11],[-11,29],[37,14],[14,20],[45,-25],[4,-22],[8,-95],[29,-35],[23,62],[32,36],[25,0],[23,-21],[21,-21],[30,-11]],[[8478,5141],[-22,-58],[-21,-12],[-27,12],[-46,-3],[-24,-8],[-4,-45],[24,-53],[15,27],[52,20],[-2,-27],[-12,9],[-12,-35],[-25,-23],[27,-76],[-5,-20],[25,-68],[-1,-39],[-14,-17],[-11,20],[13,49],[-27,-23],[-7,16],[3,23],[-20,35],[3,57],[-19,-18],[2,-69],[1,-84],[-17,-9],[-12,18],[8,54],[-4,57],[-12,1],[-9,40],[12,39],[4,47],[14,89],[5,24],[24,44],[22,-18],[35,-8],[32,3],[27,43],[5,-14]],[[8574,5124],[-2,-51],[-14,6],[-4,-36],[11,-32],[-8,-7],[-11,38],[-8,75],[6,47],[9,22],[2,-32],[16,-5],[3,-25]],[[8045,5176],[5,-39],[19,-34],[18,12],[18,-4],[16,30],[13,5],[26,-17],[23,13],[14,82],[11,21],[10,67],[32,0],[24,-10]],[[8274,5302],[-16,-53],[20,-56],[-5,-28],[32,-54],[-33,-7],[-10,-40],[2,-54],[-27,-40],[-1,-59],[-10,-91],[-5,21],[-31,-26],[-11,36],[-20,3],[-14,19],[-33,-21],[-10,29],[-18,-4],[-23,7],[-4,79],[-14,17],[-13,50],[-4,52],[3,55],[16,39]],[[7939,4712],[-31,-1],[-24,49],[-35,48],[-12,36],[-21,48],[-14,44],[-21,83],[-24,49],[-9,51],[-10,46],[-25,37],[-14,51],[-21,33],[-29,65],[-3,30],[18,-2],[43,-12],[25,-57],[21,-40],[16,-25],[26,-63],[28,-1],[23,-41],[16,-49],[22,-27],[-12,-49],[16,-20],[10,-2],[5,-41],[10,-33],[20,-5],[14,-37],[-7,-74],[-1,-91]],[[7252,6841],[-17,-27],[-11,-55],[27,-23],[26,-29],[36,-33],[38,-8],[16,-30],[22,-5],[33,-14],[23,1],[4,23],[-4,38],[2,25]],[[7703,6727],[2,-22],[-10,-11],[2,-36],[-19,10],[-36,-41],[0,-33],[-15,-50],[-1,-29],[-13,-48],[-21,13],[-1,-61],[-7,-20],[3,-25],[-14,-14]],[[7472,6360],[-4,-21],[-19,1],[-34,-13],[2,-44],[-15,-35],[-40,-40],[-31,-69],[-21,-38],[-28,-38],[0,-27],[-13,-15],[-26,-21],[-12,-3],[-9,-45],[6,-77],[1,-49],[-11,-56],[0,-101],[-15,-2],[-12,-46],[8,-19],[-25,-17],[-10,-40],[-11,-17],[-26,55],[-13,83],[-11,60],[-9,28],[-15,56],[-7,74],[-5,37],[-25,81],[-12,115],[-8,75],[0,72],[-5,55],[-41,-35],[-19,7],[-36,71],[13,22],[-8,23],[-33,50]],[[6893,6457],[19,40],[61,-1],[-6,51],[-15,30],[-4,46],[-18,26],[31,62],[32,-4],[29,61],[18,60],[27,60],[-1,42],[24,34],[-23,29],[-9,40],[-10,52],[14,25],[42,-14],[31,9],[26,49]],[[4827,8240],[5,-42],[-21,-53],[-49,-35],[-40,9],[23,62],[-15,60],[38,46],[21,28]],[[6497,7255],[25,12],[19,33],[19,-1],[12,11],[20,-6],[31,-30],[22,-6],[31,-53],[21,-2],[3,-49]],[[6690,6820],[14,-31],[11,-36],[27,-26],[1,-52],[13,-10],[2,-27],[-40,-30],[-10,-69]],[[6708,6539],[-53,18],[-30,13],[-31,8],[-12,73],[-13,10],[-22,-11],[-28,-28],[-34,20],[-28,45],[-27,17],[-18,56],[-21,79],[-15,-10],[-17,20],[-11,-24]],[[6348,6825],[-15,32],[0,31],[-9,0],[5,43],[-15,45],[-34,32],[-19,56],[6,46],[14,21],[-2,34],[-18,18],[-18,70]],[[6243,7253],[-15,48],[5,18],[-8,68],[19,17]],[[6357,7321],[9,-43],[26,-13],[20,-29],[39,-10],[44,15],[2,14]],[[6348,6825],[-16,3]],[[6332,6828],[-19,5],[-20,-56]],[[6293,6777],[-52,4],[-78,119],[-41,41],[-34,16]],[[6088,6957],[-11,72]],[[6077,7029],[61,62],[11,71],[-3,43],[16,15],[14,37]],[[6176,7257],[12,9],[32,-8],[10,-15],[13,10]],[[4597,8984],[-7,-39],[31,-40],[-36,-45],[-80,-41],[-24,-10],[-36,8],[-78,19],[28,26],[-61,29],[49,12],[-1,17],[-58,14],[19,38],[42,9],[43,-40],[42,32],[35,-17],[45,32],[47,-4]],[[5992,6990],[-5,-19]],[[5987,6971],[-10,8],[-6,-39],[7,-7],[-7,-8],[-1,-15],[13,8]],[[5983,6918],[0,-23],[-14,-95]],[[5951,6902],[8,19],[-2,4],[8,27],[5,45],[4,15],[1,0]],[[5975,7012],[9,0],[3,11],[7,0]],[[5994,7023],[1,-24],[-4,-9],[1,0]],[[5431,7316],[-10,-46],[4,-19],[-6,-30],[-21,22],[-14,7],[-39,30],[4,30],[32,-6],[28,7],[22,5]],[[5255,7492],[17,-42],[-4,-78],[-13,4],[-11,-20],[-10,16],[-2,71],[-6,34],[15,-3],[14,18]],[[5383,7805],[-3,-29],[7,-25]],[[5387,7751],[-22,8],[-23,-20],[1,-30],[-3,-17],[9,-30],[26,-29],[14,-49],[31,-48],[22,0],[7,-13],[-8,-11],[25,-22],[20,-18],[24,-30],[3,-11],[-5,-22],[-16,28],[-24,10],[-12,-39],[20,-21],[-3,-31],[-11,-4],[-15,-50],[-12,-5],[0,18],[6,32],[6,12],[-11,35],[-8,29],[-12,8],[-8,25],[-18,11],[-12,24],[-21,4],[-21,26],[-26,39],[-19,34],[-8,58],[-14,7],[-23,20],[-12,-8],[-16,-28],[-12,-4]],[[2845,6150],[19,-5],[14,-15],[5,-16],[-19,-1],[-9,-10],[-15,10],[-16,21],[3,14],[12,4],[6,-2]],[[5992,6990],[31,-24],[54,63]],[[6088,6957],[-5,-8],[-56,-30],[28,-59],[-9,-10],[-5,-20],[-21,-8],[-7,-21],[-12,-19],[-31,10]],[[5970,6792],[-1,8]],[[5983,6918],[4,17],[0,36]],[[8739,7075],[4,-20],[-16,-36],[-11,19],[-15,-14],[-7,-34],[-18,16],[0,28],[15,36],[16,-7],[12,25],[20,-13]],[[8915,7252],[-10,-47],[4,-30],[-14,-42],[-35,-27],[-49,-4],[-40,-67],[-19,22],[-1,44],[-48,-13],[-33,-27],[-32,-2],[28,-43],[-19,-101],[-18,-24],[-13,23],[7,53],[-18,17],[-11,41],[26,18],[15,37],[28,30],[20,41],[55,17],[30,-12],[29,105],[19,-28],[40,59],[16,23],[18,72],[-5,67],[11,37],[30,11],[15,-82],[-1,-48],[-25,-59],[0,-61]],[[8997,7667],[19,-12],[20,25],[6,-67],[-41,-16],[-25,-59],[-43,41],[-15,-65],[-31,-1],[-4,59],[14,46],[29,3],[8,82],[9,46],[32,-62],[22,-20]],[[6970,7554],[-15,-10],[-37,-42],[-12,-42],[-11,0],[-7,28],[-36,2],[-5,48],[-14,0],[2,60],[-33,43],[-48,-5],[-32,-8],[-27,53],[-22,22],[-43,43],[-6,5],[-71,-35],[1,-218]],[[6554,7498],[-14,-3],[-20,46],[-18,17],[-32,-12],[-12,-20]],[[6458,7526],[-2,14],[7,25],[-5,21],[-32,20],[-13,53],[-15,15],[-1,19],[27,-6],[1,44],[23,9],[25,-9],[5,58],[-5,36],[-28,-2],[-24,14],[-32,-26],[-26,-12]],[[6363,7799],[-14,9],[3,31],[-18,39],[-20,-2],[-24,40],[16,45],[-8,12],[22,65],[29,-34],[3,43],[58,64],[43,2],[61,-41],[33,-24],[30,25],[44,1],[35,-30],[8,17],[39,-2],[7,28],[-45,40],[27,29],[-5,16],[26,15],[-20,41],[13,20],[104,21],[13,14],[70,22],[25,24],[50,-12],[9,-61],[29,14],[35,-20],[-2,-32],[27,3],[69,56],[-10,-19],[35,-46],[62,-150],[15,31],[39,-34],[39,16],[16,-11],[13,-34],[20,-12],[11,-25],[36,8],[15,-36]],[[7229,7559],[-17,9],[-14,21],[-42,6],[-46,2],[-10,-6],[-39,24],[-16,-12],[-4,-35],[-46,21],[-18,-9],[-7,-26]],[[6155,4958],[-20,-24],[-7,-24],[-10,-4],[-4,-42],[-9,-24],[-5,-39],[-12,-20]],[[6088,4781],[-40,59],[-1,35],[-101,120],[-5,6]],[[5941,5001],[0,63],[8,24],[14,39],[10,43],[-13,68],[-3,30],[-13,41]],[[5944,5309],[17,35],[19,39]],[[6162,5289],[-24,-67],[0,-215],[17,-49]],[[7046,7387],[-53,-9],[-34,19],[-30,-4],[3,34],[30,-10],[10,18]],[[6972,7435],[21,-6],[36,43],[-33,31],[-20,-15],[-21,22],[24,39],[-9,5]],[[7849,5777],[-7,72],[18,49],[36,11],[26,-8]],[[7922,5901],[23,-23],[12,40],[25,-21]],[[7982,5897],[6,-40],[-3,-71],[-47,-45],[13,-36],[-30,-4],[-24,-24]],[[7897,5677],[-23,9],[-11,30],[-14,61]],[[8564,7339],[24,-70],[7,-38],[0,-68],[-10,-33],[-25,-11],[-22,-25],[-25,-5],[-3,32],[5,45],[-13,61],[21,10],[-19,51]],[[8504,7288],[2,5],[12,-2],[11,27],[20,2],[11,4],[4,15]],[[5557,7574],[5,13]],[[5562,7587],[7,4],[4,20],[5,3],[4,-8],[5,-4],[3,-10],[5,-2],[5,-11],[4,0],[-3,-14],[-3,-7],[1,-5]],[[5599,7553],[-6,-2],[-17,-9],[-1,-12],[-4,0]],[[6332,6828],[6,-26],[-3,-13],[9,-45]],[[6344,6744],[-19,-1],[-7,28],[-25,6]],[[7922,5901],[9,26],[1,50],[-22,52],[-2,58],[-21,48],[-21,4],[-6,-20],[-16,-2],[-8,10],[-30,-35],[0,53],[7,62],[-19,3],[-2,36],[-12,18]],[[7780,6264],[6,21],[24,39]],[[7837,6385],[17,-47],[12,-54],[34,0],[11,-52],[-18,-15],[-8,-21],[34,-36],[23,-70],[17,-52],[21,-41],[7,-41],[-5,-59]],[[5975,7012],[10,49],[14,41],[0,2]],[[5999,7104],[13,-3],[4,-23],[-15,-22],[-7,-33]],[[4785,5315],[-7,0],[-29,28],[-25,45],[-24,32],[-18,38]],[[4682,5458],[6,19],[2,17],[12,33],[13,27]],[[5412,6408],[-20,-22],[-15,33],[-44,25]],[[5263,6848],[13,14],[3,25],[-3,24],[19,23],[8,19],[14,17],[2,45]],[[5319,7015],[32,-20],[12,5],[23,-10],[37,-26],[13,-53],[25,-11],[39,-25],[30,-29],[13,15],[13,27],[-6,45],[9,29],[20,28],[19,8],[37,-12],[10,-27],[10,0],[9,-10],[28,-7],[6,-19]],[[5694,6357],[0,-118],[-32,0],[0,-25]],[[5662,6214],[-111,113],[-111,113],[-28,-32]],[[7271,5502],[-4,-62],[-12,-16],[-24,-14],[-13,47],[-5,85],[13,96],[19,-33],[13,-42],[13,-61]],[[5804,3347],[10,-18],[-9,-29],[-4,-19],[-16,-9],[-5,-19],[-10,-6],[-21,46],[15,37],[15,23],[13,12],[12,-18]],[[5631,8267],[-2,15],[3,16],[-13,10],[-29,10]],[[5590,8318],[-6,50]],[[5584,8368],[32,18],[47,-4],[27,6],[4,-12],[15,-4],[26,-29]],[[5652,8242],[-7,19],[-14,6]],[[5584,8368],[1,44],[14,37],[26,20],[22,-44],[22,1],[6,46]],[[5757,8453],[14,-14],[2,-28],[9,-35]],[[4759,6691],[-4,0],[0,-31],[-17,-2],[-9,-14],[-13,0],[-10,8],[-23,-6],[-9,-46],[-9,-5],[-13,-74],[-38,-64],[-9,-81],[-12,-27],[-3,-21],[-63,-5]],[[4527,6323],[1,27],[11,17],[9,30],[-2,20],[10,42],[15,38],[9,9],[8,35],[0,31],[10,37],[19,21],[18,60],[0,1],[14,23],[26,6],[22,41],[14,16],[23,49],[-7,73],[10,51],[4,31],[18,40],[28,27],[21,25],[18,61],[9,36],[20,0],[17,-25],[26,4],[29,-13],[12,-1]],[[5739,7906],[6,9],[19,6],[20,-19],[12,-2],[12,-16],[-2,-20],[11,-9],[4,-25],[9,-15],[-2,-9],[5,-6],[-7,-4],[-16,1],[-3,9],[-6,-5],[2,-11],[-7,-19],[-5,-20],[-7,-6]],[[5784,7745],[-5,27],[3,25],[-1,26],[-16,35],[-9,25],[-9,17],[-8,6]],[[6376,4321],[7,-25],[7,-39],[4,-71],[7,-28],[-2,-28],[-5,-18],[-10,35],[-5,-18],[5,-43],[-2,-25],[-8,-14],[-1,-50],[-11,-69],[-14,-81],[-17,-112],[-11,-82],[-12,-69],[-23,-14],[-24,-25],[-16,15],[-22,21],[-8,31],[-2,53],[-10,47],[-2,42],[5,43],[13,10],[0,20],[13,45],[2,37],[-6,28],[-5,38],[-2,54],[9,33],[4,38],[14,2],[15,12],[11,10],[12,1],[16,34],[23,36],[8,30],[-4,25],[12,-7],[15,41],[1,36],[9,26],[10,-25]],[[2301,6586],[-10,-52],[-5,-43],[-2,-79],[-3,-29],[5,-32],[9,-29],[5,-45],[19,-44],[6,-34],[11,-29],[29,-16],[12,-25],[24,17],[21,6],[21,11],[18,10],[17,24],[7,34],[2,50],[5,17],[19,16],[29,13],[25,-2],[17,5],[6,-12],[-1,-29],[-15,-35],[-6,-36],[5,-10],[-4,-26],[-7,-46],[-7,15],[-6,-1]],[[2438,5916],[-32,64],[-14,19],[-23,16],[-15,-5],[-22,-22],[-14,-6],[-20,16],[-21,11],[-26,27],[-21,8],[-31,28],[-23,28],[-7,16],[-16,3],[-28,19],[-12,27],[-30,34],[-14,37],[-6,29],[9,5],[-3,17],[7,16],[0,20],[-10,27],[-2,23],[-9,30],[-25,59],[-28,46],[-13,37],[-24,24],[-5,14],[4,37],[-14,13],[-17,29],[-7,41],[-14,5],[-17,31],[-13,29],[-1,19],[-15,44],[-10,45],[1,23],[-20,23],[-10,-2],[-15,16],[-5,-24],[5,-28],[2,-45],[10,-24],[21,-41],[4,-14],[4,-4],[4,-20],[5,1],[6,-38],[8,-15],[6,-21],[17,-30],[10,-55],[8,-26],[8,-28],[1,-31],[13,-2],[12,-27],[10,-26],[-1,-11],[-12,-21],[-5,0],[-7,36],[-18,33],[-20,29],[-14,15],[1,43],[-5,32],[-13,19],[-19,26],[-4,-8],[-7,16],[-17,14],[-16,34],[2,5],[11,-4],[11,22],[1,27],[-22,42],[-16,17],[-10,36],[-11,39],[-12,47],[-12,54]],[[1746,6980],[32,4],[35,7],[-2,-12],[41,-29],[64,-41],[55,0],[22,0],[0,24],[48,0],[10,-20],[15,-19],[16,-26],[9,-31],[7,-32],[15,-18],[23,-18],[17,47],[23,1],[19,-24],[14,-40],[10,-35],[16,-34],[6,-41],[8,-28],[22,-18],[20,-13],[10,2]],[[5599,7553],[9,4],[13,1]],[[4661,5921],[10,11],[4,35],[9,1],[20,-16],[15,11],[11,-4],[4,13],[112,1],[6,42],[-5,7],[-13,255],[-14,255],[43,1]],[[5118,6189],[0,-136],[-15,-39],[-2,-37],[-25,-9],[-38,-5],[-10,-21],[-18,-3]],[[4680,5793],[1,18],[-2,23],[-11,16],[-5,34],[-2,37]],[[7737,5644],[-3,44],[9,45],[-10,35],[3,65],[-12,30],[-9,71],[-5,75],[-12,49],[-18,-30],[-32,-42],[-15,5],[-17,14],[9,73],[-6,56],[-21,68],[3,21],[-16,7],[-20,49]],[[7780,6264],[-16,-14],[-16,-26],[-20,-2],[-12,-64],[-12,-11],[14,-52],[17,-43],[12,-39],[-11,-51],[-9,-11],[6,-30],[19,-47],[3,-33],[0,-27],[11,-54],[-16,-55],[-13,-61]],[[5538,7532],[-6,4],[-8,19],[-12,12]],[[5533,7629],[8,-10],[4,-9],[9,-6],[10,-12],[-2,-5]],[[7437,7970],[29,10],[53,51],[42,28],[24,-18],[29,-1],[19,-28],[28,-2],[40,-15],[27,41],[-11,35],[28,61],[31,-24],[26,-7],[32,-15],[6,-44],[39,-25],[26,11],[36,7],[27,-7],[28,-29],[16,-30],[26,1],[35,-10],[26,15],[36,9],[41,42],[17,-6],[14,-20],[33,5]],[[5959,4377],[21,5],[34,-17],[7,8],[19,1],[10,18],[17,-1],[30,23],[22,34]],[[6119,4448],[5,-26],[-1,-59],[3,-52],[1,-92],[5,-29],[-8,-43],[-11,-41],[-18,-36],[-25,-23],[-31,-28],[-32,-64],[-10,-11],[-20,-42],[-11,-13],[-3,-42],[14,-45],[5,-35],[0,-17],[5,3],[-1,-58],[-4,-28],[6,-10],[-4,-25],[-11,-21],[-23,-20],[-34,-32],[-12,-21],[3,-25],[7,-4],[-3,-31]],[[5911,3478],[-21,0]],[[5890,3478],[-2,26],[-4,27]],[[5884,3531],[-3,21],[5,66],[-7,42],[-13,83]],[[5866,3743],[29,67],[7,43],[5,5],[3,35],[-5,17],[1,44],[6,41],[0,75],[-15,19],[-13,4],[-6,15],[-13,12],[-23,-1],[-2,22]],[[5840,4141],[-2,42],[84,49]],[[5922,4232],[16,-28],[8,5],[11,-15],[1,-23],[-6,-28],[2,-42],[19,-36],[8,41],[12,12],[-2,76],[-12,43],[-10,19],[-10,-1],[-7,77],[7,45]],[[4661,5921],[-18,41],[-17,43],[-18,16],[-13,17],[-16,-1],[-13,-12],[-14,5],[-10,-19]],[[4542,6011],[-2,32],[8,29],[3,55],[-3,59],[-3,29],[2,30],[-7,28],[-14,25]],[[4526,6298],[6,20],[108,-1],[-5,86],[7,30],[26,5],[-1,152],[91,-4],[0,90]],[[5922,4232],[-15,15],[9,55],[9,21],[-6,49],[6,48],[5,16],[-7,50],[-14,26]],[[5909,4512],[28,-11],[5,-16],[10,-28],[7,-80]],[[7836,5425],[7,-5],[16,-36],[12,-40],[2,-39],[-3,-27],[2,-21],[2,-35],[10,-16],[11,-52],[-1,-20],[-19,-4],[-27,44],[-32,47],[-4,30],[-16,39],[-4,49],[-10,32],[4,43],[-7,25]],[[7779,5439],[5,11],[23,-26],[2,-30],[18,7],[9,24]],[[8045,5176],[21,-20],[21,11],[6,50],[12,11],[33,13],[20,47],[14,37]],[[8206,5379],[22,41],[14,47],[11,0],[14,-30],[1,-26],[19,-16],[23,-18],[-2,-23],[-19,-3],[5,-29],[-20,-20]],[[5453,3369],[-20,45],[-11,43],[-6,58],[-7,42],[-9,91],[-1,71],[-3,32],[-11,25],[-15,48],[-14,71],[-6,37],[-23,58],[-2,45]],[[5644,4022],[23,14],[18,-4],[11,-13],[0,-5]],[[5552,3594],[0,-218],[-25,-30],[-15,-4],[-17,11],[-13,4],[-4,25],[-11,17],[-14,-30]],[[9604,3812],[23,-36],[14,-28],[-10,-14],[-16,16],[-19,27],[-18,31],[-19,42],[-4,20],[12,-1],[16,-20],[12,-20],[9,-17]],[[5412,6408],[7,-92],[10,-15],[1,-19],[11,-20],[-6,-25],[-11,-120],[-1,-77],[-35,-56],[-12,-78],[11,-22],[0,-38],[18,-1],[-3,-28]],[[5393,5795],[-5,-1],[-19,64],[-6,3],[-22,-33],[-21,17],[-15,3],[-8,-8],[-17,2],[-16,-25],[-14,-2],[-34,31],[-13,-15],[-14,1],[-10,23],[-28,22],[-30,-7],[-7,-13],[-4,-34],[-8,-24],[-2,-53]],[[5236,5339],[-29,-21],[-11,3],[-10,-13],[-23,1],[-15,37],[-9,43],[-19,39],[-21,-1],[-25,0]],[[2619,5713],[-10,18],[-13,24],[-6,20],[-12,19],[-13,26],[3,9],[4,-9],[2,5]],[[2690,5943],[-2,-5],[-2,-13],[3,-22],[-6,-20],[-3,-24],[-1,-26],[1,-15],[1,-27],[-4,-6],[-3,-25],[2,-15],[-6,-16],[2,-16],[4,-9]],[[5092,8091],[14,16],[24,87],[38,25],[23,-2]],[[5863,9167],[-47,-24],[-22,-5]],[[5573,9140],[-17,-2],[-4,-39],[-53,9],[-7,-33],[-27,1],[-18,-42],[-28,-66],[-43,-83],[10,-20],[-10,-24],[-27,1],[-18,-55],[2,-79],[17,-29],[-9,-70],[-23,-40],[-12,-34]],[[5306,8535],[-19,36],[-55,-69],[-37,-13],[-38,30],[-10,63],[-9,137],[26,38],[73,49],[55,61],[51,82],[66,115],[47,44],[76,74],[61,26],[46,-3],[42,49],[51,-3],[50,12],[87,-43],[-36,-16],[30,-37]],[[5686,9657],[-62,-24],[-49,13],[19,16],[-16,19],[57,11],[11,-22],[40,-13]],[[5506,9766],[92,-44],[-70,-23],[-15,-44],[-25,-11],[-13,-49],[-34,-2],[-59,36],[25,21],[-42,17],[-54,50],[-21,46],[75,21],[16,-20],[39,0],[11,21],[40,2],[35,-21]],[[5706,9808],[55,-21],[-41,-32],[-81,-7],[-82,10],[-5,16],[-40,1],[-30,27],[86,17],[40,-14],[28,17],[70,-14]],[[9805,2640],[6,-24],[20,24],[8,-25],[0,-25],[-10,-27],[-18,-44],[-14,-24],[10,-28],[-22,-1],[-23,-22],[-8,-39],[-16,-60],[-21,-26],[-14,-17],[-26,1],[-18,20],[-30,4],[-5,22],[15,43],[35,59],[18,11],[20,22],[24,31],[16,31],[13,44],[10,15],[5,33],[19,27],[6,-25]],[[9849,2922],[20,-63],[1,41],[13,-16],[4,-45],[22,-19],[19,-5],[16,22],[14,-6],[-7,-53],[-8,-34],[-22,1],[-7,-18],[3,-25],[-4,-11],[-11,-32],[-14,-41],[-21,-23],[-5,15],[-12,9],[16,48],[-9,33],[-30,23],[1,22],[20,20],[5,46],[-1,38],[-12,40],[1,10],[-13,25],[-22,52],[-12,42],[11,4],[15,-33],[21,-15],[8,-52]],[[6475,6041],[-9,41],[-22,98]],[[6444,6180],[83,59],[19,118],[-13,42]],[[6566,6530],[12,-40],[16,-22],[20,-8],[17,-10],[12,-34],[8,-20],[10,-7],[0,-13],[-10,-36],[-5,-16],[-12,-19],[-10,-41],[-13,3],[-5,-14],[-5,-30],[4,-39],[-3,-7],[-13,0],[-17,-22],[-3,-29],[-6,-12],[-18,0],[-10,-15],[0,-24],[-14,-16],[-15,5],[-19,-19],[-12,-4]],[[6557,6597],[8,20],[3,-5],[-2,-25],[-4,-10]],[[6893,6457],[-20,15],[-9,43],[-21,45],[-51,-12],[-45,-1],[-39,-8]],[[2836,5484],[-9,17],[-6,32],[7,16],[-7,4],[-5,20],[-14,16],[-12,-4],[-6,-20],[-11,-15],[-6,-2],[-3,-13],[13,-32],[-7,-7],[-4,-9],[-13,-3],[-5,35],[-4,-10],[-9,4],[-5,24],[-12,3],[-7,7],[-12,0],[-1,-13],[-3,9]],[[2707,5623],[10,-22],[-1,-12],[11,-3],[3,5],[8,-14],[13,4],[12,15],[17,12],[9,17],[16,-3],[-1,-6],[15,-2],[12,-10],[10,-18],[10,-16]],[[3045,3974],[-28,33],[-2,25],[-55,59],[-50,65],[-22,36],[-11,49],[4,17],[-23,77],[-28,109],[-26,118],[-11,27],[-9,43],[-21,39],[-20,24],[9,26],[-14,57],[9,41],[22,37]],[[8510,5555],[2,-40],[2,-33],[-9,-54],[-11,60],[-13,-30],[9,-43],[-8,-28],[-32,35],[-8,42],[8,28],[-17,28],[-9,-24],[-13,2],[-21,-33],[-4,17],[11,50],[17,17],[15,22],[10,-27],[21,17],[5,26],[19,1],[-1,46],[22,-28],[3,-30],[2,-21]],[[8443,5665],[-10,-20],[-9,-37],[-8,-17],[-17,40],[5,16],[7,17],[3,36],[16,4],[-5,-40],[21,57],[-3,-56]],[[8291,5608],[-37,-56],[14,41],[20,37],[16,41],[15,58],[5,-48],[-18,-33],[-15,-40]],[[8385,5760],[16,-18],[18,0],[0,-25],[-13,-25],[-18,-18],[-1,28],[2,30],[-4,28]],[[8485,5776],[8,-66],[-21,16],[0,-20],[7,-37],[-13,-13],[-1,42],[-9,3],[-4,36],[16,-5],[0,22],[-17,45],[27,-1],[7,-22]],[[8375,5830],[-7,-51],[-12,29],[-15,45],[24,-2],[10,-21]],[[8369,6151],[17,-17],[9,15],[2,-15],[-4,-24],[9,-43],[-7,-49],[-16,-19],[-5,-48],[7,-47],[14,-7],[13,7],[34,-32],[-2,-32],[9,-15],[-3,-27],[-22,29],[-10,31],[-7,-22],[-18,36],[-25,-9],[-14,13],[1,25],[9,15],[-8,13],[-4,-21],[-14,34],[-4,26],[-1,56],[11,-19],[3,92],[9,54],[17,0]],[[9329,4655],[-8,-6],[-12,22],[-12,38],[-6,45],[4,6],[3,-18],[8,-13],[14,-38],[13,-20],[-4,-16]],[[9221,4734],[-15,-5],[-4,-17],[-15,-14],[-15,-14],[-14,0],[-23,18],[-16,16],[2,18],[25,-8],[15,4],[5,29],[4,1],[2,-31],[16,4],[8,20],[16,21],[-4,35],[17,1],[6,-9],[-1,-33],[-9,-36]],[[8916,4904],[48,-41],[51,-34],[19,-30],[16,-30],[4,-34],[46,-37],[7,-31],[-25,-7],[6,-39],[25,-39],[18,-62],[15,2],[-1,-27],[22,-10],[-9,-11],[30,-25],[-3,-17],[-18,-4],[-7,16],[-24,6],[-28,9],[-22,38],[-16,32],[-14,52],[-36,26],[-24,-17],[-17,-20],[4,-43],[-22,-20],[-16,9],[-28,3]],[[9253,4792],[-9,-16],[-5,35],[-6,23],[-13,19],[-16,25],[-20,18],[8,14],[15,-17],[9,-13],[12,-14],[11,-25],[11,-19],[3,-30]],[[5392,8233],[19,18],[43,27],[35,20],[28,-10],[2,-14],[27,-1]],[[5546,8273],[34,-7],[51,1]],[[5653,8105],[14,-52],[-3,-17],[-14,-6],[-25,-50],[7,-26],[-6,3]],[[5626,7957],[-26,23],[-20,-8],[-13,6],[-17,-13],[-14,21],[-11,-8],[-2,4]],[[3159,6151],[14,-5],[5,-12],[-7,-15],[-21,1],[-17,-2],[-1,25],[4,9],[23,-1]],[[8628,7562],[4,-10]],[[8632,7552],[-11,3],[-12,-20],[-8,-20],[1,-42],[-14,-13],[-5,-11],[-11,-17],[-18,-10],[-12,-16],[-1,-25],[-3,-7],[11,-9],[15,-26]],[[8504,7288],[-13,11],[-4,-11],[-8,-5],[-1,11],[-7,5],[-8,10],[8,26],[7,7],[-3,11],[7,31],[-2,10],[-16,7],[-13,15]],[[4792,7249],[-11,-15],[-14,8],[-15,-6],[5,46],[-3,36],[-12,6],[-7,22],[2,39],[11,21],[2,24],[6,36],[-1,25],[-5,21],[-1,20]],[[6411,6520],[-2,43],[7,31],[8,6],[8,-18],[1,-35],[-6,-35]],[[6427,6512],[-8,-4],[-8,12]],[[5630,7886],[12,13],[17,-7],[18,0],[13,-14],[10,9],[20,5],[7,14],[12,0]],[[5784,7745],[12,-11],[13,9],[13,-10]],[[5822,7733],[0,-15],[-13,-13],[-9,6],[-7,-71]],[[5629,7671],[-5,10],[6,10],[-7,7],[-8,-13],[-17,17],[-2,25],[-17,14],[-3,18],[-15,24]],[[8989,8056],[28,-105],[-41,19],[-17,-85],[27,-61],[-1,-41],[-21,36],[-18,-46],[-5,50],[3,57],[-3,64],[6,45],[2,79],[-17,58],[3,80],[25,28],[-11,27],[13,8],[7,-39],[10,-57],[-1,-58],[11,-59]],[[5546,8273],[6,26],[38,19]],[[0,9132],[68,-45],[73,-59],[-3,-37],[19,-15],[-6,43],[75,-8],[55,-56],[-28,-26],[-46,-6],[0,-57],[-11,-13],[-26,2],[-22,21],[-36,17],[-7,26],[-28,9],[-31,-7],[-16,20],[6,22],[-33,-14],[13,-28],[-16,-25]],[[0,8896],[0,236]],[[0,9282],[9999,-40],[-30,-3],[-5,19],[-9964,24]],[[0,9282],[4,3],[23,0],[40,-17],[-2,-8],[-29,-14],[-36,-4],[0,40]],[[8988,9383],[-42,-1],[-57,7],[-5,3],[27,23],[34,6],[40,-23],[3,-15]],[[9186,9493],[-32,-23],[-44,5],[-52,23],[7,20],[51,-9],[70,-16]],[[9029,9522],[-22,-44],[-102,1],[-46,-14],[-55,39],[15,40],[37,11],[73,-2],[100,-31]],[[6598,9235],[-17,-5],[-91,8],[-7,26],[-50,16],[-4,32],[28,13],[-1,32],[55,50],[-25,7],[66,52],[-7,27],[62,31],[91,38],[93,11],[48,22],[54,8],[19,-23],[-19,-19],[-98,-29],[-85,-28],[-86,-57],[-42,-57],[-43,-57],[5,-49],[54,-49]],[[0,8896],[9963,-26],[-36,4],[25,-31],[17,-49],[13,-16],[3,-24],[-7,-16],[-52,13],[-78,-44],[-25,-7],[-42,-42],[-40,-36],[-11,-27],[-39,41],[-73,-46],[-12,22],[-27,-26],[-37,8],[-9,-38],[-33,-58],[1,-24],[31,-13],[-4,-86],[-25,-2],[-12,-49],[11,-26],[-48,-30],[-10,-67],[-41,-15],[-9,-60],[-40,-55],[-10,41],[-12,86],[-15,131],[13,82],[23,35],[2,28],[43,13],[50,75],[47,60],[50,48],[23,83],[-34,-5],[-17,-49],[-70,-65],[-23,73],[-72,-20],[-69,-99],[23,-36],[-62,-16],[-43,-6],[2,43],[-43,9],[-35,-29],[-85,10],[-91,-18],[-90,-115],[-106,-139],[43,-8],[14,-37],[27,-13],[18,30],[30,-4],[40,-65],[1,-50],[-21,-59],[-3,-71],[-12,-94],[-42,-86],[-9,-41],[-38,-69],[-38,-68],[-18,-35],[-37,-34],[-17,-1],[-17,29],[-38,-44],[-4,-19]],[[6363,7799],[-12,-35],[-27,-10],[-28,-61],[25,-56],[-2,-40],[30,-70]],[[6109,7624],[-35,49],[-32,23],[-24,34],[20,10],[23,49],[-15,24],[41,24],[-1,13],[-25,-10]],[[6061,7840],[1,26],[14,17],[27,4],[5,20],[-7,33],[12,30],[-1,18],[-41,19],[-16,-1],[-17,28],[-21,-9],[-35,20],[0,12],[-10,26],[-22,3],[-2,18],[7,12],[-18,33],[-29,-5],[-8,3],[-7,-14],[-11,3]],[[5777,8571],[31,33],[-29,28]],[[5863,9167],[29,20],[46,-35],[76,-14],[105,-67],[21,-28],[2,-40],[-31,-31],[-45,-15],[-124,44],[-21,-7],[45,-43],[2,-28],[2,-60],[36,-18],[22,-15],[3,28],[-17,26],[18,22],[67,-37],[24,15],[-19,43],[65,58],[25,-4],[26,-20],[16,40],[-23,35],[14,36],[-21,36],[78,-18],[16,-34],[-35,-7],[0,-33],[22,-20],[43,13],[7,38],[58,28],[97,50],[20,-3],[-27,-35],[35,-7],[19,21],[52,1],[42,25],[31,-36],[32,39],[-29,35],[14,19],[82,-18],[39,-18],[100,-68],[19,31],[-28,31],[-1,13],[-34,6],[10,28],[-15,46],[-1,19],[51,53],[18,54],[21,11],[74,-15],[5,-33],[-26,-48],[17,-19],[9,-41],[-6,-81],[31,-36],[-12,-40],[-55,-84],[32,-8],[11,21],[31,15],[7,29],[24,29],[-16,33],[13,39],[-31,5],[-6,33],[22,59],[-36,48],[50,40],[-7,42],[14,2],[15,-33],[-11,-57],[29,-11],[-12,43],[46,23],[58,3],[51,-34],[-25,49],[-2,63],[48,12],[67,-2],[60,7],[-23,31],[33,39],[31,2],[54,29],[74,8],[9,16],[73,6],[23,-14],[62,32],[51,-1],[8,25],[26,25],[66,25],[48,-19],[-38,-15],[63,-9],[7,-29],[25,14],[82,-1],[62,-29],[23,-22],[-7,-30],[-31,-18],[-73,-33],[-21,-17],[35,-8],[41,-15],[25,11],[14,-38],[12,15],[44,10],[90,-10],[6,-28],[116,-9],[2,46],[59,-11],[44,1],[45,-32],[13,-37],[-17,-25],[35,-47],[44,-24],[27,62],[44,-26],[48,16],[53,-18],[21,16],[45,-8],[-20,55],[37,25],[251,-38],[24,-35],[72,-45],[112,11],[56,-10],[23,-24],[-4,-44],[35,-16],[37,12],[49,1],[52,-11],[53,6],[49,-52],[34,19],[-23,37],[13,27],[88,-17],[58,4],[80,-29],[-9960,-25]],[[7918,9684],[-157,-23],[51,77],[23,7],[21,-4],[70,-33],[-8,-24]],[[6420,9816],[-37,-8],[-25,-4],[-4,-10],[-33,-10],[-30,14],[16,19],[-62,2],[54,10],[43,1],[5,-16],[16,14],[26,10],[42,-13],[-11,-9]],[[7775,9718],[-60,-8],[-78,17],[-46,23],[-21,42],[-38,12],[72,40],[60,14],[54,-30],[64,-57],[-7,-53]],[[5844,4990],[11,-33],[-1,-35],[-8,-7]],[[5821,4978],[7,-6],[16,18]],[[4526,6298],[1,25]],[[6188,6023],[-4,26],[-8,17],[-2,24],[-15,21],[-15,50],[-7,48],[-20,40],[-12,10],[-18,56],[-4,41],[2,35],[-16,66],[-13,23],[-15,12],[-10,34],[2,13],[-8,31],[-8,13],[-11,44],[-17,48],[-14,40],[-14,0],[5,33],[1,20],[3,24]],[[6344,6744],[11,-51],[14,-13],[5,-21],[18,-25],[2,-24],[-3,-20],[4,-20],[8,-16],[4,-20],[4,-14]],[[6427,6512],[5,-22]],[[6444,6180],[-80,-23],[-26,-26],[-20,-62],[-13,-10],[-7,20],[-11,-3],[-27,6],[-5,5],[-32,-1],[-7,-5],[-12,15],[-7,-29],[3,-25],[-12,-19]],[[5943,5617],[-4,1],[0,29],[-3,20],[-14,24],[-4,42],[4,44],[-13,4],[-2,-13],[-17,-3],[7,-17],[2,-36],[-15,-32],[-14,-43],[-14,-6],[-23,34],[-11,-12],[-3,-17],[-14,-11],[-1,-12],[-28,0],[-3,12],[-20,2],[-10,-10],[-8,5],[-14,34],[-5,17],[-20,-9],[-8,-27],[-7,-53],[-10,-11],[-8,-6]],[[5663,5567],[-2,2]],[[5635,5716],[0,14],[-10,17],[-1,35],[-5,23],[-10,-4],[3,22],[7,25],[-3,24],[9,18],[-6,14],[7,36],[13,44],[24,-4],[-1,234]],[[6023,6357],[9,-58],[-6,-10],[4,-61],[11,-71],[10,-14],[15,-22]],[[5943,5624],[0,-7]],[[5943,5617],[0,-46]],[[5944,5309],[-17,-28],[-20,1],[-22,-14],[-18,13],[-11,-16]],[[5682,5544],[-19,23]],[[4535,5861],[-11,46],[-14,21],[12,11],[14,41],[6,31]],[[4536,5789],[-4,45]],[[9502,4438],[8,-20],[-19,0],[-11,37],[17,-15],[5,-2]],[[9467,4474],[-11,-1],[-17,6],[-5,9],[1,23],[19,-9],[9,-12],[4,-16]],[[9490,4490],[-4,-11],[-21,52],[-5,35],[9,0],[10,-47],[11,-29]],[[9440,4565],[1,-12],[-22,25],[-15,21],[-10,20],[4,6],[13,-14],[23,-27],[6,-19]],[[9375,4623],[-5,-3],[-13,14],[-11,24],[1,10],[17,-25],[11,-20]],[[4682,5458],[-8,5],[-20,24],[-14,31],[-5,22],[-3,43]],[[2561,5848],[-3,-14],[-16,1],[-10,6],[-12,12],[-15,3],[-8,13]],[[6198,5735],[9,-11],[5,-25],[13,-24],[14,-1],[26,16],[30,7],[25,18],[13,4],[10,11],[16,2]],[[6359,5732],[0,-1],[0,-25],[0,-59],[0,-31],[-13,-36],[-19,-50]],[[6359,5732],[9,1],[13,9],[14,6],[14,20],[10,0],[1,-16],[-3,-35],[0,-31],[-6,-21],[-7,-64],[-14,-66],[-17,-75],[-24,-87],[-23,-66],[-33,-81],[-28,-48],[-42,-58],[-25,-45],[-31,-72],[-6,-31],[-6,-14]],[[3412,5410],[34,-11],[2,10],[23,4],[30,-15]],[[3489,5306],[10,-35],[-4,-25]],[[5626,7957],[-8,-15],[-5,-24]],[[5380,7746],[7,5]],[[5663,8957],[-47,-17],[-27,-41],[4,-36],[-44,-48],[-54,-50],[-20,-84],[20,-41],[26,-33],[-25,-67],[-29,-14],[-11,-99],[-15,-55],[-34,6],[-16,-47],[-32,-3],[-9,56],[-23,67],[-21,84]],[[5890,3478],[-5,-26],[-17,-6],[-16,32],[0,20],[7,22],[3,17],[8,5],[14,-11]],[[5999,7104],[-2,45],[7,25]],[[6004,7174],[7,13],[7,13],[2,33],[9,-12],[31,17],[14,-12],[23,1],[32,22],[15,-1],[32,9]],[[5051,5420],[-22,-12]],[[7849,5777],[-25,28],[-24,-2],[4,47],[-24,0],[-2,-65],[-15,-87],[-10,-52],[2,-43],[18,-2],[12,-53],[5,-52],[15,-33],[17,-7],[14,-31]],[[7779,5439],[-11,23],[-4,29],[-15,34],[-14,28],[-4,-35],[-5,33],[3,37],[8,56]],[[6883,7252],[16,60],[-6,44],[-20,14],[7,26],[23,-3],[13,33],[9,38],[37,13],[-6,-27],[4,-17],[12,2]],[[6497,7255],[-5,42],[4,62],[-22,20],[8,40],[-19,4],[6,49],[26,-14],[25,19],[-20,35],[-8,34],[-23,-15],[-3,-43],[-8,38]],[[6554,7498],[31,1],[-4,29],[24,21],[23,34],[37,-31],[3,-47],[11,-12],[30,2],[9,-10],[14,-61],[32,-41],[18,-28],[29,-29],[37,-25],[-1,-36]],[[8471,4532],[3,14],[24,13],[19,2],[9,8],[10,-8],[-10,-16],[-29,-25],[-23,-17]],[[3286,5693],[16,8],[6,-2],[-1,-44],[-23,-7],[-5,6],[8,16],[-1,23]],[[5233,7240],[31,24],[19,-7],[-1,-30],[24,22],[2,-12],[-14,-29],[0,-27],[9,-15],[-3,-51],[-19,-29],[6,-33],[14,-1],[7,-28],[11,-9]],[[6004,7174],[-11,27],[11,22],[-17,-5],[-23,13],[-19,-34],[-43,-6],[-22,31],[-30,2],[-6,-24],[-20,-7],[-26,31],[-31,-1],[-16,59],[-21,33],[14,46],[-18,28],[31,56],[43,3],[12,45],[53,-8],[33,38],[32,17],[46,1],[49,-42],[40,-22],[32,9],[24,-6],[33,31]],[[5777,7539],[3,-23],[25,-19],[-5,-14],[-33,-3],[-12,-19],[-23,-31],[-9,27],[0,12]],[[8382,6499],[-17,-95],[-12,-49],[-14,50],[-4,44],[17,58],[22,45],[13,-18],[-5,-35]],[[6088,4781],[-12,-73],[1,-33],[18,-22],[1,-15],[-8,-36],[2,-18],[-2,-28],[10,-37],[11,-58],[10,-13]],[[5909,4512],[-15,18],[-18,10],[-11,10],[-12,15]],[[5844,4990],[10,8],[31,-1],[56,4]],[[6061,7840],[-22,-5],[-18,-19],[-26,-3],[-24,-22],[1,-37],[14,-14],[28,4],[-5,-21],[-31,-11],[-37,-34],[-16,12],[6,28],[-30,17],[5,12],[26,19],[-8,14],[-43,15],[-2,22],[-25,-8],[-11,-32],[-21,-44]],[[3517,3063],[-12,-38],[-31,-32],[-21,11],[-15,-6],[-26,25],[-18,-1],[-17,32]],[[679,6185],[-4,-10],[-7,8],[1,17],[-4,21],[1,7],[5,10],[-2,11],[1,6],[3,-1],[10,-10],[5,-5],[5,-8],[7,-21],[-1,-3],[-11,-13],[-9,-9]],[[664,6277],[-9,-4],[-5,12],[-3,5],[0,4],[3,5],[9,-6],[8,-9],[-3,-7]],[[646,6309],[-1,-7],[-15,2],[2,7],[14,-2]],[[621,6317],[-2,-3],[-2,1],[-9,2],[-4,13],[-1,2],[7,8],[3,-3],[8,-20]],[[574,6356],[-4,-6],[-9,11],[1,4],[5,6],[6,-1],[1,-14]],[[3135,7724],[5,-19],[-30,-29],[-29,-20],[-29,-18],[-15,-35],[-4,-13],[-1,-31],[10,-32],[11,-1],[-3,21],[8,-13],[-2,-17],[-19,-9],[-13,1],[-20,-10],[-12,-3],[-17,-3],[-23,-17],[41,11],[8,-11],[-39,-18],[-17,0],[0,7],[-8,-16],[8,-3],[-6,-43],[-20,-45],[-2,15],[-6,3],[-9,15],[5,-32],[7,-10],[1,-23],[-9,-23],[-16,-47],[-2,3],[8,40],[-14,22],[-3,49],[-5,-25],[5,-38],[-18,10],[19,-19],[1,-57],[8,-4],[3,-20],[4,-59],[-17,-44],[-29,-18],[-18,-34],[-14,-4],[-14,-22],[-4,-20],[-31,-38],[-16,-28],[-13,-35],[-4,-42],[5,-41],[9,-51],[13,-41],[0,-26],[13,-69],[-1,-39],[-1,-23],[-7,-36],[-8,-8],[-14,7],[-4,26],[-11,14],[-15,51],[-13,45],[-4,23],[6,39],[-8,33],[-22,49],[-10,9],[-28,-27],[-5,3],[-14,28],[-17,14],[-32,-7],[-24,7],[-21,-5],[-12,-9],[5,-15],[0,-24],[5,-12],[-5,-8],[-10,9],[-11,-11],[-20,2],[-20,31],[-25,-8],[-20,14],[-17,-4],[-24,-14],[-25,-44],[-27,-25],[-16,-28],[-6,-27],[0,-41],[1,-28],[5,-20]],[[1746,6980],[-4,30],[-18,34],[-13,7],[-3,17],[-16,3],[-10,16],[-26,6],[-7,9],[-3,32],[-27,60],[-23,82],[1,14],[-13,19],[-21,50],[-4,48],[-15,32],[6,49],[-1,51],[-8,45],[10,56],[4,53],[3,54],[-5,79],[-9,51],[-8,27],[4,12],[40,-20],[15,-56],[7,15],[-5,49],[-9,48]],[[750,8432],[-28,-23],[-14,15],[-4,28],[25,21],[15,9],[18,-4],[12,-18],[-24,-28]],[[401,8597],[-18,-9],[-18,11],[-17,16],[28,10],[22,-6],[3,-22]],[[230,8826],[17,-12],[17,6],[23,-15],[27,-8],[-2,-7],[-21,-12],[-21,13],[-11,11],[-24,-4],[-7,5],[2,23]],[[1374,8295],[-15,22],[-25,19],[-8,52],[-36,47],[-15,56],[-26,4],[-44,2],[-33,17],[-57,61],[-27,11],[-49,21],[-38,-5],[-55,27],[-33,25],[-30,-12],[5,-41],[-15,-4],[-32,-12],[-25,-20],[-30,-13],[-4,35],[12,58],[30,18],[-8,15],[-35,-33],[-19,-39],[-40,-42],[20,-29],[-26,-42],[-30,-25],[-28,-18],[-7,-26],[-43,-31],[-9,-28],[-32,-25],[-20,5],[-25,-17],[-29,-20],[-23,-20],[-47,-16],[-5,9],[31,28],[27,18],[29,33],[35,6],[14,25],[38,35],[6,12],[21,21],[5,44],[14,35],[-32,-18],[-9,11],[-15,-22],[-18,30],[-8,-21],[-10,29],[-28,-23],[-17,0],[-3,35],[5,21],[-17,22],[-37,-12],[-23,28],[-19,14],[0,34],[-22,25],[11,34],[23,33],[10,30],[22,4],[19,-9],[23,28],[20,-5],[21,19],[-5,27],[-16,10],[21,23],[-17,-1],[-30,-13],[-8,-13],[-22,13],[-39,-6],[-41,14],[-12,24],[-35,34],[39,25],[62,29],[23,0],[-4,-30],[59,2],[-23,37],[-34,23],[-20,29],[-26,25],[-38,19],[15,31],[49,2],[35,27],[7,29],[28,28],[28,6],[52,27],[26,-4],[42,31],[42,-12],[21,-27],[12,11],[47,-3],[-2,-14],[43,-10],[28,6],[59,-18],[53,-6],[21,-8],[37,10],[42,-18],[31,-8]],[[3018,5753],[-1,-14],[-16,-7],[9,-26],[0,-31],[-12,-35],[10,-47],[12,4],[6,43],[-8,21],[-2,45],[35,24],[-4,27],[10,19],[10,-41],[19,-1],[18,-33],[1,-20],[25,0],[30,6],[16,-27],[21,-7],[16,18],[0,15],[34,4],[34,1],[-24,-18],[10,-28],[22,-4],[21,-29],[4,-48],[15,2],[11,-14]],[[8001,6331],[-37,-51],[-24,-56],[-6,-41],[22,-62],[25,-77],[26,-37],[17,-47],[12,-109],[-3,-104],[-24,-39],[-31,-38],[-23,-49],[-35,-55],[-10,37],[8,40],[-21,34]],[[9661,4085],[-9,-8],[-9,26],[1,16],[17,-34]],[[9641,4175],[4,-47],[-7,7],[-6,-3],[-4,16],[0,45],[13,-18]],[[6475,6041],[-21,-16],[-5,-26],[-1,-20],[-27,-25],[-45,-28],[-24,-41],[-13,-3],[-8,3],[-16,-25],[-18,-11],[-23,-3],[-7,-3],[-6,-16],[-8,-4],[-4,-15],[-14,1],[-9,-8],[-19,3],[-7,35],[1,32],[-5,17],[-5,44],[-8,24],[5,3],[-2,27],[3,12],[-1,25]],[[5817,3752],[11,0],[14,-10],[9,7],[15,-6]],[[5911,3478],[-7,-43],[-3,-49],[-7,-27],[-19,-30],[-5,-8],[-12,-30],[-8,-31],[-16,-42],[-31,-61],[-20,-36],[-21,-26],[-29,-23],[-14,-3],[-3,-17],[-17,9],[-14,-11],[-30,11],[-17,-7],[-12,3],[-28,-23],[-24,-10],[-17,-22],[-13,-1],[-11,21],[-10,1],[-12,26],[-1,-8],[-4,16],[0,34],[-9,40],[9,11],[0,45],[-19,55],[-14,50],[0,1],[-20,76]],[[5840,4141],[-21,-8],[-15,-23],[-4,-21],[-10,-4],[-24,-49],[-15,-38],[-10,-2],[-9,7],[-31,7]]],
transform:{scale:[.036003600360036005,.016927109510951093],translate:[-180,-85.609038]}},h.prototype.abwTopo="__ABW__",h.prototype.afgTopo="__AFG__",h.prototype.agoTopo="__AGO__",h.prototype.aiaTopo="__AIA__",h.prototype.albTopo="__ALB__",h.prototype.aldTopo="__ALD__",h.prototype.andTopo="__AND__",h.prototype.areTopo="__ARE__",h.prototype.argTopo="__ARG__",h.prototype.armTopo="__ARM__",h.prototype.asmTopo="__ASM__",h.prototype.ataTopo="__ATA__",h.prototype.atcTopo="__ATC__",h.prototype.atfTopo="__ATF__",h.prototype.atgTopo="__ATG__",h.prototype.ausTopo="__AUS__",h.prototype.autTopo="__AUT__",h.prototype.azeTopo="__AZE__",h.prototype.bdiTopo="__BDI__",h.prototype.belTopo="__BEL__",h.prototype.benTopo="__BEN__",h.prototype.bfaTopo="__BFA__",h.prototype.bgdTopo="__BGD__",h.prototype.bgrTopo="__BGR__",h.prototype.bhrTopo="__BHR__",h.prototype.bhsTopo="__BHS__",h.prototype.bihTopo="__BIH__",h.prototype.bjnTopo="__BJN__",h.prototype.blmTopo="__BLM__",h.prototype.blrTopo="__BLR__",h.prototype.blzTopo="__BLZ__",h.prototype.bmuTopo="__BMU__",h.prototype.bolTopo="__BOL__",h.prototype.braTopo="__BRA__",h.prototype.brbTopo="__BRB__",h.prototype.brnTopo="__BRN__",h.prototype.btnTopo="__BTN__",h.prototype.norTopo="__NOR__",h.prototype.bwaTopo="__BWA__",h.prototype.cafTopo="__CAF__",h.prototype.canTopo="__CAN__",h.prototype.cheTopo="__CHE__",h.prototype.chlTopo="__CHL__",h.prototype.chnTopo="__CHN__",h.prototype.civTopo="__CIV__",h.prototype.clpTopo="__CLP__",h.prototype.cmrTopo="__CMR__",h.prototype.codTopo="__COD__",h.prototype.cogTopo="__COG__",h.prototype.cokTopo="__COK__",h.prototype.colTopo="__COL__",h.prototype.comTopo="__COM__",h.prototype.cpvTopo="__CPV__",h.prototype.criTopo="__CRI__",h.prototype.csiTopo="__CSI__",h.prototype.cubTopo="__CUB__",h.prototype.cuwTopo="__CUW__",h.prototype.cymTopo="__CYM__",h.prototype.cynTopo="__CYN__",h.prototype.cypTopo="__CYP__",h.prototype.czeTopo="__CZE__",h.prototype.deuTopo="__DEU__",h.prototype.djiTopo="__DJI__",h.prototype.dmaTopo="__DMA__",h.prototype.dnkTopo="__DNK__",h.prototype.domTopo="__DOM__",h.prototype.dzaTopo="__DZA__",h.prototype.ecuTopo="__ECU__",h.prototype.egyTopo="__EGY__",h.prototype.eriTopo="__ERI__",h.prototype.esbTopo="__ESB__",h.prototype.espTopo="__ESP__",h.prototype.estTopo="__EST__",h.prototype.ethTopo="__ETH__",h.prototype.finTopo="__FIN__",h.prototype.fjiTopo="__FJI__",h.prototype.flkTopo="__FLK__",h.prototype.fraTopo="__FRA__",h.prototype.froTopo="__FRO__",h.prototype.fsmTopo="__FSM__",h.prototype.gabTopo="__GAB__",h.prototype.psxTopo="__PSX__",h.prototype.gbrTopo="__GBR__",h.prototype.geoTopo="__GEO__",h.prototype.ggyTopo="__GGY__",h.prototype.ghaTopo="__GHA__",h.prototype.gibTopo="__GIB__",h.prototype.ginTopo="__GIN__",h.prototype.gmbTopo="__GMB__",h.prototype.gnbTopo="__GNB__",h.prototype.gnqTopo="__GNQ__",h.prototype.grcTopo="__GRC__",h.prototype.grdTopo="__GRD__",h.prototype.grlTopo="__GRL__",h.prototype.gtmTopo="__GTM__",h.prototype.gumTopo="__GUM__",h.prototype.guyTopo="__GUY__",h.prototype.hkgTopo="__HKG__",h.prototype.hmdTopo="__HMD__",h.prototype.hndTopo="__HND__",h.prototype.hrvTopo="__HRV__",h.prototype.htiTopo="__HTI__",h.prototype.hunTopo="__HUN__",h.prototype.idnTopo="__IDN__",h.prototype.imnTopo="__IMN__",h.prototype.indTopo="__IND__",h.prototype.ioaTopo="__IOA__",h.prototype.iotTopo="__IOT__",h.prototype.irlTopo="__IRL__",h.prototype.irnTopo="__IRN__",h.prototype.irqTopo="__IRQ__",h.prototype.islTopo="__ISL__",h.prototype.isrTopo="__ISR__",h.prototype.itaTopo="__ITA__",h.prototype.jamTopo="__JAM__",h.prototype.jeyTopo="__JEY__",h.prototype.jorTopo="__JOR__",h.prototype.jpnTopo="__JPN__",h.prototype.kabTopo="__KAB__",h.prototype.kasTopo="__KAS__",h.prototype.kazTopo="__KAZ__",h.prototype.kenTopo="__KEN__",h.prototype.kgzTopo="__KGZ__",h.prototype.khmTopo="__KHM__",h.prototype.kirTopo="__KIR__",h.prototype.knaTopo="__KNA__",h.prototype.korTopo="__KOR__",h.prototype.kosTopo="__KOS__",h.prototype.kwtTopo="__KWT__",h.prototype.laoTopo="__LAO__",h.prototype.lbnTopo="__LBN__",h.prototype.lbrTopo="__LBR__",h.prototype.lbyTopo="__LBY__",h.prototype.lcaTopo="__LCA__",h.prototype.lieTopo="__LIE__",h.prototype.lkaTopo="__LKA__",h.prototype.lsoTopo="__LSO__",h.prototype.ltuTopo="__LTU__",h.prototype.luxTopo="__LUX__",h.prototype.lvaTopo="__LVA__",h.prototype.macTopo="__MAC__",h.prototype.mafTopo="__MAF__",h.prototype.marTopo="__MAR__",h.prototype.mcoTopo="__MCO__",h.prototype.mdaTopo="__MDA__",h.prototype.mdgTopo="__MDG__",h.prototype.mdvTopo="__MDV__",h.prototype.mexTopo="__MEX__",h.prototype.mhlTopo="__MHL__",h.prototype.mkdTopo="__MKD__",h.prototype.mliTopo="__MLI__",h.prototype.mltTopo="__MLT__",h.prototype.mmrTopo="__MMR__",h.prototype.mneTopo="__MNE__",h.prototype.mngTopo="__MNG__",h.prototype.mnpTopo="__MNP__",h.prototype.mozTopo="__MOZ__",h.prototype.mrtTopo="__MRT__",h.prototype.msrTopo="__MSR__",h.prototype.musTopo="__MUS__",h.prototype.mwiTopo="__MWI__",h.prototype.mysTopo="__MYS__",h.prototype.namTopo="__NAM__",h.prototype.nclTopo="__NCL__",h.prototype.nerTopo="__NER__",h.prototype.nfkTopo="__NFK__",h.prototype.ngaTopo="__NGA__",h.prototype.nicTopo="__NIC__",h.prototype.niuTopo="__NIU__",h.prototype.nldTopo="__NLD__",h.prototype.nplTopo="__NPL__",h.prototype.nruTopo="__NRU__",h.prototype.nulTopo="__NUL__",h.prototype.nzlTopo="__NZL__",h.prototype.omnTopo="__OMN__",h.prototype.pakTopo="__PAK__",h.prototype.panTopo="__PAN__",h.prototype.pcnTopo="__PCN__",h.prototype.perTopo="__PER__",h.prototype.pgaTopo="__PGA__",h.prototype.phlTopo="__PHL__",h.prototype.plwTopo="__PLW__",h.prototype.pngTopo="__PNG__",h.prototype.polTopo="__POL__",h.prototype.priTopo="__PRI__",h.prototype.prkTopo="__PRK__",h.prototype.prtTopo="__PRT__",h.prototype.pryTopo="__PRY__",h.prototype.pyfTopo="__PYF__",h.prototype.qatTopo="__QAT__",h.prototype.rouTopo="__ROU__",h.prototype.rusTopo="__RUS__",h.prototype.rwaTopo="__RWA__",h.prototype.sahTopo="__SAH__",h.prototype.sauTopo="__SAU__",h.prototype.scrTopo="__SCR__",h.prototype.sdnTopo="__SDN__";h.prototype.sdsTopo="__SDS__";h.prototype.senTopo="__SEN__",h.prototype.serTopo="__SER__",h.prototype.sgpTopo="__SGP__",h.prototype.sgsTopo="__SGS__",h.prototype.shnTopo="__SHN__",h.prototype.slbTopo="__SLB__",h.prototype.sleTopo="__SLE__",h.prototype.slvTopo="__SLV__",h.prototype.smrTopo="__SMR__",h.prototype.solTopo="__SOL__",h.prototype.somTopo="__SOM__",h.prototype.spmTopo="__SPM__",h.prototype.srbTopo="__SRB__",h.prototype.stpTopo="__STP__",h.prototype.surTopo="__SUR__",h.prototype.svkTopo="__SVK__",h.prototype.svnTopo="__SVN__",h.prototype.sweTopo="__SWE__",h.prototype.swzTopo="__SWZ__",h.prototype.sxmTopo="__SXM__",h.prototype.sycTopo="__SYC__",h.prototype.syrTopo="__SYR__",h.prototype.tcaTopo="__TCA__",h.prototype.tcdTopo="__TCD__",h.prototype.tgoTopo="__TGO__",h.prototype.thaTopo="__THA__",h.prototype.tjkTopo="__TJK__",h.prototype.tkmTopo="__TKM__",h.prototype.tlsTopo="__TLS__",h.prototype.tonTopo="__TON__",h.prototype.ttoTopo="__TTO__",h.prototype.tunTopo="__TUN__",h.prototype.turTopo="__TUR__",h.prototype.tuvTopo="__TUV__",h.prototype.twnTopo="__TWN__",h.prototype.tzaTopo="__TZA__",h.prototype.ugaTopo="__UGA__",h.prototype.ukrTopo="__UKR__",h.prototype.umiTopo="__UMI__",h.prototype.uryTopo="__URY__",h.prototype.usaTopo={type:"Topology",transform:{scale:[.03514630243024302,.005240860686068607],translate:[-178.123152,18.948267]},objects:{usa:{type:"GeometryCollection",geometries:[{type:"Polygon",id:"AL",arcs:[[0,1,2,3,4]],properties:{name:"Alabama"}},{type:"MultiPolygon",id:"AK",arcs:[[[5]],[[6]],[[7]],[[8]],[[9]],[[10]],[[11]],[[12]],[[13]],[[14]],[[15]],[[16]],[[17]],[[18]],[[19]],[[20]],[[21]],[[22]],[[23]],[[24]],[[25]],[[26]],[[27]],[[28]],[[29]],[[30]],[[31]],[[32]],[[33]],[[34]],[[35]],[[36]],[[37]],[[38]],[[39]],[[40]],[[41]],[[42]],[[43]]],properties:{name:"Alaska"}},{type:"Polygon",id:"AZ",arcs:[[44,45,46,47,48]],properties:{name:"Arizona"}},{type:"Polygon",id:"AR",arcs:[[49,50,51,52,53,54]],properties:{name:"Arkansas"}},{type:"Polygon",id:"CA",arcs:[[55,-47,56,57]],properties:{name:"California"}},{type:"Polygon",id:"CO",arcs:[[58,59,60,61,62,63]],properties:{name:"Colorado"}},{type:"Polygon",id:"CT",arcs:[[64,65,66,67]],properties:{name:"Connecticut"}},{type:"Polygon",id:"DE",arcs:[[68,69,70,71]],properties:{name:"Delaware"}},{type:"Polygon",id:"DC",arcs:[[72,73]],properties:{name:"District of Columbia"}},{type:"Polygon",id:"FL",arcs:[[74,75,-2]],properties:{name:"Florida"}},{type:"Polygon",id:"GA",arcs:[[76,77,-75,-1,78,79]],properties:{name:"Georgia"}},{type:"MultiPolygon",id:"HI",arcs:[[[80]],[[81]],[[82]],[[83]],[[84]]],properties:{name:"Hawaii"}},{type:"Polygon",id:"ID",arcs:[[85,86,87,88,89,90,91]],properties:{name:"Idaho"}},{type:"Polygon",id:"IL",arcs:[[92,93,94,95,96,97]],properties:{name:"Illinois"}},{type:"Polygon",id:"IN",arcs:[[98,99,-95,100,101]],properties:{name:"Indiana"}},{type:"Polygon",id:"IA",arcs:[[102,-98,103,104,105,106]],properties:{name:"Iowa"}},{type:"Polygon",id:"KS",arcs:[[107,108,-60,109]],properties:{name:"Kansas"}},{type:"Polygon",id:"KY",arcs:[[110,111,112,113,-96,-100,114]],properties:{name:"Kentucky"}},{type:"Polygon",id:"LA",arcs:[[115,116,117,-52]],properties:{name:"Louisiana"}},{type:"Polygon",id:"ME",arcs:[[118,119]],properties:{name:"Maine"}},{type:"MultiPolygon",id:"MD",arcs:[[[120]],[[-71,121,122,123,124,-74,125,126,127]]],properties:{name:"Maryland"}},{type:"Polygon",id:"MA",arcs:[[128,129,130,131,-68,132,133,134]],properties:{name:"Massachusetts"}},{type:"MultiPolygon",id:"MI",arcs:[[[-102,135,136]],[[137]],[[138,139]],[[140]]],properties:{name:"Michigan"}},{type:"Polygon",id:"MN",arcs:[[-107,141,142,143,144]],properties:{name:"Minnesota"}},{type:"Polygon",id:"MS",arcs:[[-4,145,-116,-51,146]],properties:{name:"Mississippi"}},{type:"Polygon",id:"MO",arcs:[[-97,-114,147,-55,148,-108,149,-104]],properties:{name:"Missouri"}},{type:"Polygon",id:"MT",arcs:[[150,151,-92,152,153]],properties:{name:"Montana"}},{type:"Polygon",id:"NE",arcs:[[-105,-150,-110,-59,154,155]],properties:{name:"Nebraska"}},{type:"Polygon",id:"NV",arcs:[[156,-48,-56,157,-88]],properties:{name:"Nevada"}},{type:"Polygon",id:"NH",arcs:[[-135,158,159,-120,160]],properties:{name:"New Hampshire"}},{type:"Polygon",id:"NJ",arcs:[[161,-69,162,163]],properties:{name:"New Jersey"}},{type:"Polygon",id:"NM",arcs:[[164,165,166,-45,-62]],properties:{name:"New Mexico"}},{type:"Polygon",id:"NY",arcs:[[-133,-67,167,-164,168,169,170]],properties:{name:"New York"}},{type:"Polygon",id:"NC",arcs:[[171,172,-80,173,174]],properties:{name:"North Carolina"}},{type:"Polygon",id:"ND",arcs:[[175,-154,176,-143]],properties:{name:"North Dakota"}},{type:"Polygon",id:"OH",arcs:[[177,-115,-99,-137,178,179]],properties:{name:"Ohio"}},{type:"Polygon",id:"OK",arcs:[[-149,-54,180,-165,-61,-109]],properties:{name:"Oklahoma"}},{type:"Polygon",id:"OR",arcs:[[-89,-158,-58,181,182]],properties:{name:"Oregon"}},{type:"Polygon",id:"PA",arcs:[[-163,-72,-128,183,-180,184,-169]],properties:{name:"Pennsylvania"}},{type:"MultiPolygon",id:"RI",arcs:[[[185,-130]],[[186,-65,-132]]],properties:{name:"Rhode Island"}},{type:"Polygon",id:"SC",arcs:[[187,-77,-173]],properties:{name:"South Carolina"}},{type:"Polygon",id:"SD",arcs:[[-142,-106,-156,188,-151,-176]],properties:{name:"South Dakota"}},{type:"Polygon",id:"TN",arcs:[[189,-174,-79,-5,-147,-50,-148,-113]],properties:{name:"Tennessee"}},{type:"Polygon",id:"TX",arcs:[[-53,-118,190,-166,-181]],properties:{name:"Texas"}},{type:"Polygon",id:"UT",arcs:[[191,-63,-49,-157,-87]],properties:{name:"Utah"}},{type:"Polygon",id:"VT",arcs:[[-134,-171,192,-159]],properties:{name:"Vermont"}},{type:"MultiPolygon",id:"VA",arcs:[[[193,-123]],[[120]],[[-126,-73,-125,194,-175,-190,-112,195]]],properties:{name:"Virginia"}},{type:"MultiPolygon",id:"WA",arcs:[[[-183,196,-90]],[[197]],[[198]]],properties:{name:"Washington"}},{type:"Polygon",id:"WV",arcs:[[-184,-127,-196,-111,-178]],properties:{name:"West Virginia"}},{type:"Polygon",id:"WI",arcs:[[199,-93,-103,-145,200,-140]],properties:{name:"Wisconsin"}},{type:"Polygon",id:"WY",arcs:[[-189,-155,-64,-192,-86,-152]],properties:{name:"Wyoming"}}]}},arcs:[[[2632,3060],[5,-164],[7,-242],[4,-53],[3,-30],[-2,-19],[4,-11],[-5,-25],[0,-24],[-2,-32],[2,-57],[-2,-51],[3,-52]],[[2649,2300],[-14,-1],[-59,0],[-1,-25],[6,-37],[-1,-31],[2,-16],[-4,-28]],[[2578,2162],[-4,-6],[-7,31],[-1,47],[-2,6],[-3,-36],[-1,-34],[-7,9]],[[2553,2179],[-2,291],[6,363],[4,209],[-3,20]],[[2558,3062],[24,1],[50,-3]],[[1324,6901],[1,32],[6,-19],[-1,-32],[-8,4],[2,15]],[[1317,6960],[5,-23],[-3,-33],[-2,11],[0,45]],[[1285,7153],[6,5],[3,-8],[-1,-28],[-6,-6],[-5,17],[3,20]],[[1267,7137],[12,-7],[3,-36],[13,-41],[4,-25],[0,-21],[3,-4],[1,-27],[5,-27],[0,-25],[3,8],[2,-19],[1,-74],[-3,-17],[-7,3],[-3,38],[-2,-3],[-6,28],[-2,-10],[-5,10],[1,-28],[5,7],[3,-10],[-2,-39],[-5,4],[-9,49],[-2,25],[1,26],[-7,-2],[0,20],[5,2],[5,18],[-2,31],[-6,7],[-1,50],[-2,25],[-4,-18],[-2,28],[4,14],[-3,32],[2,8]],[[1263,6985],[5,-12],[4,15],[4,-7],[-4,-28],[-6,8],[-3,24]],[[1258,7247],[-4,19],[5,13],[15,-18],[7,1],[5,-36],[9,-29],[-1,-22],[-5,-11],[-6,5],[-5,-14],[-6,9],[-7,-9],[-1,45],[0,30],[-5,1],[-1,16]],[[1252,7162],[-4,14],[-4,32],[0,24],[3,11],[4,-11],[0,20],[12,-35],[1,-33],[-4,-5],[-3,-37],[3,-11],[-3,-43],[-5,9],[0,-27],[-3,13],[-2,54],[5,25]],[[1207,7331],[8,38],[3,-16],[7,-13],[6,-2],[0,-30],[6,-99],[0,-85],[-1,-22],[-4,13],[-10,84],[-7,25],[3,20],[-3,48],[-8,39]],[[1235,7494],[10,-15],[5,2],[0,-14],[8,-52],[-5,8],[-2,-18],[6,-27],[2,-48],[-6,-13],[-2,-16],[-10,-35],[-3,1],[-1,37],[2,22],[-1,32],[-3,40],[0,21],[-2,51],[-4,22],[-1,38],[7,-36]],[[1203,7324],[4,0],[4,-35],[-2,-24],[-6,-5],[0,38],[0,26]],[[1207,7331],[-5,7],[-3,26],[-6,18],[-5,37],[-6,17],[1,30],[4,10],[1,26],[3,-11],[8,-1],[6,17],[8,-23],[-5,-26],[2,-9],[4,28],[10,-9],[5,-21],[-3,-38],[3,-3],[3,-50],[-7,-7],[-14,41],[0,-42],[-4,-17]],[[883,7871],[-12,-48],[-1,-19],[-9,-12],[2,29],[10,30],[7,34],[3,-14]],[[870,7943],[-2,-39],[-4,-41],[-6,14],[5,47],[7,19]],[[863,9788],[3,-8],[15,-9],[8,5],[10,0],[12,-7],[7,4],[7,-15],[12,-18],[16,-4],[5,10],[11,6],[4,14],[12,2],[0,-9],[7,5],[15,-15],[9,-24],[10,-11],[2,-11],[8,-2],[8,-18],[1,-11],[5,9],[6,-7],[0,-1783],[13,-16],[2,17],[14,-24],[8,30],[18,4],[-3,-52],[4,-17],[10,-17],[2,-27],[29,-101],[4,-63],[6,17],[12,31],[7,1],[3,23],[0,34],[5,0],[1,31],[9,7],[13,26],[13,-45],[-1,-27],[3,-27],[7,-7],[10,-40],[-1,-12],[4,-22],[12,-25],[19,-110],[3,-29],[6,-29],[8,-65],[9,-55],[-3,-23],[9,-9],[-2,-33],[7,-14],[1,-38],[7,2],[14,-40],[9,-7],[5,-19],[4,-5],[1,-19],[9,-5],[3,-23],[-4,-43],[1,-36],[4,-58],[-4,-15],[-6,-53],[-10,-39],[-3,20],[-4,-6],[-3,39],[1,17],[-3,20],[7,21],[-2,7],[-7,-26],[-3,17],[-4,-10],[-12,42],[4,46],[-8,-15],[0,-23],[-6,17],[-1,22],[4,24],[-1,24],[-6,-19],[-6,42],[-3,-8],[-2,36],[5,23],[6,0],[-2,28],[3,36],[-5,-1],[-9,32],[-6,37],[-15,27],[0,77],[-4,9],[1,31],[-5,9],[-8,42],[-2,22],[-12,7],[-14,56],[-6,132],[-3,-30],[1,-27],[6,-53],[-1,-8],[3,-43],[0,-28],[-6,6],[-4,31],[-6,6],[-8,-9],[0,45],[-5,38],[-5,-12],[-17,40],[-2,-11],[10,-13],[7,-31],[3,-1],[1,-25],[4,-30],[-10,-16],[-5,10],[0,-26],[-8,20],[-2,14],[-5,0],[-13,38],[-10,33],[-1,20],[-5,30],[-14,21],[-9,21],[-14,26],[-9,24],[1,26],[2,-9],[3,17],[-3,38],[4,21],[-2,9],[-7,-40],[-14,-26],[-18,10],[-14,24],[-1,18],[-7,-4],[-7,14],[-17,12],[-9,1],[-21,-10],[-8,-7],[-10,27],[-12,12],[-3,17],[-2,28],[-8,-2],[-3,-25],[-15,34],[-2,14],[-15,-27],[-7,-32],[-3,30],[3,17],[4,-5],[14,22],[-2,17],[-6,-8],[-3,22],[-6,3],[-6,55],[-3,-13],[-8,-8],[-3,8],[-3,-18],[-11,6],[-1,-20],[-7,-5],[-3,7],[2,36],[-3,-1],[-5,-38],[7,-12],[1,-27],[4,-30],[-3,-31],[-5,10],[-2,-15],[6,-7],[3,-41],[-8,-9],[-4,9],[-7,-12],[-3,10],[-9,-2],[0,16],[-4,-10],[-3,-20],[-3,18],[-5,-25],[2,-12],[-6,-15],[-6,-2],[-3,-20],[-6,-17],[-4,6],[-5,-21],[-4,1],[-8,-43],[-9,-3],[-3,14],[-5,-23],[-11,17],[2,33],[8,11],[4,-2],[2,13],[8,25],[0,21],[-11,-28],[-9,16],[-1,12],[5,48],[8,34],[1,29],[2,5],[1,30],[-4,34],[10,12],[19,48],[4,-19],[6,-5],[9,20],[-10,26],[-4,20],[-7,-2],[-5,9],[-2,-8],[-9,-14],[-4,-26],[-9,-6],[-9,-30],[-1,-20],[-7,-11],[-2,-22],[-5,-13],[-2,-39],[-10,-25],[5,-20],[-4,-29],[-9,-5],[-1,-38],[-8,-13],[-3,15],[-4,-29],[-5,-1],[1,-21],[-11,-13],[-2,-57],[12,-3],[10,-16],[3,-19],[-4,-30],[-7,-19],[-6,-1],[0,-17],[-4,-6],[1,-21],[-4,-31],[-9,-29],[-5,0],[-5,-11],[-5,2],[-4,-11],[2,-16],[-7,-8],[-2,-23],[-5,14],[-5,-45],[-9,4],[1,-24],[-6,6],[-3,-11],[0,-32],[-6,-50],[-10,-6],[-7,-23],[-2,-13],[-5,18],[-8,-48],[-2,13],[-5,-4],[-1,-27],[-5,-10],[-6,4],[-4,-27],[8,-9],[-9,-60],[-25,-20],[-6,-54],[-2,12],[1,33],[-5,6],[-6,-13],[-1,-14],[-10,-22],[-4,-25],[-1,18],[-2,-21],[-6,14],[-10,-33],[-8,2],[1,25],[-4,24],[-3,-20],[1,-21],[-11,-64],[-3,16],[-1,-24],[-8,4],[-1,38],[-4,8],[-2,-14],[4,-16],[-2,-27],[-5,-13],[-5,29],[-5,2],[-1,-11],[5,-17],[-9,-27],[6,-7],[0,-13],[-5,9],[-7,-25],[-15,1],[-7,-16],[0,-13],[-8,-15],[-6,6],[-2,35],[6,12],[4,43],[6,1],[13,28],[10,1],[4,-27],[3,20],[-1,23],[6,10],[7,0],[8,50],[10,45],[12,40],[15,18],[6,-9],[6,12],[1,-17],[-3,-19],[4,-14],[1,23],[7,2],[2,-15],[5,-5],[0,18],[-8,15],[0,11],[5,49],[6,28],[9,27],[15,24],[10,35],[5,-13],[4,5],[-1,22],[1,21],[8,44],[11,28],[8,38],[0,21],[7,148],[11,40],[-1,31],[-27,-45],[-8,6],[-2,18],[-5,9],[-1,21],[-4,-10],[-3,-32],[5,-41],[-6,-18],[-5,7],[-9,64],[-6,33],[-4,0],[-2,-24],[-3,-4],[-4,19],[-5,4],[-2,32],[-16,-37],[-13,-26],[-1,-14],[-11,-22],[-6,20],[5,23],[-1,54],[-4,57],[7,24],[-6,49],[-5,27],[-4,39],[-6,17],[-2,-34],[-7,-8],[-12,-22],[-14,-9],[-7,2],[-7,12],[-1,30],[-5,9],[-9,42],[-8,8],[-8,46],[6,21],[1,39],[-5,-8],[0,24],[2,19],[-6,18],[0,-19],[-7,8],[-1,32],[-6,4],[-3,22],[0,27],[-5,-12],[-1,26],[7,6],[-6,30],[10,2],[0,35],[2,24],[18,77],[4,23],[3,-5],[-2,33],[7,55],[6,22],[11,9],[8,-9],[12,-33],[8,4],[11,32],[11,49],[6,6],[1,-13],[13,0],[12,10],[11,52],[0,12],[-5,48],[-1,28],[-8,31],[-3,26],[8,-7],[8,22],[0,20],[-10,39],[-8,-30],[-7,5],[-6,-17],[-8,-4],[-2,-11],[-9,-17],[-2,-28],[-5,-12],[-2,34],[-5,7],[-4,-26],[-2,12],[-10,19],[-20,-1],[-14,-21],[-6,-3],[-11,13],[-22,14],[-6,12],[-3,19],[2,26],[-8,22],[2,24],[5,12],[-2,31],[-8,0],[-6,8],[-13,6],[-7,16],[-10,16],[-1,19],[16,27],[20,43],[15,27],[8,-15],[8,-3],[2,21],[-5,3],[-1,18],[20,29],[22,22],[12,2],[7,-7],[-4,-32],[2,-22],[-3,-15],[4,-26],[8,5],[10,-5],[11,6],[4,-10],[7,-2],[7,10],[8,-11],[9,42],[5,2],[5,-8],[2,24],[-12,11],[-11,-9],[1,31],[-8,34],[-10,10],[-2,30],[7,8],[9,-31],[-1,-24],[4,-18],[10,-22],[2,23],[-11,30],[5,54],[-4,10],[-11,-12],[-11,3],[-2,10],[-6,-10],[-24,23],[0,24],[-7,54],[-6,19],[-9,17],[-19,46],[-9,18],[-8,4],[-13,31],[-12,18],[-1,6],[9,10],[4,29],[1,59],[25,-4],[31,13],[8,11],[12,29],[12,45],[3,45],[5,38],[10,33],[5,24],[13,38],[2,-10],[11,-3],[16,20],[10,21],[24,64],[9,4],[1,-10],[9,7],[9,-2],[18,9],[17,28],[17,58],[7,13],[2,-10],[26,-24],[2,-17],[-9,-22],[-4,-1],[0,-29],[14,9],[0,16],[6,14],[2,-8],[5,33],[13,-30],[-2,-23],[8,-6],[5,-14],[7,22],[13,1],[7,7],[18,-7],[10,-8],[-5,-45],[17,-12],[2,-11],[16,-20],[1,9],[12,13],[11,-1],[0,-11],[7,-1],[7,15],[11,2],[9,-6],[11,-16],[5,3],[7,-22],[4,9],[7,-7],[5,-13]],[[717,7456],[-1,-8],[-9,13],[7,49],[6,4],[4,45],[5,-40],[4,14],[8,-22],[0,-31],[-11,-4],[-5,-13],[-8,-7]],[[688,7363],[8,25],[-8,6],[0,22],[6,14],[5,-10],[0,-22],[3,15],[0,32],[5,-15],[1,21],[5,-12],[5,0],[5,11],[7,-20],[0,-55],[9,4],[-6,-37],[-11,15],[4,-24],[-3,-20],[-6,10],[0,-38],[-8,-10],[-3,-16],[-5,15],[-6,-40],[-4,-4],[-5,-18],[-2,43],[-6,-23],[-1,13],[-6,14],[0,39],[-6,15],[4,45],[11,28],[7,-2],[1,-21]],[[671,7185],[-6,-39],[-2,6],[8,33]],[[640,7055],[4,-2],[-1,-40],[-8,6],[-1,13],[6,23]],[[519,6933],[-2,-41],[-9,-33],[5,51],[2,-5],[4,28]],[[501,6947],[5,0],[0,-20],[-5,-23],[-5,15],[-3,-14],[-2,35],[2,12],[8,-5]],[[451,6875],[1,-16],[-3,-11],[-3,18],[5,9]],[[447,8527],[-4,-19],[-2,16],[6,3]],[[436,6781],[6,-7],[-1,-16],[-5,1],[0,22]],[[358,6745],[2,-22],[-5,-10],[-1,23],[4,9]],[[352,6718],[-8,-21],[-2,14],[3,19],[7,-12]],[[335,7902],[6,7],[2,-14],[5,3],[6,-12],[1,-54],[-3,-18],[-7,-11],[-2,-18],[-11,20],[-5,-1],[-10,28],[-4,0],[-6,15],[-3,25],[4,7],[10,-7],[5,20],[5,2],[3,14],[4,-6]],[[334,6690],[5,-14],[-10,-36],[1,-6],[12,26],[0,-15],[-5,-17],[-8,-12],[-1,-18],[-8,-18],[-7,-1],[-5,-18],[-9,-16],[-5,17],[9,20],[3,-3],[8,16],[-2,19],[4,20],[6,-9],[1,12],[-7,4],[-4,14],[4,23],[11,13],[2,-26],[5,25]],[[266,6527],[10,37],[1,16],[4,17],[7,9],[3,-10],[1,-25],[-12,-27],[-6,-40],[-6,-13],[-2,36]],[[238,6477],[2,-19],[-8,-1],[-1,13],[7,7]],[[227,7303],[-4,-18],[-1,18],[5,0]],[[212,6440],[2,-18],[-5,-13],[-1,19],[4,12]],[[182,8542],[22,-28],[13,24],[6,-2],[5,-14],[2,-23],[11,-12],[4,-12],[15,-5],[8,-8],[-4,-28],[-7,6],[-8,-5],[-4,-13],[-4,-28],[-5,26],[-6,18],[-6,2],[-3,20],[-15,25],[-6,1],[-11,-22],[-7,11],[-4,23],[4,44]],[[162,6381],[0,-22],[-5,-4],[1,19],[4,7]],[[128,6335],[4,-8],[10,1],[1,-7],[-13,-9],[-2,23]],[[108,6360],[0,19],[4,7],[6,-19],[-2,-17],[-4,1],[1,-20],[-5,-2],[-12,-21],[-6,6],[2,15],[7,-2],[9,33]],[[47,6279],[5,3],[0,-24],[-6,3],[-8,-28],[-4,37],[4,1],[0,29],[5,1],[0,-21],[4,-1]],[[28,6296],[3,-9],[-2,-32],[-5,-10],[0,20],[4,31]],[[0,6291],[5,-1],[4,-23],[-4,-27],[-5,51]],[[9993,6496],[6,-13],[0,-19],[-11,-12],[-8,31],[0,15],[13,-2]],[[1966,3444],[-1,-1081]],[[1965,2363],[-57,0],[-34,71],[-73,150],[3,43]],[[1804,2627],[6,8],[1,16],[-1,36],[-4,1],[-2,71],[6,27],[0,28],[-1,45],[4,34],[4,12],[4,25],[-6,27],[-4,51],[-5,31],[0,24]],[[1806,3063],[2,26],[0,36],[-3,36],[-2,112],[11,7],[3,-23],[3,1],[3,33],[0,153]],[[1823,3444],[101,2],[42,-2]],[[2515,3253],[-1,-35],[-4,-11],[-1,-29],[-5,-31],[0,-46],[-3,-34],[-3,-5]],[[2498,3062],[2,-17],[-4,-14],[-2,-33],[-3,-8],[0,-38],[-5,-10],[0,-13],[-6,-31],[2,-21],[-5,-30],[-5,-59],[5,-25],[-2,-16],[1,-39],[-2,-26]],[[2474,2682],[-69,3],[-13,0]],[[2392,2685],[0,101],[-4,8],[-5,-9],[-3,18]],[[2380,2803],[1,335],[-5,211]],[[2376,3349],[4,0],[123,-1],[2,-36],[-4,-23],[-4,-36],[18,0]],[[1654,4398],[0,-331],[0,-241],[36,-171],[35,-169],[27,-137],[20,-101],[34,-185]],[[1804,2627],[-38,-18],[-30,-16],[-4,25],[0,40],[-2,47],[-4,33],[-9,46],[-12,43],[-2,-12],[-4,8],[1,18],[-5,39],[-7,-8],[-12,28],[-2,23],[-8,28],[-9,-1],[-7,13],[-10,-6],[-5,26],[1,53],[-1,8],[1,38],[-8,28],[0,39],[-3,2],[-4,33],[-4,8],[-1,20],[-11,79],[-5,23],[-1,61],[2,-5],[2,37],[-4,33],[-5,-4],[-7,30],[-2,24],[0,23],[-3,31],[0,50],[5,0],[-2,70],[-2,-7],[-1,-35],[-5,-7],[-7,26],[-1,45],[-4,35],[-6,22],[-3,25],[-9,50],[2,14],[-4,64],[2,35],[-3,54],[-7,52],[-7,29],[-2,35],[7,83],[2,29],[-2,22],[3,57],[-2,52],[-3,13],[1,42]],[[1534,4399],[28,1],[24,1],[38,-3],[30,0]],[[2107,4208],[57,0],[0,-191]],[[2164,4017],[1,-574]],[[2165,3443],[-28,1]],[[2137,3444],[-38,-1],[-72,0],[-15,1],[-46,0]],[[1966,3444],[0,223],[-1,21],[0,162],[0,357]],[[1965,4207],[32,1],[63,-1],[47,1]],[[3025,4400],[0,-113],[-2,-18]],[[3023,4269],[-2,3],[-12,-14],[-15,4],[-7,-26],[-7,-9],[-8,-22]],[[2972,4205],[-2,22],[7,21],[-2,16],[2,144]],[[2977,4408],[12,-2],[36,-3],[0,-3]],[[2922,3980],[-2,-23]],[[2920,3957],[-3,-13],[0,-30],[5,-29],[1,-47],[6,-49],[3,-2],[1,-66]],[[2933,3721],[-19,2],[-2,241]],[[2912,3964],[5,21],[5,-5]],[[2876,3786],[-2,27]],[[2874,3813],[2,12],[4,-19],[-4,-20]],[[2649,2300],[4,-55],[39,-13],[37,-14],[1,-41],[4,1],[1,39],[-1,35],[2,15],[7,-16],[8,-7]],[[2751,2244],[1,-83],[4,-93],[8,-122],[13,-131],[-2,-9],[1,-61],[5,-68],[8,-137],[2,-42],[0,-44],[-3,-158],[-3,-3],[-3,-49],[1,-16],[-5,-36],[-2,9],[-6,-15],[-9,-8],[-2,20],[1,29],[-7,85],[-5,15],[-4,-11],[-3,47],[-1,38],[-6,43],[-2,28],[1,41],[-3,8],[1,-24],[-3,-7],[-9,104],[-4,26],[9,76],[-6,-4],[-4,-24],[-3,38],[5,104],[1,87],[-4,21],[-1,28],[-5,6],[-7,46],[-5,19],[0,28],[-4,11],[-3,31],[-11,42],[-9,-10],[0,-29],[-3,5],[-12,-35],[-12,-9],[0,21],[-3,25],[-15,57],[-10,24],[-10,6],[-8,-4],[-17,-18]],[[2703,3063],[-6,-41],[0,-20],[9,-40],[3,3],[5,-42],[1,-22],[4,-40],[7,-24],[3,-35],[8,-33],[0,-22],[5,-35],[7,-29],[2,-32],[1,-40],[3,-14],[5,-51],[0,-33],[7,-16]],[[2767,2497],[-7,-65],[-2,-34],[-3,-29],[0,-30],[-3,-14],[-1,-81]],[[2632,3060],[37,1]],[[2669,3061],[20,-1],[14,3]],[[640,0],[-7,17],[-1,16],[1,43],[-5,73],[4,24],[2,34],[-2,22],[1,23],[8,-27],[9,-20],[5,-29],[0,-26],[8,-40],[-5,-34],[-8,-15],[-7,-25],[-3,-36]],[[613,397],[3,-26],[4,11],[9,-30],[-1,-27],[-9,-14],[-2,6],[-1,33],[-5,7],[-1,19],[3,21]],[[602,432],[-3,-20],[-7,0],[2,22],[8,-2]],[[574,525],[3,-45],[-2,-26],[-6,-5],[-4,54],[4,1],[5,21]],[[531,626],[3,-2],[2,-20],[-1,-28],[-4,-18],[-9,22],[1,31],[8,15]],[[1908,4871],[0,-472]],[[1908,4399],[-31,-1],[-54,0]],[[1823,4398],[-85,1]],[[1738,4399],[0,349],[4,62],[-2,16],[-6,3],[-2,26],[6,68],[3,6],[3,29],[-1,17],[4,23],[1,34],[6,56],[-2,26],[-7,14],[-4,32]],[[1741,5160],[0,34],[-3,33],[0,16],[0,255],[0,236]],[[1738,5734],[28,0]],[[1766,5734],[0,-195],[9,-54],[1,-52],[5,-23],[6,-8],[0,-14],[11,-51],[1,-21],[8,-20],[0,-12],[8,1],[-4,-71],[-1,-45],[3,-29],[-5,-21],[2,-20],[-1,-21],[6,-20],[7,26],[3,21],[5,-19],[-1,-15],[3,-37],[5,-39],[3,-13],[0,-37],[3,-16],[6,-2],[4,-61],[3,-11],[3,18],[9,-1],[7,17],[3,-10],[7,9],[2,-11],[5,8],[7,39],[4,-33],[5,-20]],[[2489,4496],[53,-3],[28,0]],[[2570,4493],[-1,-37],[4,-43],[5,-70]],[[2578,4343],[0,-450],[-3,-35],[3,-40],[1,-34],[-4,-27],[-1,-25],[-5,-41],[-3,-3],[0,-24],[-2,-9],[-1,-45],[0,-13]],[[2563,3597],[-3,-27],[2,-34],[-11,-17],[-1,-20],[2,-25],[-3,-16],[-11,29],[-3,-2],[-4,-33],[1,-11]],[[2532,3441],[-5,2],[-6,55],[2,12],[-2,37],[0,29],[-9,41],[-3,-4],[-3,25],[-9,38],[0,31],[5,49],[-1,18],[3,23],[-4,13],[-6,9],[-3,-18],[-3,11],[-1,63],[-10,41],[-9,49],[-3,58],[-1,39],[3,27]],[[2467,4089],[0,35],[8,21],[1,29],[4,19],[0,33],[-4,27],[2,34],[11,9],[9,24],[0,29],[4,13],[1,37],[0,24],[-7,18],[-1,20],[-6,35]],[[2655,4340],[0,-228],[0,-266]],[[2655,3846],[-2,-9],[2,-52],[-5,-1],[-5,-18],[-8,9],[1,-38],[-5,-16],[-2,-24],[-5,-9],[-3,-48],[-3,-13],[-6,18],[-1,22],[-7,-24],[1,-21],[-7,-7],[-1,19],[-8,-19],[-2,-20],[-7,28],[-4,-6],[-2,13],[-3,-13],[-7,-2],[-3,-18]],[[2578,4343],[3,-12],[8,0],[9,22]],[[2598,4353],[23,0],[34,0],[0,-13]],[[2473,4685],[0,-28],[4,-19],[-3,-23],[1,-43],[2,-30],[10,-22],[2,-24]],[[2467,4089],[-3,7],[-6,38],[-3,-1],[-40,-5],[-39,-2],[-33,3]],[[2343,4129],[-3,25],[2,49],[-3,43],[0,48],[-5,17],[-1,26],[2,23],[-2,33],[-4,13],[-5,86]],[[2324,4492],[-5,41],[2,29],[1,37],[2,14],[-3,19],[1,33],[-2,16],[4,4]],[[2324,4685],[144,0],[5,0]],[[2356,4017],[3,-18],[9,-14],[-6,-56],[4,-18],[4,-45],[6,-10],[0,-412]],[[2376,3444],[-156,0],[-55,-1]],[[2164,4017],[5,0],[187,0]],[[2718,3716],[-1,-57],[4,-37],[4,-28],[2,-22],[5,-22],[4,-3]],[[2736,3547],[-11,-51],[-11,-29],[0,-14],[-4,-13],[0,-16],[-6,-8],[-1,-21],[-16,-27]],[[2687,3368],[0,-3],[-24,2],[-22,6],[-5,-2],[-32,8],[-36,-5],[-6,9],[1,-35],[-36,2],[-3,-2]],[[2524,3348],[1,24],[5,-8],[2,77]],[[2655,3846],[11,0],[5,-40],[1,-17],[9,-7],[6,-26],[5,13],[10,-14],[4,19],[4,6],[1,-32],[3,-6],[4,-26]],[[2474,2682],[3,-22],[-2,-9],[-1,-38],[5,-24],[0,-57],[-3,-44],[-7,-27],[-2,-43],[-2,4],[-1,-70],[-3,-2],[2,-37],[-2,-14],[54,0],[-3,-63],[4,-41],[1,-32],[4,-20]],[[2521,2143],[-9,-26],[0,-19],[7,-12],[3,30],[6,-30],[-1,-24],[-3,-11],[-7,10],[1,-18],[-2,-27],[5,-24],[9,-7],[3,-29],[3,-4],[-5,-32],[-5,6],[-4,33],[-10,18],[0,33],[-6,-11],[1,-27],[-3,-25],[-3,-4],[-3,28],[-7,1],[-2,-29],[-4,-9],[-5,18],[-4,2],[-3,47],[-7,21],[-2,-3],[-3,40],[-7,-5],[0,24],[-8,-23],[1,-18],[-5,-17],[-9,8],[-10,27],[-7,11],[-16,-9],[-2,-8]],[[2398,2049],[-2,19],[6,68],[-2,37],[2,20],[-1,26],[3,19],[3,50],[0,40],[-8,78],[0,41],[-7,42],[0,196]],[[3046,5029],[12,26],[-2,13],[5,30],[4,13],[-1,12],[5,18],[-1,33],[2,50],[5,17],[1,53],[22,147],[6,-7],[0,-35],[4,-13],[9,21],[6,0],[4,14],[8,-31],[4,-25],[1,-214],[-1,-51],[10,-14],[-2,-22],[3,-21],[-2,-18],[4,-30],[5,7],[5,-68],[-6,-31],[-3,12],[-3,-21],[-4,5],[0,-18],[-6,2],[-8,-40],[-2,28],[-3,2],[1,-30],[-6,-15],[-2,24],[-3,-12],[-7,0],[0,28],[-5,-6],[1,-20],[-4,-42],[1,-12],[-6,-23],[-5,9],[-3,-24],[-4,-3],[-4,-20],[-4,4],[-1,21],[-7,-34],[2,-21],[-5,-7],[0,-18],[-5,-22],[-5,-50]],[[3056,4600],[-3,14],[0,19],[-4,22],[-2,250],[-1,124]],[[2904,3626],[2,0],[-1,0],[-1,0]],[[2933,3721],[-6,-80]],[[2927,3641],[-4,-3],[-8,-12]],[[2915,3626],[-6,-8],[0,31],[-2,13],[3,13],[-4,32],[-2,-14],[-6,3],[-2,35],[2,0],[0,45],[2,18],[-2,60],[3,36],[5,6],[0,37],[-3,-5],[0,-18],[-8,-25],[-2,-21],[0,-56],[-3,-26],[1,-44],[4,-30],[-1,-23],[3,-23],[-2,-16],[-6,30],[-10,15],[-2,29],[-6,-16],[-2,23],[5,29]],[[2874,3756],[2,30]],[[2874,3813],[-4,18],[-6,10],[0,28],[-3,15],[-4,4]],[[2857,3888],[-4,53],[-4,0],[-5,18],[-3,-15],[-5,1],[-1,-21],[-8,14],[-6,-28],[-3,6],[-6,-33],[-6,-17],[1,98]],[[2807,3964],[105,0]],[[3053,4565],[1,-34],[-1,-27],[-5,-25],[0,-29],[6,-4],[4,-31],[0,-24],[3,-6],[0,-22],[8,-19],[9,18],[-2,-26],[-13,-23],[-5,-1],[-3,18],[-5,-6],[0,-13],[-5,-9]],[[3045,4302],[-3,35]],[[3042,4337],[0,6]],[[3042,4343],[-3,14],[-2,45],[-4,0],[-8,-2]],[[2977,4408],[0,7],[6,126]],[[2983,4541],[23,-3]],[[3006,4538],[34,-7],[3,18],[7,19],[3,-3]],[[2598,4353],[5,25],[4,43],[4,26],[3,36],[1,52],[0,57],[-9,111],[3,42],[-2,50],[6,51],[2,43],[-1,23],[5,9],[0,31],[8,9],[5,34],[0,-69],[3,-3],[3,35],[1,58],[2,15],[8,9],[-3,41],[5,35],[7,2],[7,-22],[7,-3],[3,-28],[6,-2],[9,-25],[3,1],[4,-41],[-3,-21],[3,-29],[2,-32],[-2,-71],[-6,-18],[-1,-37],[-7,-12],[-4,-44],[2,-17],[6,-15],[6,24],[6,49],[10,19],[5,-15],[3,-27],[3,-80],[0,-39],[3,-48],[-3,-69],[-4,-11],[-1,25],[-3,-7],[-3,-58],[-6,-21],[-2,-44],[-7,-37],[0,-16]],[[2694,4347],[-39,-7]],[[2635,5110],[1,-23],[-4,-4],[1,33],[2,-6]],[[2496,5270],[11,20],[5,23],[12,9],[8,29],[4,1],[3,20],[9,28],[4,24],[7,15],[6,-13],[-11,-59],[-2,-19],[0,-36],[5,27],[10,-4],[8,-19],[7,-52],[3,-10],[7,9],[2,-12],[7,-6],[16,44],[8,4],[10,-2],[7,15],[6,1],[1,-54],[5,-7],[6,8],[2,-12],[4,16],[8,5],[1,-67],[3,-28],[6,-8],[1,19],[5,0],[3,-20],[-3,-14],[-15,12],[-8,-8],[-8,23],[-2,-21],[1,-18],[-4,4],[-5,27],[-9,15],[-5,1],[-4,-25],[-8,-6],[-8,5],[-3,-10],[-1,-21],[-9,-18],[1,25],[-4,5],[-2,-26],[-6,-1],[-3,-11],[-5,-45],[-8,-58],[1,-5]],[[2576,4989],[-4,20],[2,27],[-7,4],[3,26],[0,34],[-5,23],[-4,24],[-12,19],[-4,-7],[-12,29],[-29,38],[-3,33],[-5,11]],[[2541,5539],[-7,-24],[-4,-3],[1,19],[18,45],[-4,-31],[-4,-6]],[[2324,4685],[0,343],[-7,22],[-5,36],[8,41],[1,22]],[[2321,5149],[-1,76],[-4,20],[-2,42],[0,51],[-1,8],[-1,123],[-5,65],[-3,36],[0,77],[1,27],[-3,60]],[[2302,5734],[59,0],[0,73],[5,-2],[4,-14],[4,-100],[3,-11],[9,-3],[1,-10],[11,-4],[1,-21],[10,5],[0,9],[7,10],[6,-4],[8,-16],[2,-19],[4,2],[4,-43],[2,18],[7,8],[1,-18],[9,-12],[0,-17],[4,-14],[8,8],[5,18],[8,12],[2,-28],[5,6],[6,-6],[6,4],[8,-24],[7,4],[0,-10],[-10,-24],[-13,-19],[-9,-20],[-12,-49],[-5,-31],[-8,-34],[-13,-46],[2,-16]],[[2450,5296],[-2,9],[-6,-16],[0,-113],[-2,-11],[-8,-16],[-6,-41],[-1,-27],[3,-2],[4,-24],[-3,-29],[0,-33],[-2,-70],[8,-34],[6,-3],[3,-21],[8,-21],[2,-25],[8,-33],[5,-7],[5,-42],[-1,-30],[2,-22]],[[2553,2179],[-3,-8],[-7,4],[-3,12],[-7,-8],[-9,-22],[-3,-14]],[[2498,3062],[53,0],[7,0]],[[2524,3348],[-2,0],[-2,0],[1,-47],[-6,-48]],[[2376,3349],[0,95]],[[2356,4017],[-7,50],[-6,62]],[[2108,5151],[0,-181],[-1,0]],[[2107,4970],[-53,1],[-90,0],[-56,0],[0,-100]],[[1766,5734],[130,-1],[58,1],[154,0]],[[2108,5734],[0,-217],[0,-366]],[[2107,4208],[0,382]],[[2107,4590],[21,0],[49,-1],[88,0],[1,-10],[15,-34],[4,19],[4,-4],[13,0],[15,-36],[2,-27],[5,-5]],[[1823,4398],[0,-954]],[[1654,4398],[37,-1],[47,2]],[[3006,4538],[-2,14],[0,28],[3,11],[-1,27],[3,81],[5,37],[2,43],[3,16],[-1,47],[10,17],[5,33],[-3,31],[4,32],[0,18]],[[3034,4973],[4,49],[6,-5],[2,12]],[[3056,4600],[-3,-35]],[[2962,4152],[-5,-13],[-2,-29],[8,-14],[0,-22],[-3,-103],[-9,-76],[-6,-22],[-5,-48],[-3,31],[-8,16],[-10,42],[-1,28],[0,4],[2,11]],[[2922,3980],[8,15],[0,15],[9,31],[2,17],[-9,39],[0,24],[-3,6],[-1,22],[5,33],[-3,20],[7,40],[2,21],[4,13]],[[2943,4276],[13,-41],[9,-28],[-3,-55]],[[2137,3444],[0,-95]],[[2137,3349],[-1,0],[0,-474],[0,-193],[0,-192],[-101,0],[-1,-18],[3,-22]],[[2037,2450],[-48,0],[0,-87],[-24,0]],[[2972,4205],[13,-15],[2,11],[10,0],[6,6],[8,31],[1,-22],[5,-10],[-11,-28],[-22,-42],[-9,-8],[-6,2],[-5,-9],[-2,31]],[[2943,4276],[-2,14],[-4,1],[-5,32],[1,29],[-4,22],[-2,-2],[-3,27],[-125,0],[0,48],[0,3]],[[2799,4450],[17,54],[3,26],[5,18],[-2,32],[-2,7],[-2,52],[17,22],[15,-1],[6,-5],[6,-21],[4,8],[12,-1],[8,14],[8,34],[5,1],[0,52],[3,31],[-7,21],[2,24],[11,32],[4,28],[14,64],[13,32],[19,-5],[23,4]],[[2981,4973],[1,-39],[-2,-36],[3,-34],[-1,-37],[-3,-39],[2,-52],[-1,-16],[4,-31],[-1,-132],[0,-16]],[[2909,3359],[4,-77],[-8,8],[-1,-10],[-10,-11],[-1,-11],[-7,-3],[0,-13],[8,9],[1,-8],[9,9],[3,-18],[5,8],[2,-46],[-2,-22],[-3,-2],[-8,-47],[-9,-2],[-2,-33],[4,-32],[4,-6],[-6,-54],[-6,7],[-9,-6],[-6,-11],[-10,-37],[-7,-48],[-4,-60],[-6,13],[-11,-12]],[[2833,2844],[-32,181],[-32,4],[1,21],[-5,33],[-3,-12],[0,20],[-35,10],[-8,-8],[-6,-17],[-10,-13]],[[2669,3061],[1,45],[5,4],[3,31],[7,29],[7,1],[7,29],[8,10],[6,43],[4,13],[1,-19],[11,37],[5,-8],[4,36],[5,9],[1,45]],[[2744,3366],[20,-5],[19,-3],[23,-1],[103,2]],[[2321,5149],[-213,2]],[[2108,5734],[194,0]],[[2777,4138],[-4,-10],[2,-21],[0,-29],[-4,-46],[-3,-70],[-11,-62],[-3,-8],[-4,12],[-3,-27],[-3,1],[-4,-36],[1,-22],[-3,-18],[-4,29],[-5,-46],[1,-29],[-3,-11],[-1,-25],[-8,-4]],[[2694,4347],[11,-26],[3,-15],[3,14],[6,-30],[4,-9],[14,25],[7,-6],[9,36],[12,34],[14,24]],[[2777,4394],[0,-256]],[[2380,2803],[-11,21],[-3,22],[-7,18],[-2,-16],[-8,1],[-1,10],[-7,-19],[-3,11],[-6,-10],[-5,-29],[-2,17],[-6,14],[-7,0],[-2,21],[-7,-42],[-2,24],[-3,-8],[-3,16],[-7,15],[-5,-25],[-2,26],[-4,3],[-2,21],[-6,8],[-3,-18],[-3,16],[-5,-2],[-6,17],[-6,-2],[-2,36],[-9,2],[-4,-6],[-6,37],[-2,-3],[0,370],[-52,0],[-34,0]],[[1534,4399],[-4,22],[-2,61],[0,43],[-4,33],[3,32],[2,51],[4,54],[2,48],[3,162],[0,22],[3,71],[1,99],[-2,54],[1,32],[12,29]],[[1553,5212],[5,-22],[4,5],[3,2],[6,-20],[3,-23],[1,-57],[15,-21],[12,30],[8,3],[9,-10],[1,-13],[16,27],[3,-9],[9,5],[7,19],[12,17],[12,4],[4,12],[58,-1]],[[2807,3964],[-30,0],[0,174]],[[2777,4394],[5,11],[17,45]],[[3045,4302],[-6,-4],[3,39]],[[3042,4343],[-4,3],[-3,-28],[-1,-40],[-11,-9]],[[2833,2844],[-5,-10],[-6,-31],[-6,-49],[-1,-40],[-5,-31],[-6,0],[-2,-23],[-6,-25],[-4,-28],[-6,-11],[-6,-29],[-1,-14],[-6,-16],[-6,-40]],[[2107,4590],[0,380]],[[2687,3368],[57,-2]],[[2398,2049],[-5,-1],[-14,-26],[-6,15],[-1,31],[-3,-22],[-3,5],[-1,-27],[3,-11],[0,-36],[-5,-37],[-9,-47],[-17,-51],[-2,9],[-5,-13],[0,12],[-7,-9],[-3,24],[-2,-5],[7,-49],[-5,-16],[-5,10],[-1,-35],[-7,-35],[-6,-66],[-4,-69],[-3,5],[-1,-25],[3,6],[-2,-50],[-2,-2],[0,-28],[3,-16],[1,-57],[3,-20],[0,-37],[3,-32],[-9,-20],[-3,25],[-7,10],[-9,-3],[-8,32],[-5,3],[-5,25],[-6,8],[-4,24],[-2,58],[-5,34],[0,30],[-2,31],[1,27],[-4,30],[-3,4],[-5,27],[-1,34],[-5,32],[-6,26],[-3,57],[-2,16],[-4,46],[-1,38],[-4,27],[-6,24],[-1,16],[-6,15],[-4,42],[-13,9],[-7,-2],[-7,15],[-1,-20],[-7,-6],[-5,-40],[-3,-64],[-2,-1],[-4,-37],[-5,-1],[-7,29],[-17,47],[-4,25],[-6,24],[-5,54],[-1,49],[-4,40],[-2,35],[-3,22],[-11,32],[-6,44],[-4,15],[-6,38],[-7,20],[-5,50],[-4,11]],[[1908,4399],[0,-192],[57,0]],[[2981,4973],[30,-2],[23,2]],[[2927,3641],[-4,-32],[-3,-12],[-3,-44],[-6,-71],[-5,-15],[-1,27],[2,58],[8,74]],[[2874,3756],[-4,-8],[-2,-28],[1,-19],[8,6],[1,-31],[10,-12],[3,-24],[8,-26],[-4,-54],[4,-41],[-4,-20],[-1,-24],[4,-15],[-4,-23],[-6,30],[-1,-10],[5,-22],[14,-5],[3,-71]],[[2736,3547],[-1,-16],[4,-32],[5,-16],[4,1],[5,25],[4,-20],[7,11],[13,36],[1,-11],[5,17],[0,34],[4,30],[5,29],[2,34],[6,36],[2,44],[5,-27],[4,-8],[3,16],[6,68],[4,-17],[13,77],[2,57],[15,-64],[3,37]],[[1553,5212],[-5,7],[-4,-12],[-6,17],[1,26],[4,14],[-6,40],[-4,103],[-2,14],[-3,73],[-6,28],[-2,56],[3,38],[6,-18],[11,-24],[8,1],[8,-9],[8,9],[3,-16],[7,1],[5,-42],[3,3],[1,-56],[2,-52],[3,6],[-3,43],[1,43],[4,44],[-3,18],[-1,31],[-3,35],[2,25],[-2,29],[-5,4],[-4,22],[1,21],[163,0]],[[1576,5602],[4,9],[0,-39],[-5,15],[1,15]],[[1568,5655],[3,25],[4,-30],[-1,-27],[-7,8],[1,24]],[[2576,4989],[-1,-23],[-6,-4],[-4,-44],[-2,-30],[3,-6],[5,20],[4,38],[6,15],[5,48],[6,10],[-1,-25],[-4,-23],[-8,-79],[-2,-44],[0,-32],[-3,-10],[-2,-43],[1,-37],[-3,-24],[-3,-59],[0,-47],[4,-42],[-1,-55]],[[2450,5296],[6,-2],[20,33],[8,17],[2,-13],[-4,-25],[9,-33],[5,-3]]]
},h.prototype.usgTopo="__USG__",h.prototype.uzbTopo="__UZB__",h.prototype.vatTopo="__VAT__",h.prototype.vctTopo="__VCT__",h.prototype.venTopo="__VEN__",h.prototype.vgbTopo="__VGB__",h.prototype.virTopo="__VIR__",h.prototype.vnmTopo="__VNM__",h.prototype.vutTopo="__VUT__",h.prototype.wlfTopo="__WLF__",h.prototype.wsbTopo="__WSB__",h.prototype.wsmTopo="__WSM__",h.prototype.yemTopo="__YEM__",h.prototype.zafTopo="__ZAF__",h.prototype.zmbTopo="__ZMB__",h.prototype.zweTopo="__ZWE__",h.prototype.latLngToXY=function(t,e){return this.projection([e,t])},h.prototype.addLayer=function(t,e,n){var r;return r=n?this.svg.insert("g",":first-child"):this.svg.append("g"),r.attr("id",e||"").attr("class",t||"")},h.prototype.updateChoropleth=function(t,e){var n=this.svg;e&&e.reset===!0&&n.selectAll(".datamaps-subunit").attr("data-info",function(){return"{}"}).transition().style("fill",this.options.fills.defaultFill);for(var r in t)if(t.hasOwnProperty(r)){var o,i=t[r];if(!r)continue;if(o="string"==typeof i?i:"string"==typeof i.color?i.color:"string"==typeof i.fillColor?i.fillColor:this.options.fills[i.fillKey],i===Object(i)){this.options.data[r]=p(i,this.options.data[r]||{});this.svg.select("."+r).attr("data-info",JSON.stringify(this.options.data[r]))}n.selectAll("."+r).transition().style("fill",o)}},h.prototype.updatePopup=function(t,e,n){var r=this;t.on("mousemove",null),t.on("mousemove",function(){var o=g.mouse(r.options.element);g.select(r.svg[0][0].parentNode).select(".datamaps-hoverover").style("top",o[1]+30+"px").html(function(){var r=JSON.parse(t.attr("data-info"));try{return n.popupTemplate(e,r)}catch(t){return""}}).style("left",o[0]+"px")}),g.select(r.svg[0][0].parentNode).select(".datamaps-hoverover").style("display","block")},h.prototype.addPlugin=function(t,e){var n=this;"undefined"==typeof h.prototype[t]&&(h.prototype[t]=function(r,o,i,a){var s;"undefined"==typeof a&&(a=!1),"function"==typeof o&&(i=o,o=void 0),o=p(o||{},n.options[t+"Config"]),!a&&this.options[t+"Layer"]?(s=this.options[t+"Layer"],o=o||this.options[t+"Options"]):(s=this.addLayer(t),this.options[t+"Layer"]=s,this.options[t+"Options"]=o),e.apply(this,[s,r,o]),i&&i(s)})},g=n(170),v=n(174),t.exports=h,window.jQuery&&(window.jQuery.fn.datamaps=function(t,e){t=t||{},t.element=this[0];var n=new h(t);return"function"==typeof e&&e(n,t),this})}()},function(t,e,n){!function(t,n){n(e)}(this,function(t){"use strict";function e(){}function n(t){if(!t)return e;var n,r,o=t.scale[0],i=t.scale[1],a=t.translate[0],s=t.translate[1];return function(t,e){e||(n=r=0),t[0]=(n+=t[0])*o+a,t[1]=(r+=t[1])*i+s}}function r(t){if(!t)return e;var n,r,o=t.scale[0],i=t.scale[1],a=t.translate[0],s=t.translate[1];return function(t,e){e||(n=r=0);var l=Math.round((t[0]-a)/o),u=Math.round((t[1]-s)/i);t[0]=l-n,t[1]=u-r,n=l,r=u}}function o(t,e){for(var n,r=t.length,o=r-e;o<--r;)n=t[o],t[o++]=t[r],t[r]=n}function i(t,e){for(var n=0,r=t.length;n<r;){var o=n+r>>>1;t[o]<e?n=o+1:r=o}return n}function a(t,e){return"GeometryCollection"===e.type?{type:"FeatureCollection",features:e.geometries.map(function(e){return s(t,e)})}:s(t,e)}function s(t,e){var n={type:"Feature",id:e.id,properties:e.properties||{},geometry:l(t,e)};return null==e.id&&delete n.id,n}function l(t,e){function r(t,e){e.length&&e.pop();for(var n,r=f[t<0?~t:t],i=0,a=r.length;i<a;++i)e.push(n=r[i].slice()),c(n,i);t<0&&o(e,a)}function i(t){return t=t.slice(),c(t,0),t}function a(t){for(var e=[],n=0,o=t.length;n<o;++n)r(t[n],e);return e.length<2&&e.push(e[0].slice()),e}function s(t){for(var e=a(t);e.length<4;)e.push(e[0].slice());return e}function l(t){return t.map(s)}function u(t){var e=t.type;return"GeometryCollection"===e?{type:e,geometries:t.geometries.map(u)}:e in d?{type:e,coordinates:d[e](t)}:null}var c=n(t.transform),f=t.arcs,d={Point:function(t){return i(t.coordinates)},MultiPoint:function(t){return t.coordinates.map(i)},LineString:function(t){return a(t.arcs)},MultiLineString:function(t){return t.arcs.map(a)},Polygon:function(t){return l(t.arcs)},MultiPolygon:function(t){return t.arcs.map(l)}};return u(e)}function u(t,e){function n(e){var n,r=t.arcs[e<0?~e:e],o=r[0];return t.transform?(n=[0,0],r.forEach(function(t){n[0]+=t[0],n[1]+=t[1]})):n=r[r.length-1],e<0?[n,o]:[o,n]}function r(t,e){for(var n in t){var r=t[n];delete e[r.start],delete r.start,delete r.end,r.forEach(function(t){o[t<0?~t:t]=1}),s.push(r)}}var o={},i={},a={},s=[],l=-1;return e.forEach(function(n,r){var o,i=t.arcs[n<0?~n:n];i.length<3&&!i[1][0]&&!i[1][1]&&(o=e[++l],e[l]=n,e[r]=o)}),e.forEach(function(t){var e,r,o=n(t),s=o[0],l=o[1];if(e=a[s])if(delete a[e.end],e.push(t),e.end=l,r=i[l]){delete i[r.start];var u=r===e?e:e.concat(r);i[u.start=e.start]=a[u.end=r.end]=u}else i[e.start]=a[e.end]=e;else if(e=i[l])if(delete i[e.start],e.unshift(t),e.start=s,r=a[s]){delete a[r.end];var c=r===e?e:r.concat(e);i[c.start=r.start]=a[c.end=e.end]=c}else i[e.start]=a[e.end]=e;else e=[t],i[e.start=s]=a[e.end=l]=e}),r(a,i),r(i,a),e.forEach(function(t){o[t<0?~t:t]||s.push([t])}),s}function c(t){return l(t,f.apply(this,arguments))}function f(t,e,n){function r(t){var e=t<0?~t:t;(c[e]||(c[e]=[])).push({i:t,g:l})}function o(t){t.forEach(r)}function i(t){t.forEach(o)}function a(t){"GeometryCollection"===t.type?t.geometries.forEach(a):t.type in f&&(l=t,f[t.type](t.arcs))}var s=[];if(arguments.length>1){var l,c=[],f={LineString:o,MultiLineString:i,Polygon:i,MultiPolygon:function(t){t.forEach(i)}};a(e),c.forEach(arguments.length<3?function(t){s.push(t[0].i)}:function(t){n(t[0].g,t[t.length-1].g)&&s.push(t[0].i)})}else for(var d=0,p=t.arcs.length;d<p;++d)s.push(d);return{type:"MultiLineString",arcs:u(t,s)}}function d(t){var e=t[0],n=t[1],r=t[2];return Math.abs((e[0]-r[0])*(n[1]-e[1])-(e[0]-n[0])*(r[1]-e[1]))}function p(t){for(var e,n=-1,r=t.length,o=t[r-1],i=0;++n<r;)e=o,o=t[n],i+=e[0]*o[1]-e[1]*o[0];return i/2}function h(t){return l(t,g.apply(this,arguments))}function g(t,e){function n(t){t.forEach(function(e){e.forEach(function(e){(o[e=e<0?~e:e]||(o[e]=[])).push(t)})}),i.push(t)}function r(e){return Math.abs(p(l(t,{type:"Polygon",arcs:[e]}).coordinates[0]))}var o={},i=[],a=[];return e.forEach(function(t){"Polygon"===t.type?n(t.arcs):"MultiPolygon"===t.type&&t.arcs.forEach(n)}),i.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,a.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){o[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),i.forEach(function(t){delete t._}),{type:"MultiPolygon",arcs:a.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){o[t<0?~t:t].length<2&&i.push(t)})})}),i=u(t,i),(n=i.length)>1)for(var a,s,l=1,c=r(i[0]);l<n;++l)(a=r(i[l]))>c&&(s=i[0],i[0]=i[l],i[l]=s,c=a);return i})}}function v(t){function e(t,e){t.forEach(function(t){t<0&&(t=~t);var n=o[t];n?n.push(e):o[t]=[e]})}function n(t,n){t.forEach(function(t){e(t,n)})}function r(t,e){"GeometryCollection"===t.type?t.geometries.forEach(function(t){r(t,e)}):t.type in s&&s[t.type](t.arcs,e)}var o={},a=t.map(function(){return[]}),s={LineString:e,MultiLineString:n,Polygon:n,MultiPolygon:function(t,e){t.forEach(function(t){n(t,e)})}};t.forEach(r);for(var l in o)for(var u=o[l],c=u.length,f=0;f<c;++f)for(var d=f+1;d<c;++d){var p,h=u[f],g=u[d];(p=a[h])[l=i(p,g)]!==g&&p.splice(l,0,g),(p=a[g])[l=i(p,h)]!==h&&p.splice(l,0,h)}return a}function m(t,e){return t[1][2]-e[1][2]}function y(){function t(t,e){for(;e>0;){var n=(e+1>>1)-1,o=r[n];if(m(t,o)>=0)break;r[o._=e]=o,r[t._=e=n]=t}}function e(t,e){for(;;){var n=e+1<<1,i=n-1,a=e,s=r[a];if(i<o&&m(r[i],s)<0&&(s=r[a=i]),n<o&&m(r[n],s)<0&&(s=r[a=n]),a===e)break;r[s._=e]=s,r[t._=e=a]=t}}var n={},r=[],o=0;return n.push=function(e){return t(r[e._=o]=e,o++),o},n.pop=function(){if(!(o<=0)){var t,n=r[0];return--o>0&&(t=r[o],e(r[t._=0]=t,0)),n}},n.remove=function(n){var i,a=n._;if(r[a]===n)return a!==--o&&(i=r[o],(m(i,n)<0?t:e)(r[i._=a]=i,a)),a},n}function b(t,e){function o(t){s.remove(t),t[1][2]=e(t),s.push(t)}var i=n(t.transform),a=r(t.transform),s=y();return e||(e=d),t.arcs.forEach(function(t){var n,r,l,u,c=[],f=0;for(r=0,l=t.length;r<l;++r)u=t[r],i(t[r]=[u[0],u[1],1/0],r);for(r=1,l=t.length-1;r<l;++r)n=t.slice(r-1,r+2),n[1][2]=e(n),c.push(n),s.push(n);for(r=0,l=c.length;r<l;++r)n=c[r],n.previous=c[r-1],n.next=c[r+1];for(;n=s.pop();){var d=n.previous,p=n.next;n[1][2]<f?n[1][2]=f:f=n[1][2],d&&(d.next=p,d[2]=n[2],o(d)),p&&(p.previous=d,p[0]=n[0],o(p))}t.forEach(a)}),t}var x="1.6.27";t.version=x,t.mesh=c,t.meshArcs=f,t.merge=h,t.mergeArcs=g,t.feature=a,t.neighbors=v,t.presimplify=b,Object.defineProperty(t,"__esModule",{value:!0})})},function(t,e,n){(function(r){!function(){var o={};o.dev=!1,o.tooltip=o.tooltip||{},o.utils=o.utils||{},o.models=o.models||{},o.charts={},o.logs={},o.dom={},"undefined"!=typeof t&&"undefined"!=typeof e&&"undefined"==typeof r&&(r=n(170)),o.dispatch=r.dispatch("render_start","render_end"),Function.prototype.bind||(Function.prototype.bind=function(t){if("function"!=typeof this)throw new TypeError("Function.prototype.bind - what is trying to be bound is not callable");var e=Array.prototype.slice.call(arguments,1),n=this,r=function(){},o=function(){return n.apply(this instanceof r&&t?this:t,e.concat(Array.prototype.slice.call(arguments)))};return r.prototype=this.prototype,o.prototype=new r,o}),o.dev&&(o.dispatch.on("render_start",function(t){o.logs.startTime=+new Date}),o.dispatch.on("render_end",function(t){o.logs.endTime=+new Date,o.logs.totalTime=o.logs.endTime-o.logs.startTime,o.log("total",o.logs.totalTime)})),o.log=function(){if(o.dev&&window.console&&console.log&&console.log.apply)console.log.apply(console,arguments);else if(o.dev&&window.console&&"function"==typeof console.log&&Function.prototype.bind){var t=Function.prototype.bind.call(console.log,console);t.apply(console,arguments)}return arguments[arguments.length-1]},o.deprecated=function(t,e){console&&console.warn&&console.warn("nvd3 warning: `"+t+"` has been deprecated. ",e||"")},o.render=function(t){t=t||1,o.render.active=!0,o.dispatch.render_start();var e=function(){for(var n,r,i=0;i<t&&(r=o.render.queue[i]);i++)n=r.generate(),typeof r.callback==typeof Function&&r.callback(n);o.render.queue.splice(0,i),o.render.queue.length?setTimeout(e):(o.dispatch.render_end(),o.render.active=!1)};setTimeout(e)},o.render.active=!1,o.render.queue=[],o.addGraph=function(t){typeof arguments[0]==typeof Function&&(t={generate:arguments[0],callback:arguments[1]}),o.render.queue.push(t),o.render.active||o.render()},t.exports=o,"undefined"!=typeof window&&(window.nv=o),o.dom.write=function(t){return void 0!==window.fastdom?fastdom.mutate(t):t()},o.dom.read=function(t){return void 0!==window.fastdom?fastdom.measure(t):t()},o.interactiveGuideline=function(){"use strict";function t(d){d.each(function(d){function p(){var n=r.mouse(this),o=n[0],i=n[1],l=!0,u=!1;if(f&&(o=r.event.offsetX,i=r.event.offsetY,"svg"!==r.event.target.tagName&&(l=!1),r.event.target.className.baseVal.match("nv-legend")&&(u=!0)),l&&(o-=e.left,i-=e.top),"mouseout"===r.event.type||o<0||i<0||o>g||i>v||r.event.relatedTarget&&void 0===r.event.relatedTarget.ownerSVGElement||u){if(f&&r.event.relatedTarget&&void 0===r.event.relatedTarget.ownerSVGElement&&(void 0===r.event.relatedTarget.className||r.event.relatedTarget.className.match(c.nvPointerEventsClass)))return;return s.elementMouseout({mouseX:o,mouseY:i}),t.renderGuideLine(null),void c.hidden(!0)}c.hidden(!1);var d="function"==typeof a.rangeBands,p=void 0;if(d){var h=r.bisect(a.range(),o)-1;if(!(a.range()[h]+a.rangeBand()>=o))return s.elementMouseout({mouseX:o,mouseY:i}),t.renderGuideLine(null),void c.hidden(!0);p=a.domain()[r.bisect(a.range(),o)-1]}else p=a.invert(o);s.elementMousemove({mouseX:o,mouseY:i,pointXValue:p}),"dblclick"===r.event.type&&s.elementDblclick({mouseX:o,mouseY:i,pointXValue:p}),"click"===r.event.type&&s.elementClick({mouseX:o,mouseY:i,pointXValue:p}),"mousedown"===r.event.type&&s.elementMouseDown({mouseX:o,mouseY:i,pointXValue:p}),"mouseup"===r.event.type&&s.elementMouseUp({mouseX:o,mouseY:i,pointXValue:p})}var h=r.select(this),g=n||960,v=i||400,m=h.selectAll("g.nv-wrap.nv-interactiveLineLayer").data([d]),y=m.enter().append("g").attr("class"," nv-wrap nv-interactiveLineLayer");y.append("g").attr("class","nv-interactiveGuideLine"),u&&(u.on("touchmove",p).on("mousemove",p,!0).on("mouseout",p,!0).on("mousedown",p,!0).on("mouseup",p,!0).on("dblclick",p).on("click",p),t.guideLine=null,t.renderGuideLine=function(e){l&&(t.guideLine&&t.guideLine.attr("x1")===e||o.dom.write(function(){var t=m.select(".nv-interactiveGuideLine").selectAll("line").data(null!=e?[o.utils.NaNtoZero(e)]:[],String);t.enter().append("line").attr("class","nv-guideline").attr("x1",function(t){return t}).attr("x2",function(t){return t}).attr("y1",v).attr("y2",0),t.exit().remove()}))})})}var e={left:0,top:0},n=null,i=null,a=r.scale.linear(),s=r.dispatch("elementMousemove","elementMouseout","elementClick","elementDblclick","elementMouseDown","elementMouseUp"),l=!0,u=null,c=o.models.tooltip(),f=window.ActiveXObject;return c.duration(0).hideDelay(0).hidden(!1),t.dispatch=s,t.tooltip=c,t.margin=function(n){return arguments.length?(e.top="undefined"!=typeof n.top?n.top:e.top,e.left="undefined"!=typeof n.left?n.left:e.left,t):e},t.width=function(e){return arguments.length?(n=e,t):n},t.height=function(e){return arguments.length?(i=e,t):i},t.xScale=function(e){return arguments.length?(a=e,t):a},t.showGuideLine=function(e){return arguments.length?(l=e,t):l},t.svgContainer=function(e){return arguments.length?(u=e,t):u},t},o.interactiveBisect=function(t,e,n){"use strict";if(!(t instanceof Array))return null;var o;o="function"!=typeof n?function(t){return t.x}:n;var i=function(t,e){return o(t)-e},a=r.bisector(i).left,s=r.max([0,a(t,e)-1]),l=o(t[s]);if("undefined"==typeof l&&(l=s),l===e)return s;var u=r.min([s+1,t.length-1]),c=o(t[u]);return"undefined"==typeof c&&(c=u),Math.abs(c-e)>=Math.abs(l-e)?s:u},o.nearestValueIndex=function(t,e,n){"use strict";var r=1/0,o=null;return t.forEach(function(t,i){var a=Math.abs(e-t);null!=t&&a<=r&&a<n&&(r=a,o=i)}),o},o.models.tooltip=function(){"use strict";function t(){if(!d||!d.node()){var t=[1];d=r.select(document.body).select("#"+n).data(t),d.enter().append("div").attr("class","nvtooltip "+(u?u:"xy-tooltip")).attr("id",n).style("top",0).style("left",0).style("opacity",0).style("position","fixed").selectAll("div, table, td, tr").classed(m,!0).classed(m,!0),d.exit().remove()}}function e(){if(h&&T(i))return o.dom.write(function(){t();var e=_(i);e&&(d.node().innerHTML=e),k()}),e}var n="nvtooltip-"+Math.floor(1e5*Math.random()),i=null,a="w",s=25,l=0,u=null,c=!0,f=200,d=null,p={left:null,top:null},h=!0,g=100,v=!0,m="nv-pointer-events-none",y=function(t,e){return t},b=function(t){return t},x=function(t,e){return t},_=function(t){if(null===t)return"";var e=r.select(document.createElement("table"));if(v){var n=e.selectAll("thead").data([t]).enter().append("thead");n.append("tr").append("td").attr("colspan",3).append("strong").classed("x-value",!0).html(b(t.value))}var o=e.selectAll("tbody").data([t]).enter().append("tbody"),i=o.selectAll("tr").data(function(t){return t.series}).enter().append("tr").classed("highlight",function(t){return t.highlight});i.append("td").classed("legend-color-guide",!0).append("div").style("background-color",function(t){return t.color}),i.append("td").classed("key",!0).classed("total",function(t){return!!t.total}).html(function(t,e){return x(t.key,e)}),i.append("td").classed("value",!0).html(function(t,e){return y(t.value,e)}),i.filter(function(t,e){return void 0!==t.percent}).append("td").classed("percent",!0).html(function(t,e){return"("+r.format("%")(t.percent)+")"}),i.selectAll("td").each(function(t){if(t.highlight){var e=r.scale.linear().domain([0,1]).range(["#fff",t.color]),n=.6;r.select(this).style("border-bottom-color",e(n)).style("border-top-color",e(n))}});var a=e.node().outerHTML;return void 0!==t.footer&&(a+="<div class='footer'>"+t.footer+"</div>"),a},w=function(){var t={left:null!==r.event?r.event.clientX:0,top:null!==r.event?r.event.clientY:0};if("none"!=getComputedStyle(document.body).transform){var e=document.body.getBoundingClientRect();t.left-=e.left,t.top-=e.top}return t},T=function(t){if(t&&t.series){if(o.utils.isArray(t.series))return!0;if(o.utils.isObject(t.series))return t.series=[t.series],!0}return!1},C=function(t){var e,n,r,o=d.node().offsetHeight,i=d.node().offsetWidth,l=document.documentElement.clientWidth,u=document.documentElement.clientHeight;switch(a){case"e":e=-i-s,n=-(o/2),t.left+e<0&&(e=s),(r=t.top+n)<0&&(n-=r),(r=t.top+n+o)>u&&(n-=r-u);break;case"w":e=s,n=-(o/2),t.left+e+i>l&&(e=-i-s),(r=t.top+n)<0&&(n-=r),(r=t.top+n+o)>u&&(n-=r-u);break;case"n":e=-(i/2)-5,n=s,t.top+n+o>u&&(n=-o-s),(r=t.left+e)<0&&(e-=r),(r=t.left+e+i)>l&&(e-=r-l);break;case"s":e=-(i/2),n=-o-s,t.top+n<0&&(n=s),(r=t.left+e)<0&&(e-=r),(r=t.left+e+i)>l&&(e-=r-l);break;case"center":e=-(i/2),n=-(o/2);break;default:e=0,n=0}return{left:e,top:n}},k=function(){o.dom.read(function(){var t=w(),e=C(t),n=t.left+e.left,o=t.top+e.top;if(c)d.interrupt().transition().delay(f).duration(0).style("opacity",0);else{var i="translate("+p.left+"px, "+p.top+"px)",a="translate("+Math.round(n)+"px, "+Math.round(o)+"px)",s=r.interpolateString(i,a),l=d.style("opacity")<.1;d.interrupt().transition().duration(l?0:g).styleTween("transform",function(t){return s},"important").styleTween("-webkit-transform",function(t){return s}).style("-ms-transform",a).style("opacity",1)}p.left=n,p.top=o})};return e.nvPointerEventsClass=m,e.options=o.utils.optionsFunc.bind(e),e._options=Object.create({},{duration:{get:function(){return g},set:function(t){g=t}},gravity:{get:function(){return a},set:function(t){a=t}},distance:{get:function(){return s},set:function(t){s=t}},snapDistance:{get:function(){return l},set:function(t){l=t}},classes:{get:function(){return u},set:function(t){u=t}},enabled:{get:function(){return h},set:function(t){h=t}},hideDelay:{get:function(){return f},set:function(t){f=t}},contentGenerator:{get:function(){return _},set:function(t){_=t}},valueFormatter:{get:function(){return y},set:function(t){y=t}},headerFormatter:{get:function(){return b},set:function(t){b=t}},keyFormatter:{get:function(){return x},set:function(t){x=t}},headerEnabled:{get:function(){return v},set:function(t){v=t}},position:{get:function(){return w},set:function(t){w=t}},chartContainer:{get:function(){return document.body},set:function(t){o.deprecated("chartContainer","feature removed after 1.8.3")}},fixedTop:{get:function(){return null},set:function(t){o.deprecated("fixedTop","feature removed after 1.8.1")}},offset:{get:function(){return{left:0,top:0}},set:function(t){o.deprecated("offset","use chart.tooltip.distance() instead")}},hidden:{get:function(){return c},set:function(t){c!=t&&(c=!!t,e())}},data:{get:function(){return i},set:function(t){t.point&&(t.value=t.point.x,t.series=t.series||{},t.series.value=t.point.y,t.series.color=t.point.color||t.series.color),i=t}},node:{get:function(){return d.node()},set:function(t){}},id:{get:function(){return n},set:function(t){}}}),o.utils.initOptions(e),e},o.utils.windowSize=function(){var t={width:640,height:480};return window.innerWidth&&window.innerHeight?(t.width=window.innerWidth,t.height=window.innerHeight,t):"CSS1Compat"==document.compatMode&&document.documentElement&&document.documentElement.offsetWidth?(t.width=document.documentElement.offsetWidth,t.height=document.documentElement.offsetHeight,t):document.body&&document.body.offsetWidth?(t.width=document.body.offsetWidth,t.height=document.body.offsetHeight,t):t},o.utils.isArray=Array.isArray,o.utils.isObject=function(t){return null!==t&&"object"==typeof t},o.utils.isFunction=function(t){return"function"==typeof t},o.utils.isDate=function(t){return"[object Date]"===toString.call(t)},o.utils.isNumber=function(t){return!isNaN(t)&&"number"==typeof t},o.utils.windowResize=function(t){return window.addEventListener?window.addEventListener("resize",t):o.log("ERROR: Failed to bind to window.resize with: ",t),{callback:t,clear:function(){window.removeEventListener("resize",t)}}},o.utils.getColor=function(t){if(void 0===t)return o.utils.defaultColor();if(o.utils.isArray(t)){var e=r.scale.ordinal().range(t);return function(t,n){var r=void 0===n?t:n;return t.color||e(r)}}return t},o.utils.defaultColor=function(){return o.utils.getColor(r.scale.category20().range())},o.utils.customTheme=function(t,e,n){e=e||function(t){return t.key},n=n||r.scale.category20().range();var i=n.length;return function(r,a){var s=e(r);return o.utils.isFunction(t[s])?t[s]():void 0!==t[s]?t[s]:(i||(i=n.length),i-=1,n[i])}},o.utils.pjax=function(t,e){var n=function(n){r.html(n,function(n){var i=r.select(e).node();i.parentNode.replaceChild(r.select(n).select(e).node(),i),o.utils.pjax(t,e)})};r.selectAll(t).on("click",function(){history.pushState(this.href,this.textContent,this.href),n(this.href),r.event.preventDefault()}),r.select(window).on("popstate",function(){r.event.state&&n(r.event.state)})},o.utils.calcApproxTextWidth=function(t){if(o.utils.isFunction(t.style)&&o.utils.isFunction(t.text)){var e=parseInt(t.style("font-size").replace("px",""),10),n=t.text().length;return o.utils.NaNtoZero(n*e*.5)}return 0},o.utils.NaNtoZero=function(t){return!o.utils.isNumber(t)||isNaN(t)||null===t||t===1/0||t===-(1/0)?0:t},r.selection.prototype.watchTransition=function(t){var e=[this].concat([].slice.call(arguments,1));return t.transition.apply(t,e)},o.utils.renderWatch=function(t,e){if(!(this instanceof o.utils.renderWatch))return new o.utils.renderWatch(t,e);var n=void 0!==e?e:250,r=[],i=this;this.models=function(t){return t=[].slice.call(arguments,0),t.forEach(function(t){t.__rendered=!1,function(t){t.dispatch.on("renderEnd",function(e){t.__rendered=!0,i.renderEnd("model")})}(t),r.indexOf(t)<0&&r.push(t)}),this},this.reset=function(t){void 0!==t&&(n=t),r=[]},this.transition=function(t,e,o){if(e=arguments.length>1?[].slice.call(arguments,1):[],o=e.length>1?e.pop():void 0!==n?n:250,t.__rendered=!1,r.indexOf(t)<0&&r.push(t),0===o)return t.__rendered=!0,t.delay=function(){return this},t.duration=function(){return this},t;0===t.length?t.__rendered=!0:t.every(function(t){return!t.length})?t.__rendered=!0:t.__rendered=!1;var a=0;return t.transition().duration(o).each(function(){++a}).each("end",function(n,r){0===--a&&(t.__rendered=!0,i.renderEnd.apply(this,e))})},this.renderEnd=function(){r.every(function(t){return t.__rendered})&&(r.forEach(function(t){t.__rendered=!1}),t.renderEnd.apply(this,arguments))}},o.utils.deepExtend=function(t){var e=arguments.length>1?[].slice.call(arguments,1):[];e.forEach(function(e){for(var n in e){var r=o.utils.isArray(t[n]),i=o.utils.isObject(t[n]),a=o.utils.isObject(e[n]);i&&!r&&a?o.utils.deepExtend(t[n],e[n]):t[n]=e[n]}})},o.utils.state=function(){if(!(this instanceof o.utils.state))return new o.utils.state;var t={},e=function(){},n=function(){return{}},i=null,a=null;this.dispatch=r.dispatch("change","set"),this.dispatch.on("set",function(t){e(t,!0)}),this.getter=function(t){return n=t,this},this.setter=function(t,n){return n||(n=function(){}),e=function(e,r){t(e),r&&n()},this},this.init=function(t){i=i||{},o.utils.deepExtend(i,t)};var s=function(){var e=n();if(JSON.stringify(e)===JSON.stringify(t))return!1;for(var r in e)void 0===t[r]&&(t[r]={}),t[r]=e[r],a=!0;return!0};this.update=function(){i&&(e(i,!1),i=null),s.call(this)&&this.dispatch.change(t)}},o.utils.optionsFunc=function(t){return t&&r.map(t).forEach(function(t,e){o.utils.isFunction(this[t])&&this[t](e)}.bind(this)),this},o.utils.calcTicksX=function(t,e){var n=1,r=0;for(r;r<e.length;r+=1){var i=e[r]&&e[r].values?e[r].values.length:0;n=i>n?i:n}return o.log("Requested number of ticks: ",t),o.log("Calculated max values to be: ",n),t=t>n?t=n-1:t,t=t<1?1:t,t=Math.floor(t),o.log("Calculating tick count as: ",t),t},o.utils.calcTicksY=function(t,e){return o.utils.calcTicksX(t,e)},o.utils.initOption=function(t,e){t._calls&&t._calls[e]?t[e]=t._calls[e]:(t[e]=function(n){return arguments.length?(t._overrides[e]=!0,t._options[e]=n,t):t._options[e]},t["_"+e]=function(n){return arguments.length?(t._overrides[e]||(t._options[e]=n),t):t._options[e]})},o.utils.initOptions=function(t){t._overrides=t._overrides||{};var e=Object.getOwnPropertyNames(t._options||{}),n=Object.getOwnPropertyNames(t._calls||{});e=e.concat(n);for(var r in e)o.utils.initOption(t,e[r])},o.utils.inheritOptionsD3=function(t,e,n){t._d3options=n.concat(t._d3options||[]),n.unshift(e),n.unshift(t),r.rebind.apply(this,n)},o.utils.arrayUnique=function(t){return t.sort().filter(function(e,n){return!n||e!=t[n-1]})},o.utils.symbolMap=r.map(),o.utils.symbol=function(){function t(t,i){var a=e.call(this,t,i),s=n.call(this,t,i);return r.svg.symbolTypes.indexOf(a)!==-1?r.svg.symbol().type(a).size(s)():o.utils.symbolMap.get(a)(s)}var e,n=64;return t.type=function(n){return arguments.length?(e=r.functor(n),t):e},t.size=function(e){return arguments.length?(n=r.functor(e),t):n},t},o.utils.inheritOptions=function(t,e){var n=Object.getOwnPropertyNames(e._options||{}),i=Object.getOwnPropertyNames(e._calls||{}),a=e._inherited||[],s=e._d3options||[],l=n.concat(i).concat(a).concat(s);l.unshift(e),l.unshift(t),r.rebind.apply(this,l),t._inherited=o.utils.arrayUnique(n.concat(i).concat(a).concat(n).concat(t._inherited||[])),t._d3options=o.utils.arrayUnique(s.concat(t._d3options||[]))},o.utils.initSVG=function(t){t.classed({"nvd3-svg":!0})},o.utils.sanitizeHeight=function(t,e){return t||parseInt(e.style("height"),10)||400},o.utils.sanitizeWidth=function(t,e){return t||parseInt(e.style("width"),10)||960},o.utils.availableHeight=function(t,e,n){return Math.max(0,o.utils.sanitizeHeight(t,e)-n.top-n.bottom)},o.utils.availableWidth=function(t,e,n){return Math.max(0,o.utils.sanitizeWidth(t,e)-n.left-n.right)},o.utils.noData=function(t,e){var n=t.options(),r=n.margin(),i=n.noData(),a=null==i?["No Data Available."]:[i],s=o.utils.availableHeight(null,e,r),l=o.utils.availableWidth(null,e,r),u=r.left+l/2,c=r.top+s/2;e.selectAll("g").remove();var f=e.selectAll(".nv-noData").data(a);f.enter().append("text").attr("class","nvd3 nv-noData").attr("dy","-.7em").style("text-anchor","middle"),f.attr("x",u).attr("y",c).text(function(t){return t})},o.utils.wrapTicks=function(t,e){t.each(function(){for(var t,n=r.select(this),o=n.text().split(/\s+/).reverse(),i=[],a=0,s=1.1,l=n.attr("y"),u=parseFloat(n.attr("dy")),c=n.text(null).append("tspan").attr("x",0).attr("y",l).attr("dy",u+"em");t=o.pop();)i.push(t),c.text(i.join(" ")),c.node().getComputedTextLength()>e&&(i.pop(),c.text(i.join(" ")),i=[t],c=n.append("tspan").attr("x",0).attr("y",l).attr("dy",++a*s+u+"em").text(t))})},o.utils.arrayEquals=function(t,e){if(t===e)return!0;if(!t||!e)return!1;if(t.length!=e.length)return!1;for(var n=0,r=t.length;n<r;n++)if(t[n]instanceof Array&&e[n]instanceof Array){if(!o.arrayEquals(t[n],e[n]))return!1}else if(t[n]!=e[n])return!1;return!0},o.models.axis=function(){"use strict";function t(s){return x.reset(),s.each(function(t){var s=r.select(this);o.utils.initSVG(s);var m=s.selectAll("g.nv-wrap.nv-axis").data([t]),y=m.enter().append("g").attr("class","nvd3 nv-wrap nv-axis"),_=(y.append("g"),m.select("g"));null!==h?e.ticks(h):"top"!=e.orient()&&"bottom"!=e.orient()||e.ticks(Math.abs(n.range()[1]-n.range()[0])/100),_.watchTransition(x,"axis").call(e),b=b||e.scale();var w=e.tickFormat();null==w&&(w=b.tickFormat());var T=_.selectAll("text.nv-axislabel").data([l||null]);T.exit().remove(),void 0!==v&&_.selectAll("g").select("text").style("font-size",v);var C,k,E;switch(e.orient()){case"top":T.enter().append("text").attr("class","nv-axislabel"),E=0,1===n.range().length?E=p?2*n.range()[0]+n.rangeBand():0:2===n.range().length?E=p?n.range()[0]+n.range()[1]+n.rangeBand():n.range()[1]:n.range().length>2&&(E=n.range()[n.range().length-1]+(n.range()[1]-n.range()[0])),T.attr("text-anchor","middle").attr("y",0).attr("x",E/2),u&&(k=m.selectAll("g.nv-axisMaxMin").data(n.domain()),k.enter().append("g").attr("class",function(t,e){return["nv-axisMaxMin","nv-axisMaxMin-x",0==e?"nv-axisMin-x":"nv-axisMax-x"].join(" ")}).append("text"),k.exit().remove(),k.attr("transform",function(t,e){return"translate("+o.utils.NaNtoZero(n(t))+",0)"}).select("text").attr("dy","-0.5em").attr("y",-e.tickPadding()).attr("text-anchor","middle").text(function(t,e){var n=w(t);return(""+n).match("NaN")?"":n}),k.watchTransition(x,"min-max top").attr("transform",function(t,e){return"translate("+o.utils.NaNtoZero(n.range()[e])+",0)"}));break;case"bottom":C=g+36;var P=30,S=0,M=_.selectAll("g").select("text"),N="";if(c%360){M.attr("transform",""),M.each(function(t,e){var n=this.getBoundingClientRect(),r=n.width;S=n.height,r>P&&(P=r)}),N="rotate("+c+" 0,"+(S/2+e.tickPadding())+")";var A=Math.abs(Math.sin(c*Math.PI/180));C=(A?A*P:P)+30,M.attr("transform",N).style("text-anchor",c%360>0?"start":"end")}else d?M.attr("transform",function(t,e){return"translate(0,"+(e%2==0?"0":"12")+")"}):M.attr("transform","translate(0,0)");T.enter().append("text").attr("class","nv-axislabel"),E=0,1===n.range().length?E=p?2*n.range()[0]+n.rangeBand():0:2===n.range().length?E=p?n.range()[0]+n.range()[1]+n.rangeBand():n.range()[1]:n.range().length>2&&(E=n.range()[n.range().length-1]+(n.range()[1]-n.range()[0])),T.attr("text-anchor","middle").attr("y",C).attr("x",E/2),u&&(k=m.selectAll("g.nv-axisMaxMin").data([n.domain()[0],n.domain()[n.domain().length-1]]),k.enter().append("g").attr("class",function(t,e){return["nv-axisMaxMin","nv-axisMaxMin-x",0==e?"nv-axisMin-x":"nv-axisMax-x"].join(" ")}).append("text"),k.exit().remove(),k.attr("transform",function(t,e){return"translate("+o.utils.NaNtoZero(n(t)+(p?n.rangeBand()/2:0))+",0)"}).select("text").attr("dy",".71em").attr("y",e.tickPadding()).attr("transform",N).style("text-anchor",c?c%360>0?"start":"end":"middle").text(function(t,e){var n=w(t);return(""+n).match("NaN")?"":n}),k.watchTransition(x,"min-max bottom").attr("transform",function(t,e){return"translate("+o.utils.NaNtoZero(n(t)+(p?n.rangeBand()/2:0))+",0)"}));break;case"right":T.enter().append("text").attr("class","nv-axislabel"),T.style("text-anchor",f?"middle":"begin").attr("transform",f?"rotate(90)":"").attr("y",f?-Math.max(i.right,a)+12-(g||0):-10).attr("x",f?r.max(n.range())/2:e.tickPadding()),u&&(k=m.selectAll("g.nv-axisMaxMin").data(n.domain()),k.enter().append("g").attr("class",function(t,e){return["nv-axisMaxMin","nv-axisMaxMin-y",0==e?"nv-axisMin-y":"nv-axisMax-y"].join(" ")}).append("text").style("opacity",0),k.exit().remove(),k.attr("transform",function(t,e){return"translate(0,"+o.utils.NaNtoZero(n(t))+")"}).select("text").attr("dy",".32em").attr("y",0).attr("x",e.tickPadding()).style("text-anchor","start").text(function(t,e){var n=w(t);return(""+n).match("NaN")?"":n}),k.watchTransition(x,"min-max right").attr("transform",function(t,e){return"translate(0,"+o.utils.NaNtoZero(n.range()[e])+")"}).select("text").style("opacity",1));break;case"left":T.enter().append("text").attr("class","nv-axislabel"),T.style("text-anchor",f?"middle":"end").attr("transform",f?"rotate(-90)":"").attr("y",f?-Math.max(i.left,a)+25-(g||0):-10).attr("x",f?-r.max(n.range())/2:-e.tickPadding()),u&&(k=m.selectAll("g.nv-axisMaxMin").data(n.domain()),k.enter().append("g").attr("class",function(t,e){return["nv-axisMaxMin","nv-axisMaxMin-y",0==e?"nv-axisMin-y":"nv-axisMax-y"].join(" ")}).append("text").style("opacity",0),k.exit().remove(),k.attr("transform",function(t,e){return"translate(0,"+o.utils.NaNtoZero(b(t))+")"}).select("text").attr("dy",".32em").attr("y",0).attr("x",-e.tickPadding()).attr("text-anchor","end").text(function(t,e){var n=w(t);return(""+n).match("NaN")?"":n}),k.watchTransition(x,"min-max right").attr("transform",function(t,e){return"translate(0,"+o.utils.NaNtoZero(n.range()[e])+")"}).select("text").style("opacity",1))}if(T.text(function(t){return t}),!u||"left"!==e.orient()&&"right"!==e.orient()||(_.selectAll("g").each(function(t,e){r.select(this).select("text").attr("opacity",1),(n(t)<n.range()[1]+10||n(t)>n.range()[0]-10)&&((t>1e-10||t<-1e-10)&&r.select(this).attr("opacity",0),
r.select(this).select("text").attr("opacity",0))}),n.domain()[0]==n.domain()[1]&&0==n.domain()[0]&&m.selectAll("g.nv-axisMaxMin").style("opacity",function(t,e){return e?0:1})),u&&("top"===e.orient()||"bottom"===e.orient())){var O=[];m.selectAll("g.nv-axisMaxMin").each(function(t,e){try{e?O.push(n(t)-this.getBoundingClientRect().width-4):O.push(n(t)+this.getBoundingClientRect().width+4)}catch(r){e?O.push(n(t)-4):O.push(n(t)+4)}}),_.selectAll("g").each(function(t,e){(n(t)<O[0]||n(t)>O[1])&&(t>1e-10||t<-1e-10?r.select(this).remove():r.select(this).select("text").remove())})}_.selectAll(".tick").filter(function(t){return!parseFloat(Math.round(1e5*t)/1e6)&&void 0!==t}).classed("zero",!0),b=n.copy()}),x.renderEnd("axis immediate"),t}var e=r.svg.axis(),n=r.scale.linear(),i={top:0,right:0,bottom:0,left:0},a=75,s=60,l=null,u=!0,c=0,f=!0,d=!1,p=!1,h=null,g=0,v=void 0,m=250,y=r.dispatch("renderEnd");e.scale(n).orient("bottom").tickFormat(function(t){return t});var b,x=o.utils.renderWatch(y,m);return t.axis=e,t.dispatch=y,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{axisLabelDistance:{get:function(){return g},set:function(t){g=t}},staggerLabels:{get:function(){return d},set:function(t){d=t}},rotateLabels:{get:function(){return c},set:function(t){c=t}},rotateYLabel:{get:function(){return f},set:function(t){f=t}},showMaxMin:{get:function(){return u},set:function(t){u=t}},axisLabel:{get:function(){return l},set:function(t){l=t}},height:{get:function(){return s},set:function(t){s=t}},ticks:{get:function(){return h},set:function(t){h=t}},width:{get:function(){return a},set:function(t){a=t}},fontSize:{get:function(){return v},set:function(t){v=t}},margin:{get:function(){return i},set:function(t){i.top=void 0!==t.top?t.top:i.top,i.right=void 0!==t.right?t.right:i.right,i.bottom=void 0!==t.bottom?t.bottom:i.bottom,i.left=void 0!==t.left?t.left:i.left}},duration:{get:function(){return m},set:function(t){m=t,x.reset(m)}},scale:{get:function(){return n},set:function(r){n=r,e.scale(n),p="function"==typeof n.rangeBands,o.utils.inheritOptionsD3(t,n,["domain","range","rangeBand","rangeBands"])}}}),o.utils.initOptions(t),o.utils.inheritOptionsD3(t,e,["orient","tickValues","tickSubdivide","tickSize","tickPadding","tickFormat"]),o.utils.inheritOptionsD3(t,n,["domain","range","rangeBand","rangeBands"]),t},o.models.boxPlot=function(){"use strict";function t(d){return A.reset(),d.each(function(t){var d=c-u.left-u.right,O=f-u.top-u.bottom;P=r.select(this),o.utils.initSVG(P),p.domain(e||t.map(function(t,e){return g(t,e)})).rangeBands(n||[0,d],.1);var D=[];if(!i){var I,R,L=[];t.forEach(function(t,e){var n=v(t),r=y(t),o=b(t),i=x(t),a=w(t);a&&a.forEach(function(t,e){L.push(T(t,e,void 0))}),o&&L.push(o),n&&L.push(n),r&&L.push(r),i&&L.push(i)}),I=r.min(L),R=r.max(L),D=[I,R]}h.domain(i||D),h.range(a||[O,0]),s=s||p,l=l||h.copy().range([h(0),h(0)]);var F=P.selectAll("g.nv-wrap").data([t]);F.enter().append("g").attr("class","nvd3 nv-wrap");F.attr("transform","translate("+u.left+","+u.top+")");var j=F.selectAll(".nv-boxplot").data(function(t){return t}),B=j.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6);j.attr("class","nv-boxplot").attr("transform",function(t,e,n){return"translate("+(p(g(t,e))+.05*p.rangeBand())+", 0)"}).classed("hover",function(t){return t.hover}),j.watchTransition(A,"nv-boxplot: boxplots").style("stroke-opacity",1).style("fill-opacity",.75).delay(function(e,n){return n*M/t.length}).attr("transform",function(t,e){return"translate("+(p(g(t,e))+.05*p.rangeBand())+", 0)"}),j.exit().remove(),B.each(function(t,e){var n=r.select(this);[b,x].forEach(function(r){if(void 0!==r(t)&&null!==r(t)){var o=r===b?"low":"high";n.append("line").style("stroke",_(t)||E(t,e)).attr("class","nv-boxplot-whisker nv-boxplot-"+o),n.append("line").style("stroke",_(t)||E(t,e)).attr("class","nv-boxplot-tick nv-boxplot-"+o)}})});var U=function(){return null===N?.9*p.rangeBand():Math.min(75,.9*p.rangeBand())},H=function(){return.45*p.rangeBand()-U()/2},z=function(){return.45*p.rangeBand()+U()/2};[b,x].forEach(function(t){var e=t===b?"low":"high",n=t===b?v:y;j.select("line.nv-boxplot-whisker.nv-boxplot-"+e).watchTransition(A,"nv-boxplot: boxplots").attr("x1",.45*p.rangeBand()).attr("y1",function(e,n){return h(t(e))}).attr("x2",.45*p.rangeBand()).attr("y2",function(t,e){return h(n(t))}),j.select("line.nv-boxplot-tick.nv-boxplot-"+e).watchTransition(A,"nv-boxplot: boxplots").attr("x1",H).attr("y1",function(e,n){return h(t(e))}).attr("x2",z).attr("y2",function(e,n){return h(t(e))})}),[b,x].forEach(function(t){var e=t===b?"low":"high";B.selectAll(".nv-boxplot-"+e).on("mouseover",function(e,n,o){r.select(this).classed("hover",!0),S.elementMouseover({series:{key:t(e),color:_(e)||E(e,o)},e:r.event})}).on("mouseout",function(e,n,o){r.select(this).classed("hover",!1),S.elementMouseout({series:{key:t(e),color:_(e)||E(e,o)},e:r.event})}).on("mousemove",function(t,e){S.elementMousemove({e:r.event})})}),B.append("rect").attr("class","nv-boxplot-box").on("mouseover",function(t,e){r.select(this).classed("hover",!0),S.elementMouseover({key:g(t),value:g(t),series:[{key:"Q3",value:y(t),color:_(t)||E(t,e)},{key:"Q2",value:m(t),color:_(t)||E(t,e)},{key:"Q1",value:v(t),color:_(t)||E(t,e)}],data:t,index:e,e:r.event})}).on("mouseout",function(t,e){r.select(this).classed("hover",!1),S.elementMouseout({key:g(t),value:g(t),series:[{key:"Q3",value:y(t),color:_(t)||E(t,e)},{key:"Q2",value:m(t),color:_(t)||E(t,e)},{key:"Q1",value:v(t),color:_(t)||E(t,e)}],data:t,index:e,e:r.event})}).on("mousemove",function(t,e){S.elementMousemove({e:r.event})}),j.select("rect.nv-boxplot-box").watchTransition(A,"nv-boxplot: boxes").attr("y",function(t,e){return h(y(t))}).attr("width",U).attr("x",H).attr("height",function(t,e){return Math.abs(h(y(t))-h(v(t)))||1}).style("fill",function(t,e){return _(t)||E(t,e)}).style("stroke",function(t,e){return _(t)||E(t,e)}),B.append("line").attr("class","nv-boxplot-median"),j.select("line.nv-boxplot-median").watchTransition(A,"nv-boxplot: boxplots line").attr("x1",H).attr("y1",function(t,e){return h(m(t))}).attr("x2",z).attr("y2",function(t,e){return h(m(t))});var W=j.selectAll(".nv-boxplot-outlier").data(function(t){return w(t)||[]});W.enter().append("circle").style("fill",function(t,e,n){return k(t,e,n)||E(t,n)}).style("stroke",function(t,e,n){return k(t,e,n)||E(t,n)}).style("z-index",9e3).on("mouseover",function(t,e,n){r.select(this).classed("hover",!0),S.elementMouseover({series:{key:C(t,e,n),color:k(t,e,n)||E(t,n)},e:r.event})}).on("mouseout",function(t,e,n){r.select(this).classed("hover",!1),S.elementMouseout({series:{key:C(t,e,n),color:k(t,e,n)||E(t,n)},e:r.event})}).on("mousemove",function(t,e){S.elementMousemove({e:r.event})}),W.attr("class","nv-boxplot-outlier"),W.watchTransition(A,"nv-boxplot: nv-boxplot-outlier").attr("cx",.45*p.rangeBand()).attr("cy",function(t,e,n){return h(T(t,e,n))}).attr("r","3"),W.exit().remove(),s=p.copy(),l=h.copy()}),A.renderEnd("nv-boxplot immediate"),t}var e,n,i,a,s,l,u={top:0,right:0,bottom:0,left:0},c=960,f=500,d=Math.floor(1e4*Math.random()),p=r.scale.ordinal(),h=r.scale.linear(),g=function(t){return t.label},v=function(t){return t.values.Q1},m=function(t){return t.values.Q2},y=function(t){return t.values.Q3},b=function(t){return t.values.whisker_low},x=function(t){return t.values.whisker_high},_=function(t){return t.color},w=function(t){return t.values.outliers},T=function(t,e,n){return t},C=function(t,e,n){return t},k=function(t,e,n){},E=o.utils.defaultColor(),P=null,S=r.dispatch("elementMouseover","elementMouseout","elementMousemove","renderEnd"),M=250,N=null,A=o.utils.renderWatch(S,M);return t.dispatch=S,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return c},set:function(t){c=t}},height:{get:function(){return f},set:function(t){f=t}},maxBoxWidth:{get:function(){return N},set:function(t){N=t}},x:{get:function(){return g},set:function(t){g=t}},q1:{get:function(){return v},set:function(t){v=t}},q2:{get:function(){return m},set:function(t){m=t}},q3:{get:function(){return y},set:function(t){y=t}},wl:{get:function(){return b},set:function(t){b=t}},wh:{get:function(){return x},set:function(t){x=t}},itemColor:{get:function(){return _},set:function(t){_=t}},outliers:{get:function(){return w},set:function(t){w=t}},outlierValue:{get:function(){return T},set:function(t){T=t}},outlierLabel:{get:function(){return C},set:function(t){C=t}},outlierColor:{get:function(){return k},set:function(t){k=t}},xScale:{get:function(){return p},set:function(t){p=t}},yScale:{get:function(){return h},set:function(t){h=t}},xDomain:{get:function(){return e},set:function(t){e=t}},yDomain:{get:function(){return i},set:function(t){i=t}},xRange:{get:function(){return n},set:function(t){n=t}},yRange:{get:function(){return a},set:function(t){a=t}},id:{get:function(){return d},set:function(t){d=t}},y:{get:function(){return console.warn("BoxPlot 'y' chart option is deprecated. Please use model overrides instead."),{}},set:function(t){console.warn("BoxPlot 'y' chart option is deprecated. Please use model overrides instead.")}},margin:{get:function(){return u},set:function(t){u.top=void 0!==t.top?t.top:u.top,u.right=void 0!==t.right?t.right:u.right,u.bottom=void 0!==t.bottom?t.bottom:u.bottom,u.left=void 0!==t.left?t.left:u.left}},color:{get:function(){return E},set:function(t){E=o.utils.getColor(t)}},duration:{get:function(){return M},set:function(t){M=t,A.reset(M)}}}),o.utils.initOptions(t),t},o.models.boxPlotChart=function(){"use strict";function t(f){return x.reset(),x.models(i),d&&x.models(a),p&&x.models(s),f.each(function(f){var v=r.select(this);o.utils.initSVG(v);var x=(u||parseInt(v.style("width"))||960)-l.left-l.right,_=(c||parseInt(v.style("height"))||400)-l.top-l.bottom;if(t.update=function(){y.beforeUpdate(),v.transition().duration(b).call(t)},t.container=this,!f||!f.length){var w=v.selectAll(".nv-noData").data([m]);return w.enter().append("text").attr("class","nvd3 nv-noData").attr("dy","-.7em").style("text-anchor","middle"),w.attr("x",l.left+x/2).attr("y",l.top+_/2).text(function(t){return t}),t}v.selectAll(".nv-noData").remove(),e=i.xScale(),n=i.yScale().clamp(!0);var T=v.selectAll("g.nv-wrap.nv-boxPlotWithAxes").data([f]),C=T.enter().append("g").attr("class","nvd3 nv-wrap nv-boxPlotWithAxes").append("g"),k=C.append("defs"),E=T.select("g");C.append("g").attr("class","nv-x nv-axis"),C.append("g").attr("class","nv-y nv-axis").append("g").attr("class","nv-zeroLine").append("line"),C.append("g").attr("class","nv-barsWrap"),E.attr("transform","translate("+l.left+","+l.top+")"),h&&E.select(".nv-y.nv-axis").attr("transform","translate("+x+",0)"),i.width(x).height(_);var P=E.select(".nv-barsWrap").datum(f.filter(function(t){return!t.disabled}));if(P.transition().call(i),k.append("clipPath").attr("id","nv-x-label-clip-"+i.id()).append("rect"),E.select("#nv-x-label-clip-"+i.id()+" rect").attr("width",e.rangeBand()*(g?2:1)).attr("height",16).attr("x",-e.rangeBand()/(g?1:2)),d){a.scale(e).ticks(o.utils.calcTicksX(x/100,f)).tickSize(-_,0),E.select(".nv-x.nv-axis").attr("transform","translate(0,"+n.range()[0]+")"),E.select(".nv-x.nv-axis").call(a);var S=E.select(".nv-x.nv-axis").selectAll("g");g&&S.selectAll("text").attr("transform",function(t,e,n){return"translate(0,"+(n%2===0?"5":"17")+")"})}p&&(s.scale(n).ticks(Math.floor(_/36)).tickSize(-x,0),E.select(".nv-y.nv-axis").call(s)),E.select(".nv-zeroLine line").attr("x1",0).attr("x2",x).attr("y1",n(0)).attr("y2",n(0))}),x.renderEnd("nv-boxplot chart immediate"),t}var e,n,i=o.models.boxPlot(),a=o.models.axis(),s=o.models.axis(),l={top:15,right:10,bottom:50,left:60},u=null,c=null,f=o.utils.getColor(),d=!0,p=!0,h=!1,g=!1,v=o.models.tooltip(),m="No Data Available.",y=r.dispatch("beforeUpdate","renderEnd"),b=250;a.orient("bottom").showMaxMin(!1).tickFormat(function(t){return t}),s.orient(h?"right":"left").tickFormat(r.format(",.1f")),v.duration(0);var x=o.utils.renderWatch(y,b);return i.dispatch.on("elementMouseover.tooltip",function(t){v.data(t).hidden(!1)}),i.dispatch.on("elementMouseout.tooltip",function(t){v.data(t).hidden(!0)}),i.dispatch.on("elementMousemove.tooltip",function(t){v()}),t.dispatch=y,t.boxplot=i,t.xAxis=a,t.yAxis=s,t.tooltip=v,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return u},set:function(t){u=t}},height:{get:function(){return c},set:function(t){c=t}},staggerLabels:{get:function(){return g},set:function(t){g=t}},showXAxis:{get:function(){return d},set:function(t){d=t}},showYAxis:{get:function(){return p},set:function(t){p=t}},tooltipContent:{get:function(){return v},set:function(t){v=t}},noData:{get:function(){return m},set:function(t){m=t}},margin:{get:function(){return l},set:function(t){l.top=void 0!==t.top?t.top:l.top,l.right=void 0!==t.right?t.right:l.right,l.bottom=void 0!==t.bottom?t.bottom:l.bottom,l.left=void 0!==t.left?t.left:l.left}},duration:{get:function(){return b},set:function(t){b=t,x.reset(b),i.duration(b),a.duration(b),s.duration(b)}},color:{get:function(){return f},set:function(t){f=o.utils.getColor(t),i.color(f)}},rightAlignYAxis:{get:function(){return h},set:function(t){h=t,s.orient(t?"right":"left")}}}),o.utils.inheritOptions(t,i),o.utils.initOptions(t),t},o.models.bullet=function(){"use strict";function t(t,e){var n=t.slice();t.sort(function(t,o){var i=n.indexOf(t),a=n.indexOf(o);return r.descending(e[i],e[a])})}function e(i){return i.each(function(e,i){var b=v-n.left-n.right,k=m-n.top-n.bottom;y=r.select(this),o.utils.initSVG(y);var E=s.call(this,e,i).slice(),P=l.call(this,e,i).slice(),S=u.call(this,e,i).slice(),M=c.call(this,e,i).slice(),N=f.call(this,e,i).slice(),A=d.call(this,e,i).slice(),O=p.call(this,e,i).slice(),D=h.call(this,e,i).slice();t(N,E),t(A,P),t(O,S),t(D,M),E.sort(r.descending),P.sort(r.descending),S.sort(r.descending),M.sort(r.descending);var I=r.scale.linear().domain(r.extent(r.merge([g,E]))).range(a?[b,0]:[0,b]);this.__chart__||r.scale.linear().domain([0,1/0]).range(I.range());this.__chart__=I;for(var R=(r.min(E),r.max(E),E[1],y.selectAll("g.nv-wrap.nv-bullet").data([e])),L=R.enter().append("g").attr("class","nvd3 nv-wrap nv-bullet"),F=L.append("g"),j=R.select("g"),i=0,B=E.length;i<B;i++){var U="nv-range nv-range"+i;i<=2&&(U=U+" nv-range"+T[i]),F.append("rect").attr("class",U)}F.append("rect").attr("class","nv-measure"),R.attr("transform","translate("+n.left+","+n.top+")");for(var H=function(t){return Math.abs(I(t)-I(0))},z=function(t){return I(t<0?t:0)},i=0,B=E.length;i<B;i++){var W=E[i];j.select("rect.nv-range"+i).datum(W).attr("height",k).transition().duration(C).attr("width",H(W)).attr("x",z(W))}j.select("rect.nv-measure").style("fill",x).attr("height",k/3).attr("y",k/3).on("mouseover",function(){_.elementMouseover({value:M[0],label:D[0]||"Current",color:r.select(this).style("fill")})}).on("mousemove",function(){_.elementMousemove({value:M[0],label:D[0]||"Current",color:r.select(this).style("fill")})}).on("mouseout",function(){_.elementMouseout({value:M[0],label:D[0]||"Current",color:r.select(this).style("fill")})}).transition().duration(C).attr("width",M<0?I(0)-I(M[0]):I(M[0])-I(0)).attr("x",z(M));var q=k/6,V=P.map(function(t,e){return{value:t,label:A[e]}});F.selectAll("path.nv-markerTriangle").data(V).enter().append("path").attr("class","nv-markerTriangle").attr("d","M0,"+q+"L"+q+","+-q+" "+-q+","+-q+"Z").on("mouseover",function(t){_.elementMouseover({value:t.value,label:t.label||"Previous",color:r.select(this).style("fill"),pos:[I(t.value),k/2]})}).on("mousemove",function(t){_.elementMousemove({value:t.value,label:t.label||"Previous",color:r.select(this).style("fill")})}).on("mouseout",function(t,e){_.elementMouseout({value:t.value,label:t.label||"Previous",color:r.select(this).style("fill")})}),j.selectAll("path.nv-markerTriangle").data(V).transition().duration(C).attr("transform",function(t){return"translate("+I(t.value)+","+k/2+")"});var K=S.map(function(t,e){return{value:t,label:O[e]}});F.selectAll("line.nv-markerLine").data(K).enter().append("line").attr("cursor","").attr("class","nv-markerLine").attr("x1",function(t){return I(t.value)}).attr("y1","2").attr("x2",function(t){return I(t.value)}).attr("y2",k-2).on("mouseover",function(t){_.elementMouseover({value:t.value,label:t.label||"Previous",color:r.select(this).style("fill"),pos:[I(t.value),k/2]})}).on("mousemove",function(t){_.elementMousemove({value:t.value,label:t.label||"Previous",color:r.select(this).style("fill")})}).on("mouseout",function(t,e){_.elementMouseout({value:t.value,label:t.label||"Previous",color:r.select(this).style("fill")})}),j.selectAll("line.nv-markerLine").data(K).transition().duration(C).attr("x1",function(t){return I(t.value)}).attr("x2",function(t){return I(t.value)}),R.selectAll(".nv-range").on("mouseover",function(t,e){var n=N[e]||w[e];_.elementMouseover({value:t,label:n,color:r.select(this).style("fill")})}).on("mousemove",function(){_.elementMousemove({value:M[0],label:D[0]||"Previous",color:r.select(this).style("fill")})}).on("mouseout",function(t,e){var n=N[e]||w[e];_.elementMouseout({value:t,label:n,color:r.select(this).style("fill")})})}),e}var n={top:0,right:0,bottom:0,left:0},i="left",a=!1,s=function(t){return t.ranges},l=function(t){return t.markers?t.markers:[]},u=function(t){return t.markerLines?t.markerLines:[0]},c=function(t){return t.measures},f=function(t){return t.rangeLabels?t.rangeLabels:[]},d=function(t){return t.markerLabels?t.markerLabels:[]},p=function(t){return t.markerLineLabels?t.markerLineLabels:[]},h=function(t){return t.measureLabels?t.measureLabels:[]},g=[0],v=380,m=30,y=null,b=null,x=o.utils.getColor(["#1f77b4"]),_=r.dispatch("elementMouseover","elementMouseout","elementMousemove"),w=["Maximum","Mean","Minimum"],T=["Max","Avg","Min"],C=1e3;return e.dispatch=_,e.options=o.utils.optionsFunc.bind(e),e._options=Object.create({},{ranges:{get:function(){return s},set:function(t){s=t}},markers:{get:function(){return l},set:function(t){l=t}},measures:{get:function(){return c},set:function(t){c=t}},forceX:{get:function(){return g},set:function(t){g=t}},width:{get:function(){return v},set:function(t){v=t}},height:{get:function(){return m},set:function(t){m=t}},tickFormat:{get:function(){return b},set:function(t){b=t}},duration:{get:function(){return C},set:function(t){C=t}},margin:{get:function(){return n},set:function(t){n.top=void 0!==t.top?t.top:n.top,n.right=void 0!==t.right?t.right:n.right,n.bottom=void 0!==t.bottom?t.bottom:n.bottom,n.left=void 0!==t.left?t.left:n.left}},orient:{get:function(){return i},set:function(t){i=t,a="right"==i||"bottom"==i}},color:{get:function(){return x},set:function(t){x=o.utils.getColor(t)}}}),o.utils.initOptions(e),e},o.models.bulletChart=function(){"use strict";function t(n){return n.each(function(i,g){var v=r.select(this);o.utils.initSVG(v);var m=o.utils.availableWidth(f,v,s),y=d-s.top-s.bottom;if(t.update=function(){t(n)},t.container=this,!i||!l.call(this,i,g))return o.utils.noData(t,v),t;v.selectAll(".nv-noData").remove();var b=l.call(this,i,g).slice().sort(r.descending),x=u.call(this,i,g).slice().sort(r.descending),_=c.call(this,i,g).slice().sort(r.descending),w=v.selectAll("g.nv-wrap.nv-bulletChart").data([i]),T=w.enter().append("g").attr("class","nvd3 nv-wrap nv-bulletChart"),C=T.append("g"),k=w.select("g");C.append("g").attr("class","nv-bulletWrap"),C.append("g").attr("class","nv-titles"),w.attr("transform","translate("+s.left+","+s.top+")");var E=r.scale.linear().domain([0,Math.max(b[0],x[0]||0,_[0])]).range(a?[m,0]:[0,m]),P=this.__chart__||r.scale.linear().domain([0,1/0]).range(E.range());this.__chart__=E;var S=C.select(".nv-titles").append("g").attr("text-anchor","end").attr("transform","translate(-6,"+(d-s.top-s.bottom)/2+")");S.append("text").attr("class","nv-title").text(function(t){return t.title}),S.append("text").attr("class","nv-subtitle").attr("dy","1em").text(function(t){return t.subtitle}),e.width(m).height(y);var M=k.select(".nv-bulletWrap");r.transition(M).call(e);var N=p||E.tickFormat(m/100),A=k.selectAll("g.nv-tick").data(E.ticks(h?h:m/50),function(t){return this.textContent||N(t)}),O=A.enter().append("g").attr("class","nv-tick").attr("transform",function(t){return"translate("+P(t)+",0)"}).style("opacity",1e-6);O.append("line").attr("y1",y).attr("y2",7*y/6),O.append("text").attr("text-anchor","middle").attr("dy","1em").attr("y",7*y/6).text(N);var D=r.transition(A).transition().duration(e.duration()).attr("transform",function(t){return"translate("+E(t)+",0)"}).style("opacity",1);D.select("line").attr("y1",y).attr("y2",7*y/6),D.select("text").attr("y",7*y/6),r.transition(A.exit()).transition().duration(e.duration()).attr("transform",function(t){return"translate("+E(t)+",0)"}).style("opacity",1e-6).remove()}),r.timer.flush(),t}var e=o.models.bullet(),n=o.models.tooltip(),i="left",a=!1,s={top:5,right:40,bottom:20,left:120},l=function(t){return t.ranges},u=function(t){return t.markers?t.markers:[]},c=function(t){return t.measures},f=null,d=55,p=null,h=null,g=null,v=r.dispatch();return n.duration(0).headerEnabled(!1),e.dispatch.on("elementMouseover.tooltip",function(t){t.series={key:t.label,value:t.value,color:t.color},n.data(t).hidden(!1)}),e.dispatch.on("elementMouseout.tooltip",function(t){n.hidden(!0)}),e.dispatch.on("elementMousemove.tooltip",function(t){n()}),t.bullet=e,t.dispatch=v,t.tooltip=n,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{ranges:{get:function(){return l},set:function(t){l=t}},markers:{get:function(){return u},set:function(t){u=t}},measures:{get:function(){return c},set:function(t){c=t}},width:{get:function(){return f},set:function(t){f=t}},height:{get:function(){return d},set:function(t){d=t}},tickFormat:{get:function(){return p},set:function(t){p=t}},ticks:{get:function(){return h},set:function(t){h=t}},noData:{get:function(){return g},set:function(t){g=t}},margin:{get:function(){return s},set:function(t){s.top=void 0!==t.top?t.top:s.top,s.right=void 0!==t.right?t.right:s.right,s.bottom=void 0!==t.bottom?t.bottom:s.bottom,s.left=void 0!==t.left?t.left:s.left}},orient:{get:function(){return i},set:function(t){i=t,a="right"==i||"bottom"==i}}}),o.utils.inheritOptions(t,e),o.utils.initOptions(t),t},o.models.candlestickBar=function(){"use strict";function t(C){return C.each(function(t){e=r.select(this);var C=o.utils.availableWidth(u,e,l),k=o.utils.availableHeight(c,e,l);o.utils.initSVG(e);var P=C/t[0].values.length*.45;d.domain(n||r.extent(t[0].values.map(h).concat(x))),w?d.range(a||[.5*C/t[0].values.length,C*(t[0].values.length-.5)/t[0].values.length]):d.range(a||[5+P/2,C-P/2-5]),p.domain(i||[r.min(t[0].values.map(b).concat(_)),r.max(t[0].values.map(y).concat(_))]).range(s||[k,0]),d.domain()[0]===d.domain()[1]&&(d.domain()[0]?d.domain([d.domain()[0]-.01*d.domain()[0],d.domain()[1]+.01*d.domain()[1]]):d.domain([-1,1])),p.domain()[0]===p.domain()[1]&&(p.domain()[0]?p.domain([p.domain()[0]+.01*p.domain()[0],p.domain()[1]-.01*p.domain()[1]]):p.domain([-1,1]));var S=r.select(this).selectAll("g.nv-wrap.nv-candlestickBar").data([t[0].values]),M=S.enter().append("g").attr("class","nvd3 nv-wrap nv-candlestickBar"),N=M.append("defs"),A=M.append("g"),O=S.select("g");A.append("g").attr("class","nv-ticks"),S.attr("transform","translate("+l.left+","+l.top+")"),e.on("click",function(t,e){E.chartClick({data:t,index:e,pos:r.event,id:f})}),N.append("clipPath").attr("id","nv-chart-clip-path-"+f).append("rect"),S.select("#nv-chart-clip-path-"+f+" rect").attr("width",C).attr("height",k),O.attr("clip-path",T?"url(#nv-chart-clip-path-"+f+")":"");var D=S.select(".nv-ticks").selectAll(".nv-tick").data(function(t){return t});D.exit().remove();var I=D.enter().append("g");D.attr("class",function(t,e,n){return(v(t,e)>m(t,e)?"nv-tick negative":"nv-tick positive")+" nv-tick-"+n+"-"+e});I.append("line").attr("class","nv-candlestick-lines").attr("transform",function(t,e){return"translate("+d(h(t,e))+",0)"}).attr("x1",0).attr("y1",function(t,e){return p(y(t,e))}).attr("x2",0).attr("y2",function(t,e){return p(b(t,e))}),I.append("rect").attr("class","nv-candlestick-rects nv-bars").attr("transform",function(t,e){return"translate("+(d(h(t,e))-P/2)+","+(p(g(t,e))-(v(t,e)>m(t,e)?p(m(t,e))-p(v(t,e)):0))+")"}).attr("x",0).attr("y",0).attr("width",P).attr("height",function(t,e){var n=v(t,e),r=m(t,e);return n>r?p(r)-p(n):p(n)-p(r)});D.select(".nv-candlestick-lines").transition().attr("transform",function(t,e){return"translate("+d(h(t,e))+",0)"}).attr("x1",0).attr("y1",function(t,e){return p(y(t,e))}).attr("x2",0).attr("y2",function(t,e){return p(b(t,e))}),D.select(".nv-candlestick-rects").transition().attr("transform",function(t,e){return"translate("+(d(h(t,e))-P/2)+","+(p(g(t,e))-(v(t,e)>m(t,e)?p(m(t,e))-p(v(t,e)):0))+")"}).attr("x",0).attr("y",0).attr("width",P).attr("height",function(t,e){var n=v(t,e),r=m(t,e);return n>r?p(r)-p(n):p(n)-p(r)})}),t}var e,n,i,a,s,l={top:0,right:0,bottom:0,left:0},u=null,c=null,f=Math.floor(1e4*Math.random()),d=r.scale.linear(),p=r.scale.linear(),h=function(t){return t.x},g=function(t){return t.y},v=function(t){return t.open},m=function(t){return t.close},y=function(t){return t.high},b=function(t){return t.low},x=[],_=[],w=!1,T=!0,C=o.utils.defaultColor(),k=!1,E=r.dispatch("stateChange","changeState","renderEnd","chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove");return t.highlightPoint=function(n,r){t.clearHighlights(),e.select(".nv-candlestickBar .nv-tick-0-"+n).classed("hover",r)},t.clearHighlights=function(){e.select(".nv-candlestickBar .nv-tick.hover").classed("hover",!1)},t.dispatch=E,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return u},set:function(t){u=t}},height:{get:function(){return c},set:function(t){c=t}},xScale:{get:function(){return d},set:function(t){d=t}},yScale:{get:function(){return p},set:function(t){p=t}},xDomain:{get:function(){return n},set:function(t){n=t}},yDomain:{get:function(){return i},set:function(t){i=t}},xRange:{get:function(){return a},set:function(t){a=t}},yRange:{get:function(){return s},set:function(t){s=t}},forceX:{get:function(){return x},set:function(t){x=t}},forceY:{get:function(){return _},set:function(t){_=t}},padData:{get:function(){return w},set:function(t){w=t}},clipEdge:{get:function(){return T},set:function(t){T=t}},id:{get:function(){return f},set:function(t){f=t}},interactive:{get:function(){return k},set:function(t){k=t}},x:{get:function(){return h},set:function(t){h=t}},y:{get:function(){return g},set:function(t){g=t}},open:{get:function(){return v()},set:function(t){v=t}},close:{get:function(){return m()},set:function(t){m=t}},high:{get:function(){return y},set:function(t){y=t}},low:{get:function(){return b},set:function(t){b=t}},margin:{get:function(){return l},set:function(t){l.top=void 0!=t.top?t.top:l.top,l.right=void 0!=t.right?t.right:l.right,l.bottom=void 0!=t.bottom?t.bottom:l.bottom,l.left=void 0!=t.left?t.left:l.left}},color:{get:function(){return C},set:function(t){C=o.utils.getColor(t)}}}),o.utils.initOptions(t),t},o.models.cumulativeLineChart=function(){"use strict";function t(d){return R.reset(),R.models(a),b&&R.models(s),x&&R.models(l),d.each(function(d){function S(e,n){r.select(t.container).style("cursor","ew-resize")}function O(t,e){I.x=r.event.x,I.i=Math.round(D.invert(I.x)),j()}function R(e,n){r.select(t.container).style("cursor","auto"),E.index=I.i,N.stateChange(E)}function j(){nt.data([I]);var e=t.duration();t.duration(0),t.update(),t.duration(e)}var B=r.select(this);o.utils.initSVG(B),B.classed("nv-chart-"+k,!0);var U=o.utils.availableWidth(v,B,p),H=o.utils.availableHeight(m,B,p);if(t.update=function(){0===A?B.call(t):B.transition().duration(A).call(t)},t.container=this,E.setter(F(d),t.update).getter(L(d)).update(),E.disabled=d.map(function(t){return!!t.disabled}),!P){var z;P={};for(z in E)E[z]instanceof Array?P[z]=E[z].slice(0):P[z]=E[z]}var W=r.behavior.drag().on("dragstart",S).on("drag",O).on("dragend",R);if(!(d&&d.length&&d.filter(function(t){return t.values.length}).length))return o.utils.noData(t,B),t;if(B.selectAll(".nv-noData").remove(),n=a.xScale(),i=a.yScale(),C)a.yDomain(null);else{var q=d.filter(function(t){return!t.disabled}).map(function(t,e){var n=r.extent(t.values,a.y());return n[0]<-.95&&(n[0]=-.95),[(n[0]-n[1])/(1+n[1]),(n[1]-n[0])/(1+n[0])]}),V=[r.min(q,function(t){return t[0]}),r.max(q,function(t){return t[1]})];a.yDomain(V)}D.domain([0,d[0].values.length-1]).range([0,U]).clamp(!0);var d=e(I.i,d),K=T?"none":"all",Y=B.selectAll("g.nv-wrap.nv-cumulativeLine").data([d]),G=Y.enter().append("g").attr("class","nvd3 nv-wrap nv-cumulativeLine").append("g"),X=Y.select("g");if(G.append("g").attr("class","nv-interactive"),G.append("g").attr("class","nv-x nv-axis").style("pointer-events","none"),G.append("g").attr("class","nv-y nv-axis"),G.append("g").attr("class","nv-background"),G.append("g").attr("class","nv-linesWrap").style("pointer-events",K),G.append("g").attr("class","nv-avgLinesWrap").style("pointer-events","none"),G.append("g").attr("class","nv-legendWrap"),G.append("g").attr("class","nv-controlsWrap"),y?(u.width(U),X.select(".nv-legendWrap").datum(d).call(u),h||u.height()===p.top||(p.top=u.height(),H=o.utils.availableHeight(m,B,p)),X.select(".nv-legendWrap").attr("transform","translate(0,"+-p.top+")")):X.select(".nv-legendWrap").selectAll("*").remove(),w){var $=[{key:"Re-scale y-axis",disabled:!C}];c.width(140).color(["#444","#444","#444"]).rightAlign(!1).margin({top:5,right:0,bottom:5,left:20}),X.select(".nv-controlsWrap").datum($).attr("transform","translate(0,"+-p.top+")").call(c)}else X.select(".nv-controlsWrap").selectAll("*").remove();Y.attr("transform","translate("+p.left+","+p.top+")"),_&&X.select(".nv-y.nv-axis").attr("transform","translate("+U+",0)");var Z=d.filter(function(t){return t.tempDisabled});Y.select(".tempDisabled").remove(),Z.length&&Y.append("text").attr("class","tempDisabled").attr("x",U/2).attr("y","-.71em").style("text-anchor","end").text(Z.map(function(t){return t.key}).join(", ")+" values cannot be calculated for this time period."),T&&(f.width(U).height(H).margin({left:p.left,top:p.top}).svgContainer(B).xScale(n),Y.select(".nv-interactive").call(f)),G.select(".nv-background").append("rect"),X.select(".nv-background rect").attr("width",U).attr("height",H),a.y(function(t){return t.display.y}).width(U).height(H).color(d.map(function(t,e){return t.color||g(t,e)}).filter(function(t,e){return!d[e].disabled&&!d[e].tempDisabled}));var J=X.select(".nv-linesWrap").datum(d.filter(function(t){return!t.disabled&&!t.tempDisabled}));J.call(a),d.forEach(function(t,e){t.seriesIndex=e});var Q=d.filter(function(t){return!t.disabled&&!!M(t)}),tt=X.select(".nv-avgLinesWrap").selectAll("line").data(Q,function(t){return t.key}),et=function(t){var e=i(M(t));return e<0?0:e>H?H:e};tt.enter().append("line").style("stroke-width",2).style("stroke-dasharray","10,10").style("stroke",function(t,e){return a.color()(t,t.seriesIndex)}).attr("x1",0).attr("x2",U).attr("y1",et).attr("y2",et),tt.style("stroke-opacity",function(t){var e=i(M(t));return e<0||e>H?0:1}).attr("x1",0).attr("x2",U).attr("y1",et).attr("y2",et),tt.exit().remove();var nt=J.selectAll(".nv-indexLine").data([I]);nt.enter().append("rect").attr("class","nv-indexLine").attr("width",3).attr("x",-2).attr("fill","red").attr("fill-opacity",.5).style("pointer-events","all").call(W),nt.attr("transform",function(t){return"translate("+D(t.i)+",0)"}).attr("height",H),b&&(s.scale(n)._ticks(o.utils.calcTicksX(U/70,d)).tickSize(-H,0),X.select(".nv-x.nv-axis").attr("transform","translate(0,"+i.range()[0]+")"),X.select(".nv-x.nv-axis").call(s)),x&&(l.scale(i)._ticks(o.utils.calcTicksY(H/36,d)).tickSize(-U,0),X.select(".nv-y.nv-axis").call(l)),X.select(".nv-background rect").on("click",function(){I.x=r.mouse(this)[0],I.i=Math.round(D.invert(I.x)),E.index=I.i,N.stateChange(E),j()}),a.dispatch.on("elementClick",function(t){I.i=t.pointIndex,I.x=D(I.i),E.index=I.i,N.stateChange(E),
j()}),c.dispatch.on("legendClick",function(e,n){e.disabled=!e.disabled,C=!e.disabled,E.rescaleY=C,N.stateChange(E),t.update()}),u.dispatch.on("stateChange",function(e){for(var n in e)E[n]=e[n];N.stateChange(E),t.update()}),f.dispatch.on("elementMousemove",function(e){a.clearHighlights();var n,r,i,u=[];if(d.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(s,l){r=o.interactiveBisect(s.values,e.pointXValue,t.x()),a.highlightPoint(l,r,!0);var c=s.values[r];"undefined"!=typeof c&&("undefined"==typeof n&&(n=c),"undefined"==typeof i&&(i=t.xScale()(t.x()(c,r))),u.push({key:s.key,value:t.y()(c,r),color:g(s,s.seriesIndex)}))}),u.length>2){var c=t.yScale().invert(e.mouseY),p=Math.abs(t.yScale().domain()[0]-t.yScale().domain()[1]),h=.03*p,v=o.nearestValueIndex(u.map(function(t){return t.value}),c,h);null!==v&&(u[v].highlight=!0)}var m=s.tickFormat()(t.x()(n,r),r);f.tooltip.valueFormatter(function(t,e){return l.tickFormat()(t)}).data({value:m,series:u})(),f.renderGuideLine(i)}),f.dispatch.on("elementMouseout",function(t){a.clearHighlights()}),N.on("changeState",function(e){"undefined"!=typeof e.disabled&&(d.forEach(function(t,n){t.disabled=e.disabled[n]}),E.disabled=e.disabled),"undefined"!=typeof e.index&&(I.i=e.index,I.x=D(I.i),E.index=e.index,nt.data([I])),"undefined"!=typeof e.rescaleY&&(C=e.rescaleY),t.update()})}),R.renderEnd("cumulativeLineChart immediate"),t}function e(t,e){return j||(j=a.y()),e.map(function(e,n){if(!e.values)return e;var r=e.values[t];if(null==r)return e;var o=j(r,t);return o<-.95&&!O?(e.tempDisabled=!0,e):(e.tempDisabled=!1,e.values=e.values.map(function(t,e){return t.display={y:(j(t,e)-o)/(1+o)},t}),e)})}var n,i,a=o.models.line(),s=o.models.axis(),l=o.models.axis(),u=o.models.legend(),c=o.models.legend(),f=o.interactiveGuideline(),d=o.models.tooltip(),p={top:30,right:30,bottom:50,left:60},h=null,g=o.utils.defaultColor(),v=null,m=null,y=!0,b=!0,x=!0,_=!1,w=!0,T=!1,C=!0,k=a.id(),E=o.utils.state(),P=null,S=null,M=function(t){return t.average},N=r.dispatch("stateChange","changeState","renderEnd"),A=250,O=!1;E.index=0,E.rescaleY=C,s.orient("bottom").tickPadding(7),l.orient(_?"right":"left"),d.valueFormatter(function(t,e){return l.tickFormat()(t,e)}).headerFormatter(function(t,e){return s.tickFormat()(t,e)}),c.updateState(!1);var D=r.scale.linear(),I={i:0,x:0},R=o.utils.renderWatch(N,A),L=function(t){return function(){return{active:t.map(function(t){return!t.disabled}),index:I.i,rescaleY:C}}},F=function(t){return function(e){void 0!==e.index&&(I.i=e.index),void 0!==e.rescaleY&&(C=e.rescaleY),void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};a.dispatch.on("elementMouseover.tooltip",function(e){var n={x:t.x()(e.point),y:t.y()(e.point),color:e.point.color};e.point=n,d.data(e).hidden(!1)}),a.dispatch.on("elementMouseout.tooltip",function(t){d.hidden(!0)});var j=null;return t.dispatch=N,t.lines=a,t.legend=u,t.controls=c,t.xAxis=s,t.yAxis=l,t.interactiveLayer=f,t.state=E,t.tooltip=d,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return v},set:function(t){v=t}},height:{get:function(){return m},set:function(t){m=t}},rescaleY:{get:function(){return C},set:function(t){C=t}},showControls:{get:function(){return w},set:function(t){w=t}},showLegend:{get:function(){return y},set:function(t){y=t}},average:{get:function(){return M},set:function(t){M=t}},defaultState:{get:function(){return P},set:function(t){P=t}},noData:{get:function(){return S},set:function(t){S=t}},showXAxis:{get:function(){return b},set:function(t){b=t}},showYAxis:{get:function(){return x},set:function(t){x=t}},noErrorCheck:{get:function(){return O},set:function(t){O=t}},margin:{get:function(){return p},set:function(t){void 0!==t.top&&(p.top=t.top,h=t.top),p.right=void 0!==t.right?t.right:p.right,p.bottom=void 0!==t.bottom?t.bottom:p.bottom,p.left=void 0!==t.left?t.left:p.left}},color:{get:function(){return g},set:function(t){g=o.utils.getColor(t),u.color(g)}},useInteractiveGuideline:{get:function(){return T},set:function(e){T=e,e===!0&&(t.interactive(!1),t.useVoronoi(!1))}},rightAlignYAxis:{get:function(){return _},set:function(t){_=t,l.orient(t?"right":"left")}},duration:{get:function(){return A},set:function(t){A=t,a.duration(A),s.duration(A),l.duration(A),R.reset(A)}}}),o.utils.inheritOptions(t,a),o.utils.initOptions(t),t},o.models.discreteBar=function(){"use strict";function t(p){return k.reset(),p.each(function(t){var p=f-c.left-c.right,C=d-c.top-c.bottom;e=r.select(this),o.utils.initSVG(e),t.forEach(function(t,e){t.values.forEach(function(t){t.series=e})});var E=n&&i?[]:t.map(function(t){return t.values.map(function(t,e){return{x:v(t,e),y:m(t,e),y0:t.y0}})});h.domain(n||r.merge(E).map(function(t){return t.x})).rangeBands(a||[0,p],.1),g.domain(i||r.extent(r.merge(E).map(function(t){return t.y}).concat(y))),x?g.range(s||[C-(g.domain()[0]<0?12:0),g.domain()[1]>0?12:0]):g.range(s||[C,0]),l=l||h,u=u||g.copy().range([g(0),g(0)]);var P=e.selectAll("g.nv-wrap.nv-discretebar").data([t]),S=P.enter().append("g").attr("class","nvd3 nv-wrap nv-discretebar"),M=S.append("g");P.select("g");M.append("g").attr("class","nv-groups"),P.attr("transform","translate("+c.left+","+c.top+")");var N=P.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t){return t.key});N.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6),N.exit().watchTransition(k,"discreteBar: exit groups").style("stroke-opacity",1e-6).style("fill-opacity",1e-6).remove(),N.attr("class",function(t,e){return"nv-group nv-series-"+e}).classed("hover",function(t){return t.hover}),N.watchTransition(k,"discreteBar: groups").style("stroke-opacity",1).style("fill-opacity",.75);var A=N.selectAll("g.nv-bar").data(function(t){return t.values});A.exit().remove();var O=A.enter().append("g").attr("transform",function(t,e,n){return"translate("+(h(v(t,e))+.05*h.rangeBand())+", "+g(0)+")"}).on("mouseover",function(t,e){r.select(this).classed("hover",!0),w.elementMouseover({data:t,index:e,color:r.select(this).style("fill")})}).on("mouseout",function(t,e){r.select(this).classed("hover",!1),w.elementMouseout({data:t,index:e,color:r.select(this).style("fill")})}).on("mousemove",function(t,e){w.elementMousemove({data:t,index:e,color:r.select(this).style("fill")})}).on("click",function(t,e){var n=this;w.elementClick({data:t,index:e,color:r.select(this).style("fill"),event:r.event,element:n}),r.event.stopPropagation()}).on("dblclick",function(t,e){w.elementDblClick({data:t,index:e,color:r.select(this).style("fill")}),r.event.stopPropagation()});O.append("rect").attr("height",0).attr("width",.9*h.rangeBand()/t.length),x?(O.append("text").attr("text-anchor","middle"),A.select("text").text(function(t,e){return _(m(t,e))}).watchTransition(k,"discreteBar: bars text").attr("x",.9*h.rangeBand()/2).attr("y",function(t,e){return m(t,e)<0?g(m(t,e))-g(0)+12:-4})):A.selectAll("text").remove(),A.attr("class",function(t,e){return m(t,e)<0?"nv-bar negative":"nv-bar positive"}).style("fill",function(t,e){return t.color||b(t,e)}).style("stroke",function(t,e){return t.color||b(t,e)}).select("rect").attr("class",T).watchTransition(k,"discreteBar: bars rect").attr("width",.9*h.rangeBand()/t.length),A.watchTransition(k,"discreteBar: bars").attr("transform",function(t,e){var n=h(v(t,e))+.05*h.rangeBand(),r=m(t,e)<0?g(0):g(0)-g(m(t,e))<1?g(0)-1:g(m(t,e));return"translate("+n+", "+r+")"}).select("rect").attr("height",function(t,e){return Math.max(Math.abs(g(m(t,e))-g(0)),1)}),l=h.copy(),u=g.copy()}),k.renderEnd("discreteBar immediate"),t}var e,n,i,a,s,l,u,c={top:0,right:0,bottom:0,left:0},f=960,d=500,p=Math.floor(1e4*Math.random()),h=r.scale.ordinal(),g=r.scale.linear(),v=function(t){return t.x},m=function(t){return t.y},y=[0],b=o.utils.defaultColor(),x=!1,_=r.format(",.2f"),w=r.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),T="discreteBar",C=250,k=o.utils.renderWatch(w,C);return t.dispatch=w,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return f},set:function(t){f=t}},height:{get:function(){return d},set:function(t){d=t}},forceY:{get:function(){return y},set:function(t){y=t}},showValues:{get:function(){return x},set:function(t){x=t}},x:{get:function(){return v},set:function(t){v=t}},y:{get:function(){return m},set:function(t){m=t}},xScale:{get:function(){return h},set:function(t){h=t}},yScale:{get:function(){return g},set:function(t){g=t}},xDomain:{get:function(){return n},set:function(t){n=t}},yDomain:{get:function(){return i},set:function(t){i=t}},xRange:{get:function(){return a},set:function(t){a=t}},yRange:{get:function(){return s},set:function(t){s=t}},valueFormat:{get:function(){return _},set:function(t){_=t}},id:{get:function(){return p},set:function(t){p=t}},rectClass:{get:function(){return T},set:function(t){T=t}},margin:{get:function(){return c},set:function(t){c.top=void 0!==t.top?t.top:c.top,c.right=void 0!==t.right?t.right:c.right,c.bottom=void 0!==t.bottom?t.bottom:c.bottom,c.left=void 0!==t.left?t.left:c.left}},color:{get:function(){return b},set:function(t){b=o.utils.getColor(t)}},duration:{get:function(){return C},set:function(t){C=t,k.reset(C)}}}),o.utils.initOptions(t),t},o.models.discreteBarChart=function(){"use strict";function t(u){return k.reset(),k.models(i),v&&k.models(a),m&&k.models(s),u.each(function(u){var h=r.select(this);o.utils.initSVG(h);var w=o.utils.availableWidth(d,h,c),k=o.utils.availableHeight(p,h,c);if(t.update=function(){T.beforeUpdate(),h.transition().duration(C).call(t)},t.container=this,!(u&&u.length&&u.filter(function(t){return t.values.length}).length))return o.utils.noData(t,h),t;h.selectAll(".nv-noData").remove(),e=i.xScale(),n=i.yScale().clamp(!0);var E=h.selectAll("g.nv-wrap.nv-discreteBarWithAxes").data([u]),P=E.enter().append("g").attr("class","nvd3 nv-wrap nv-discreteBarWithAxes").append("g"),S=P.append("defs"),M=E.select("g");P.append("g").attr("class","nv-x nv-axis"),P.append("g").attr("class","nv-y nv-axis").append("g").attr("class","nv-zeroLine").append("line"),P.append("g").attr("class","nv-barsWrap"),P.append("g").attr("class","nv-legendWrap"),M.attr("transform","translate("+c.left+","+c.top+")"),g?(l.width(w),M.select(".nv-legendWrap").datum(u).call(l),f||l.height()===c.top||(c.top=l.height(),k=o.utils.availableHeight(p,h,c)),E.select(".nv-legendWrap").attr("transform","translate(0,"+-c.top+")")):M.select(".nv-legendWrap").selectAll("*").remove(),y&&M.select(".nv-y.nv-axis").attr("transform","translate("+w+",0)"),i.width(w).height(k);var N=M.select(".nv-barsWrap").datum(u.filter(function(t){return!t.disabled}));if(N.transition().call(i),S.append("clipPath").attr("id","nv-x-label-clip-"+i.id()).append("rect"),M.select("#nv-x-label-clip-"+i.id()+" rect").attr("width",e.rangeBand()*(b?2:1)).attr("height",16).attr("x",-e.rangeBand()/(b?1:2)),v){a.scale(e)._ticks(o.utils.calcTicksX(w/100,u)).tickSize(-k,0),M.select(".nv-x.nv-axis").attr("transform","translate(0,"+(n.range()[0]+(i.showValues()&&n.domain()[0]<0?16:0))+")"),M.select(".nv-x.nv-axis").call(a);var A=M.select(".nv-x.nv-axis").selectAll("g");b&&A.selectAll("text").attr("transform",function(t,e,n){return"translate(0,"+(n%2==0?"5":"17")+")"}),_&&A.selectAll(".tick text").attr("transform","rotate("+_+" 0,0)").style("text-anchor",_>0?"start":"end"),x&&M.selectAll(".tick text").call(o.utils.wrapTicks,t.xAxis.rangeBand())}m&&(s.scale(n)._ticks(o.utils.calcTicksY(k/36,u)).tickSize(-w,0),M.select(".nv-y.nv-axis").call(s)),M.select(".nv-zeroLine line").attr("x1",0).attr("x2",y?-w:w).attr("y1",n(0)).attr("y2",n(0))}),k.renderEnd("discreteBar chart immediate"),t}var e,n,i=o.models.discreteBar(),a=o.models.axis(),s=o.models.axis(),l=o.models.legend(),u=o.models.tooltip(),c={top:15,right:10,bottom:50,left:60},f=null,d=null,p=null,h=o.utils.getColor(),g=!1,v=!0,m=!0,y=!1,b=!1,x=!1,_=0,w=null,T=r.dispatch("beforeUpdate","renderEnd"),C=250;a.orient("bottom").showMaxMin(!1).tickFormat(function(t){return t}),s.orient(y?"right":"left").tickFormat(r.format(",.1f")),u.duration(0).headerEnabled(!1).valueFormatter(function(t,e){return s.tickFormat()(t,e)}).keyFormatter(function(t,e){return a.tickFormat()(t,e)});var k=o.utils.renderWatch(T,C);return i.dispatch.on("elementMouseover.tooltip",function(e){e.series={key:t.x()(e.data),value:t.y()(e.data),color:e.color},u.data(e).hidden(!1)}),i.dispatch.on("elementMouseout.tooltip",function(t){u.hidden(!0)}),i.dispatch.on("elementMousemove.tooltip",function(t){u()}),t.dispatch=T,t.discretebar=i,t.legend=l,t.xAxis=a,t.yAxis=s,t.tooltip=u,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return d},set:function(t){d=t}},height:{get:function(){return p},set:function(t){p=t}},showLegend:{get:function(){return g},set:function(t){g=t}},staggerLabels:{get:function(){return b},set:function(t){b=t}},rotateLabels:{get:function(){return _},set:function(t){_=t}},wrapLabels:{get:function(){return x},set:function(t){x=!!t}},showXAxis:{get:function(){return v},set:function(t){v=t}},showYAxis:{get:function(){return m},set:function(t){m=t}},noData:{get:function(){return w},set:function(t){w=t}},margin:{get:function(){return c},set:function(t){void 0!==t.top&&(c.top=t.top,f=t.top),c.right=void 0!==t.right?t.right:c.right,c.bottom=void 0!==t.bottom?t.bottom:c.bottom,c.left=void 0!==t.left?t.left:c.left}},duration:{get:function(){return C},set:function(t){C=t,k.reset(C),i.duration(C),a.duration(C),s.duration(C)}},color:{get:function(){return h},set:function(t){h=o.utils.getColor(t),i.color(h),l.color(h)}},rightAlignYAxis:{get:function(){return y},set:function(t){y=t,s.orient(t?"right":"left")}}}),o.utils.inheritOptions(t,i),o.utils.initOptions(t),t},o.models.distribution=function(){"use strict";function t(f){return p.reset(),f.each(function(t){var f=(i-("x"===s?n.left+n.right:n.top+n.bottom),"x"==s?"y":"x"),d=r.select(this);o.utils.initSVG(d),e=e||c;var h=d.selectAll("g.nv-distribution").data([t]),g=h.enter().append("g").attr("class","nvd3 nv-distribution"),v=(g.append("g"),h.select("g"));h.attr("transform","translate("+n.left+","+n.top+")");var m=v.selectAll("g.nv-dist").data(function(t){return t},function(t){return t.key});m.enter().append("g"),m.attr("class",function(t,e){return"nv-dist nv-series-"+e}).style("stroke",function(t,e){return u(t,e)});var y=m.selectAll("line.nv-dist"+s).data(function(t){return t.values});y.enter().append("line").attr(s+"1",function(t,n){return e(l(t,n))}).attr(s+"2",function(t,n){return e(l(t,n))}),p.transition(m.exit().selectAll("line.nv-dist"+s),"dist exit").attr(s+"1",function(t,e){return c(l(t,e))}).attr(s+"2",function(t,e){return c(l(t,e))}).style("stroke-opacity",0).remove(),y.attr("class",function(t,e){return"nv-dist"+s+" nv-dist"+s+"-"+e}).attr(f+"1",0).attr(f+"2",a),p.transition(y,"dist").attr(s+"1",function(t,e){return c(l(t,e))}).attr(s+"2",function(t,e){return c(l(t,e))}),e=c.copy()}),p.renderEnd("distribution immediate"),t}var e,n={top:0,right:0,bottom:0,left:0},i=400,a=8,s="x",l=function(t){return t[s]},u=o.utils.defaultColor(),c=r.scale.linear(),f=250,d=r.dispatch("renderEnd"),p=o.utils.renderWatch(d,f);return t.options=o.utils.optionsFunc.bind(t),t.dispatch=d,t.margin=function(e){return arguments.length?(n.top="undefined"!=typeof e.top?e.top:n.top,n.right="undefined"!=typeof e.right?e.right:n.right,n.bottom="undefined"!=typeof e.bottom?e.bottom:n.bottom,n.left="undefined"!=typeof e.left?e.left:n.left,t):n},t.width=function(e){return arguments.length?(i=e,t):i},t.axis=function(e){return arguments.length?(s=e,t):s},t.size=function(e){return arguments.length?(a=e,t):a},t.getData=function(e){return arguments.length?(l=r.functor(e),t):l},t.scale=function(e){return arguments.length?(c=e,t):c},t.color=function(e){return arguments.length?(u=o.utils.getColor(e),t):u},t.duration=function(e){return arguments.length?(f=e,p.reset(f),t):f},t},o.models.focus=function(t){"use strict";function e(_){return x.reset(),x.models(t),p&&x.models(a),h&&x.models(s),_.each(function(x){function _(t){var e=+("e"==t),n=e?1:-1,r=E/3;return"M"+.5*n+","+r+"A6,6 0 0 "+e+" "+6.5*n+","+(r+6)+"V"+(2*r-6)+"A6,6 0 0 "+e+" "+.5*n+","+2*r+"ZM"+2.5*n+","+(r+8)+"V"+(2*r-8)+"M"+4.5*n+","+(r+8)+"V"+(2*r-8)}function w(){l.empty()||l.extent(v),A.data([l.empty()?n.domain():v]).each(function(t,e){var o=n(t[0])-n.range()[0],i=k-n(t[1]);r.select(this).select(".left").attr("width",o<0?0:o),r.select(this).select(".right").attr("x",n(t[1])).attr("width",i<0?0:i)})}function T(t){v=l.empty()?null:l.extent();var e=l.empty()?n.domain():l.extent();y.brush({extent:e,brush:l}),w(),t&&y.onBrush(e)}var C=r.select(this);o.utils.initSVG(C);var k=o.utils.availableWidth(f,C,u),E=d-u.top-u.bottom;e.update=function(){0===m?C.call(e):C.transition().duration(m).call(e)},e.container=this,n=t.xScale(),i=t.yScale();var P=C.selectAll("g.nv-focus").data([x]),S=P.enter().append("g").attr("class","nvd3 nv-focus").append("g"),M=P.select("g");P.attr("transform","translate("+u.left+","+u.top+")"),S.append("g").attr("class","nv-background").append("rect"),S.append("g").attr("class","nv-x nv-axis"),S.append("g").attr("class","nv-y nv-axis"),S.append("g").attr("class","nv-contentWrap"),S.append("g").attr("class","nv-brushBackground"),S.append("g").attr("class","nv-x nv-brush"),g&&M.select(".nv-y.nv-axis").attr("transform","translate("+k+",0)"),M.select(".nv-background rect").attr("width",k).attr("height",E),t.width(k).height(E).color(x.map(function(t,e){return t.color||c(t,e)}).filter(function(t,e){return!x[e].disabled}));var N=M.select(".nv-contentWrap").datum(x.filter(function(t){return!t.disabled}));r.transition(N).call(t),l.x(n).on("brush",function(){T(b)}),l.on("brushend",function(){b||y.onBrush(l.empty()?n.domain():l.extent())}),v&&l.extent(v);var A=M.select(".nv-brushBackground").selectAll("g").data([v||l.extent()]),O=A.enter().append("g");O.append("rect").attr("class","left").attr("x",0).attr("y",0).attr("height",E),O.append("rect").attr("class","right").attr("x",0).attr("y",0).attr("height",E);var D=M.select(".nv-x.nv-brush").call(l);D.selectAll("rect").attr("height",E),D.selectAll(".resize").append("path").attr("d",_),T(!0),M.select(".nv-background rect").attr("width",k).attr("height",E),p&&(a.scale(n)._ticks(o.utils.calcTicksX(k/100,x)).tickSize(-E,0),M.select(".nv-x.nv-axis").attr("transform","translate(0,"+i.range()[0]+")"),r.transition(M.select(".nv-x.nv-axis")).call(a)),h&&(s.scale(i)._ticks(o.utils.calcTicksY(E/36,x)).tickSize(-k,0),r.transition(M.select(".nv-y.nv-axis")).call(s)),M.select(".nv-x.nv-axis").attr("transform","translate(0,"+i.range()[0]+")")}),x.renderEnd("focus immediate"),e}var n,i,t=t||o.models.line(),a=o.models.axis(),s=o.models.axis(),l=r.svg.brush(),u={top:10,right:0,bottom:30,left:0},c=o.utils.defaultColor(),f=null,d=70,p=!0,h=!1,g=!1,v=null,m=250,y=r.dispatch("brush","onBrush","renderEnd"),b=!0;t.interactive(!1),t.pointActive(function(t){return!1});var x=o.utils.renderWatch(y,m);return e.dispatch=y,e.content=t,e.brush=l,e.xAxis=a,e.yAxis=s,e.options=o.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return f},set:function(t){f=t}},height:{get:function(){return d},set:function(t){d=t}},showXAxis:{get:function(){return p},set:function(t){p=t}},showYAxis:{get:function(){return h},set:function(t){h=t}},brushExtent:{get:function(){return v},set:function(t){v=t}},syncBrushing:{get:function(){return b},set:function(t){b=t}},margin:{get:function(){return u},set:function(t){u.top=void 0!==t.top?t.top:u.top,u.right=void 0!==t.right?t.right:u.right,u.bottom=void 0!==t.bottom?t.bottom:u.bottom,u.left=void 0!==t.left?t.left:u.left}},duration:{get:function(){return m},set:function(e){m=e,x.reset(m),t.duration(m),a.duration(m),s.duration(m)}},color:{get:function(){return c},set:function(e){c=o.utils.getColor(e),t.color(c)}},interpolate:{get:function(){return t.interpolate()},set:function(e){t.interpolate(e)}},xTickFormat:{get:function(){return a.tickFormat()},set:function(t){a.tickFormat(t)}},yTickFormat:{get:function(){return s.tickFormat()},set:function(t){s.tickFormat(t)}},x:{get:function(){return t.x()},set:function(e){t.x(e)}},y:{get:function(){return t.y()},set:function(e){t.y(e)}},rightAlignYAxis:{get:function(){return g},set:function(t){g=t,s.orient(g?"right":"left")}}}),o.utils.inheritOptions(e,t),o.utils.initOptions(e),e},o.models.forceDirectedGraph=function(){"use strict";function t(s){return _.reset(),s.each(function(s){a=r.select(this),o.utils.initSVG(a);var c=o.utils.availableWidth(n,a,e),_=o.utils.availableHeight(i,a,e);if(a.attr("width",c).attr("height",_),!(s&&s.links&&s.nodes))return o.utils.noData(t,a),t;a.selectAll(".nv-noData").remove(),a.selectAll("*").remove();var w=new Set;s.nodes.forEach(function(t){var e=Object.keys(t);e.forEach(function(t){w.add(t)})});var T=r.layout.force().nodes(s.nodes).links(s.links).size([c,_]).linkStrength(f).friction(d).linkDistance(p).charge(h).gravity(g).theta(v).alpha(m).start(),C=a.selectAll(".link").data(s.links).enter().append("line").attr("class","nv-force-link").style("stroke-width",function(t){return Math.sqrt(t.value)}),k=a.selectAll(".node").data(s.nodes).enter().append("g").attr("class","nv-force-node").call(T.drag);k.append("circle").attr("r",y).style("fill",function(t){return l(t)}).on("mouseover",function(t){a.select(".nv-series-"+t.seriesIndex+" .nv-distx-"+t.pointIndex).attr("y1",t.py),a.select(".nv-series-"+t.seriesIndex+" .nv-disty-"+t.pointIndex).attr("x2",t.px);var e=l(t);t.series=[],w.forEach(function(n){t.series.push({color:e,key:n,value:t[n]})}),u.data(t).hidden(!1)}).on("mouseout",function(t){u.hidden(!0)}),u.headerFormatter(function(t){return"Node"}),x(C),b(k),T.on("tick",function(){C.attr("x1",function(t){return t.source.x}).attr("y1",function(t){return t.source.y}).attr("x2",function(t){return t.target.x}).attr("y2",function(t){return t.target.y}),k.attr("transform",function(t){return"translate("+t.x+", "+t.y+")"})})}),t}var e={top:2,right:0,bottom:2,left:0},n=400,i=32,a=null,s=r.dispatch("renderEnd"),l=o.utils.getColor(["#000"]),u=o.models.tooltip(),c=null,f=.1,d=.9,p=30,h=-120,g=.1,v=.8,m=.1,y=5,b=function(t){},x=function(t){},_=o.utils.renderWatch(s);return t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return n},set:function(t){n=t}},height:{get:function(){return i},set:function(t){i=t}},linkStrength:{get:function(){return f},set:function(t){f=t}},friction:{get:function(){return d},set:function(t){d=t}},linkDist:{get:function(){return p},set:function(t){p=t}},charge:{get:function(){return h},set:function(t){h=t}},gravity:{get:function(){return g},set:function(t){g=t}},theta:{get:function(){return v},set:function(t){v=t}},alpha:{get:function(){return m},set:function(t){m=t}},radius:{get:function(){return y},set:function(t){y=t}},x:{get:function(){return getX},set:function(t){getX=r.functor(t)}},y:{get:function(){return getY},set:function(t){getY=r.functor(t)}},margin:{get:function(){return e},set:function(t){e.top=void 0!==t.top?t.top:e.top,e.right=void 0!==t.right?t.right:e.right,e.bottom=void 0!==t.bottom?t.bottom:e.bottom,e.left=void 0!==t.left?t.left:e.left}},color:{get:function(){return l},set:function(t){l=o.utils.getColor(t)}},noData:{get:function(){return c},set:function(t){c=t}},nodeExtras:{get:function(){return b},set:function(t){b=t}},linkExtras:{get:function(){return x},set:function(t){x=t}}}),t.dispatch=s,t.tooltip=u,o.utils.initOptions(t),t},o.models.furiousLegend=function(){"use strict";function t(y){function b(t,e){return"furious"!=m?"#000":g?t.disengaged?l(t,e):"#fff":g?void 0:t.disabled?l(t,e):"#fff"}function x(t,e){return g&&"furious"==m?t.disengaged?"#fff":l(t,e):t.disabled?"#fff":l(t,e)}return y.each(function(t){var y=n-e.left-e.right,_=r.select(this);o.utils.initSVG(_);var w=_.selectAll("g.nv-legend").data([t]),T=(w.enter().append("g").attr("class","nvd3 nv-legend").append("g"),w.select("g"));w.attr("transform","translate("+e.left+","+e.top+")");var C,k=T.selectAll(".nv-series").data(function(t){return"furious"!=m?t:t.filter(function(t){return!!g||!t.disengaged})}),E=k.enter().append("g").attr("class","nv-series");if("classic"==m)E.append("circle").style("stroke-width",2).attr("class","nv-legend-symbol").attr("r",5),C=k.select("circle");else if("furious"==m){E.append("rect").style("stroke-width",2).attr("class","nv-legend-symbol").attr("rx",3).attr("ry",3),C=k.select("rect"),E.append("g").attr("class","nv-check-box").property("innerHTML",'<path d="M0.5,5 L22.5,5 L22.5,26.5 L0.5,26.5 L0.5,5 Z" class="nv-box"></path><path d="M5.5,12.8618467 L11.9185089,19.2803556 L31,0.198864511" class="nv-check"></path>').attr("transform","translate(-10,-8)scale(0.5)");var P=k.select(".nv-check-box");P.each(function(t,e){r.select(this).selectAll("path").attr("stroke",b(t,e))})}E.append("text").attr("text-anchor","start").attr("class","nv-legend-text").attr("dy",".32em").attr("dx","8");var S=k.select("text.nv-legend-text");k.on("mouseover",function(t,e){v.legendMouseover(t,e)}).on("mouseout",function(t,e){v.legendMouseout(t,e)}).on("click",function(t,e){v.legendClick(t,e);var n=k.data();if(p){if("classic"==m)h?(n.forEach(function(t){t.disabled=!0}),t.disabled=!1):(t.disabled=!t.disabled,n.every(function(t){return t.disabled})&&n.forEach(function(t){t.disabled=!1}));else if("furious"==m)if(g)t.disengaged=!t.disengaged,t.userDisabled=void 0==t.userDisabled?!!t.disabled:t.userDisabled,t.disabled=t.disengaged||t.userDisabled;else if(!g){t.disabled=!t.disabled,t.userDisabled=t.disabled;var r=n.filter(function(t){return!t.disengaged});r.every(function(t){return t.userDisabled})&&n.forEach(function(t){t.disabled=t.userDisabled=!1})}v.stateChange({disabled:n.map(function(t){return!!t.disabled}),disengaged:n.map(function(t){return!!t.disengaged})})}}).on("dblclick",function(t,e){if(("furious"!=m||!g)&&(v.legendDblclick(t,e),p)){var n=k.data();n.forEach(function(t){t.disabled=!0,"furious"==m&&(t.userDisabled=t.disabled)}),t.disabled=!1,"furious"==m&&(t.userDisabled=t.disabled),v.stateChange({disabled:n.map(function(t){return!!t.disabled})})}}),k.classed("nv-disabled",function(t){return t.userDisabled}),k.exit().remove(),S.attr("fill",b).text(function(t){return s(a(t))});var M;switch(m){case"furious":M=23;break;case"classic":M=20}if(c){var N=[];k.each(function(t,e){var n;if(s(a(t))&&s(a(t)).length>u){var i=s(a(t)).substring(0,u);n=r.select(this).select("text").text(i+"..."),r.select(this).append("svg:title").text(s(a(t)))}else n=r.select(this).select("text");var l;try{if(l=n.node().getComputedTextLength(),l<=0)throw Error()}catch(t){l=o.utils.calcApproxTextWidth(n)}N.push(l+f)});for(var A=0,O=0,D=[];O<y&&A<N.length;)D[A]=N[A],O+=N[A++];for(0===A&&(A=1);O>y&&A>1;){D=[],A--;for(var I=0;I<N.length;I++)N[I]>(D[I%A]||0)&&(D[I%A]=N[I]);O=D.reduce(function(t,e,n,r){return t+e})}for(var R=[],L=0,F=0;L<A;L++)R[L]=F,F+=D[L];k.attr("transform",function(t,e){return"translate("+R[e%A]+","+(5+Math.floor(e/A)*M)+")"}),d?T.attr("transform","translate("+(n-e.right-O)+","+e.top+")"):T.attr("transform","translate(0,"+e.top+")"),i=e.top+e.bottom+Math.ceil(N.length/A)*M}else{var j,B=5,U=5,H=0;k.attr("transform",function(t,o){var i=r.select(this).select("text").node().getComputedTextLength()+f;return j=U,n<e.left+e.right+j+i&&(U=j=5,B+=M),U+=i,U>H&&(H=U),"translate("+j+","+B+")"}),T.attr("transform","translate("+(n-e.right-H)+","+e.top+")"),i=e.top+e.bottom+B+15}"furious"==m&&C.attr("width",function(t,e){return S[0][e].getComputedTextLength()+27}).attr("height",18).attr("y",-9).attr("x",-15),C.style("fill",x).style("stroke",function(t,e){return t.color||l(t,e)})}),t}var e={top:5,right:0,bottom:5,left:0},n=400,i=20,a=function(t){return t.key},s=function(t){return t},l=o.utils.getColor(),u=20,c=!0,f=28,d=!0,p=!0,h=!1,g=!1,v=r.dispatch("legendClick","legendDblclick","legendMouseover","legendMouseout","stateChange"),m="classic";return t.dispatch=v,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return n},set:function(t){n=t}},height:{get:function(){return i},set:function(t){i=t}},key:{get:function(){return a},set:function(t){a=t}},keyFormatter:{get:function(){return s},set:function(t){s=t}},align:{get:function(){return c},set:function(t){c=t}},rightAlign:{get:function(){return d},set:function(t){d=t}},maxKeyLength:{get:function(){return u},set:function(t){u=t}},padding:{get:function(){return f},set:function(t){f=t}},updateState:{get:function(){return p},set:function(t){p=t}},radioButtonMode:{get:function(){return h},set:function(t){h=t}},expanded:{get:function(){return g},set:function(t){g=t}},vers:{get:function(){return m},set:function(t){m=t}},margin:{get:function(){return e},set:function(t){e.top=void 0!==t.top?t.top:e.top,e.right=void 0!==t.right?t.right:e.right,e.bottom=void 0!==t.bottom?t.bottom:e.bottom,e.left=void 0!==t.left?t.left:e.left}},color:{get:function(){return l},set:function(t){l=o.utils.getColor(t)}}}),o.utils.initOptions(t),t},o.models.historicalBar=function(){"use strict";function t(C){return C.each(function(t){T.reset(),f=r.select(this);var C=o.utils.availableWidth(l,f,s),k=o.utils.availableHeight(u,f,s);o.utils.initSVG(f),d.domain(e||r.extent(t[0].values.map(h).concat(v))),y?d.range(i||[.5*C/t[0].values.length,C*(t[0].values.length-.5)/t[0].values.length]):d.range(i||[0,C]),p.domain(n||r.extent(t[0].values.map(g).concat(m))).range(a||[k,0]),d.domain()[0]===d.domain()[1]&&(d.domain()[0]?d.domain([d.domain()[0]-.01*d.domain()[0],d.domain()[1]+.01*d.domain()[1]]):d.domain([-1,1])),p.domain()[0]===p.domain()[1]&&(p.domain()[0]?p.domain([p.domain()[0]+.01*p.domain()[0],p.domain()[1]-.01*p.domain()[1]]):p.domain([-1,1]));var E=f.selectAll("g.nv-wrap.nv-historicalBar-"+c).data([t[0].values]),P=E.enter().append("g").attr("class","nvd3 nv-wrap nv-historicalBar-"+c),S=P.append("defs"),M=P.append("g"),N=E.select("g");M.append("g").attr("class","nv-bars"),E.attr("transform","translate("+s.left+","+s.top+")"),f.on("click",function(t,e){_.chartClick({data:t,index:e,pos:r.event,id:c})}),S.append("clipPath").attr("id","nv-chart-clip-path-"+c).append("rect"),E.select("#nv-chart-clip-path-"+c+" rect").attr("width",C).attr("height",k),N.attr("clip-path",b?"url(#nv-chart-clip-path-"+c+")":"");var A=E.select(".nv-bars").selectAll(".nv-bar").data(function(t){return t},function(t,e){return h(t,e)});A.exit().remove(),A.enter().append("rect").attr("x",0).attr("y",function(t,e){return o.utils.NaNtoZero(p(Math.max(0,g(t,e))))}).attr("height",function(t,e){return o.utils.NaNtoZero(Math.abs(p(g(t,e))-p(0)))}).attr("transform",function(e,n){return"translate("+(d(h(e,n))-C/t[0].values.length*.45)+",0)"}).on("mouseover",function(t,e){w&&(r.select(this).classed("hover",!0),_.elementMouseover({data:t,index:e,color:r.select(this).style("fill")}))}).on("mouseout",function(t,e){w&&(r.select(this).classed("hover",!1),_.elementMouseout({data:t,index:e,color:r.select(this).style("fill")}))}).on("mousemove",function(t,e){w&&_.elementMousemove({data:t,index:e,color:r.select(this).style("fill")})}).on("click",function(t,e){if(w){var n=this;_.elementClick({data:t,index:e,color:r.select(this).style("fill"),event:r.event,element:n}),r.event.stopPropagation()}}).on("dblclick",function(t,e){w&&(_.elementDblClick({data:t,index:e,color:r.select(this).style("fill")}),r.event.stopPropagation())}),A.attr("fill",function(t,e){return x(t,e)}).attr("class",function(t,e,n){return(g(t,e)<0?"nv-bar negative":"nv-bar positive")+" nv-bar-"+n+"-"+e}).watchTransition(T,"bars").attr("transform",function(e,n){return"translate("+(d(h(e,n))-C/t[0].values.length*.45)+",0)"}).attr("width",C/t[0].values.length*.9),A.watchTransition(T,"bars").attr("y",function(t,e){var n=g(t,e)<0?p(0):p(0)-p(g(t,e))<1?p(0)-1:p(g(t,e));return o.utils.NaNtoZero(n)}).attr("height",function(t,e){return o.utils.NaNtoZero(Math.max(Math.abs(p(g(t,e))-p(0)),1))})}),T.renderEnd("historicalBar immediate"),t}var e,n,i,a,s={top:0,right:0,bottom:0,
left:0},l=null,u=null,c=Math.floor(1e4*Math.random()),f=null,d=r.scale.linear(),p=r.scale.linear(),h=function(t){return t.x},g=function(t){return t.y},v=[],m=[0],y=!1,b=!0,x=o.utils.defaultColor(),_=r.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),w=!0,T=o.utils.renderWatch(_,0);return t.highlightPoint=function(t,e){f.select(".nv-bars .nv-bar-0-"+t).classed("hover",e)},t.clearHighlights=function(){f.select(".nv-bars .nv-bar.hover").classed("hover",!1)},t.dispatch=_,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return l},set:function(t){l=t}},height:{get:function(){return u},set:function(t){u=t}},forceX:{get:function(){return v},set:function(t){v=t}},forceY:{get:function(){return m},set:function(t){m=t}},padData:{get:function(){return y},set:function(t){y=t}},x:{get:function(){return h},set:function(t){h=t}},y:{get:function(){return g},set:function(t){g=t}},xScale:{get:function(){return d},set:function(t){d=t}},yScale:{get:function(){return p},set:function(t){p=t}},xDomain:{get:function(){return e},set:function(t){e=t}},yDomain:{get:function(){return n},set:function(t){n=t}},xRange:{get:function(){return i},set:function(t){i=t}},yRange:{get:function(){return a},set:function(t){a=t}},clipEdge:{get:function(){return b},set:function(t){b=t}},id:{get:function(){return c},set:function(t){c=t}},interactive:{get:function(){return w},set:function(t){w=t}},margin:{get:function(){return s},set:function(t){s.top=void 0!==t.top?t.top:s.top,s.right=void 0!==t.right?t.right:s.right,s.bottom=void 0!==t.bottom?t.bottom:s.bottom,s.left=void 0!==t.left?t.left:s.left}},color:{get:function(){return x},set:function(t){x=o.utils.getColor(t)}}}),o.utils.initOptions(t),t},o.models.historicalBarChart=function(t){"use strict";function e(t){return t.each(function(f){P.reset(),P.models(a),y&&P.models(s),b&&P.models(l);var C=r.select(this);o.utils.initSVG(C);var S=o.utils.availableWidth(g,C,d),M=o.utils.availableHeight(v,C,d);if(e.update=function(){C.transition().duration(E).call(e)},e.container=this,w.disabled=f.map(function(t){return!!t.disabled}),!T){var N;T={};for(N in w)w[N]instanceof Array?T[N]=w[N].slice(0):T[N]=w[N]}if(!(f&&f.length&&f.filter(function(t){return t.values.length}).length))return o.utils.noData(e,C),e;C.selectAll(".nv-noData").remove(),n=a.xScale(),i=a.yScale();var A=C.selectAll("g.nv-wrap.nv-historicalBarChart").data([f]),O=A.enter().append("g").attr("class","nvd3 nv-wrap nv-historicalBarChart").append("g"),D=A.select("g");O.append("g").attr("class","nv-x nv-axis"),O.append("g").attr("class","nv-y nv-axis"),O.append("g").attr("class","nv-barsWrap"),O.append("g").attr("class","nv-legendWrap"),O.append("g").attr("class","nv-interactive"),m?(u.width(S),D.select(".nv-legendWrap").datum(f).call(u),p||u.height()===d.top||(d.top=u.height(),M=o.utils.availableHeight(v,C,d)),A.select(".nv-legendWrap").attr("transform","translate(0,"+-d.top+")")):D.select(".nv-legendWrap").selectAll("*").remove(),A.attr("transform","translate("+d.left+","+d.top+")"),x&&D.select(".nv-y.nv-axis").attr("transform","translate("+S+",0)"),_&&(c.width(S).height(M).margin({left:d.left,top:d.top}).svgContainer(C).xScale(n),A.select(".nv-interactive").call(c)),a.width(S).height(M).color(f.map(function(t,e){return t.color||h(t,e)}).filter(function(t,e){return!f[e].disabled}));var I=D.select(".nv-barsWrap").datum(f.filter(function(t){return!t.disabled}));I.transition().call(a),y&&(s.scale(n)._ticks(o.utils.calcTicksX(S/100,f)).tickSize(-M,0),D.select(".nv-x.nv-axis").attr("transform","translate(0,"+i.range()[0]+")"),D.select(".nv-x.nv-axis").transition().call(s)),b&&(l.scale(i)._ticks(o.utils.calcTicksY(M/36,f)).tickSize(-S,0),D.select(".nv-y.nv-axis").transition().call(l)),c.dispatch.on("elementMousemove",function(t){a.clearHighlights();var n,r,i,u=[];f.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(s,l){r=o.interactiveBisect(s.values,t.pointXValue,e.x()),a.highlightPoint(r,!0);var c=s.values[r];void 0!==c&&(void 0===n&&(n=c),void 0===i&&(i=e.xScale()(e.x()(c,r))),u.push({key:s.key,value:e.y()(c,r),color:h(s,s.seriesIndex),data:s.values[r]}))});var d=s.tickFormat()(e.x()(n,r));c.tooltip.valueFormatter(function(t,e){return l.tickFormat()(t)}).data({value:d,index:r,series:u})(),c.renderGuideLine(i)}),c.dispatch.on("elementMouseout",function(t){k.tooltipHide(),a.clearHighlights()}),u.dispatch.on("legendClick",function(n,r){n.disabled=!n.disabled,f.filter(function(t){return!t.disabled}).length||f.map(function(t){return t.disabled=!1,A.selectAll(".nv-series").classed("disabled",!1),t}),w.disabled=f.map(function(t){return!!t.disabled}),k.stateChange(w),t.transition().call(e)}),u.dispatch.on("legendDblclick",function(t){f.forEach(function(t){t.disabled=!0}),t.disabled=!1,w.disabled=f.map(function(t){return!!t.disabled}),k.stateChange(w),e.update()}),k.on("changeState",function(t){"undefined"!=typeof t.disabled&&(f.forEach(function(e,n){e.disabled=t.disabled[n]}),w.disabled=t.disabled),e.update()})}),P.renderEnd("historicalBarChart immediate"),e}var n,i,a=t||o.models.historicalBar(),s=o.models.axis(),l=o.models.axis(),u=o.models.legend(),c=o.interactiveGuideline(),f=o.models.tooltip(),d={top:30,right:90,bottom:50,left:90},p=null,h=o.utils.defaultColor(),g=null,v=null,m=!1,y=!0,b=!0,x=!1,_=!1,w={},T=null,C=null,k=r.dispatch("tooltipHide","stateChange","changeState","renderEnd"),E=250;s.orient("bottom").tickPadding(7),l.orient(x?"right":"left"),f.duration(0).headerEnabled(!1).valueFormatter(function(t,e){return l.tickFormat()(t,e)}).headerFormatter(function(t,e){return s.tickFormat()(t,e)});var P=o.utils.renderWatch(k,0);return a.dispatch.on("elementMouseover.tooltip",function(t){t.series={key:e.x()(t.data),value:e.y()(t.data),color:t.color},f.data(t).hidden(!1)}),a.dispatch.on("elementMouseout.tooltip",function(t){f.hidden(!0)}),a.dispatch.on("elementMousemove.tooltip",function(t){f()}),e.dispatch=k,e.bars=a,e.legend=u,e.xAxis=s,e.yAxis=l,e.interactiveLayer=c,e.tooltip=f,e.options=o.utils.optionsFunc.bind(e),e._options=Object.create({},{width:{get:function(){return g},set:function(t){g=t}},height:{get:function(){return v},set:function(t){v=t}},showLegend:{get:function(){return m},set:function(t){m=t}},showXAxis:{get:function(){return y},set:function(t){y=t}},showYAxis:{get:function(){return b},set:function(t){b=t}},defaultState:{get:function(){return T},set:function(t){T=t}},noData:{get:function(){return C},set:function(t){C=t}},margin:{get:function(){return d},set:function(t){void 0!==t.top&&(d.top=t.top,p=t.top),d.right=void 0!==t.right?t.right:d.right,d.bottom=void 0!==t.bottom?t.bottom:d.bottom,d.left=void 0!==t.left?t.left:d.left}},color:{get:function(){return h},set:function(t){h=o.utils.getColor(t),u.color(h),a.color(h)}},duration:{get:function(){return E},set:function(t){E=t,P.reset(E),l.duration(E),s.duration(E)}},rightAlignYAxis:{get:function(){return x},set:function(t){x=t,l.orient(t?"right":"left")}},useInteractiveGuideline:{get:function(){return _},set:function(t){_=t,t===!0&&e.interactive(!1)}}}),o.utils.inheritOptions(e,a),o.utils.initOptions(e),e},o.models.ohlcBarChart=function(){var t=o.models.historicalBarChart(o.models.ohlcBar());return t.useInteractiveGuideline(!0),t.interactiveLayer.tooltip.contentGenerator(function(e){var n=e.series[0].data,r=n.open<n.close?"2ca02c":"d62728";return'<h3 style="color: #'+r+'">'+e.value+"</h3><table><tr><td>open:</td><td>"+t.yAxis.tickFormat()(n.open)+"</td></tr><tr><td>close:</td><td>"+t.yAxis.tickFormat()(n.close)+"</td></tr><tr><td>high</td><td>"+t.yAxis.tickFormat()(n.high)+"</td></tr><tr><td>low:</td><td>"+t.yAxis.tickFormat()(n.low)+"</td></tr></table>"}),t},o.models.candlestickBarChart=function(){var t=o.models.historicalBarChart(o.models.candlestickBar());return t.useInteractiveGuideline(!0),t.interactiveLayer.tooltip.contentGenerator(function(e){var n=e.series[0].data,r=n.open<n.close?"2ca02c":"d62728";return'<h3 style="color: #'+r+'">'+e.value+"</h3><table><tr><td>open:</td><td>"+t.yAxis.tickFormat()(n.open)+"</td></tr><tr><td>close:</td><td>"+t.yAxis.tickFormat()(n.close)+"</td></tr><tr><td>high</td><td>"+t.yAxis.tickFormat()(n.high)+"</td></tr><tr><td>low:</td><td>"+t.yAxis.tickFormat()(n.low)+"</td></tr></table>"}),t},o.models.legend=function(){"use strict";function t(y){function b(t,e){return"furious"!=m?"#000":g?t.disengaged?"#000":"#fff":g?void 0:(t.color||(t.color=l(t,e)),t.disabled?t.color:"#fff")}function x(t,e){return g&&"furious"==m&&t.disengaged?"#eee":t.color||l(t,e)}function _(t,e){return g&&"furious"==m?1:t.disabled?0:1}return y.each(function(t){var l=n-e.left-e.right,y=r.select(this);o.utils.initSVG(y);var w=y.selectAll("g.nv-legend").data([t]),T=w.enter().append("g").attr("class","nvd3 nv-legend").append("g"),C=w.select("g");d?w.attr("transform","translate("+-e.right+","+e.top+")"):w.attr("transform","translate("+e.left+","+e.top+")");var k,E,P=C.selectAll(".nv-series").data(function(t){return"furious"!=m?t:t.filter(function(t){return!!g||!t.disengaged})}),S=P.enter().append("g").attr("class","nv-series");switch(m){case"furious":E=23;break;case"classic":E=20}if("classic"==m)S.append("circle").style("stroke-width",2).attr("class","nv-legend-symbol").attr("r",5),k=P.select(".nv-legend-symbol");else if("furious"==m){S.append("rect").style("stroke-width",2).attr("class","nv-legend-symbol").attr("rx",3).attr("ry",3),k=P.select(".nv-legend-symbol"),S.append("g").attr("class","nv-check-box").property("innerHTML",'<path d="M0.5,5 L22.5,5 L22.5,26.5 L0.5,26.5 L0.5,5 Z" class="nv-box"></path><path d="M5.5,12.8618467 L11.9185089,19.2803556 L31,0.198864511" class="nv-check"></path>').attr("transform","translate(-10,-8)scale(0.5)");var M=P.select(".nv-check-box");M.each(function(t,e){r.select(this).selectAll("path").attr("stroke",b(t,e))})}S.append("text").attr("text-anchor","start").attr("class","nv-legend-text").attr("dy",".32em").attr("dx","8");var N=P.select("text.nv-legend-text");P.on("mouseover",function(t,e){v.legendMouseover(t,e)}).on("mouseout",function(t,e){v.legendMouseout(t,e)}).on("click",function(t,e){v.legendClick(t,e);var n=P.data();if(p){if("classic"==m)h?(n.forEach(function(t){t.disabled=!0}),t.disabled=!1):(t.disabled=!t.disabled,n.every(function(t){return t.disabled})&&n.forEach(function(t){t.disabled=!1}));else if("furious"==m)if(g)t.disengaged=!t.disengaged,t.userDisabled=void 0==t.userDisabled?!!t.disabled:t.userDisabled,t.disabled=t.disengaged||t.userDisabled;else if(!g){t.disabled=!t.disabled,t.userDisabled=t.disabled;var r=n.filter(function(t){return!t.disengaged});r.every(function(t){return t.userDisabled})&&n.forEach(function(t){t.disabled=t.userDisabled=!1})}v.stateChange({disabled:n.map(function(t){return!!t.disabled}),disengaged:n.map(function(t){return!!t.disengaged})})}}).on("dblclick",function(t,e){if(("furious"!=m||!g)&&(v.legendDblclick(t,e),p)){var n=P.data();n.forEach(function(t){t.disabled=!0,"furious"==m&&(t.userDisabled=t.disabled)}),t.disabled=!1,"furious"==m&&(t.userDisabled=t.disabled),v.stateChange({disabled:n.map(function(t){return!!t.disabled})})}}),P.classed("nv-disabled",function(t){return t.userDisabled}),P.exit().remove(),N.attr("fill",b).text(function(t){return s(a(t))});var A=0;if(c){var O=[];P.each(function(t,e){var n;if(s(a(t))&&s(a(t)).length>u){var i=s(a(t)).substring(0,u);n=r.select(this).select("text").text(i+"..."),r.select(this).append("svg:title").text(s(a(t)))}else n=r.select(this).select("text");var l;try{if(l=n.node().getComputedTextLength(),l<=0)throw Error()}catch(t){l=o.utils.calcApproxTextWidth(n)}O.push(l+f)});var D=0,I=[];for(A=0;A<l&&D<O.length;)I[D]=O[D],A+=O[D++];for(0===D&&(D=1);A>l&&D>1;){I=[],D--;for(var R=0;R<O.length;R++)O[R]>(I[R%D]||0)&&(I[R%D]=O[R]);A=I.reduce(function(t,e,n,r){return t+e})}for(var L=[],F=0,j=0;F<D;F++)L[F]=j,j+=I[F];P.attr("transform",function(t,e){return"translate("+L[e%D]+","+(5+Math.floor(e/D)*E)+")"}),d?C.attr("transform","translate("+(n-e.right-A)+","+e.top+")"):C.attr("transform","translate(0,"+e.top+")"),i=e.top+e.bottom+Math.ceil(O.length/D)*E}else{var B,U=5,H=5,z=0;P.attr("transform",function(t,o){var i=r.select(this).select("text").node().getComputedTextLength()+f;return B=H,n<e.left+e.right+B+i&&(H=B=5,U+=E),H+=i,H>z&&(z=H),A<B+z&&(A=B+z),"translate("+B+","+U+")"}),C.attr("transform","translate("+(n-e.right-z)+","+e.top+")"),i=e.top+e.bottom+U+15}if("furious"==m){k.attr("width",function(t,e){return N[0][e].getComputedTextLength()+27}).attr("height",18).attr("y",-9).attr("x",-15),T.insert("rect",":first-child").attr("class","nv-legend-bg").attr("fill","#eee").attr("opacity",0);var W=C.select(".nv-legend-bg");W.transition().duration(300).attr("x",-E).attr("width",A+E-12).attr("height",i+10).attr("y",-e.top-10).attr("opacity",g?1:0)}k.style("fill",x).style("fill-opacity",_).style("stroke",x)}),t}var e={top:5,right:0,bottom:5,left:0},n=400,i=20,a=function(t){return t.key},s=function(t){return t},l=o.utils.getColor(),u=20,c=!0,f=32,d=!0,p=!0,h=!1,g=!1,v=r.dispatch("legendClick","legendDblclick","legendMouseover","legendMouseout","stateChange"),m="classic";return t.dispatch=v,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return n},set:function(t){n=t}},height:{get:function(){return i},set:function(t){i=t}},key:{get:function(){return a},set:function(t){a=t}},keyFormatter:{get:function(){return s},set:function(t){s=t}},align:{get:function(){return c},set:function(t){c=t}},maxKeyLength:{get:function(){return u},set:function(t){u=t}},rightAlign:{get:function(){return d},set:function(t){d=t}},padding:{get:function(){return f},set:function(t){f=t}},updateState:{get:function(){return p},set:function(t){p=t}},radioButtonMode:{get:function(){return h},set:function(t){h=t}},expanded:{get:function(){return g},set:function(t){g=t}},vers:{get:function(){return m},set:function(t){m=t}},margin:{get:function(){return e},set:function(t){e.top=void 0!==t.top?t.top:e.top,e.right=void 0!==t.right?t.right:e.right,e.bottom=void 0!==t.bottom?t.bottom:e.bottom,e.left=void 0!==t.left?t.left:e.left}},color:{get:function(){return l},set:function(t){l=o.utils.getColor(t)}}}),o.utils.initOptions(t),t},o.models.line=function(){"use strict";function t(y){return w.reset(),w.models(i),y.each(function(t){u=r.select(this);var y=o.utils.availableWidth(s,u,a),b=o.utils.availableHeight(l,u,a);o.utils.initSVG(u),e=i.xScale(),n=i.yScale(),x=x||e,_=_||n;var T=u.selectAll("g.nv-wrap.nv-line").data([t]),C=T.enter().append("g").attr("class","nvd3 nv-wrap nv-line"),k=C.append("defs"),E=C.append("g"),P=T.select("g");E.append("g").attr("class","nv-groups"),E.append("g").attr("class","nv-scatterWrap"),T.attr("transform","translate("+a.left+","+a.top+")"),i.width(y).height(b);var S=T.select(".nv-scatterWrap");S.call(i),k.append("clipPath").attr("id","nv-edge-clip-"+i.id()).append("rect"),T.select("#nv-edge-clip-"+i.id()+" rect").attr("width",y).attr("height",b>0?b:0),P.attr("clip-path",v?"url(#nv-edge-clip-"+i.id()+")":""),S.attr("clip-path",v?"url(#nv-edge-clip-"+i.id()+")":"");var M=T.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t){return t.key});M.enter().append("g").style("stroke-opacity",1e-6).style("stroke-width",function(t){return t.strokeWidth||c}).style("fill-opacity",1e-6),M.exit().remove(),M.attr("class",function(t,e){return(t.classed||"")+" nv-group nv-series-"+e}).classed("hover",function(t){return t.hover}).style("fill",function(t,e){return f(t,e)}).style("stroke",function(t,e){return f(t,e)}),M.watchTransition(w,"line: groups").style("stroke-opacity",1).style("fill-opacity",function(t){return t.fillOpacity||.5});var N=M.selectAll("path.nv-area").data(function(t){return g(t)?[t]:[]});N.enter().append("path").attr("class","nv-area").attr("d",function(t){return r.svg.area().interpolate(m).defined(h).x(function(t,e){return o.utils.NaNtoZero(x(d(t,e)))}).y0(function(t,e){return o.utils.NaNtoZero(_(p(t,e)))}).y1(function(t,e){return _(n.domain()[0]<=0?n.domain()[1]>=0?0:n.domain()[1]:n.domain()[0])}).apply(this,[t.values])}),M.exit().selectAll("path.nv-area").remove(),N.watchTransition(w,"line: areaPaths").attr("d",function(t){return r.svg.area().interpolate(m).defined(h).x(function(t,n){return o.utils.NaNtoZero(e(d(t,n)))}).y0(function(t,e){return o.utils.NaNtoZero(n(p(t,e)))}).y1(function(t,e){return n(n.domain()[0]<=0?n.domain()[1]>=0?0:n.domain()[1]:n.domain()[0])}).apply(this,[t.values])});var A=M.selectAll("path.nv-line").data(function(t){return[t.values]});A.enter().append("path").attr("class","nv-line").attr("d",r.svg.line().interpolate(m).defined(h).x(function(t,e){return o.utils.NaNtoZero(x(d(t,e)))}).y(function(t,e){return o.utils.NaNtoZero(_(p(t,e)))})),A.watchTransition(w,"line: linePaths").attr("d",r.svg.line().interpolate(m).defined(h).x(function(t,n){return o.utils.NaNtoZero(e(d(t,n)))}).y(function(t,e){return o.utils.NaNtoZero(n(p(t,e)))})),x=e.copy(),_=n.copy()}),w.renderEnd("line immediate"),t}var e,n,i=o.models.scatter(),a={top:0,right:0,bottom:0,left:0},s=960,l=500,u=null,c=1.5,f=o.utils.defaultColor(),d=function(t){return t.x},p=function(t){return t.y},h=function(t,e){return!isNaN(p(t,e))&&null!==p(t,e)},g=function(t){return t.area},v=!1,m="linear",y=250,b=r.dispatch("elementClick","elementMouseover","elementMouseout","renderEnd");i.pointSize(16).pointDomain([16,256]);var x,_,w=o.utils.renderWatch(b,y);return t.dispatch=b,t.scatter=i,i.dispatch.on("elementClick",function(){b.elementClick.apply(this,arguments)}),i.dispatch.on("elementMouseover",function(){b.elementMouseover.apply(this,arguments)}),i.dispatch.on("elementMouseout",function(){b.elementMouseout.apply(this,arguments)}),t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return s},set:function(t){s=t}},height:{get:function(){return l},set:function(t){l=t}},defined:{get:function(){return h},set:function(t){h=t}},interpolate:{get:function(){return m},set:function(t){m=t}},clipEdge:{get:function(){return v},set:function(t){v=t}},margin:{get:function(){return a},set:function(t){a.top=void 0!==t.top?t.top:a.top,a.right=void 0!==t.right?t.right:a.right,a.bottom=void 0!==t.bottom?t.bottom:a.bottom,a.left=void 0!==t.left?t.left:a.left}},duration:{get:function(){return y},set:function(t){y=t,w.reset(y),i.duration(y)}},isArea:{get:function(){return g},set:function(t){g=r.functor(t)}},x:{get:function(){return d},set:function(t){d=t,i.x(t)}},y:{get:function(){return p},set:function(t){p=t,i.y(t)}},color:{get:function(){return f},set:function(t){f=o.utils.getColor(t),i.color(f)}}}),o.utils.inheritOptions(t,i),o.utils.initOptions(t),t},o.models.lineChart=function(){"use strict";function t(c){return M.reset(),M.models(i),b&&M.models(a),x&&M.models(s),c.each(function(c){function E(){b&&B.select(".nv-focus .nv-x.nv-axis").transition().duration(S).call(a)}function M(){x&&B.select(".nv-focus .nv-y.nv-axis").transition().duration(S).call(s)}function O(t){var e=B.select(".nv-focus .nv-linesWrap").datum(c.filter(function(t){return!t.disabled}).map(function(e,n){return{key:e.key,area:e.area,classed:e.classed,values:e.values.filter(function(e,n){return i.x()(e,n)>=t[0]&&i.x()(e,n)<=t[1]}),disableTooltip:e.disableTooltip}}));e.transition().duration(S).call(i),E(),M()}var D=r.select(this);o.utils.initSVG(D);var I=o.utils.availableWidth(g,D,d),R=o.utils.availableHeight(v,D,d)-(T?f.height():0);if(t.update=function(){0===S?D.call(t):D.transition().duration(S).call(t)},t.container=this,C.setter(A(c),t.update).getter(N(c)).update(),C.disabled=c.map(function(t){return!!t.disabled}),!k){var L;k={};for(L in C)C[L]instanceof Array?k[L]=C[L].slice(0):k[L]=C[L]}if(!(c&&c.length&&c.filter(function(t){return t.values.length}).length))return o.utils.noData(t,D),t;D.selectAll(".nv-noData").remove(),f.dispatch.on("onBrush",function(t){O(t)}),e=i.xScale(),n=i.yScale();var F=D.selectAll("g.nv-wrap.nv-lineChart").data([c]),j=F.enter().append("g").attr("class","nvd3 nv-wrap nv-lineChart").append("g"),B=F.select("g");j.append("g").attr("class","nv-legendWrap");var U=j.append("g").attr("class","nv-focus");U.append("g").attr("class","nv-background").append("rect"),U.append("g").attr("class","nv-x nv-axis"),U.append("g").attr("class","nv-y nv-axis"),U.append("g").attr("class","nv-linesWrap"),U.append("g").attr("class","nv-interactive");j.append("g").attr("class","nv-focusWrap");m?(l.width(I),B.select(".nv-legendWrap").datum(c).call(l),"bottom"===y?F.select(".nv-legendWrap").attr("transform","translate(0,"+R+")"):"top"===y&&(p||l.height()===d.top||(d.top=l.height(),R=o.utils.availableHeight(v,D,d)-(T?f.height():0)),F.select(".nv-legendWrap").attr("transform","translate(0,"+-d.top+")"))):B.select(".nv-legendWrap").selectAll("*").remove(),F.attr("transform","translate("+d.left+","+d.top+")"),_&&B.select(".nv-y.nv-axis").attr("transform","translate("+I+",0)"),w&&(u.width(I).height(R).margin({left:d.left,top:d.top}).svgContainer(D).xScale(e),F.select(".nv-interactive").call(u)),B.select(".nv-focus .nv-background rect").attr("width",I).attr("height",R),i.width(I).height(R).color(c.map(function(t,e){return t.color||h(t,e)}).filter(function(t,e){return!c[e].disabled}));var H=B.select(".nv-linesWrap").datum(c.filter(function(t){return!t.disabled}));if(b&&a.scale(e)._ticks(o.utils.calcTicksX(I/100,c)).tickSize(-R,0),x&&s.scale(n)._ticks(o.utils.calcTicksY(R/36,c)).tickSize(-I,0),B.select(".nv-focus .nv-x.nv-axis").attr("transform","translate(0,"+R+")"),T){f.width(I),B.select(".nv-focusWrap").attr("transform","translate(0,"+(R+d.bottom+f.margin().top)+")").datum(c.filter(function(t){return!t.disabled})).call(f);var z=f.brush.empty()?f.xDomain():f.brush.extent();null!==z&&O(z)}else H.call(i),E(),M();l.dispatch.on("stateChange",function(e){for(var n in e)C[n]=e[n];P.stateChange(C),t.update()}),u.dispatch.on("elementMousemove",function(n){i.clearHighlights();var r,a,l,d=[];if(c.filter(function(t,e){return t.seriesIndex=e,!t.disabled&&!t.disableTooltip}).forEach(function(s,u){var c=T?f.brush.empty()?f.xScale().domain():f.brush.extent():e.domain(),p=s.values.filter(function(t,e){return c[0]<=c[1]?i.x()(t,e)>=c[0]&&i.x()(t,e)<=c[1]:i.x()(t,e)>=c[1]&&i.x()(t,e)<=c[0]});a=o.interactiveBisect(p,n.pointXValue,i.x());var g=p[a],v=t.y()(g,a);null!==v&&i.highlightPoint(u,a,!0),void 0!==g&&(void 0===r&&(r=g),void 0===l&&(l=t.xScale()(t.x()(g,a))),d.push({key:s.key,value:v,color:h(s,s.seriesIndex),data:g}))}),d.length>2){var p=t.yScale().invert(n.mouseY),g=Math.abs(t.yScale().domain()[0]-t.yScale().domain()[1]),v=.03*g,m=o.nearestValueIndex(d.map(function(t){return t.value}),p,v);null!==m&&(d[m].highlight=!0)}var y=function(t,e){return null==t?"N/A":s.tickFormat()(t)};u.tooltip.valueFormatter(u.tooltip.valueFormatter()||y).data({value:t.x()(r,a),index:a,series:d})(),u.renderGuideLine(l)}),u.dispatch.on("elementClick",function(e){var n,r=[];c.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(i){var a=o.interactiveBisect(i.values,e.pointXValue,t.x()),s=i.values[a];if("undefined"!=typeof s){"undefined"==typeof n&&(n=t.xScale()(t.x()(s,a)));var l=t.yScale()(t.y()(s,a));r.push({point:s,pointIndex:a,pos:[n,l],seriesIndex:i.seriesIndex,series:i})}}),i.dispatch.elementClick(r)}),u.dispatch.on("elementMouseout",function(t){i.clearHighlights()}),P.on("changeState",function(e){"undefined"!=typeof e.disabled&&c.length===e.disabled.length&&(c.forEach(function(t,n){t.disabled=e.disabled[n]}),C.disabled=e.disabled),t.update()})}),M.renderEnd("lineChart immediate"),t}var e,n,i=o.models.line(),a=o.models.axis(),s=o.models.axis(),l=o.models.legend(),u=o.interactiveGuideline(),c=o.models.tooltip(),f=o.models.focus(o.models.line()),d={top:30,right:20,bottom:50,left:60},p=null,h=o.utils.defaultColor(),g=null,v=null,m=!0,y="top",b=!0,x=!0,_=!1,w=!1,T=!1,C=o.utils.state(),k=null,E=null,P=r.dispatch("tooltipShow","tooltipHide","stateChange","changeState","renderEnd"),S=250;a.orient("bottom").tickPadding(7),s.orient(_?"right":"left"),i.clipEdge(!0).duration(0),c.valueFormatter(function(t,e){return s.tickFormat()(t,e)}).headerFormatter(function(t,e){return a.tickFormat()(t,e)}),u.tooltip.valueFormatter(function(t,e){return s.tickFormat()(t,e)}).headerFormatter(function(t,e){return a.tickFormat()(t,e)});var M=o.utils.renderWatch(P,S),N=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},A=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return i.dispatch.on("elementMouseover.tooltip",function(t){t.series.disableTooltip||c.data(t).hidden(!1)}),i.dispatch.on("elementMouseout.tooltip",function(t){c.hidden(!0)}),t.dispatch=P,t.lines=i,t.legend=l,t.focus=f,t.xAxis=a,t.x2Axis=f.xAxis,t.yAxis=s,t.y2Axis=f.yAxis,t.interactiveLayer=u,t.tooltip=c,t.state=C,t.dispatch=P,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return g},set:function(t){g=t}},height:{get:function(){return v},set:function(t){v=t}},showLegend:{get:function(){return m},set:function(t){m=t}},legendPosition:{get:function(){return y},set:function(t){y=t}},showXAxis:{get:function(){return b},set:function(t){b=t}},showYAxis:{get:function(){return x},set:function(t){x=t}},defaultState:{get:function(){return k},set:function(t){k=t}},noData:{get:function(){return E},set:function(t){E=t}},focusEnable:{get:function(){return T},set:function(t){T=t}},focusHeight:{get:function(){return f.height()},set:function(t){f.height(t)}},focusShowAxisX:{get:function(){return f.showXAxis()},set:function(t){f.showXAxis(t)}},focusShowAxisY:{get:function(){return f.showYAxis()},set:function(t){f.showYAxis(t)}},brushExtent:{get:function(){return f.brushExtent()},set:function(t){f.brushExtent(t)}},focusMargin:{get:function(){return f.margin},set:function(t){void 0!==t.top&&(d.top=t.top,p=t.top),f.margin.right=void 0!==t.right?t.right:f.margin.right,f.margin.bottom=void 0!==t.bottom?t.bottom:f.margin.bottom,f.margin.left=void 0!==t.left?t.left:f.margin.left}},margin:{get:function(){return d},set:function(t){d.top=void 0!==t.top?t.top:d.top,d.right=void 0!==t.right?t.right:d.right,d.bottom=void 0!==t.bottom?t.bottom:d.bottom,d.left=void 0!==t.left?t.left:d.left}},duration:{get:function(){return S},set:function(t){S=t,M.reset(S),i.duration(S),f.duration(S),a.duration(S),s.duration(S)}},color:{get:function(){return h},set:function(t){h=o.utils.getColor(t),l.color(h),i.color(h),f.color(h)}},interpolate:{get:function(){return i.interpolate()},set:function(t){i.interpolate(t),f.interpolate(t)}},xTickFormat:{get:function(){return a.tickFormat()},set:function(t){a.tickFormat(t),f.xTickFormat(t)}},yTickFormat:{get:function(){return s.tickFormat()},set:function(t){s.tickFormat(t),f.yTickFormat(t)}},x:{get:function(){return i.x()},set:function(t){i.x(t),f.x(t)}},y:{get:function(){return i.y()},set:function(t){i.y(t),f.y(t)}},rightAlignYAxis:{get:function(){return _},set:function(t){_=t,s.orient(_?"right":"left")}},useInteractiveGuideline:{get:function(){return w},set:function(t){w=t,w&&(i.interactive(!1),i.useVoronoi(!1))}}}),o.utils.inheritOptions(t,i),o.utils.initOptions(t),t},o.models.lineWithFocusChart=function(){return o.models.lineChart().margin({bottom:30}).focusEnable(!0)},o.models.linePlusBarChart=function(){"use strict";function t(w){return w.each(function(w){function F(t){var e=+("e"==t),n=e?1:-1,r=Q/3;return"M"+.5*n+","+r+"A6,6 0 0 "+e+" "+6.5*n+","+(r+6)+"V"+(2*r-6)+"A6,6 0 0 "+e+" "+.5*n+","+2*r+"ZM"+2.5*n+","+(r+8)+"V"+(2*r-8)+"M"+4.5*n+","+(r+8)+"V"+(2*r-8)}function V(){_.empty()||_.extent(L),ht.data([_.empty()?i.domain():L]).each(function(t,e){var n=i(t[0])-i.range()[0],o=i.range()[1]-i(t[1]);r.select(this).select(".left").attr("width",n<0?0:n),r.select(this).select(".right").attr("x",i(t[1])).attr("width",o<0?0:o)})}function K(){L=_.empty()?null:_.extent(),e=_.empty()?i.domain():_.extent(),j.brush({extent:e,brush:_}),V(),d.width(Z).height(J).color(w.map(function(t,e){return t.color||N(t,e)}).filter(function(t,e){return!w[e].disabled&&w[e].bar})),c.width(Z).height(J).color(w.map(function(t,e){return t.color||N(t,e)}).filter(function(t,e){return!w[e].disabled&&!w[e].bar}));var t=st.select(".nv-focus .nv-barsWrap").datum(et.length?et.map(function(t,n){return{key:t.key,values:t.values.filter(function(t,n){return d.x()(t,n)>=e[0]&&d.x()(t,n)<=e[1]})}}):[{values:[]}]),r=st.select(".nv-focus .nv-linesWrap").datum(X(nt)?[{values:[]}]:nt.filter(function(t){return!t.disabled}).map(function(t,n){return{area:t.area,fillOpacity:t.fillOpacity,strokeWidth:t.strokeWidth,key:t.key,values:t.values.filter(function(t,n){return c.x()(t,n)>=e[0]&&c.x()(t,n)<=e[1]})}}));n=et.length&&!q?d.xScale():c.xScale(),h.scale(n)._ticks(o.utils.calcTicksX(Z/100,w)).tickSize(-J,0),h.domain([Math.ceil(e[0]),Math.floor(e[1])]),st.select(".nv-x.nv-axis").transition().duration(B).call(h),t.transition().duration(B).call(d),r.transition().duration(B).call(c),st.select(".nv-focus .nv-x.nv-axis").attr("transform","translate(0,"+a.range()[0]+")"),v.scale(a)._ticks(o.utils.calcTicksY(J/36,w)).tickSize(-Z,0),m.scale(s)._ticks(o.utils.calcTicksY(J/36,w)),q?m.tickSize(nt.length?0:-Z,0):m.tickSize(et.length?0:-Z,0);var l=et.length?1:0,u=nt.length&&!X(nt)?1:0,f=q?u:l,p=q?l:u;st.select(".nv-focus .nv-y1.nv-axis").style("opacity",f),st.select(".nv-focus .nv-y2.nv-axis").style("opacity",p).attr("transform","translate("+n.range()[1]+",0)"),st.select(".nv-focus .nv-y1.nv-axis").transition().duration(B).call(v),st.select(".nv-focus .nv-y2.nv-axis").transition().duration(B).call(m)}var $=r.select(this);o.utils.initSVG($);var Z=o.utils.availableWidth(E,$,T),J=o.utils.availableHeight(P,$,T)-(O?R:0),Q=R-k.top-k.bottom;if(t.update=function(){$.transition().duration(B).call(t)},t.container=this,U.setter(G(w),t.update).getter(Y(w)).update(),U.disabled=w.map(function(t){return!!t.disabled}),!H){var tt;H={};for(tt in U)U[tt]instanceof Array?H[tt]=U[tt].slice(0):H[tt]=U[tt]}if(!(w&&w.length&&w.filter(function(t){return t.values.length}).length))return o.utils.noData(t,$),t;$.selectAll(".nv-noData").remove();var et=w.filter(function(t){return!t.disabled&&t.bar}),nt=w.filter(function(t){return!t.bar});n=et.length&&!q?d.xScale():c.xScale(),i=g.scale(),a=q?c.yScale():d.yScale(),s=q?d.yScale():c.yScale(),l=q?f.yScale():p.yScale(),u=q?p.yScale():f.yScale();var rt=w.filter(function(t){return!t.disabled&&(q?!t.bar:t.bar)}).map(function(t){return t.values.map(function(t,e){return{x:S(t,e),y:M(t,e)}})}),ot=w.filter(function(t){return!t.disabled&&(q?t.bar:!t.bar)}).map(function(t){return t.values.map(function(t,e){return{x:S(t,e),y:M(t,e)}})});n.range([0,Z]),i.domain(r.extent(r.merge(rt.concat(ot)),function(t){return t.x})).range([0,Z]);var it=$.selectAll("g.nv-wrap.nv-linePlusBar").data([w]),at=it.enter().append("g").attr("class","nvd3 nv-wrap nv-linePlusBar").append("g"),st=it.select("g");at.append("g").attr("class","nv-legendWrap");var lt=at.append("g").attr("class","nv-focus");lt.append("g").attr("class","nv-x nv-axis"),lt.append("g").attr("class","nv-y1 nv-axis"),lt.append("g").attr("class","nv-y2 nv-axis"),lt.append("g").attr("class","nv-barsWrap"),lt.append("g").attr("class","nv-linesWrap");var ut=at.append("g").attr("class","nv-context");if(ut.append("g").attr("class","nv-x nv-axis"),ut.append("g").attr("class","nv-y1 nv-axis"),ut.append("g").attr("class","nv-y2 nv-axis"),ut.append("g").attr("class","nv-barsWrap"),ut.append("g").attr("class","nv-linesWrap"),ut.append("g").attr("class","nv-brushBackground"),ut.append("g").attr("class","nv-x nv-brush"),A){var ct=x.align()?Z/2:Z,ft=x.align()?ct:0;x.width(ct),st.select(".nv-legendWrap").datum(w.map(function(t){return t.originalKey=void 0===t.originalKey?t.key:t.originalKey,q?t.key=t.originalKey+(t.bar?W:z):t.key=t.originalKey+(t.bar?z:W),t})).call(x),C||x.height()===T.top||(T.top=x.height(),J=o.utils.availableHeight(P,$,T)-R),st.select(".nv-legendWrap").attr("transform","translate("+ft+","+-T.top+")")}else st.select(".nv-legendWrap").selectAll("*").remove();
it.attr("transform","translate("+T.left+","+T.top+")"),st.select(".nv-context").style("display",O?"initial":"none"),p.width(Z).height(Q).color(w.map(function(t,e){return t.color||N(t,e)}).filter(function(t,e){return!w[e].disabled&&w[e].bar})),f.width(Z).height(Q).color(w.map(function(t,e){return t.color||N(t,e)}).filter(function(t,e){return!w[e].disabled&&!w[e].bar}));var dt=st.select(".nv-context .nv-barsWrap").datum(et.length?et:[{values:[]}]),pt=st.select(".nv-context .nv-linesWrap").datum(X(nt)?[{values:[]}]:nt.filter(function(t){return!t.disabled}));st.select(".nv-context").attr("transform","translate(0,"+(J+T.bottom+k.top)+")"),dt.transition().call(p),pt.transition().call(f),I&&(g._ticks(o.utils.calcTicksX(Z/100,w)).tickSize(-Q,0),st.select(".nv-context .nv-x.nv-axis").attr("transform","translate(0,"+l.range()[0]+")"),st.select(".nv-context .nv-x.nv-axis").transition().call(g)),D&&(y.scale(l)._ticks(Q/36).tickSize(-Z,0),b.scale(u)._ticks(Q/36).tickSize(et.length?0:-Z,0),st.select(".nv-context .nv-y3.nv-axis").style("opacity",et.length?1:0).attr("transform","translate(0,"+i.range()[0]+")"),st.select(".nv-context .nv-y2.nv-axis").style("opacity",nt.length?1:0).attr("transform","translate("+i.range()[1]+",0)"),st.select(".nv-context .nv-y1.nv-axis").transition().call(y),st.select(".nv-context .nv-y2.nv-axis").transition().call(b)),_.x(i).on("brush",K),L&&_.extent(L);var ht=st.select(".nv-brushBackground").selectAll("g").data([L||_.extent()]),gt=ht.enter().append("g");gt.append("rect").attr("class","left").attr("x",0).attr("y",0).attr("height",Q),gt.append("rect").attr("class","right").attr("x",0).attr("y",0).attr("height",Q);var vt=st.select(".nv-x.nv-brush").call(_);vt.selectAll("rect").attr("height",Q),vt.selectAll(".resize").append("path").attr("d",F),x.dispatch.on("stateChange",function(e){for(var n in e)U[n]=e[n];j.stateChange(U),t.update()}),j.on("changeState",function(e){"undefined"!=typeof e.disabled&&(w.forEach(function(t,n){t.disabled=e.disabled[n]}),U.disabled=e.disabled),t.update()}),K()}),t}var e,n,i,a,s,l,u,c=o.models.line(),f=o.models.line(),d=o.models.historicalBar(),p=o.models.historicalBar(),h=o.models.axis(),g=o.models.axis(),v=o.models.axis(),m=o.models.axis(),y=o.models.axis(),b=o.models.axis(),x=o.models.legend(),_=r.svg.brush(),w=o.models.tooltip(),T={top:30,right:30,bottom:30,left:60},C=null,k={top:0,right:30,bottom:20,left:60},E=null,P=null,S=function(t){return t.x},M=function(t){return t.y},N=o.utils.defaultColor(),A=!0,O=!0,D=!1,I=!0,R=50,L=null,F=null,j=r.dispatch("brush","stateChange","changeState"),B=0,U=o.utils.state(),H=null,z=" (left axis)",W=" (right axis)",q=!1;c.clipEdge(!0),f.interactive(!1),f.pointActive(function(t){return!1}),h.orient("bottom").tickPadding(5),v.orient("left"),m.orient("right"),g.orient("bottom").tickPadding(5),y.orient("left"),b.orient("right"),w.headerEnabled(!0).headerFormatter(function(t,e){return h.tickFormat()(t,e)});var V=function(){return q?{main:m,focus:b}:{main:v,focus:y}},K=function(){return q?{main:v,focus:y}:{main:m,focus:b}},Y=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},G=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}},X=function(t){return t.every(function(t){return t.disabled})};return c.dispatch.on("elementMouseover.tooltip",function(t){w.duration(100).valueFormatter(function(t,e){return K().main.tickFormat()(t,e)}).data(t).hidden(!1)}),c.dispatch.on("elementMouseout.tooltip",function(t){w.hidden(!0)}),d.dispatch.on("elementMouseover.tooltip",function(e){e.value=t.x()(e.data),e.series={value:t.y()(e.data),color:e.color},w.duration(0).valueFormatter(function(t,e){return V().main.tickFormat()(t,e)}).data(e).hidden(!1)}),d.dispatch.on("elementMouseout.tooltip",function(t){w.hidden(!0)}),d.dispatch.on("elementMousemove.tooltip",function(t){w()}),t.dispatch=j,t.legend=x,t.lines=c,t.lines2=f,t.bars=d,t.bars2=p,t.xAxis=h,t.x2Axis=g,t.y1Axis=v,t.y2Axis=m,t.y3Axis=y,t.y4Axis=b,t.tooltip=w,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return E},set:function(t){E=t}},height:{get:function(){return P},set:function(t){P=t}},showLegend:{get:function(){return A},set:function(t){A=t}},brushExtent:{get:function(){return L},set:function(t){L=t}},noData:{get:function(){return F},set:function(t){F=t}},focusEnable:{get:function(){return O},set:function(t){O=t}},focusHeight:{get:function(){return R},set:function(t){R=t}},focusShowAxisX:{get:function(){return I},set:function(t){I=t}},focusShowAxisY:{get:function(){return D},set:function(t){D=t}},legendLeftAxisHint:{get:function(){return z},set:function(t){z=t}},legendRightAxisHint:{get:function(){return W},set:function(t){W=t}},margin:{get:function(){return T},set:function(t){void 0!==t.top&&(T.top=t.top,C=t.top),T.right=void 0!==t.right?t.right:T.right,T.bottom=void 0!==t.bottom?t.bottom:T.bottom,T.left=void 0!==t.left?t.left:T.left}},focusMargin:{get:function(){return k},set:function(t){k.top=void 0!==t.top?t.top:k.top,k.right=void 0!==t.right?t.right:k.right,k.bottom=void 0!==t.bottom?t.bottom:k.bottom,k.left=void 0!==t.left?t.left:k.left}},duration:{get:function(){return B},set:function(t){B=t}},color:{get:function(){return N},set:function(t){N=o.utils.getColor(t),x.color(N)}},x:{get:function(){return S},set:function(t){S=t,c.x(t),f.x(t),d.x(t),p.x(t)}},y:{get:function(){return M},set:function(t){M=t,c.y(t),f.y(t),d.y(t),p.y(t)}},switchYAxisOrder:{get:function(){return q},set:function(t){if(q!==t){var e=v;v=m,m=e;var n=y;y=b,b=n}q=t,v.orient("left"),m.orient("right"),y.orient("left"),b.orient("right")}}}),o.utils.inheritOptions(t,c),o.utils.initOptions(t),t},o.models.multiBar=function(){"use strict";function t(O){return N.reset(),O.each(function(t){var O=f-c.left-c.right,D=d-c.top-c.bottom;v=r.select(this),o.utils.initSVG(v);var I=0;if(C&&t.length&&(C=[{values:t[0].values.map(function(t){return{x:t.x,y:0,series:t.series,size:.01}})}]),_){var R=r.layout.stack().offset(w).values(function(t){return t.values}).y(y)(!t.length&&C?C:t);R.forEach(function(e,n){e.nonStackable?(t[n].nonStackableSeries=I++,R[n]=t[n]):n>0&&R[n-1].nonStackable&&R[n].values.map(function(t,e){t.y0-=R[n-1].values[e].y,t.y1=t.y0+t.y})}),t=R}t.forEach(function(t,e){t.values.forEach(function(n){n.series=e,n.key=t.key})}),_&&t.length>0&&t[0].values.map(function(e,n){var r=0,o=0;t.map(function(e,i){if(!t[i].nonStackable){var a=e.values[n];a.size=Math.abs(a.y),a.y<0?(a.y1=o,o-=a.size):(a.y1=a.size+r,r+=a.size)}})});var L=n&&i?[]:t.map(function(t,e){return t.values.map(function(t,n){return{x:m(t,n),y:y(t,n),y0:t.y0,y1:t.y1,idx:e}})});p.domain(n||r.merge(L).map(function(t){return t.x})).rangeBands(a||[0,O],P),h.domain(i||r.extent(r.merge(L).map(function(e){var n=e.y;return _&&!t[e.idx].nonStackable&&(n=e.y>0?e.y1:e.y1+e.y),n}).concat(b))).range(s||[D,0]),p.domain()[0]===p.domain()[1]&&(p.domain()[0]?p.domain([p.domain()[0]-.01*p.domain()[0],p.domain()[1]+.01*p.domain()[1]]):p.domain([-1,1])),h.domain()[0]===h.domain()[1]&&(h.domain()[0]?h.domain([h.domain()[0]+.01*h.domain()[0],h.domain()[1]-.01*h.domain()[1]]):h.domain([-1,1])),l=l||p,u=u||h;var F=v.selectAll("g.nv-wrap.nv-multibar").data([t]),j=F.enter().append("g").attr("class","nvd3 nv-wrap nv-multibar"),B=j.append("defs"),U=j.append("g"),H=F.select("g");U.append("g").attr("class","nv-groups"),F.attr("transform","translate("+c.left+","+c.top+")"),B.append("clipPath").attr("id","nv-edge-clip-"+g).append("rect"),F.select("#nv-edge-clip-"+g+" rect").attr("width",O).attr("height",D),H.attr("clip-path",x?"url(#nv-edge-clip-"+g+")":"");var z=F.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t,e){return e});z.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6);var W=N.transition(z.exit().selectAll("rect.nv-bar"),"multibarExit",Math.min(100,E)).attr("y",function(e,n,r){var o=u(0)||0;return _&&t[e.series]&&!t[e.series].nonStackable&&(o=u(e.y0)),o}).attr("height",0).remove();W.delay&&W.delay(function(t,e){var n=e*(E/(A+1))-e;return n}),z.attr("class",function(t,e){return"nv-group nv-series-"+e}).classed("hover",function(t){return t.hover}).style("fill",function(t,e){return T(t,e)}).style("stroke",function(t,e){return T(t,e)}),z.style("stroke-opacity",1).style("fill-opacity",S);var q=z.selectAll("rect.nv-bar").data(function(e){return C&&!t.length?C.values:e.values});q.exit().remove();q.enter().append("rect").attr("class",function(t,e){return y(t,e)<0?"nv-bar negative":"nv-bar positive"}).attr("x",function(e,n,r){return _&&!t[r].nonStackable?0:r*p.rangeBand()/t.length}).attr("y",function(e,n,r){return u(_&&!t[r].nonStackable?e.y0:0)||0}).attr("height",0).attr("width",function(e,n,r){return p.rangeBand()/(_&&!t[r].nonStackable?1:t.length)}).attr("transform",function(t,e){return"translate("+p(m(t,e))+",0)"});q.style("fill",function(t,e,n){return T(t,n,e)}).style("stroke",function(t,e,n){return T(t,n,e)}).on("mouseover",function(t,e){r.select(this).classed("hover",!0),M.elementMouseover({data:t,index:e,color:r.select(this).style("fill")})}).on("mouseout",function(t,e){r.select(this).classed("hover",!1),M.elementMouseout({data:t,index:e,color:r.select(this).style("fill")})}).on("mousemove",function(t,e){M.elementMousemove({data:t,index:e,color:r.select(this).style("fill")})}).on("click",function(t,e){var n=this;M.elementClick({data:t,index:e,color:r.select(this).style("fill"),event:r.event,element:n}),r.event.stopPropagation()}).on("dblclick",function(t,e){M.elementDblClick({data:t,index:e,color:r.select(this).style("fill")}),r.event.stopPropagation()}),q.attr("class",function(t,e){return y(t,e)<0?"nv-bar negative":"nv-bar positive"}).attr("transform",function(t,e){return"translate("+p(m(t,e))+",0)"}),k&&(e||(e=t.map(function(){return!0})),q.style("fill",function(t,n,o){return r.rgb(k(t,n)).darker(e.map(function(t,e){return e}).filter(function(t,n){return!e[n]})[o]).toString()}).style("stroke",function(t,n,o){return r.rgb(k(t,n)).darker(e.map(function(t,e){return e}).filter(function(t,n){return!e[n]})[o]).toString()}));var V=q.watchTransition(N,"multibar",Math.min(250,E)).delay(function(e,n){return n*E/t[0].values.length});_?V.attr("y",function(e,n,r){var o=0;return o=t[r].nonStackable?y(e,n)<0?h(0):h(0)-h(y(e,n))<-1?h(0)-1:h(y(e,n))||0:h(e.y1)}).attr("height",function(e,n,r){return t[r].nonStackable?Math.max(Math.abs(h(y(e,n))-h(0)),0)||0:Math.max(Math.abs(h(e.y+e.y0)-h(e.y0)),0)}).attr("x",function(e,n,r){var o=0;return t[r].nonStackable&&(o=e.series*p.rangeBand()/t.length,t.length!==I&&(o=t[r].nonStackableSeries*p.rangeBand()/(2*I))),o}).attr("width",function(e,n,r){if(t[r].nonStackable){var o=p.rangeBand()/I;return t.length!==I&&(o=p.rangeBand()/(2*I)),o}return p.rangeBand()}):V.attr("x",function(e,n){return e.series*p.rangeBand()/t.length}).attr("width",p.rangeBand()/t.length).attr("y",function(t,e){return y(t,e)<0?h(0):h(0)-h(y(t,e))<1?h(0)-1:h(y(t,e))||0}).attr("height",function(t,e){return Math.max(Math.abs(h(y(t,e))-h(0)),1)||0}),l=p.copy(),u=h.copy(),t[0]&&t[0].values&&(A=t[0].values.length)}),N.renderEnd("multibar immediate"),t}var e,n,i,a,s,l,u,c={top:0,right:0,bottom:0,left:0},f=960,d=500,p=r.scale.ordinal(),h=r.scale.linear(),g=Math.floor(1e4*Math.random()),v=null,m=function(t){return t.x},y=function(t){return t.y},b=[0],x=!0,_=!1,w="zero",T=o.utils.defaultColor(),C=!1,k=null,E=500,P=.1,S=.75,M=r.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),N=o.utils.renderWatch(M,E),A=0;return t.dispatch=M,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return f},set:function(t){f=t}},height:{get:function(){return d},set:function(t){d=t}},x:{get:function(){return m},set:function(t){m=t}},y:{get:function(){return y},set:function(t){y=t}},xScale:{get:function(){return p},set:function(t){p=t}},yScale:{get:function(){return h},set:function(t){h=t}},xDomain:{get:function(){return n},set:function(t){n=t}},yDomain:{get:function(){return i},set:function(t){i=t}},xRange:{get:function(){return a},set:function(t){a=t}},yRange:{get:function(){return s},set:function(t){s=t}},forceY:{get:function(){return b},set:function(t){b=t}},stacked:{get:function(){return _},set:function(t){_=t}},stackOffset:{get:function(){return w},set:function(t){w=t}},clipEdge:{get:function(){return x},set:function(t){x=t}},disabled:{get:function(){return e},set:function(t){e=t}},id:{get:function(){return g},set:function(t){g=t}},hideable:{get:function(){return C},set:function(t){C=t}},groupSpacing:{get:function(){return P},set:function(t){P=t}},fillOpacity:{get:function(){return S},set:function(t){S=t}},margin:{get:function(){return c},set:function(t){c.top=void 0!==t.top?t.top:c.top,c.right=void 0!==t.right?t.right:c.right,c.bottom=void 0!==t.bottom?t.bottom:c.bottom,c.left=void 0!==t.left?t.left:c.left}},duration:{get:function(){return E},set:function(t){E=t,N.reset(E)}},color:{get:function(){return T},set:function(t){T=o.utils.getColor(t)}},barColor:{get:function(){return k},set:function(t){k=t?o.utils.getColor(t):null}}}),o.utils.initOptions(t),t},o.models.multiBarChart=function(){"use strict";function t(M){return I.reset(),I.models(i),x&&I.models(a),_&&I.models(s),M.each(function(M){var I=r.select(this);o.utils.initSVG(I);var j=o.utils.availableWidth(h,I,d),B=o.utils.availableHeight(g,I,d);if(t.update=function(){0===O?I.call(t):I.transition().duration(O).call(t)},t.container=this,P.setter(F(M),t.update).getter(L(M)).update(),P.disabled=M.map(function(t){return!!t.disabled}),!S){var U;S={};for(U in P)P[U]instanceof Array?S[U]=P[U].slice(0):S[U]=P[U]}if(!(M&&M.length&&M.filter(function(t){return t.values.length}).length))return o.utils.noData(t,I),t;I.selectAll(".nv-noData").remove(),e=i.xScale(),n=i.yScale();var H=I.selectAll("g.nv-wrap.nv-multiBarWithLegend").data([M]),z=H.enter().append("g").attr("class","nvd3 nv-wrap nv-multiBarWithLegend").append("g"),W=H.select("g");if(z.append("g").attr("class","nv-x nv-axis"),z.append("g").attr("class","nv-y nv-axis"),z.append("g").attr("class","nv-barsWrap"),z.append("g").attr("class","nv-legendWrap"),z.append("g").attr("class","nv-controlsWrap"),z.append("g").attr("class","nv-interactive"),b?(u.width(j-A()),W.select(".nv-legendWrap").datum(M).call(u),p||u.height()===d.top||(d.top=u.height(),B=o.utils.availableHeight(g,I,d)),W.select(".nv-legendWrap").attr("transform","translate("+A()+","+-d.top+")")):W.select(".nv-legendWrap").selectAll("*").remove(),m){var q=[{key:y.grouped||"Grouped",disabled:i.stacked()},{key:y.stacked||"Stacked",disabled:!i.stacked()}];c.width(A()).color(["#444","#444","#444"]),W.select(".nv-controlsWrap").datum(q).attr("transform","translate(0,"+-d.top+")").call(c)}else W.select(".nv-controlsWrap").selectAll("*").remove();H.attr("transform","translate("+d.left+","+d.top+")"),w&&W.select(".nv-y.nv-axis").attr("transform","translate("+j+",0)"),i.disabled(M.map(function(t){return t.disabled})).width(j).height(B).color(M.map(function(t,e){return t.color||v(t,e)}).filter(function(t,e){return!M[e].disabled}));var V=W.select(".nv-barsWrap").datum(M.filter(function(t){return!t.disabled}));if(V.call(i),x){a.scale(e)._ticks(o.utils.calcTicksX(j/100,M)).tickSize(-B,0),W.select(".nv-x.nv-axis").attr("transform","translate(0,"+n.range()[0]+")"),W.select(".nv-x.nv-axis").call(a);var K=W.select(".nv-x.nv-axis > g").selectAll("g");if(K.selectAll("line, text").style("opacity",1),C){var Y=function(t,e){return"translate("+t+","+e+")"},G=5,X=17;K.selectAll("text").attr("transform",function(t,e,n){return Y(0,n%2==0?G:X)});var $=r.selectAll(".nv-x.nv-axis .nv-wrap g g text")[0].length;W.selectAll(".nv-x.nv-axis .nv-axisMaxMin text").attr("transform",function(t,e){return Y(0,0===e||$%2!==0?X:G)})}k&&W.selectAll(".tick text").call(o.utils.wrapTicks,t.xAxis.rangeBand()),T&&K.filter(function(t,e){return e%Math.ceil(M[0].values.length/(j/100))!==0}).selectAll("text, line").style("opacity",0),E&&K.selectAll(".tick text").attr("transform","rotate("+E+" 0,0)").style("text-anchor",E>0?"start":"end"),W.select(".nv-x.nv-axis").selectAll("g.nv-axisMaxMin text").style("opacity",1)}_&&(s.scale(n)._ticks(o.utils.calcTicksY(B/36,M)).tickSize(-j,0),W.select(".nv-y.nv-axis").call(s)),D&&(l.width(j).height(B).margin({left:d.left,top:d.top}).svgContainer(I).xScale(e),H.select(".nv-interactive").call(l)),u.dispatch.on("stateChange",function(e){for(var n in e)P[n]=e[n];N.stateChange(P),t.update()}),c.dispatch.on("legendClick",function(e,n){if(e.disabled){switch(q=q.map(function(t){return t.disabled=!0,t}),e.disabled=!1,e.key){case"Grouped":case y.grouped:i.stacked(!1);break;case"Stacked":case y.stacked:i.stacked(!0)}P.stacked=i.stacked(),N.stateChange(P),t.update()}}),N.on("changeState",function(e){"undefined"!=typeof e.disabled&&(M.forEach(function(t,n){t.disabled=e.disabled[n]}),P.disabled=e.disabled),"undefined"!=typeof e.stacked&&(i.stacked(e.stacked),P.stacked=e.stacked,R=e.stacked),t.update()}),D?(l.dispatch.on("elementMousemove",function(n){if(void 0!=n.pointXValue){var r,o,i,a,s=[];M.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(l,u){o=e.domain().indexOf(n.pointXValue);var c=l.values[o];void 0!==c&&(a=c.x,void 0===r&&(r=c),void 0===i&&(i=n.mouseX),s.push({key:l.key,value:t.y()(c,o),color:v(l,l.seriesIndex),data:l.values[o]}))}),l.tooltip.data({value:a,index:o,series:s})(),l.renderGuideLine(i)}}),l.dispatch.on("elementMouseout",function(t){l.tooltip.hidden(!0)})):(i.dispatch.on("elementMouseover.tooltip",function(e){e.value=t.x()(e.data),e.series={key:e.data.key,value:t.y()(e.data),color:e.color},f.data(e).hidden(!1)}),i.dispatch.on("elementMouseout.tooltip",function(t){f.hidden(!0)}),i.dispatch.on("elementMousemove.tooltip",function(t){f()}))}),I.renderEnd("multibarchart immediate"),t}var e,n,i=o.models.multiBar(),a=o.models.axis(),s=o.models.axis(),l=o.interactiveGuideline(),u=o.models.legend(),c=o.models.legend(),f=o.models.tooltip(),d={top:30,right:20,bottom:50,left:60},p=null,h=null,g=null,v=o.utils.defaultColor(),m=!0,y={},b=!0,x=!0,_=!0,w=!1,T=!0,C=!1,k=!1,E=0,P=o.utils.state(),S=null,M=null,N=r.dispatch("stateChange","changeState","renderEnd"),A=function(){return m?180:0},O=250,D=!1;P.stacked=!1,i.stacked(!1),a.orient("bottom").tickPadding(7).showMaxMin(!1).tickFormat(function(t){return t}),s.orient(w?"right":"left").tickFormat(r.format(",.1f")),f.duration(0).valueFormatter(function(t,e){return s.tickFormat()(t,e)}).headerFormatter(function(t,e){return a.tickFormat()(t,e)}),l.tooltip.valueFormatter(function(t,e){return null==t?"N/A":s.tickFormat()(t,e)}).headerFormatter(function(t,e){return a.tickFormat()(t,e)}),l.tooltip.valueFormatter(function(t,e){return null==t?"N/A":s.tickFormat()(t,e)}).headerFormatter(function(t,e){return a.tickFormat()(t,e)}),l.tooltip.duration(0).valueFormatter(function(t,e){return s.tickFormat()(t,e)}).headerFormatter(function(t,e){return a.tickFormat()(t,e)}),c.updateState(!1);var I=o.utils.renderWatch(N),R=!1,L=function(t){return function(){return{active:t.map(function(t){return!t.disabled}),stacked:R}}},F=function(t){return function(e){void 0!==e.stacked&&(R=e.stacked),void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return t.dispatch=N,t.multibar=i,t.legend=u,t.controls=c,t.xAxis=a,t.yAxis=s,t.state=P,t.tooltip=f,t.interactiveLayer=l,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return h},set:function(t){h=t}},height:{get:function(){return g},set:function(t){g=t}},showLegend:{get:function(){return b},set:function(t){b=t}},showControls:{get:function(){return m},set:function(t){m=t}},controlLabels:{get:function(){return y},set:function(t){y=t}},showXAxis:{get:function(){return x},set:function(t){x=t}},showYAxis:{get:function(){return _},set:function(t){_=t}},defaultState:{get:function(){return S},set:function(t){S=t}},noData:{get:function(){return M},set:function(t){M=t}},reduceXTicks:{get:function(){return T},set:function(t){T=t}},rotateLabels:{get:function(){return E},set:function(t){E=t}},staggerLabels:{get:function(){return C},set:function(t){C=t}},wrapLabels:{get:function(){return k},set:function(t){k=!!t}},margin:{get:function(){return d},set:function(t){void 0!==t.top&&(d.top=t.top,p=t.top),d.right=void 0!==t.right?t.right:d.right,d.bottom=void 0!==t.bottom?t.bottom:d.bottom,d.left=void 0!==t.left?t.left:d.left}},duration:{get:function(){return O},set:function(t){O=t,i.duration(O),a.duration(O),s.duration(O),I.reset(O)}},color:{get:function(){return v},set:function(t){v=o.utils.getColor(t),u.color(v)}},rightAlignYAxis:{get:function(){return w},set:function(t){w=t,s.orient(w?"right":"left")}},useInteractiveGuideline:{get:function(){return D},set:function(t){D=t}},barColor:{get:function(){return i.barColor},set:function(t){i.barColor(t),u.color(function(t,e){return r.rgb("#ccc").darker(1.5*e).toString()})}}}),o.utils.inheritOptions(t,i),o.utils.initOptions(t),t},o.models.multiBarHorizontal=function(){"use strict";function t(p){return O.reset(),p.each(function(t){var p=f-c.left-c.right,N=d-c.top-c.bottom;h=r.select(this),o.utils.initSVG(h),T&&(t=r.layout.stack().offset("zero").values(function(t){return t.values}).y(y)(t)),t.forEach(function(t,e){t.values.forEach(function(n){n.series=e,n.key=t.key})}),T&&t[0].values.map(function(e,n){var r=0,o=0;t.map(function(t){var e=t.values[n];e.size=Math.abs(e.y),e.y<0?(e.y1=o-e.size,o-=e.size):(e.y1=r,r+=e.size)})});var D=n&&i?[]:t.map(function(t){return t.values.map(function(t,e){return{x:m(t,e),y:y(t,e),y0:t.y0,y1:t.y1}})});g.domain(n||r.merge(D).map(function(t){return t.x})).rangeBands(a||[0,N],P),v.domain(i||r.extent(r.merge(D).map(function(t){return T?t.y>0?t.y1+t.y:t.y1:t.y}).concat(x))),C&&!T?v.range(s||[v.domain()[0]<0?E:0,p-(v.domain()[1]>0?E:0)]):v.range(s||[0,p]),l=l||g,u=u||r.scale.linear().domain(v.domain()).range([v(0),v(0)]);var I=r.select(this).selectAll("g.nv-wrap.nv-multibarHorizontal").data([t]),R=I.enter().append("g").attr("class","nvd3 nv-wrap nv-multibarHorizontal"),L=(R.append("defs"),R.append("g"));I.select("g");L.append("g").attr("class","nv-groups"),I.attr("transform","translate("+c.left+","+c.top+")");var F=I.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t,e){return e});F.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6),F.exit().watchTransition(O,"multibarhorizontal: exit groups").style("stroke-opacity",1e-6).style("fill-opacity",1e-6).remove(),F.attr("class",function(t,e){return"nv-group nv-series-"+e}).classed("hover",function(t){return t.hover}).style("fill",function(t,e){return _(t,e)}).style("stroke",function(t,e){return _(t,e)}),F.watchTransition(O,"multibarhorizontal: groups").style("stroke-opacity",1).style("fill-opacity",S);var j=F.selectAll("g.nv-bar").data(function(t){return t.values});j.exit().remove();var B=j.enter().append("g").attr("transform",function(e,n,r){return"translate("+u(T?e.y0:0)+","+(T?0:r*g.rangeBand()/t.length+g(m(e,n)))+")"});B.append("rect").attr("width",0).attr("height",g.rangeBand()/(T?1:t.length)),j.on("mouseover",function(t,e){r.select(this).classed("hover",!0),A.elementMouseover({data:t,index:e,color:r.select(this).style("fill")})}).on("mouseout",function(t,e){r.select(this).classed("hover",!1),A.elementMouseout({data:t,index:e,color:r.select(this).style("fill")})}).on("mouseout",function(t,e){A.elementMouseout({data:t,index:e,color:r.select(this).style("fill")})}).on("mousemove",function(t,e){A.elementMousemove({data:t,index:e,color:r.select(this).style("fill")})}).on("click",function(t,e){var n=this;A.elementClick({data:t,index:e,color:r.select(this).style("fill"),event:r.event,element:n}),r.event.stopPropagation()}).on("dblclick",function(t,e){A.elementDblClick({data:t,index:e,color:r.select(this).style("fill")}),r.event.stopPropagation()}),b(t[0],0)&&(B.append("polyline"),j.select("polyline").attr("fill","none").attr("points",function(e,n){var r=b(e,n),o=.8*g.rangeBand()/(2*(T?1:t.length));r=r.length?r:[-Math.abs(r),Math.abs(r)],r=r.map(function(t){return v(t)-v(0)});var i=[[r[0],-o],[r[0],o],[r[0],0],[r[1],0],[r[1],-o],[r[1],o]];return i.map(function(t){return t.join(",")}).join(" ")}).attr("transform",function(e,n){var r=g.rangeBand()/(2*(T?1:t.length));return"translate("+(y(e,n)<0?0:v(y(e,n))-v(0))+", "+r+")"})),B.append("text"),C&&!T?(j.select("text").attr("text-anchor",function(t,e){return y(t,e)<0?"end":"start"}).attr("y",g.rangeBand()/(2*t.length)).attr("dy",".32em").text(function(t,e){var n=M(y(t,e)),r=b(t,e);return void 0===r?n:r.length?n+"+"+M(Math.abs(r[1]))+"-"+M(Math.abs(r[0])):n+"±"+M(Math.abs(r))}),j.watchTransition(O,"multibarhorizontal: bars").select("text").attr("x",function(t,e){return y(t,e)<0?-4:v(y(t,e))-v(0)+4})):j.selectAll("text").text(""),k&&!T?(B.append("text").classed("nv-bar-label",!0),j.select("text.nv-bar-label").attr("text-anchor",function(t,e){return y(t,e)<0?"start":"end"}).attr("y",g.rangeBand()/(2*t.length)).attr("dy",".32em").text(function(t,e){return m(t,e)}),j.watchTransition(O,"multibarhorizontal: bars").select("text.nv-bar-label").attr("x",function(t,e){return y(t,e)<0?v(0)-v(y(t,e))+4:-4})):j.selectAll("text.nv-bar-label").text(""),j.attr("class",function(t,e){return y(t,e)<0?"nv-bar negative":"nv-bar positive"}),w&&(e||(e=t.map(function(){return!0})),j.style("fill",function(t,n,o){return r.rgb(w(t,n)).darker(e.map(function(t,e){return e}).filter(function(t,n){return!e[n]})[o]).toString()}).style("stroke",function(t,n,o){return r.rgb(w(t,n)).darker(e.map(function(t,e){return e}).filter(function(t,n){return!e[n]})[o]).toString()})),T?j.watchTransition(O,"multibarhorizontal: bars").attr("transform",function(t,e){return"translate("+v(t.y1)+","+g(m(t,e))+")"}).select("rect").attr("width",function(t,e){return Math.abs(v(y(t,e)+t.y0)-v(t.y0))||0}).attr("height",g.rangeBand()):j.watchTransition(O,"multibarhorizontal: bars").attr("transform",function(e,n){return"translate("+v(y(e,n)<0?y(e,n):0)+","+(e.series*g.rangeBand()/t.length+g(m(e,n)))+")"}).select("rect").attr("height",g.rangeBand()/t.length).attr("width",function(t,e){return Math.max(Math.abs(v(y(t,e))-v(0)),1)||0}),l=g.copy(),u=v.copy()}),O.renderEnd("multibarHorizontal immediate"),t}var e,n,i,a,s,l,u,c={top:0,right:0,bottom:0,left:0},f=960,d=500,p=Math.floor(1e4*Math.random()),h=null,g=r.scale.ordinal(),v=r.scale.linear(),m=function(t){return t.x},y=function(t){return t.y},b=function(t){return t.yErr},x=[0],_=o.utils.defaultColor(),w=null,T=!1,C=!1,k=!1,E=60,P=.1,S=.75,M=r.format(",.2f"),N=250,A=r.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),O=o.utils.renderWatch(A,N);return t.dispatch=A,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return f},set:function(t){f=t}},height:{get:function(){return d},set:function(t){d=t}},x:{get:function(){return m},set:function(t){m=t}},y:{get:function(){return y},set:function(t){y=t}},yErr:{get:function(){return b},set:function(t){b=t}},xScale:{get:function(){return g},set:function(t){g=t}},yScale:{get:function(){return v},set:function(t){v=t}},xDomain:{get:function(){return n},set:function(t){n=t}},yDomain:{get:function(){return i},set:function(t){i=t}},xRange:{get:function(){return a},set:function(t){a=t}},yRange:{get:function(){return s},set:function(t){s=t}},forceY:{get:function(){return x},set:function(t){x=t}},stacked:{get:function(){return T},set:function(t){T=t}},showValues:{get:function(){return C},set:function(t){C=t}},disabled:{get:function(){return e},set:function(t){e=t}},id:{get:function(){return p},set:function(t){p=t}},valueFormat:{get:function(){return M},set:function(t){M=t}},valuePadding:{get:function(){return E},set:function(t){E=t}},groupSpacing:{get:function(){return P},set:function(t){P=t}},fillOpacity:{get:function(){return S},set:function(t){S=t}},margin:{get:function(){return c},set:function(t){c.top=void 0!==t.top?t.top:c.top,c.right=void 0!==t.right?t.right:c.right,c.bottom=void 0!==t.bottom?t.bottom:c.bottom,c.left=void 0!==t.left?t.left:c.left}},duration:{get:function(){return N},set:function(t){N=t,O.reset(N)}},color:{get:function(){return _},set:function(t){_=o.utils.getColor(t)}},barColor:{get:function(){return w},set:function(t){w=t?o.utils.getColor(t):null}}}),o.utils.initOptions(t),t},o.models.multiBarHorizontalChart=function(){"use strict";function t(c){return N.reset(),N.models(i),b&&N.models(a),x&&N.models(s),c.each(function(c){var C=r.select(this);o.utils.initSVG(C);var N=o.utils.availableWidth(p,C,f),A=o.utils.availableHeight(h,C,f);if(t.update=function(){C.transition().duration(P).call(t)},t.container=this,_=i.stacked(),w.setter(M(c),t.update).getter(S(c)).update(),w.disabled=c.map(function(t){return!!t.disabled}),!T){var O;T={};for(O in w)w[O]instanceof Array?T[O]=w[O].slice(0):T[O]=w[O]}if(!(c&&c.length&&c.filter(function(t){return t.values.length}).length))return o.utils.noData(t,C),t;C.selectAll(".nv-noData").remove(),e=i.xScale(),n=i.yScale().clamp(!0);var D=C.selectAll("g.nv-wrap.nv-multiBarHorizontalChart").data([c]),I=D.enter().append("g").attr("class","nvd3 nv-wrap nv-multiBarHorizontalChart").append("g"),R=D.select("g");if(I.append("g").attr("class","nv-x nv-axis"),I.append("g").attr("class","nv-y nv-axis").append("g").attr("class","nv-zeroLine").append("line"),I.append("g").attr("class","nv-barsWrap"),I.append("g").attr("class","nv-legendWrap"),I.append("g").attr("class","nv-controlsWrap"),y?(l.width(N-E()),R.select(".nv-legendWrap").datum(c).call(l),d||l.height()===f.top||(f.top=l.height(),A=o.utils.availableHeight(h,C,f)),R.select(".nv-legendWrap").attr("transform","translate("+E()+","+-f.top+")")):R.select(".nv-legendWrap").selectAll("*").remove(),v){var L=[{key:m.grouped||"Grouped",disabled:i.stacked()},{key:m.stacked||"Stacked",disabled:!i.stacked()}];u.width(E()).color(["#444","#444","#444"]),R.select(".nv-controlsWrap").datum(L).attr("transform","translate(0,"+-f.top+")").call(u)}else R.select(".nv-controlsWrap").selectAll("*").remove();D.attr("transform","translate("+f.left+","+f.top+")"),i.disabled(c.map(function(t){return t.disabled})).width(N).height(A).color(c.map(function(t,e){return t.color||g(t,e)}).filter(function(t,e){return!c[e].disabled}));var F=R.select(".nv-barsWrap").datum(c.filter(function(t){return!t.disabled}));if(F.transition().call(i),b){a.scale(e)._ticks(o.utils.calcTicksY(A/24,c)).tickSize(-N,0),R.select(".nv-x.nv-axis").call(a);var j=R.select(".nv-x.nv-axis").selectAll("g");j.selectAll("line, text")}x&&(s.scale(n)._ticks(o.utils.calcTicksX(N/100,c)).tickSize(-A,0),R.select(".nv-y.nv-axis").attr("transform","translate(0,"+A+")"),R.select(".nv-y.nv-axis").call(s)),R.select(".nv-zeroLine line").attr("x1",n(0)).attr("x2",n(0)).attr("y1",0).attr("y2",-A),l.dispatch.on("stateChange",function(e){for(var n in e)w[n]=e[n];k.stateChange(w),t.update()}),u.dispatch.on("legendClick",function(e,n){if(e.disabled){switch(L=L.map(function(t){return t.disabled=!0,t}),e.disabled=!1,e.key){case"Grouped":case m.grouped:i.stacked(!1);break;case"Stacked":case m.stacked:i.stacked(!0)}w.stacked=i.stacked(),k.stateChange(w),_=i.stacked(),t.update()}}),k.on("changeState",function(e){"undefined"!=typeof e.disabled&&(c.forEach(function(t,n){t.disabled=e.disabled[n]}),w.disabled=e.disabled),"undefined"!=typeof e.stacked&&(i.stacked(e.stacked),w.stacked=e.stacked,_=e.stacked),t.update()})}),N.renderEnd("multibar horizontal chart immediate"),t}var e,n,i=o.models.multiBarHorizontal(),a=o.models.axis(),s=o.models.axis(),l=o.models.legend().height(30),u=o.models.legend().height(30),c=o.models.tooltip(),f={top:30,right:20,bottom:50,left:60},d=null,p=null,h=null,g=o.utils.defaultColor(),v=!0,m={},y=!0,b=!0,x=!0,_=!1,w=o.utils.state(),T=null,C=null,k=r.dispatch("stateChange","changeState","renderEnd"),E=function(){return v?180:0},P=250;w.stacked=!1,i.stacked(_),a.orient("left").tickPadding(5).showMaxMin(!1).tickFormat(function(t){
return t}),s.orient("bottom").tickFormat(r.format(",.1f")),c.duration(0).valueFormatter(function(t,e){return s.tickFormat()(t,e)}).headerFormatter(function(t,e){return a.tickFormat()(t,e)}),u.updateState(!1);var S=function(t){return function(){return{active:t.map(function(t){return!t.disabled}),stacked:_}}},M=function(t){return function(e){void 0!==e.stacked&&(_=e.stacked),void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}},N=o.utils.renderWatch(k,P);return i.dispatch.on("elementMouseover.tooltip",function(e){e.value=t.x()(e.data),e.series={key:e.data.key,value:t.y()(e.data),color:e.color},c.data(e).hidden(!1)}),i.dispatch.on("elementMouseout.tooltip",function(t){c.hidden(!0)}),i.dispatch.on("elementMousemove.tooltip",function(t){c()}),t.dispatch=k,t.multibar=i,t.legend=l,t.controls=u,t.xAxis=a,t.yAxis=s,t.state=w,t.tooltip=c,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return p},set:function(t){p=t}},height:{get:function(){return h},set:function(t){h=t}},showLegend:{get:function(){return y},set:function(t){y=t}},showControls:{get:function(){return v},set:function(t){v=t}},controlLabels:{get:function(){return m},set:function(t){m=t}},showXAxis:{get:function(){return b},set:function(t){b=t}},showYAxis:{get:function(){return x},set:function(t){x=t}},defaultState:{get:function(){return T},set:function(t){T=t}},noData:{get:function(){return C},set:function(t){C=t}},margin:{get:function(){return f},set:function(t){void 0!==t.top&&(f.top=t.top,d=t.top),f.right=void 0!==t.right?t.right:f.right,f.bottom=void 0!==t.bottom?t.bottom:f.bottom,f.left=void 0!==t.left?t.left:f.left}},duration:{get:function(){return P},set:function(t){P=t,N.reset(P),i.duration(P),a.duration(P),s.duration(P)}},color:{get:function(){return g},set:function(t){g=o.utils.getColor(t),l.color(g)}},barColor:{get:function(){return i.barColor},set:function(t){i.barColor(t),l.color(function(t,e){return r.rgb("#ccc").darker(1.5*e).toString()})}}}),o.utils.inheritOptions(t,i),o.utils.initOptions(t),t},o.models.multiChart=function(){"use strict";function t(f){return f.each(function(f){function g(t){var e=2===f[t.seriesIndex].yAxis?D:O;t.value=t.point.x,t.series={value:t.point.y,color:t.point.color,key:t.series.key},R.duration(0).headerFormatter(function(t,e){return A.tickFormat()(t,e)}).valueFormatter(function(t,n){return e.tickFormat()(t,n)}).data(t).hidden(!1)}function b(t){var e=2===f[t.seriesIndex].yAxis?D:O;t.value=t.point.x,t.series={value:t.point.y,color:t.point.color,key:t.series.key},R.duration(100).headerFormatter(function(t,e){return A.tickFormat()(t,e)}).valueFormatter(function(t,n){return e.tickFormat()(t,n)}).data(t).hidden(!1)}function L(t){var e=2===f[t.seriesIndex].yAxis?D:O;t.point.x=M.x()(t.point),t.point.y=M.y()(t.point),R.duration(0).headerFormatter(function(t,e){return A.tickFormat()(t,e)}).valueFormatter(function(t,n){return e.tickFormat()(t,n)}).data(t).hidden(!1)}function j(t){var e=2===f[t.data.series].yAxis?D:O;t.value=P.x()(t.data),t.series={value:P.y()(t.data),color:t.color,key:t.data.key},R.duration(0).headerFormatter(function(t,e){return A.tickFormat()(t,e)}).valueFormatter(function(t,n){return e.tickFormat()(t,n)}).data(t).hidden(!1)}function B(){for(var t=0,e=F.length;t<e;t++){var n=F[t];try{n.clearHighlights()}catch(t){}}}function U(t,e,n){for(var r=0,o=F.length;r<o;r++){var i=F[r];try{i.highlightPoint(t,e,n)}catch(t){}}}var H=r.select(this);o.utils.initSVG(H),t.update=function(){H.transition().call(t)},t.container=this;var z=o.utils.availableWidth(l,H,i),W=o.utils.availableHeight(u,H,i),q=f.filter(function(t){return"line"==t.type&&1==t.yAxis}),V=f.filter(function(t){return"line"==t.type&&2==t.yAxis}),K=f.filter(function(t){return"scatter"==t.type&&1==t.yAxis}),Y=f.filter(function(t){return"scatter"==t.type&&2==t.yAxis}),G=f.filter(function(t){return"bar"==t.type&&1==t.yAxis}),X=f.filter(function(t){return"bar"==t.type&&2==t.yAxis}),$=f.filter(function(t){return"area"==t.type&&1==t.yAxis}),Z=f.filter(function(t){return"area"==t.type&&2==t.yAxis});if(!(f&&f.length&&f.filter(function(t){return t.values.length}).length))return o.utils.noData(t,H),t;H.selectAll(".nv-noData").remove();var J=f.filter(function(t){return!t.disabled&&1==t.yAxis}).map(function(t){return t.values.map(function(t,e){return{x:d(t),y:p(t)}})}),Q=f.filter(function(t){return!t.disabled&&2==t.yAxis}).map(function(t){return t.values.map(function(t,e){return{x:d(t),y:p(t)}})});x.domain(r.extent(r.merge(J.concat(Q)),function(t){return t.x})).range([0,z]);var tt=H.selectAll("g.wrap.multiChart").data([f]),et=tt.enter().append("g").attr("class","wrap nvd3 multiChart").append("g");et.append("g").attr("class","nv-x nv-axis"),et.append("g").attr("class","nv-y1 nv-axis"),et.append("g").attr("class","nv-y2 nv-axis"),et.append("g").attr("class","stack1Wrap"),et.append("g").attr("class","stack2Wrap"),et.append("g").attr("class","bars1Wrap"),et.append("g").attr("class","bars2Wrap"),et.append("g").attr("class","scatters1Wrap"),et.append("g").attr("class","scatters2Wrap"),et.append("g").attr("class","lines1Wrap"),et.append("g").attr("class","lines2Wrap"),et.append("g").attr("class","legendWrap"),et.append("g").attr("class","nv-interactive");var nt=tt.select("g"),rt=f.map(function(t,e){return f[e].color||s(t,e)});if(c){var ot=I.align()?z/2:z,it=I.align()?ot:0;I.width(ot),I.color(rt),nt.select(".legendWrap").datum(f.map(function(t){return t.originalKey=void 0===t.originalKey?t.key:t.originalKey,t.key=t.originalKey+(1==t.yAxis?"":y),t})).call(I),a||I.height()===i.top||(i.top=I.height(),W=o.utils.availableHeight(u,H,i)),nt.select(".legendWrap").attr("transform","translate("+it+","+-i.top+")")}else nt.select(".legendWrap").selectAll("*").remove();T.width(z).height(W).interpolate(h).color(rt.filter(function(t,e){return!f[e].disabled&&1==f[e].yAxis&&"line"==f[e].type})),C.width(z).height(W).interpolate(h).color(rt.filter(function(t,e){return!f[e].disabled&&2==f[e].yAxis&&"line"==f[e].type})),k.width(z).height(W).color(rt.filter(function(t,e){return!f[e].disabled&&1==f[e].yAxis&&"scatter"==f[e].type})),E.width(z).height(W).color(rt.filter(function(t,e){return!f[e].disabled&&2==f[e].yAxis&&"scatter"==f[e].type})),P.width(z).height(W).color(rt.filter(function(t,e){return!f[e].disabled&&1==f[e].yAxis&&"bar"==f[e].type})),S.width(z).height(W).color(rt.filter(function(t,e){return!f[e].disabled&&2==f[e].yAxis&&"bar"==f[e].type})),M.width(z).height(W).interpolate(h).color(rt.filter(function(t,e){return!f[e].disabled&&1==f[e].yAxis&&"area"==f[e].type})),N.width(z).height(W).interpolate(h).color(rt.filter(function(t,e){return!f[e].disabled&&2==f[e].yAxis&&"area"==f[e].type})),nt.attr("transform","translate("+i.left+","+i.top+")");var at=nt.select(".lines1Wrap").datum(q.filter(function(t){return!t.disabled})),st=nt.select(".scatters1Wrap").datum(K.filter(function(t){return!t.disabled})),lt=nt.select(".bars1Wrap").datum(G.filter(function(t){return!t.disabled})),ut=nt.select(".stack1Wrap").datum($.filter(function(t){return!t.disabled})),ct=nt.select(".lines2Wrap").datum(V.filter(function(t){return!t.disabled})),ft=nt.select(".scatters2Wrap").datum(Y.filter(function(t){return!t.disabled})),dt=nt.select(".bars2Wrap").datum(X.filter(function(t){return!t.disabled})),pt=nt.select(".stack2Wrap").datum(Z.filter(function(t){return!t.disabled})),ht=$.length?$.map(function(t){return t.values}).reduce(function(t,e){return t.map(function(t,n){return{x:t.x,y:t.y+e[n].y}})}).concat([{x:0,y:0}]):[],gt=Z.length?Z.map(function(t){return t.values}).reduce(function(t,e){return t.map(function(t,n){return{x:t.x,y:t.y+e[n].y}})}).concat([{x:0,y:0}]):[];_.domain(e||r.extent(r.merge(J).concat(ht),function(t){return t.y})).range([0,W]),w.domain(n||r.extent(r.merge(Q).concat(gt),function(t){return t.y})).range([0,W]),T.yDomain(_.domain()),k.yDomain(_.domain()),P.yDomain(_.domain()),M.yDomain(_.domain()),C.yDomain(w.domain()),E.yDomain(w.domain()),S.yDomain(w.domain()),N.yDomain(w.domain()),$.length&&r.transition(ut).call(M),Z.length&&r.transition(pt).call(N),G.length&&r.transition(lt).call(P),X.length&&r.transition(dt).call(S),q.length&&r.transition(at).call(T),V.length&&r.transition(ct).call(C),K.length&&r.transition(st).call(k),Y.length&&r.transition(ft).call(E),A._ticks(o.utils.calcTicksX(z/100,f)).tickSize(-W,0),nt.select(".nv-x.nv-axis").attr("transform","translate(0,"+W+")"),r.transition(nt.select(".nv-x.nv-axis")).call(A),O._ticks(o.utils.calcTicksY(W/36,f)).tickSize(-z,0),r.transition(nt.select(".nv-y1.nv-axis")).call(O),D._ticks(o.utils.calcTicksY(W/36,f)).tickSize(-z,0),r.transition(nt.select(".nv-y2.nv-axis")).call(D),nt.select(".nv-y1.nv-axis").classed("nv-disabled",!J.length).attr("transform","translate("+x.range()[0]+",0)"),nt.select(".nv-y2.nv-axis").classed("nv-disabled",!Q.length).attr("transform","translate("+x.range()[1]+",0)"),I.dispatch.on("stateChange",function(e){t.update()}),m&&(v.width(z).height(W).margin({left:i.left,top:i.top}).svgContainer(H).xScale(x),tt.select(".nv-interactive").call(v)),m?(v.dispatch.on("elementMousemove",function(e){B();var n,r,i,a=[];f.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(l,u){var c=x.domain(),f=l.values.filter(function(e,n){return t.x()(e,n)>=c[0]&&t.x()(e,n)<=c[1]});r=o.interactiveBisect(f,e.pointXValue,t.x());var d=f[r],p=t.y()(d,r);null!==p&&U(u,r,!0),void 0!==d&&(void 0===n&&(n=d),void 0===i&&(i=x(t.x()(d,r))),a.push({key:l.key,value:p,color:s(l,l.seriesIndex),data:d,yAxis:2==l.yAxis?D:O}))});var l=function(t,e){var n=a[e].yAxis;return null==t?"N/A":n.tickFormat()(t)};v.tooltip.headerFormatter(function(t,e){return A.tickFormat()(t,e)}).valueFormatter(v.tooltip.valueFormatter()||l).data({value:t.x()(n,r),index:r,series:a})(),v.renderGuideLine(i)}),v.dispatch.on("elementMouseout",function(t){B()})):(T.dispatch.on("elementMouseover.tooltip",g),C.dispatch.on("elementMouseover.tooltip",g),T.dispatch.on("elementMouseout.tooltip",function(t){R.hidden(!0)}),C.dispatch.on("elementMouseout.tooltip",function(t){R.hidden(!0)}),k.dispatch.on("elementMouseover.tooltip",b),E.dispatch.on("elementMouseover.tooltip",b),k.dispatch.on("elementMouseout.tooltip",function(t){R.hidden(!0)}),E.dispatch.on("elementMouseout.tooltip",function(t){R.hidden(!0)}),M.dispatch.on("elementMouseover.tooltip",L),N.dispatch.on("elementMouseover.tooltip",L),M.dispatch.on("elementMouseout.tooltip",function(t){R.hidden(!0)}),N.dispatch.on("elementMouseout.tooltip",function(t){R.hidden(!0)}),P.dispatch.on("elementMouseover.tooltip",j),S.dispatch.on("elementMouseover.tooltip",j),P.dispatch.on("elementMouseout.tooltip",function(t){R.hidden(!0)}),S.dispatch.on("elementMouseout.tooltip",function(t){R.hidden(!0)}),P.dispatch.on("elementMousemove.tooltip",function(t){R()}),S.dispatch.on("elementMousemove.tooltip",function(t){R()}))}),t}var e,n,i={top:30,right:20,bottom:50,left:60},a=null,s=o.utils.defaultColor(),l=null,u=null,c=!0,f=null,d=function(t){return t.x},p=function(t){return t.y},h="linear",g=!0,v=o.interactiveGuideline(),m=!1,y=" (right axis)",b=250,x=r.scale.linear(),_=r.scale.linear(),w=r.scale.linear(),T=o.models.line().yScale(_).duration(b),C=o.models.line().yScale(w).duration(b),k=o.models.scatter().yScale(_).duration(b),E=o.models.scatter().yScale(w).duration(b),P=o.models.multiBar().stacked(!1).yScale(_).duration(b),S=o.models.multiBar().stacked(!1).yScale(w).duration(b),M=o.models.stackedArea().yScale(_).duration(b),N=o.models.stackedArea().yScale(w).duration(b),A=o.models.axis().scale(x).orient("bottom").tickPadding(5).duration(b),O=o.models.axis().scale(_).orient("left").duration(b),D=o.models.axis().scale(w).orient("right").duration(b),I=o.models.legend().height(30),R=o.models.tooltip(),L=r.dispatch(),F=[T,C,k,E,P,S,M,N];return t.dispatch=L,t.legend=I,t.lines1=T,t.lines2=C,t.scatters1=k,t.scatters2=E,t.bars1=P,t.bars2=S,t.stack1=M,t.stack2=N,t.xAxis=A,t.yAxis1=O,t.yAxis2=D,t.tooltip=R,t.interactiveLayer=v,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return l},set:function(t){l=t}},height:{get:function(){return u},set:function(t){u=t}},showLegend:{get:function(){return c},set:function(t){c=t}},yDomain1:{get:function(){return e},set:function(t){e=t}},yDomain2:{get:function(){return n},set:function(t){n=t}},noData:{get:function(){return f},set:function(t){f=t}},interpolate:{get:function(){return h},set:function(t){h=t}},legendRightAxisHint:{get:function(){return y},set:function(t){y=t}},margin:{get:function(){return i},set:function(t){void 0!==t.top&&(i.top=t.top,a=t.top),i.right=void 0!==t.right?t.right:i.right,i.bottom=void 0!==t.bottom?t.bottom:i.bottom,i.left=void 0!==t.left?t.left:i.left}},color:{get:function(){return s},set:function(t){s=o.utils.getColor(t)}},x:{get:function(){return d},set:function(t){d=t,T.x(t),C.x(t),k.x(t),E.x(t),P.x(t),S.x(t),M.x(t),N.x(t)}},y:{get:function(){return p},set:function(t){p=t,T.y(t),C.y(t),k.y(t),E.y(t),M.y(t),N.y(t),P.y(t),S.y(t)}},useVoronoi:{get:function(){return g},set:function(t){g=t,T.useVoronoi(t),C.useVoronoi(t),M.useVoronoi(t),N.useVoronoi(t)}},useInteractiveGuideline:{get:function(){return m},set:function(t){m=t,m&&(T.interactive(!1),T.useVoronoi(!1),C.interactive(!1),C.useVoronoi(!1),M.interactive(!1),M.useVoronoi(!1),N.interactive(!1),N.useVoronoi(!1),k.interactive(!1),E.interactive(!1))}},duration:{get:function(){return b},set:function(t){b=t,[T,C,M,N,k,E,A,O,D].forEach(function(t){t.duration(b)})}}}),o.utils.initOptions(t),t},o.models.ohlcBar=function(){"use strict";function t(k){return k.each(function(t){f=r.select(this);var k=o.utils.availableWidth(l,f,s),P=o.utils.availableHeight(u,f,s);o.utils.initSVG(f);var S=k/t[0].values.length*.9;d.domain(e||r.extent(t[0].values.map(h).concat(x))),w?d.range(i||[.5*k/t[0].values.length,k*(t[0].values.length-.5)/t[0].values.length]):d.range(i||[5+S/2,k-S/2-5]),p.domain(n||[r.min(t[0].values.map(b).concat(_)),r.max(t[0].values.map(y).concat(_))]).range(a||[P,0]),d.domain()[0]===d.domain()[1]&&(d.domain()[0]?d.domain([d.domain()[0]-.01*d.domain()[0],d.domain()[1]+.01*d.domain()[1]]):d.domain([-1,1])),p.domain()[0]===p.domain()[1]&&(p.domain()[0]?p.domain([p.domain()[0]+.01*p.domain()[0],p.domain()[1]-.01*p.domain()[1]]):p.domain([-1,1]));var M=r.select(this).selectAll("g.nv-wrap.nv-ohlcBar").data([t[0].values]),N=M.enter().append("g").attr("class","nvd3 nv-wrap nv-ohlcBar"),A=N.append("defs"),O=N.append("g"),D=M.select("g");O.append("g").attr("class","nv-ticks"),M.attr("transform","translate("+s.left+","+s.top+")"),f.on("click",function(t,e){E.chartClick({data:t,index:e,pos:r.event,id:c})}),A.append("clipPath").attr("id","nv-chart-clip-path-"+c).append("rect"),M.select("#nv-chart-clip-path-"+c+" rect").attr("width",k).attr("height",P),D.attr("clip-path",T?"url(#nv-chart-clip-path-"+c+")":"");var I=M.select(".nv-ticks").selectAll(".nv-tick").data(function(t){return t});I.exit().remove(),I.enter().append("path").attr("class",function(t,e,n){return(v(t,e)>m(t,e)?"nv-tick negative":"nv-tick positive")+" nv-tick-"+n+"-"+e}).attr("d",function(t,e){return"m0,0l0,"+(p(v(t,e))-p(y(t,e)))+"l"+-S/2+",0l"+S/2+",0l0,"+(p(b(t,e))-p(v(t,e)))+"l0,"+(p(m(t,e))-p(b(t,e)))+"l"+S/2+",0l"+-S/2+",0z"}).attr("transform",function(t,e){return"translate("+d(h(t,e))+","+p(y(t,e))+")"}).attr("fill",function(t,e){return C[0]}).attr("stroke",function(t,e){return C[0]}).attr("x",0).attr("y",function(t,e){return p(Math.max(0,g(t,e)))}).attr("height",function(t,e){return Math.abs(p(g(t,e))-p(0))}),I.attr("class",function(t,e,n){return(v(t,e)>m(t,e)?"nv-tick negative":"nv-tick positive")+" nv-tick-"+n+"-"+e}),r.transition(I).attr("transform",function(t,e){return"translate("+d(h(t,e))+","+p(y(t,e))+")"}).attr("d",function(e,n){var r=k/t[0].values.length*.9;return"m0,0l0,"+(p(v(e,n))-p(y(e,n)))+"l"+-r/2+",0l"+r/2+",0l0,"+(p(b(e,n))-p(v(e,n)))+"l0,"+(p(m(e,n))-p(b(e,n)))+"l"+r/2+",0l"+-r/2+",0z"})}),t}var e,n,i,a,s={top:0,right:0,bottom:0,left:0},l=null,u=null,c=Math.floor(1e4*Math.random()),f=null,d=r.scale.linear(),p=r.scale.linear(),h=function(t){return t.x},g=function(t){return t.y},v=function(t){return t.open},m=function(t){return t.close},y=function(t){return t.high},b=function(t){return t.low},x=[],_=[],w=!1,T=!0,C=o.utils.defaultColor(),k=!1,E=r.dispatch("stateChange","changeState","renderEnd","chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove");return t.highlightPoint=function(e,n){t.clearHighlights(),f.select(".nv-ohlcBar .nv-tick-0-"+e).classed("hover",n)},t.clearHighlights=function(){f.select(".nv-ohlcBar .nv-tick.hover").classed("hover",!1)},t.dispatch=E,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return l},set:function(t){l=t}},height:{get:function(){return u},set:function(t){u=t}},xScale:{get:function(){return d},set:function(t){d=t}},yScale:{get:function(){return p},set:function(t){p=t}},xDomain:{get:function(){return e},set:function(t){e=t}},yDomain:{get:function(){return n},set:function(t){n=t}},xRange:{get:function(){return i},set:function(t){i=t}},yRange:{get:function(){return a},set:function(t){a=t}},forceX:{get:function(){return x},set:function(t){x=t}},forceY:{get:function(){return _},set:function(t){_=t}},padData:{get:function(){return w},set:function(t){w=t}},clipEdge:{get:function(){return T},set:function(t){T=t}},id:{get:function(){return c},set:function(t){c=t}},interactive:{get:function(){return k},set:function(t){k=t}},x:{get:function(){return h},set:function(t){h=t}},y:{get:function(){return g},set:function(t){g=t}},open:{get:function(){return v()},set:function(t){v=t}},close:{get:function(){return m()},set:function(t){m=t}},high:{get:function(){return y},set:function(t){y=t}},low:{get:function(){return b},set:function(t){b=t}},margin:{get:function(){return s},set:function(t){s.top=void 0!=t.top?t.top:s.top,s.right=void 0!=t.right?t.right:s.right,s.bottom=void 0!=t.bottom?t.bottom:s.bottom,s.left=void 0!=t.left?t.left:s.left}},color:{get:function(){return C},set:function(t){C=o.utils.getColor(t)}}}),o.utils.initOptions(t),t},o.models.parallelCoordinates=function(){"use strict";function t(S){return P.reset(),S.each(function(t){function P(t){return C(g.map(function(e){if(isNaN(t.values[e.key])||isNaN(parseFloat(t.values[e.key]))||H){var n=d[e.key].domain(),o=d[e.key].range(),i=n[0]-(n[1]-n[0])/9;if(w.indexOf(e.key)<0){var a=r.scale.linear().domain([i,n[1]]).range([c-12,o[1]]);d[e.key].brush.y(a),w.push(e.key)}if(isNaN(t.values[e.key])||isNaN(parseFloat(t.values[e.key])))return[f(e.key),d[e.key](i)]}return void 0!==Y&&(w.length>0||H?(Y.style("display","inline"),G.style("display","inline")):(Y.style("display","none"),G.style("display","none"))),[f(e.key),d[e.key](t.values[e.key])]}))}function S(t){b.forEach(function(e){var n=d[e.dimension].brush.y().domain();e.hasOnlyNaN&&(e.extent[1]=(d[e.dimension].domain()[1]-n[0])*(e.extent[1]-e.extent[0])/(U[e.dimension]-e.extent[0])+n[0]),e.hasNaN&&(e.extent[0]=n[0]),t&&d[e.dimension].brush.extent(e.extent)}),i.select(".nv-brushBackground").each(function(t){r.select(this).call(d[t.key].brush)}).selectAll("rect").attr("x",-8).attr("width",16),O()}function M(){m===!1&&(m=!0,S(!0))}function N(){Q=v.filter(function(t){return!d[t].brush.empty()}),tt=Q.map(function(t){return d[t].brush.extent()}),b=[],Q.forEach(function(t,e){b[e]={dimension:t,extent:tt[e],hasNaN:!1,hasOnlyNaN:!1}}),x=[],e.style("display",function(t){var e=Q.every(function(e,n){return!(!isNaN(t.values[e])&&!isNaN(parseFloat(t.values[e]))||tt[n][0]!=d[e].brush.y().domain()[0])||tt[n][0]<=t.values[e]&&t.values[e]<=tt[n][1]&&!isNaN(parseFloat(t.values[e]))});return e&&x.push(t),e?null:"none"}),O(),E.brush({filters:b,active:x})}function A(){var t=Q.length>0;b.forEach(function(t){t.extent[0]===d[t.dimension].brush.y().domain()[0]&&w.indexOf(t.dimension)>=0&&(t.hasNaN=!0),t.extent[1]<d[t.dimension].domain()[0]&&(t.hasOnlyNaN=!0)}),E.brushEnd(x,t)}function O(){i.select(".nv-axis").each(function(t,e){var n=b.filter(function(e){return e.dimension==t.key});z[t.key]=d[t.key].domain(),0!=n.length&&m&&(z[t.key]=[],n[0].extent[1]>d[t.key].domain()[0]&&(z[t.key]=[n[0].extent[1]]),n[0].extent[0]>=d[t.key].domain()[0]&&z[t.key].push(n[0].extent[0])),r.select(this).call(k.scale(d[t.key]).tickFormat(t.format).tickValues(z[t.key]))})}function D(t){_[t.key]=this.parentNode.__origin__=f(t.key),n.attr("visibility","hidden")}function I(t){_[t.key]=Math.min(u,Math.max(0,this.parentNode.__origin__+=r.event.x)),e.attr("d",P),g.sort(function(t,e){return L(t.key)-L(e.key)}),g.forEach(function(t,e){return t.currentPosition=e}),f.domain(g.map(function(t){return t.key})),i.attr("transform",function(t){return"translate("+L(t.key)+")"})}function R(t,o){delete this.parentNode.__origin__,delete _[t.key],r.select(this.parentNode).attr("transform","translate("+f(t.key)+")"),e.attr("d",P),n.attr("d",P).attr("visibility",null),E.dimensionsOrder(g)}function L(t){var e=_[t];return null==e?f(t):e}var F=r.select(this);if(u=o.utils.availableWidth(s,F,a),c=o.utils.availableHeight(l,F,a),o.utils.initSVG(F),void 0===t[0].values){var j=[];t.forEach(function(t){var e={},n=Object.keys(t);n.forEach(function(n){"name"!==n&&(e[n]=t[n])}),j.push({key:t.name,values:e})}),t=j}var B=t.map(function(t){return t.values});0===x.length&&(x=t),v=h.sort(function(t,e){return t.currentPosition-e.currentPosition}).map(function(t){return t.key}),g=h.filter(function(t){return!t.disabled}),f.rangePoints([0,u],1).domain(g.map(function(t){return t.key}));var U={},H=!1,z=[];v.forEach(function(t){var e=r.extent(B,function(e){return+e[t]}),n=e[0],o=e[1],i=!1;(isNaN(n)||isNaN(o))&&(i=!0,n=0,o=0),n===o&&(n-=1,o+=1);var a=b.filter(function(e){return e.dimension==t});0!==a.length&&(i?(n=d[t].domain()[0],o=d[t].domain()[1]):!a[0].hasOnlyNaN&&m?(n=n>a[0].extent[0]?a[0].extent[0]:n,o=o<a[0].extent[1]?a[0].extent[1]:o):a[0].hasNaN&&(o=o<a[0].extent[1]?a[0].extent[1]:o,U[t]=d[t].domain()[1],H=!0)),d[t]=r.scale.linear().domain([n,o]).range([.9*(c-12),0]),w=[],d[t].brush=r.svg.brush().y(d[t]).on("brushstart",M).on("brush",N).on("brushend",A)});var W=F.selectAll("g.nv-wrap.nv-parallelCoordinates").data([t]),q=W.enter().append("g").attr("class","nvd3 nv-wrap nv-parallelCoordinates"),V=q.append("g"),K=W.select("g");V.append("g").attr("class","nv-parallelCoordinates background"),V.append("g").attr("class","nv-parallelCoordinates foreground"),V.append("g").attr("class","nv-parallelCoordinates missingValuesline"),W.attr("transform","translate("+a.left+","+a.top+")"),C.interpolate("cardinal").tension(T),k.orient("left");var Y,G,X=r.behavior.drag().on("dragstart",D).on("drag",I).on("dragend",R),$=f.range()[1]-f.range()[0];if($=isNaN($)?f.range()[0]:$,!isNaN($)){var Z=[0+$/2,c-12,u-$/2,c-12];Y=W.select(".missingValuesline").selectAll("line").data([Z]),Y.enter().append("line"),Y.exit().remove(),Y.attr("x1",function(t){return t[0]}).attr("y1",function(t){return t[1]}).attr("x2",function(t){return t[2]}).attr("y2",function(t){return t[3]}),G=W.select(".missingValuesline").selectAll("text").data([p]),G.append("text").data([p]),G.enter().append("text"),G.exit().remove(),G.attr("y",c).attr("x",u-92-$/2).text(function(t){return t})}n=W.select(".background").selectAll("path").data(t),n.enter().append("path"),n.exit().remove(),n.attr("d",P),e=W.select(".foreground").selectAll("path").data(t),e.enter().append("path"),e.exit().remove(),e.attr("d",P).style("stroke-width",function(t,e){return isNaN(t.strokeWidth)&&(t.strokeWidth=1),t.strokeWidth}).attr("stroke",function(t,e){return t.color||y(t,e)}),e.on("mouseover",function(t,e){r.select(this).classed("hover",!0).style("stroke-width",t.strokeWidth+2+"px").style("stroke-opacity",1),E.elementMouseover({label:t.name,color:t.color||y(t,e),values:t.values,dimensions:g})}),e.on("mouseout",function(t,e){r.select(this).classed("hover",!1).style("stroke-width",t.strokeWidth+"px").style("stroke-opacity",.7),E.elementMouseout({label:t.name,index:e})}),e.on("mousemove",function(t,e){E.elementMousemove()}),e.on("click",function(t){E.elementClick({id:t.id})}),i=K.selectAll(".dimension").data(g);var J=i.enter().append("g").attr("class","nv-parallelCoordinates dimension");i.attr("transform",function(t){return"translate("+f(t.key)+",0)"}),J.append("g").attr("class","nv-axis"),J.append("text").attr("class","nv-label").style("cursor","move").attr("dy","-1em").attr("text-anchor","middle").on("mouseover",function(t,e){E.elementMouseover({label:t.tooltip||t.key,color:t.color})}).on("mouseout",function(t,e){E.elementMouseout({label:t.tooltip})}).on("mousemove",function(t,e){E.elementMousemove()}).call(X),J.append("g").attr("class","nv-brushBackground"),i.exit().remove(),i.select(".nv-label").text(function(t){return t.key}),S(m);var Q=v.filter(function(t){return!d[t].brush.empty()}),tt=Q.map(function(t){return d[t].brush.extent()}),et=x.slice(0);x=[],e.style("display",function(t){var e=Q.every(function(e,n){return!(!isNaN(t.values[e])&&!isNaN(parseFloat(t.values[e]))||tt[n][0]!=d[e].brush.y().domain()[0])||tt[n][0]<=t.values[e]&&t.values[e]<=tt[n][1]&&!isNaN(parseFloat(t.values[e]))});return e&&x.push(t),e?null:"none"}),(b.length>0||!o.utils.arrayEquals(x,et))&&E.activeChanged(x)}),t}var e,n,i,a={top:30,right:0,bottom:10,left:0},s=null,l=null,u=null,c=null,f=r.scale.ordinal(),d={},p="undefined values",h=[],g=[],v=[],m=!0,y=o.utils.defaultColor(),b=[],x=[],_=[],w=[],T=1,C=r.svg.line(),k=r.svg.axis(),E=r.dispatch("brushstart","brush","brushEnd","dimensionsOrder","stateChange","elementClick","elementMouseover","elementMouseout","elementMousemove","renderEnd","activeChanged"),P=o.utils.renderWatch(E);return t.dispatch=E,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return s},set:function(t){s=t}},height:{get:function(){return l},set:function(t){l=t}},dimensionData:{get:function(){return h},set:function(t){h=t}},displayBrush:{get:function(){return m},set:function(t){m=t}},filters:{get:function(){return b},set:function(t){b=t}},active:{get:function(){return x},set:function(t){x=t}},lineTension:{get:function(){return T},set:function(t){T=t}},undefinedValuesLabel:{get:function(){return p},set:function(t){p=t}},dimensions:{get:function(){return h.map(function(t){return t.key})},set:function(t){o.deprecated("dimensions","use dimensionData instead"),0===h.length?t.forEach(function(t){h.push({key:t})}):t.forEach(function(t,e){h[e].key=t})}},dimensionNames:{get:function(){return h.map(function(t){return t.key})},set:function(t){o.deprecated("dimensionNames","use dimensionData instead"),v=[],0===h.length?t.forEach(function(t){h.push({key:t})}):t.forEach(function(t,e){h[e].key=t})}},dimensionFormats:{get:function(){return h.map(function(t){return t.format})},set:function(t){o.deprecated("dimensionFormats","use dimensionData instead"),0===h.length?t.forEach(function(t){h.push({format:t})}):t.forEach(function(t,e){h[e].format=t})}},margin:{get:function(){return a},set:function(t){a.top=void 0!==t.top?t.top:a.top,a.right=void 0!==t.right?t.right:a.right,a.bottom=void 0!==t.bottom?t.bottom:a.bottom,a.left=void 0!==t.left?t.left:a.left}},color:{get:function(){return y},set:function(t){y=o.utils.getColor(t)}}}),o.utils.initOptions(t),t},o.models.parallelCoordinatesChart=function(){"use strict";function t(i){return b.reset(),b.models(e),i.each(function(i){var f=r.select(this);o.utils.initSVG(f);var v=o.utils.availableWidth(l,f,a),m=o.utils.availableHeight(u,f,a);if(t.update=function(){f.call(t)},t.container=this,d.setter(_(p),t.update).getter(x(p)).update(),d.disabled=p.map(function(t){return!!t.disabled}),p=p.map(function(t){return t.disabled=!!t.disabled,t}),p.forEach(function(t,e){t.originalPosition=isNaN(t.originalPosition)?e:t.originalPosition,t.currentPosition=isNaN(t.currentPosition)?e:t.currentPosition}),!g){var b;g={};for(b in d)d[b]instanceof Array?g[b]=d[b].slice(0):g[b]=d[b]}if(!i||!i.length)return o.utils.noData(t,f),t;f.selectAll(".nv-noData").remove();var w=f.selectAll("g.nv-wrap.nv-parallelCoordinatesChart").data([i]),T=w.enter().append("g").attr("class","nvd3 nv-wrap nv-parallelCoordinatesChart").append("g"),C=w.select("g");T.append("g").attr("class","nv-parallelCoordinatesWrap"),T.append("g").attr("class","nv-legendWrap"),C.select("rect").attr("width",v).attr("height",m>0?m:0),c?(n.width(v).color(function(t){return"rgb(188,190,192)"}),C.select(".nv-legendWrap").datum(p.sort(function(t,e){return t.originalPosition-e.originalPosition})).call(n),s||n.height()===a.top||(a.top=n.height(),m=o.utils.availableHeight(u,f,a)),w.select(".nv-legendWrap").attr("transform","translate( 0 ,"+-a.top+")")):C.select(".nv-legendWrap").selectAll("*").remove(),w.attr("transform","translate("+a.left+","+a.top+")"),e.width(v).height(m).dimensionData(p).displayBrush(h);var k=C.select(".nv-parallelCoordinatesWrap ").datum(i);k.transition().call(e),e.dispatch.on("brushEnd",function(t,e){e?(h=!0,y.brushEnd(t)):h=!1}),n.dispatch.on("stateChange",function(e){for(var n in e)d[n]=e[n];y.stateChange(d),t.update()}),e.dispatch.on("dimensionsOrder",function(t){p.sort(function(t,e){return t.currentPosition-e.currentPosition});var e=!1;p.forEach(function(t,n){t.currentPosition=n,t.currentPosition!==t.originalPosition&&(e=!0)}),y.dimensionsOrder(p,e)}),y.on("changeState",function(e){"undefined"!=typeof e.disabled&&(p.forEach(function(t,n){t.disabled=e.disabled[n]}),d.disabled=e.disabled),t.update()})}),b.renderEnd("parraleleCoordinateChart immediate"),t}var e=o.models.parallelCoordinates(),n=o.models.legend(),i=o.models.tooltip(),a=(o.models.tooltip(),{top:0,right:0,bottom:0,left:0}),s=null,l=null,u=null,c=!0,f=o.utils.defaultColor(),d=o.utils.state(),p=[],h=!0,g=null,v=null,m="undefined",y=r.dispatch("dimensionsOrder","brushEnd","stateChange","changeState","renderEnd"),b=o.utils.renderWatch(y),x=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},_=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return i.contentGenerator(function(t){var e='<table><thead><tr><td class="legend-color-guide"><div style="background-color:'+t.color+'"></div></td><td><strong>'+t.key+"</strong></td></tr></thead>";return 0!==t.series.length&&(e+='<tbody><tr><td height ="10px"></td></tr>',t.series.forEach(function(t){e=e+'<tr><td class="legend-color-guide"><div style="background-color:'+t.color+'"></div></td><td class="key">'+t.key+'</td><td class="value">'+t.value+"</td></tr>"}),e+="</tbody>"),e+="</table>"}),e.dispatch.on("elementMouseover.tooltip",function(t){var e={key:t.label,color:t.color,series:[]};t.values&&(Object.keys(t.values).forEach(function(n){var r=t.dimensions.filter(function(t){return t.key===n})[0];if(r){var o;o=isNaN(t.values[n])||isNaN(parseFloat(t.values[n]))?m:r.format(t.values[n]),e.series.push({idx:r.currentPosition,key:n,value:o,color:r.color})}}),e.series.sort(function(t,e){return t.idx-e.idx})),i.data(e).hidden(!1)}),e.dispatch.on("elementMouseout.tooltip",function(t){i.hidden(!0)}),e.dispatch.on("elementMousemove.tooltip",function(){i()}),t.dispatch=y,t.parallelCoordinates=e,t.legend=n,t.tooltip=i,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return l},set:function(t){l=t}},height:{get:function(){return u},set:function(t){u=t}},showLegend:{get:function(){return c},set:function(t){c=t}},defaultState:{get:function(){return g},set:function(t){g=t}},dimensionData:{get:function(){return p},set:function(t){p=t}},displayBrush:{get:function(){return h},set:function(t){h=t}},noData:{get:function(){return v},set:function(t){v=t}},nanValue:{get:function(){return m},set:function(t){m=t}},margin:{get:function(){return a},set:function(t){void 0!==t.top&&(a.top=t.top,s=t.top),a.right=void 0!==t.right?t.right:a.right,a.bottom=void 0!==t.bottom?t.bottom:a.bottom,a.left=void 0!==t.left?t.left:a.left}},color:{get:function(){return f},set:function(t){f=o.utils.getColor(t),n.color(f),e.color(f)}}}),o.utils.inheritOptions(t,e),
o.utils.initOptions(t),t},o.models.pie=function(){"use strict";function t(O){return A.reset(),O.each(function(t){function O(t,e){t.endAngle=isNaN(t.endAngle)?0:t.endAngle,t.startAngle=isNaN(t.startAngle)?0:t.startAngle,v||(t.innerRadius=0);var n=r.interpolate(this._current,t);return this._current=n(0),function(t){return M[e](n(t))}}var D=n-e.left-e.right,I=i-e.top-e.bottom,R=Math.min(D,I)/2,L=[],F=[];if(u=r.select(this),0===P.length)for(var j=R-R/5,B=k*R,U=0;U<t[0].length;U++)L.push(j),F.push(B);else y?(L=P.map(function(t){return(t.outer-t.outer/5)*R}),F=P.map(function(t){return(t.inner-t.inner/5)*R}),k=r.min(P.map(function(t){return t.inner-t.inner/5}))):(L=P.map(function(t){return t.outer*R}),F=P.map(function(t){return t.inner*R}),k=r.min(P.map(function(t){return t.inner})));o.utils.initSVG(u);var H=u.selectAll(".nv-wrap.nv-pie").data(t),z=H.enter().append("g").attr("class","nvd3 nv-wrap nv-pie nv-chart-"+l),W=z.append("g"),q=H.select("g"),V=W.append("g").attr("class","nv-pie");W.append("g").attr("class","nv-pieLabels"),H.attr("transform","translate("+e.left+","+e.top+")"),q.select(".nv-pie").attr("transform","translate("+D/2+","+I/2+")"),q.select(".nv-pieLabels").attr("transform","translate("+D/2+","+I/2+")"),u.on("click",function(t,e){S.chartClick({data:t,index:e,pos:r.event,id:l})}),M=[],N=[];for(var U=0;U<t[0].length;U++){var K=r.svg.arc().outerRadius(L[U]),Y=r.svg.arc().outerRadius(L[U]+5);_!==!1&&(K.startAngle(_),Y.startAngle(_)),T!==!1&&(K.endAngle(T),Y.endAngle(T)),v&&(K.innerRadius(F[U]),Y.innerRadius(F[U])),K.cornerRadius&&C&&(K.cornerRadius(C),Y.cornerRadius(C)),M.push(K),N.push(Y)}var G=r.layout.pie().sort(null).value(function(t){return t.disabled?0:s(t)});G.padAngle&&w&&G.padAngle(w),v&&m&&(V.append("text").attr("class","nv-pie-title"),H.select(".nv-pie-title").style("text-anchor","middle").text(function(t){return m}).style("font-size",Math.min(D,I)*k*2/(m.length+2)+"px").attr("dy","0.35em").attr("transform",function(t,e){return"translate(0, "+b+")"}));var X=H.select(".nv-pie").selectAll(".nv-slice").data(G),$=H.select(".nv-pieLabels").selectAll(".nv-label").data(G);X.exit().remove(),$.exit().remove();var Z=X.enter().append("g");Z.attr("class","nv-slice"),Z.on("mouseover",function(t,e){r.select(this).classed("hover",!0),y&&r.select(this).select("path").transition().duration(70).attr("d",N[e]),S.elementMouseover({data:t.data,index:e,color:r.select(this).style("fill"),percent:(t.endAngle-t.startAngle)/(2*Math.PI)})}),Z.on("mouseout",function(t,e){r.select(this).classed("hover",!1),y&&r.select(this).select("path").transition().duration(50).attr("d",M[e]),S.elementMouseout({data:t.data,index:e})}),Z.on("mousemove",function(t,e){S.elementMousemove({data:t.data,index:e})}),Z.on("click",function(t,e){var n=this;S.elementClick({data:t.data,index:e,color:r.select(this).style("fill"),event:r.event,element:n})}),Z.on("dblclick",function(t,e){S.elementDblClick({data:t.data,index:e,color:r.select(this).style("fill")})}),X.attr("fill",function(t,e){return c(t.data,e)}),X.attr("stroke",function(t,e){return c(t.data,e)});Z.append("path").each(function(t){this._current=t});if(X.select("path").transition().duration(E).attr("d",function(t,e){return M[e](t)}).attrTween("d",O),d){for(var J=[],U=0;U<t[0].length;U++)J.push(M[U]),p?v&&(J[U]=r.svg.arc().outerRadius(M[U].outerRadius()),_!==!1&&J[U].startAngle(_),T!==!1&&J[U].endAngle(T)):v||J[U].innerRadius(0);$.enter().append("g").classed("nv-label",!0).each(function(t,e){var n=r.select(this);n.attr("transform",function(t,e){if(x){t.outerRadius=L[e]+10,t.innerRadius=L[e]+15;var n=(t.startAngle+t.endAngle)/2*(180/Math.PI);return(t.startAngle+t.endAngle)/2<Math.PI?n-=90:n+=90,"translate("+J[e].centroid(t)+") rotate("+n+")"}return t.outerRadius=R+10,t.innerRadius=R+15,"translate("+J[e].centroid(t)+")"}),n.append("rect").style("stroke","#fff").style("fill","#fff").attr("rx",3).attr("ry",3),n.append("text").style("text-anchor",x?(t.startAngle+t.endAngle)/2<Math.PI?"start":"end":"middle").style("fill","#000")});var Q={},tt=14,et=140,nt=function(t){return Math.floor(t[0]/et)*et+","+Math.floor(t[1]/tt)*tt},rt=function(t){return(t.endAngle-t.startAngle)/(2*Math.PI)};$.watchTransition(A,"pie labels").attr("transform",function(t,e){if(x){t.outerRadius=L[e]+10,t.innerRadius=L[e]+15;var n=(t.startAngle+t.endAngle)/2*(180/Math.PI);return(t.startAngle+t.endAngle)/2<Math.PI?n-=90:n+=90,"translate("+J[e].centroid(t)+") rotate("+n+")"}t.outerRadius=R+10,t.innerRadius=R+15;var r=J[e].centroid(t),o=rt(t);if(t.value&&o>=g){var i=nt(r);Q[i]&&(r[1]-=tt),Q[nt(r)]=!0}return"translate("+r+")"}),$.select(".nv-label text").style("text-anchor",function(t,e){return x?(t.startAngle+t.endAngle)/2<Math.PI?"start":"end":"middle"}).text(function(t,e){var n=rt(t),o="";if(!t.value||n<g)return"";if("function"==typeof h)o=h(t,e,{key:a(t.data),value:s(t.data),percent:f(n)});else switch(h){case"key":o=a(t.data);break;case"value":o=f(s(t.data));break;case"percent":o=r.format("%")(n)}return o})}}),A.renderEnd("pie immediate"),t}var e={top:0,right:0,bottom:0,left:0},n=500,i=500,a=function(t){return t.x},s=function(t){return t.y},l=Math.floor(1e4*Math.random()),u=null,c=o.utils.defaultColor(),f=r.format(",.2f"),d=!0,p=!1,h="key",g=.02,v=!1,m=!1,y=!0,b=0,x=!1,_=!1,w=!1,T=!1,C=0,k=.5,E=250,P=[],S=r.dispatch("chartClick","elementClick","elementDblClick","elementMouseover","elementMouseout","elementMousemove","renderEnd"),M=[],N=[],A=o.utils.renderWatch(S);return t.dispatch=S,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{arcsRadius:{get:function(){return P},set:function(t){P=t}},width:{get:function(){return n},set:function(t){n=t}},height:{get:function(){return i},set:function(t){i=t}},showLabels:{get:function(){return d},set:function(t){d=t}},title:{get:function(){return m},set:function(t){m=t}},titleOffset:{get:function(){return b},set:function(t){b=t}},labelThreshold:{get:function(){return g},set:function(t){g=t}},valueFormat:{get:function(){return f},set:function(t){f=t}},x:{get:function(){return a},set:function(t){a=t}},id:{get:function(){return l},set:function(t){l=t}},endAngle:{get:function(){return T},set:function(t){T=t}},startAngle:{get:function(){return _},set:function(t){_=t}},padAngle:{get:function(){return w},set:function(t){w=t}},cornerRadius:{get:function(){return C},set:function(t){C=t}},donutRatio:{get:function(){return k},set:function(t){k=t}},labelsOutside:{get:function(){return p},set:function(t){p=t}},labelSunbeamLayout:{get:function(){return x},set:function(t){x=t}},donut:{get:function(){return v},set:function(t){v=t}},growOnHover:{get:function(){return y},set:function(t){y=t}},pieLabelsOutside:{get:function(){return p},set:function(t){p=t,o.deprecated("pieLabelsOutside","use labelsOutside instead")}},donutLabelsOutside:{get:function(){return p},set:function(t){p=t,o.deprecated("donutLabelsOutside","use labelsOutside instead")}},labelFormat:{get:function(){return f},set:function(t){f=t,o.deprecated("labelFormat","use valueFormat instead")}},margin:{get:function(){return e},set:function(t){e.top="undefined"!=typeof t.top?t.top:e.top,e.right="undefined"!=typeof t.right?t.right:e.right,e.bottom="undefined"!=typeof t.bottom?t.bottom:e.bottom,e.left="undefined"!=typeof t.left?t.left:e.left}},duration:{get:function(){return E},set:function(t){E=t,A.reset(E)}},y:{get:function(){return s},set:function(t){s=r.functor(t)}},color:{get:function(){return c},set:function(t){c=o.utils.getColor(t)}},labelType:{get:function(){return h},set:function(t){h=t||"key"}}}),o.utils.initOptions(t),t},o.models.pieChart=function(){"use strict";function t(i){return b.reset(),b.models(e),i.each(function(i){var c=r.select(this);o.utils.initSVG(c);var p=o.utils.availableWidth(l,c,a),v=o.utils.availableHeight(u,c,a);if(t.update=function(){c.transition().call(t)},t.container=this,h.setter(_(i),t.update).getter(x(i)).update(),h.disabled=i.map(function(t){return!!t.disabled}),!g){var m;g={};for(m in h)h[m]instanceof Array?g[m]=h[m].slice(0):g[m]=h[m]}if(!i||!i.length)return o.utils.noData(t,c),t;c.selectAll(".nv-noData").remove();var b=c.selectAll("g.nv-wrap.nv-pieChart").data([i]),w=b.enter().append("g").attr("class","nvd3 nv-wrap nv-pieChart").append("g"),T=b.select("g");if(w.append("g").attr("class","nv-pieWrap"),w.append("g").attr("class","nv-legendWrap"),f){if("top"===d)n.width(p).key(e.x()),b.select(".nv-legendWrap").datum(i).call(n),s||n.height()===a.top||(a.top=n.height(),v=o.utils.availableHeight(u,c,a)),b.select(".nv-legendWrap").attr("transform","translate(0,"+-a.top+")");else if("right"===d){var C=o.models.legend().width();p/2<C&&(C=p/2),n.height(v).key(e.x()),n.width(C),p-=n.width(),b.select(".nv-legendWrap").datum(i).call(n).attr("transform","translate("+p+",0)")}}else T.select(".nv-legendWrap").selectAll("*").remove();b.attr("transform","translate("+a.left+","+a.top+")"),e.width(p).height(v);var k=T.select(".nv-pieWrap").datum([i]);r.transition(k).call(e),n.dispatch.on("stateChange",function(e){for(var n in e)h[n]=e[n];y.stateChange(h),t.update()}),y.on("changeState",function(e){"undefined"!=typeof e.disabled&&(i.forEach(function(t,n){t.disabled=e.disabled[n]}),h.disabled=e.disabled),t.update()})}),b.renderEnd("pieChart immediate"),t}var e=o.models.pie(),n=o.models.legend(),i=o.models.tooltip(),a={top:30,right:20,bottom:20,left:20},s=null,l=null,u=null,c=!1,f=!0,d="top",p=o.utils.defaultColor(),h=o.utils.state(),g=null,v=null,m=250,y=r.dispatch("stateChange","changeState","renderEnd");i.duration(0).headerEnabled(!1).valueFormatter(function(t,n){return e.valueFormat()(t,n)});var b=o.utils.renderWatch(y),x=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},_=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return e.dispatch.on("elementMouseover.tooltip",function(e){e.series={key:t.x()(e.data),value:t.y()(e.data),color:e.color,percent:e.percent},c||(delete e.percent,delete e.series.percent),i.data(e).hidden(!1)}),e.dispatch.on("elementMouseout.tooltip",function(t){i.hidden(!0)}),e.dispatch.on("elementMousemove.tooltip",function(t){i()}),t.legend=n,t.dispatch=y,t.pie=e,t.tooltip=i,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return l},set:function(t){l=t}},height:{get:function(){return u},set:function(t){u=t}},noData:{get:function(){return v},set:function(t){v=t}},showTooltipPercent:{get:function(){return c},set:function(t){c=t}},showLegend:{get:function(){return f},set:function(t){f=t}},legendPosition:{get:function(){return d},set:function(t){d=t}},defaultState:{get:function(){return g},set:function(t){g=t}},color:{get:function(){return p},set:function(t){p=t,n.color(p),e.color(p)}},duration:{get:function(){return m},set:function(t){m=t,b.reset(m),e.duration(m)}},margin:{get:function(){return a},set:function(t){void 0!==t.top&&(a.top=t.top,s=t.top),a.right=void 0!==t.right?t.right:a.right,a.bottom=void 0!==t.bottom?t.bottom:a.bottom,a.left=void 0!==t.left?t.left:a.left}}}),o.utils.inheritOptions(t,e),o.utils.initOptions(t),t},o.models.sankey=function(){"use strict";function t(){h.forEach(function(t){t.sourceLinks=[],t.targetLinks=[]}),g.forEach(function(t){var e=t.source,n=t.target;"number"==typeof e&&(e=t.source=h[t.source]),"number"==typeof n&&(n=t.target=h[t.target]),e.sourceLinks.push(t),n.targetLinks.push(t)})}function e(){h.forEach(function(t){t.value=Math.max(r.sum(t.sourceLinks,u),r.sum(t.targetLinks,u))})}function n(){for(var t,e=h,n=0;e.length&&n<h.length;)t=[],e.forEach(function(e){e.x=n,e.dx=f,e.sourceLinks.forEach(function(e){t.indexOf(e.target)<0&&t.push(e.target)})}),e=t,++n;v&&i(n),a((p[0]-f)/(n-1))}function i(t){h.forEach(function(e){e.sourceLinks.length||(e.x=t-1)})}function a(t){h.forEach(function(e){e.x*=t})}function s(t){function e(){var t=r.min(s,function(t){return(p[1]-(t.length-1)*d)/r.sum(t,u)});s.forEach(function(e){e.forEach(function(e,n){e.y=n,e.dy=e.value*t})}),g.forEach(function(e){e.dy=e.value*t})}function n(t){function e(t){return(t.source.y+t.sy+t.dy/2)*t.value}s.forEach(function(n,o){n.forEach(function(n){if(n.targetLinks.length){var o=r.sum(n.targetLinks,e)/r.sum(n.targetLinks,u);n.y+=(o-x(n))*t}})})}function o(t){function e(t){return(t.target.y+t.ty+t.dy/2)*t.value}s.slice().reverse().forEach(function(n){n.forEach(function(n){if(n.sourceLinks.length){var o=r.sum(n.sourceLinks,e)/r.sum(n.sourceLinks,u);n.y+=(o-x(n))*t}})})}function i(){s.forEach(function(t){var e,n,r,o=0,i=t.length;for(t.sort(a),r=0;r<i;++r)e=t[r],n=o-e.y,n>0&&(e.y+=n),o=e.y+e.dy+d;if(n=o-d-p[1],n>0)for(o=e.y-=n,r=i-2;r>=0;--r)e=t[r],n=e.y+e.dy+d-o,n>0&&(e.y-=n),o=e.y})}function a(t,e){return t.y-e.y}var s=r.nest().key(function(t){return t.x}).sortKeys(r.ascending).entries(h).map(function(t){return t.values});e(),i(),l();for(var c=1;t>0;--t)o(c*=.99),i(),l(),n(c),i(),l()}function l(){function t(t,e){return t.source.y-e.source.y}function e(t,e){return t.target.y-e.target.y}h.forEach(function(n){n.sourceLinks.sort(e),n.targetLinks.sort(t)}),h.forEach(function(t){var e=0,n=0;t.sourceLinks.forEach(function(t){t.sy=e,e+=t.dy}),t.targetLinks.forEach(function(t){t.ty=n,n+=t.dy})})}function u(t){return t.value}var c={},f=24,d=8,p=[1,1],h=[],g=[],v=!0,m=function(r){t(),e(),n(),s(r)},y=function(){l()},b=function(){function t(t){var n=t.source.x+t.source.dx,o=t.target.x,i=r.interpolateNumber(n,o),a=i(e),s=i(1-e),l=t.source.y+t.sy+t.dy/2,u=t.target.y+t.ty+t.dy/2,c="M"+n+","+l+"C"+a+","+l+" "+s+","+u+" "+o+","+u;return c}var e=.5;return t.curvature=function(n){return arguments.length?(e=+n,t):e},t},x=function(t){return t.y+t.dy/2};return c.options=o.utils.optionsFunc.bind(c),c._options=Object.create({},{nodeWidth:{get:function(){return f},set:function(t){f=+t}},nodePadding:{get:function(){return d},set:function(t){d=t}},nodes:{get:function(){return h},set:function(t){h=t}},links:{get:function(){return g},set:function(t){g=t}},size:{get:function(){return p},set:function(t){p=t}},sinksRight:{get:function(){return v},set:function(t){v=t}},layout:{get:function(){m(32)},set:function(t){m(t)}},relayout:{get:function(){y()},set:function(t){}},center:{get:function(){return x()},set:function(t){"function"==typeof t&&(x=t)}},link:{get:function(){return b()},set:function(t){return"function"==typeof t&&(b=t),b()}}}),o.utils.initOptions(c),c},o.models.sankeyChart=function(){"use strict";function t(e){return e.each(function(t){function o(t){r.select(this).attr("transform","translate("+t.x+","+(t.y=Math.max(0,Math.min(a-t.dy,r.event.y)))+")"),n.relayout(),x.attr("d",b)}var u={nodes:[{node:1,name:"Test 1"},{node:2,name:"Test 2"},{node:3,name:"Test 3"},{node:4,name:"Test 4"},{node:5,name:"Test 5"},{node:6,name:"Test 6"}],links:[{source:0,target:1,value:2295},{source:0,target:5,value:1199},{source:1,target:2,value:1119},{source:1,target:5,value:1176},{source:2,target:3,value:487},{source:2,target:5,value:632},{source:3,target:4,value:301},{source:3,target:5,value:186}]},f=!1,d=!1;if(("object"==typeof t.nodes&&t.nodes.length)>=0&&("object"==typeof t.links&&t.links.length)>=0&&(f=!0),t.nodes&&t.nodes.length>0&&t.links&&t.links.length>0&&(d=!0),!f)return console.error("NVD3 Sankey chart error:","invalid data format for",t),console.info("Valid data format is: ",u,JSON.stringify(u)),y(e,"Error loading chart, data is invalid"),!1;if(!d)return y(e,"No data available"),!1;var p=e.append("svg").attr("width",i).attr("height",a).append("g").attr("class","nvd3 nv-wrap nv-sankeyChart");n.nodeWidth(s).nodePadding(l).size([i,a]);var b=n.link();n.nodes(t.nodes).links(t.links).layout(32).center(c);var x=p.append("g").selectAll(".link").data(t.links).enter().append("path").attr("class","link").attr("d",b).style("stroke-width",function(t){return Math.max(1,t.dy)}).sort(function(t,e){return e.dy-t.dy});x.append("title").text(h);var _=p.append("g").selectAll(".node").data(t.nodes).enter().append("g").attr("class","node").attr("transform",function(t){return"translate("+t.x+","+t.y+")"}).call(r.behavior.drag().origin(function(t){return t}).on("dragstart",function(){this.parentNode.appendChild(this)}).on("drag",o));_.append("rect").attr("height",function(t){return t.dy}).attr("width",n.nodeWidth()).style("fill",g).style("stroke",v).append("title").text(m),_.append("text").attr("x",-6).attr("y",function(t){return t.dy/2}).attr("dy",".35em").attr("text-anchor","end").attr("transform",null).text(function(t){return t.name}).filter(function(t){return t.x<i/2}).attr("x",6+n.nodeWidth()).attr("text-anchor","start")}),t}var e={top:5,right:0,bottom:5,left:0},n=o.models.sankey(),i=600,a=400,s=36,l=40,u="units",c=void 0,f=r.format(",.0f"),d=function(t){return f(t)+" "+u},p=r.scale.category20(),h=function(t){return t.source.name+" → "+t.target.name+"\n"+d(t.value)},g=function(t){return t.color=p(t.name.replace(/ .*/,""))},v=function(t){return r.rgb(t.color).darker(2)},m=function(t){return t.name+"\n"+d(t.value)},y=function(t,e){t.append("text").attr("x",0).attr("y",0).attr("class","nvd3-sankey-chart-error").attr("text-anchor","middle").text(e)};return t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{units:{get:function(){return u},set:function(t){u=t}},width:{get:function(){return i},set:function(t){i=t}},height:{get:function(){return a},set:function(t){a=t}},format:{get:function(){return d},set:function(t){d=t}},linkTitle:{get:function(){return h},set:function(t){h=t}},nodeWidth:{get:function(){return s},set:function(t){s=t}},nodePadding:{get:function(){return l},set:function(t){l=t}},center:{get:function(){return c},set:function(t){c=t}},margin:{get:function(){return e},set:function(t){e.top=void 0!==t.top?t.top:e.top,e.right=void 0!==t.right?t.right:e.right,e.bottom=void 0!==t.bottom?t.bottom:e.bottom,e.left=void 0!==t.left?t.left:e.left}},nodeStyle:{get:function(){return{}},set:function(t){g=void 0!==t.fillColor?t.fillColor:g,v=void 0!==t.strokeColor?t.strokeColor:v,m=void 0!==t.title?t.title:m}}}),o.utils.initOptions(t),t},o.models.scatter=function(){"use strict";function t(t){var e,n;return e=t[0].series+":"+t[1],n=J[e]=J[e]||{}}function e(t){var e;e=t[0].series+":"+t[1],delete J[e]}function n(e){var n,r,o,i=t(e),a=!1;for(n=1;n<arguments.length;n+=2)r=arguments[n],o=arguments[n+1](e[0],e[1]),i[r]===o&&i.hasOwnProperty(r)||(i[r]=o,a=!0);return a}function i(t){return $.reset(),t.each(function(t){function K(){if(X=!1,!M)return!1;if(V===!0){var e=r.merge(t.map(function(t,e){return t.values.map(function(t,n){var r=w(t,n),i=T(t,n);return[o.utils.NaNtoZero(b(r))+1e-4*Math.random(),o.utils.NaNtoZero(x(i))+1e-4*Math.random(),e,n,t]}).filter(function(t,e){return N(t[4],e)})}));if(0==e.length)return!1;e.length<3&&(e.push([b.range()[0]-20,x.range()[0]-20,null,null]),e.push([b.range()[1]+20,x.range()[1]+20,null,null]),e.push([b.range()[0]-20,x.range()[0]+20,null,null]),e.push([b.range()[1]+20,x.range()[1]-20,null,null]));var n=r.geom.polygon([[-10,-10],[-10,h+10],[p+10,h+10],[p+10,-10]]),i=r.geom.voronoi(e).map(function(t,r){return{data:n.clip(t),series:e[r][2],point:e[r][3]}});it.select(".nv-point-paths").selectAll("path").remove();var a=it.select(".nv-point-paths").selectAll("path").data(i),s=a.enter().append("svg:path").attr("d",function(t){return t&&t.data&&0!==t.data.length?"M"+t.data.join(",")+"Z":"M 0 0"}).attr("id",function(t,e){return"nv-path-"+e}).attr("clip-path",function(t,e){return"url(#nv-clip-"+m+"-"+e+")"});if(R&&s.style("fill",r.rgb(230,230,230)).style("fill-opacity",.4).style("stroke-opacity",1).style("stroke",r.rgb(200,200,200)),I){it.select(".nv-point-clips").selectAll("*").remove();var l=it.select(".nv-point-clips").selectAll("clipPath").data(e);l.enter().append("svg:clipPath").attr("id",function(t,e){return"nv-clip-"+m+"-"+e}).append("svg:circle").attr("cx",function(t){return t[0]}).attr("cy",function(t){return t[1]}).attr("r",L)}var u=function(e,n,o){if(X)return 0;var i=t[n.series];if(void 0!==i){var a=i.values[n.point];a.color=g(i,n.series),a.x=w(a),a.y=T(a);var s=y.node().getBoundingClientRect(),l=window.pageYOffset||document.documentElement.scrollTop,u=window.pageXOffset||document.documentElement.scrollLeft,c={left:b(w(a,n.point))+s.left+u+d.left+10,top:x(T(a,n.point))+s.top+l+d.top+10};o({point:a,series:i,pos:c,relativePos:[b(w(a,n.point))+d.left,x(T(a,n.point))+d.top],seriesIndex:n.series,pointIndex:n.point,event:r.event,element:e})}};a.on("click",function(t){u(this,t,q.elementClick)}).on("dblclick",function(t){u(this,t,q.elementDblClick)}).on("mouseover",function(t){u(this,t,q.elementMouseover)}).on("mouseout",function(t,e){u(this,t,q.elementMouseout)})}else it.select(".nv-groups").selectAll(".nv-group").selectAll(".nv-point").on("click",function(e,n){if(X||!t[e.series])return 0;var o=t[e.series],i=o.values[n],a=this;q.elementClick({point:i,series:o,pos:[b(w(i,n))+d.left,x(T(i,n))+d.top],relativePos:[b(w(i,n))+d.left,x(T(i,n))+d.top],seriesIndex:e.series,pointIndex:n,event:r.event,element:a})}).on("dblclick",function(e,n){if(X||!t[e.series])return 0;var r=t[e.series],o=r.values[n];q.elementDblClick({point:o,series:r,pos:[b(w(o,n))+d.left,x(T(o,n))+d.top],relativePos:[b(w(o,n))+d.left,x(T(o,n))+d.top],seriesIndex:e.series,pointIndex:n})}).on("mouseover",function(e,n){if(X||!t[e.series])return 0;var r=t[e.series],o=r.values[n];q.elementMouseover({point:o,series:r,pos:[b(w(o,n))+d.left,x(T(o,n))+d.top],relativePos:[b(w(o,n))+d.left,x(T(o,n))+d.top],seriesIndex:e.series,pointIndex:n,color:g(e,n)})}).on("mouseout",function(e,n){if(X||!t[e.series])return 0;var r=t[e.series],o=r.values[n];q.elementMouseout({point:o,series:r,pos:[b(w(o,n))+d.left,x(T(o,n))+d.top],relativePos:[b(w(o,n))+d.left,x(T(o,n))+d.top],seriesIndex:e.series,pointIndex:n,color:g(e,n)})})}y=r.select(this);var J=o.utils.availableWidth(p,y,d),Q=o.utils.availableHeight(h,y,d);o.utils.initSVG(y),t.forEach(function(t,e){t.values.forEach(function(t){t.series=e})});var tt=i.yScale().name===r.scale.log().name,et=F&&j&&H?[]:r.merge(t.map(function(t){return t.values.map(function(t,e){return{x:w(t,e),y:T(t,e),size:C(t,e)}})}));if(b.domain(F||r.extent(et.map(function(t){return t.x}).concat(E))),A&&t[0]?b.range(B||[(J*O+J)/(2*t[0].values.length),J-J*(1+O)/(2*t[0].values.length)]):b.range(B||[0,J]),tt){var nt=r.min(et.map(function(t){if(0!==t.y)return t.y}));x.clamp(!0).domain(j||r.extent(et.map(function(t){return 0!==t.y?t.y:.1*nt}).concat(P))).range(U||[Q,0])}else x.domain(j||r.extent(et.map(function(t){return t.y}).concat(P))).range(U||[Q,0]);_.domain(H||r.extent(et.map(function(t){return t.size}).concat(S))).range(z||Z),W=b.domain()[0]===b.domain()[1]||x.domain()[0]===x.domain()[1],b.domain()[0]===b.domain()[1]&&(b.domain()[0]?b.domain([b.domain()[0]-.01*b.domain()[0],b.domain()[1]+.01*b.domain()[1]]):b.domain([-1,1])),x.domain()[0]===x.domain()[1]&&(x.domain()[0]?x.domain([x.domain()[0]-.01*x.domain()[0],x.domain()[1]+.01*x.domain()[1]]):x.domain([-1,1])),isNaN(b.domain()[0])&&b.domain([-1,1]),isNaN(x.domain()[0])&&x.domain([-1,1]),a=a||b,s=s||x,l=l||_;var rt=b(1)!==a(1)||x(1)!==s(1)||_(1)!==l(1);u=u||p,c=c||h;var ot=u!==p||c!==h,it=y.selectAll("g.nv-wrap.nv-scatter").data([t]),at=it.enter().append("g").attr("class","nvd3 nv-wrap nv-scatter nv-chart-"+m),st=at.append("defs"),lt=at.append("g"),ut=it.select("g");it.classed("nv-single-point",W),lt.append("g").attr("class","nv-groups"),lt.append("g").attr("class","nv-point-paths"),at.append("g").attr("class","nv-point-clips"),it.attr("transform","translate("+d.left+","+d.top+")"),st.append("clipPath").attr("id","nv-edge-clip-"+m).append("rect").attr("transform","translate( -10, -10)"),it.select("#nv-edge-clip-"+m+" rect").attr("width",J+20).attr("height",Q>0?Q+20:0),ut.attr("clip-path",D?"url(#nv-edge-clip-"+m+")":""),X=!0;var ct=it.select(".nv-groups").selectAll(".nv-group").data(function(t){return t},function(t){return t.key});ct.enter().append("g").style("stroke-opacity",1e-6).style("fill-opacity",1e-6),ct.exit().remove(),ct.attr("class",function(t,e){return(t.classed||"")+" nv-group nv-series-"+e}).classed("nv-noninteractive",!M).classed("hover",function(t){return t.hover}),ct.watchTransition($,"scatter: groups").style("fill",function(t,e){return g(t,e)}).style("stroke",function(t,e){return t.pointBorderColor||v||g(t,e)}).style("stroke-opacity",1).style("fill-opacity",.5);var ft=ct.selectAll("path.nv-point").data(function(t){return t.values.map(function(t,e){return[t,e]}).filter(function(t,e){return N(t[0],e)})});if(ft.enter().append("path").attr("class",function(t){return"nv-point nv-point-"+t[1]}).style("fill",function(t){return t.color}).style("stroke",function(t){return t.color}).attr("transform",function(t){return"translate("+o.utils.NaNtoZero(a(w(t[0],t[1])))+","+o.utils.NaNtoZero(s(T(t[0],t[1])))+")"}).attr("d",o.utils.symbol().type(function(t){return k(t[0])}).size(function(t){return _(C(t[0],t[1]))})),ft.exit().each(e).remove(),ct.exit().selectAll("path.nv-point").watchTransition($,"scatter exit").attr("transform",function(t){return"translate("+o.utils.NaNtoZero(b(w(t[0],t[1])))+","+o.utils.NaNtoZero(x(T(t[0],t[1])))+")"}).remove(),ft.filter(function(t){return rt||ot||n(t,"x",w,"y",T)}).watchTransition($,"scatter points").attr("transform",function(t){return"translate("+o.utils.NaNtoZero(b(w(t[0],t[1])))+","+o.utils.NaNtoZero(x(T(t[0],t[1])))+")"}),ft.filter(function(t){return rt||ot||n(t,"shape",k,"size",C)}).watchTransition($,"scatter points").attr("d",o.utils.symbol().type(function(t){return k(t[0])}).size(function(t){return _(C(t[0],t[1]))})),G){var dt=ct.selectAll(".nv-label").data(function(t){return t.values.map(function(t,e){return[t,e]}).filter(function(t,e){return N(t[0],e)})});dt.enter().append("text").style("fill",function(t,e){return t.color}).style("stroke-opacity",0).style("fill-opacity",1).attr("transform",function(t){var e=o.utils.NaNtoZero(a(w(t[0],t[1])))+Math.sqrt(_(C(t[0],t[1]))/Math.PI)+2;return"translate("+e+","+o.utils.NaNtoZero(s(T(t[0],t[1])))+")"}).text(function(t,e){return t[0].label}),dt.exit().remove(),ct.exit().selectAll("path.nv-label").watchTransition($,"scatter exit").attr("transform",function(t){var e=o.utils.NaNtoZero(b(w(t[0],t[1])))+Math.sqrt(_(C(t[0],t[1]))/Math.PI)+2;return"translate("+e+","+o.utils.NaNtoZero(x(T(t[0],t[1])))+")"}).remove(),dt.each(function(t){r.select(this).classed("nv-label",!0).classed("nv-label-"+t[1],!1).classed("hover",!1)}),dt.watchTransition($,"scatter labels").attr("transform",function(t){var e=o.utils.NaNtoZero(b(w(t[0],t[1])))+Math.sqrt(_(C(t[0],t[1]))/Math.PI)+2;return"translate("+e+","+o.utils.NaNtoZero(x(T(t[0],t[1])))+")"})}Y?(clearTimeout(f),f=setTimeout(K,Y)):K(),a=b.copy(),s=x.copy(),l=_.copy(),u=p,c=h}),$.renderEnd("scatter immediate"),i}var a,s,l,u,c,f,d={top:0,right:0,bottom:0,left:0},p=null,h=null,g=o.utils.defaultColor(),v=null,m=Math.floor(1e5*Math.random()),y=null,b=r.scale.linear(),x=r.scale.linear(),_=r.scale.linear(),w=function(t){return t.x},T=function(t){return t.y},C=function(t){return t.size||1},k=function(t){return t.shape||"circle"},E=[],P=[],S=[],M=!0,N=function(t){return!t.notActive},A=!1,O=.1,D=!1,I=!0,R=!1,L=function(){return 25},F=null,j=null,B=null,U=null,H=null,z=null,W=!1,q=r.dispatch("elementClick","elementDblClick","elementMouseover","elementMouseout","renderEnd"),V=!0,K=250,Y=300,G=!1,X=!1,$=o.utils.renderWatch(q,K),Z=[16,256],J={};return i.dispatch=q,i.options=o.utils.optionsFunc.bind(i),i._calls=new function(){this.clearHighlights=function(){return o.dom.write(function(){y.selectAll(".nv-point.hover").classed("hover",!1)}),null},this.highlightPoint=function(t,e,n){o.dom.write(function(){y.select(".nv-groups").selectAll(".nv-series-"+t).selectAll(".nv-point-"+e).classed("hover",n)})}},q.on("elementMouseover.point",function(t){M&&i._calls.highlightPoint(t.seriesIndex,t.pointIndex,!0)}),q.on("elementMouseout.point",function(t){M&&i._calls.highlightPoint(t.seriesIndex,t.pointIndex,!1)}),i._options=Object.create({},{width:{get:function(){return p},set:function(t){p=t}},height:{get:function(){return h},set:function(t){h=t}},xScale:{get:function(){return b},set:function(t){b=t}},yScale:{get:function(){return x},set:function(t){x=t}},pointScale:{get:function(){return _},set:function(t){_=t}},xDomain:{get:function(){return F},set:function(t){F=t}},yDomain:{get:function(){return j},set:function(t){j=t}},pointDomain:{get:function(){return H},set:function(t){H=t}},xRange:{get:function(){return B},set:function(t){B=t}},yRange:{get:function(){return U},set:function(t){U=t}},pointRange:{get:function(){return z},set:function(t){z=t}},forceX:{get:function(){return E},set:function(t){E=t}},forceY:{get:function(){return P},set:function(t){P=t}},forcePoint:{get:function(){return S},set:function(t){S=t}},interactive:{get:function(){return M},set:function(t){M=t}},pointActive:{get:function(){return N},set:function(t){N=t}},padDataOuter:{get:function(){return O},set:function(t){O=t}},padData:{get:function(){return A},set:function(t){A=t}},clipEdge:{get:function(){return D},set:function(t){D=t}},clipVoronoi:{get:function(){return I},set:function(t){I=t}},clipRadius:{get:function(){return L},set:function(t){L=t}},showVoronoi:{get:function(){return R},set:function(t){R=t}},id:{get:function(){return m},set:function(t){m=t}},interactiveUpdateDelay:{get:function(){return Y},set:function(t){Y=t}},showLabels:{get:function(){return G},set:function(t){G=t}},pointBorderColor:{get:function(){return v},set:function(t){v=t}},x:{get:function(){return w},set:function(t){w=r.functor(t)}},y:{get:function(){return T},set:function(t){T=r.functor(t)}},pointSize:{get:function(){return C},set:function(t){C=r.functor(t)}},pointShape:{get:function(){return k},set:function(t){k=r.functor(t)}},margin:{get:function(){return d},set:function(t){d.top=void 0!==t.top?t.top:d.top,d.right=void 0!==t.right?t.right:d.right,d.bottom=void 0!==t.bottom?t.bottom:d.bottom,d.left=void 0!==t.left?t.left:d.left}},duration:{get:function(){return K},set:function(t){K=t,$.reset(K)}},color:{get:function(){return g},set:function(t){g=o.utils.getColor(t)}},useVoronoi:{get:function(){return V},set:function(t){V=t,V===!1&&(I=!1)}}}),o.utils.initOptions(i),i},o.models.scatterChart=function(){"use strict";function t(P){return O.reset(),O.models(e),_&&O.models(n),w&&O.models(i),y&&O.models(s),b&&O.models(l),P.each(function(P){h=r.select(this),o.utils.initSVG(h);var R=o.utils.availableWidth(d,h,c),L=o.utils.availableHeight(p,h,c);if(t.update=function(){0===S?h.call(t):h.transition().duration(S).call(t)},t.container=this,C.setter(I(P),t.update).getter(D(P)).update(),C.disabled=P.map(function(t){return!!t.disabled}),!k){var F;k={};for(F in C)C[F]instanceof Array?k[F]=C[F].slice(0):k[F]=C[F]}if(!(P&&P.length&&P.filter(function(t){return t.values.length}).length))return o.utils.noData(t,h),O.renderEnd("scatter immediate"),t;h.selectAll(".nv-noData").remove(),v=e.xScale(),m=e.yScale();var j=h.selectAll("g.nv-wrap.nv-scatterChart").data([P]),B=j.enter().append("g").attr("class","nvd3 nv-wrap nv-scatterChart nv-chart-"+e.id()),U=B.append("g"),H=j.select("g");if(U.append("rect").attr("class","nvd3 nv-background").style("pointer-events","none"),U.append("g").attr("class","nv-x nv-axis"),U.append("g").attr("class","nv-y nv-axis"),U.append("g").attr("class","nv-scatterWrap"),U.append("g").attr("class","nv-regressionLinesWrap"),U.append("g").attr("class","nv-distWrap"),U.append("g").attr("class","nv-legendWrap"),T&&H.select(".nv-y.nv-axis").attr("transform","translate("+R+",0)"),x){var z=R;a.width(z),j.select(".nv-legendWrap").datum(P).call(a),f||a.height()===c.top||(c.top=a.height(),L=o.utils.availableHeight(p,h,c)),j.select(".nv-legendWrap").attr("transform","translate(0,"+-c.top+")")}else H.select(".nv-legendWrap").selectAll("*").remove();j.attr("transform","translate("+c.left+","+c.top+")"),e.width(R).height(L).color(P.map(function(t,e){return t.color=t.color||g(t,e),t.color}).filter(function(t,e){return!P[e].disabled})).showLabels(M),j.select(".nv-scatterWrap").datum(P.filter(function(t){return!t.disabled})).call(e),j.select(".nv-regressionLinesWrap").attr("clip-path","url(#nv-edge-clip-"+e.id()+")");
var W=j.select(".nv-regressionLinesWrap").selectAll(".nv-regLines").data(function(t){return t});W.enter().append("g").attr("class","nv-regLines");var q=W.selectAll(".nv-regLine").data(function(t){return[t]});q.enter().append("line").attr("class","nv-regLine").style("stroke-opacity",0),q.filter(function(t){return t.intercept&&t.slope}).watchTransition(O,"scatterPlusLineChart: regline").attr("x1",v.range()[0]).attr("x2",v.range()[1]).attr("y1",function(t,e){return m(v.domain()[0]*t.slope+t.intercept)}).attr("y2",function(t,e){return m(v.domain()[1]*t.slope+t.intercept)}).style("stroke",function(t,e,n){return g(t,n)}).style("stroke-opacity",function(t,e){return t.disabled||"undefined"==typeof t.slope||"undefined"==typeof t.intercept?0:1}),_&&(n.scale(v)._ticks(o.utils.calcTicksX(R/100,P)).tickSize(-L,0),H.select(".nv-x.nv-axis").attr("transform","translate(0,"+m.range()[0]+")").call(n)),w&&(i.scale(m)._ticks(o.utils.calcTicksY(L/36,P)).tickSize(-R,0),H.select(".nv-y.nv-axis").call(i)),y&&(s.getData(e.x()).scale(v).width(R).color(P.map(function(t,e){return t.color||g(t,e)}).filter(function(t,e){return!P[e].disabled})),U.select(".nv-distWrap").append("g").attr("class","nv-distributionX"),H.select(".nv-distributionX").attr("transform","translate(0,"+m.range()[0]+")").datum(P.filter(function(t){return!t.disabled})).call(s)),b&&(l.getData(e.y()).scale(m).width(L).color(P.map(function(t,e){return t.color||g(t,e)}).filter(function(t,e){return!P[e].disabled})),U.select(".nv-distWrap").append("g").attr("class","nv-distributionY"),H.select(".nv-distributionY").attr("transform","translate("+(T?R:-l.size())+",0)").datum(P.filter(function(t){return!t.disabled})).call(l)),a.dispatch.on("stateChange",function(e){for(var n in e)C[n]=e[n];E.stateChange(C),t.update()}),E.on("changeState",function(e){"undefined"!=typeof e.disabled&&(P.forEach(function(t,n){t.disabled=e.disabled[n]}),C.disabled=e.disabled),t.update()}),e.dispatch.on("elementMouseout.tooltip",function(t){u.hidden(!0),h.select(".nv-chart-"+e.id()+" .nv-series-"+t.seriesIndex+" .nv-distx-"+t.pointIndex).attr("y1",0),h.select(".nv-chart-"+e.id()+" .nv-series-"+t.seriesIndex+" .nv-disty-"+t.pointIndex).attr("x2",l.size())}),e.dispatch.on("elementMouseover.tooltip",function(t){h.select(".nv-series-"+t.seriesIndex+" .nv-distx-"+t.pointIndex).attr("y1",t.relativePos[1]-L),h.select(".nv-series-"+t.seriesIndex+" .nv-disty-"+t.pointIndex).attr("x2",t.relativePos[0]+s.size()),u.data(t).hidden(!1)}),N=v.copy(),A=m.copy()}),O.renderEnd("scatter with line immediate"),t}var e=o.models.scatter(),n=o.models.axis(),i=o.models.axis(),a=o.models.legend(),s=o.models.distribution(),l=o.models.distribution(),u=o.models.tooltip(),c={top:30,right:20,bottom:50,left:75},f=null,d=null,p=null,h=null,g=o.utils.defaultColor(),v=e.xScale(),m=e.yScale(),y=!1,b=!1,x=!0,_=!0,w=!0,T=!1,C=o.utils.state(),k=null,E=r.dispatch("stateChange","changeState","renderEnd"),P=null,S=250,M=!1;e.xScale(v).yScale(m),n.orient("bottom").tickPadding(10),i.orient(T?"right":"left").tickPadding(10),s.axis("x"),l.axis("y"),u.headerFormatter(function(t,e){return n.tickFormat()(t,e)}).valueFormatter(function(t,e){return i.tickFormat()(t,e)});var N,A,O=o.utils.renderWatch(E,S),D=function(t){return function(){return{active:t.map(function(t){return!t.disabled})}}},I=function(t){return function(e){void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}};return t.dispatch=E,t.scatter=e,t.legend=a,t.xAxis=n,t.yAxis=i,t.distX=s,t.distY=l,t.tooltip=u,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return d},set:function(t){d=t}},height:{get:function(){return p},set:function(t){p=t}},container:{get:function(){return h},set:function(t){h=t}},showDistX:{get:function(){return y},set:function(t){y=t}},showDistY:{get:function(){return b},set:function(t){b=t}},showLegend:{get:function(){return x},set:function(t){x=t}},showXAxis:{get:function(){return _},set:function(t){_=t}},showYAxis:{get:function(){return w},set:function(t){w=t}},defaultState:{get:function(){return k},set:function(t){k=t}},noData:{get:function(){return P},set:function(t){P=t}},duration:{get:function(){return S},set:function(t){S=t}},showLabels:{get:function(){return M},set:function(t){M=t}},margin:{get:function(){return c},set:function(t){void 0!==t.top&&(c.top=t.top,f=t.top),c.right=void 0!==t.right?t.right:c.right,c.bottom=void 0!==t.bottom?t.bottom:c.bottom,c.left=void 0!==t.left?t.left:c.left}},rightAlignYAxis:{get:function(){return T},set:function(t){T=t,i.orient(t?"right":"left")}},color:{get:function(){return g},set:function(t){g=o.utils.getColor(t),a.color(g),s.color(g),l.color(g)}}}),o.utils.inheritOptions(t,e),o.utils.initOptions(t),t},o.models.sparkline=function(){"use strict";function t(f){return x.reset(),f.each(function(t){var f=l-s.left-s.right,b=u-s.top-s.bottom;c=r.select(this),o.utils.initSVG(c),d.domain(e||r.extent(t,h)).range(i||[0,f]),p.domain(n||r.extent(t,g)).range(a||[b,0]);var x=c.selectAll("g.nv-wrap.nv-sparkline").data([t]),_=x.enter().append("g").attr("class","nvd3 nv-wrap nv-sparkline");_.append("g"),x.select("g");x.attr("transform","translate("+s.left+","+s.top+")");var w=x.selectAll("path").data(function(t){return[t]});w.enter().append("path"),w.exit().remove(),w.style("stroke",function(t,e){return t.color||v(t,e)}).attr("d",r.svg.line().x(function(t,e){return d(h(t,e))}).y(function(t,e){return p(g(t,e))}));var T=x.selectAll("circle.nv-point").data(function(t){function e(e){if(e!=-1){var n=t[e];return n.pointIndex=e,n}return null}var n=t.map(function(t,e){return g(t,e)}),r=e(n.lastIndexOf(p.domain()[1])),o=e(n.indexOf(p.domain()[0])),i=e(n.length-1);return[m?o:null,m?r:null,y?i:null].filter(function(t){return null!=t})});T.enter().append("circle"),T.exit().remove(),T.attr("cx",function(t,e){return d(h(t,t.pointIndex))}).attr("cy",function(t,e){return p(g(t,t.pointIndex))}).attr("r",2).attr("class",function(t,e){return h(t,t.pointIndex)==d.domain()[1]?"nv-point nv-currentValue":g(t,t.pointIndex)==p.domain()[0]?"nv-point nv-minValue":"nv-point nv-maxValue"})}),x.renderEnd("sparkline immediate"),t}var e,n,i,a,s={top:2,right:0,bottom:2,left:0},l=400,u=32,c=null,f=!0,d=r.scale.linear(),p=r.scale.linear(),h=function(t){return t.x},g=function(t){return t.y},v=o.utils.getColor(["#000"]),m=!0,y=!0,b=r.dispatch("renderEnd"),x=o.utils.renderWatch(b);return t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return l},set:function(t){l=t}},height:{get:function(){return u},set:function(t){u=t}},xDomain:{get:function(){return e},set:function(t){e=t}},yDomain:{get:function(){return n},set:function(t){n=t}},xRange:{get:function(){return i},set:function(t){i=t}},yRange:{get:function(){return a},set:function(t){a=t}},xScale:{get:function(){return d},set:function(t){d=t}},yScale:{get:function(){return p},set:function(t){p=t}},animate:{get:function(){return f},set:function(t){f=t}},showMinMaxPoints:{get:function(){return m},set:function(t){m=t}},showCurrentPoint:{get:function(){return y},set:function(t){y=t}},x:{get:function(){return h},set:function(t){h=r.functor(t)}},y:{get:function(){return g},set:function(t){g=r.functor(t)}},margin:{get:function(){return s},set:function(t){s.top=void 0!==t.top?t.top:s.top,s.right=void 0!==t.right?t.right:s.right,s.bottom=void 0!==t.bottom?t.bottom:s.bottom,s.left=void 0!==t.left?t.left:s.left}},color:{get:function(){return v},set:function(t){v=o.utils.getColor(t)}}}),t.dispatch=b,o.utils.initOptions(t),t},o.models.sparklinePlus=function(){"use strict";function t(v){return y.reset(),y.models(i),v.each(function(v){function m(){if(!c){var t=E.selectAll(".nv-hoverValue").data(u),n=t.enter().append("g").attr("class","nv-hoverValue").style("stroke-opacity",0).style("fill-opacity",0);t.exit().transition().duration(250).style("stroke-opacity",0).style("fill-opacity",0).remove(),t.attr("transform",function(t){return"translate("+e(i.x()(v[t],t))+",0)"}).transition().duration(250).style("stroke-opacity",1).style("fill-opacity",1),u.length&&(n.append("line").attr("x1",0).attr("y1",-a.top).attr("x2",0).attr("y2",_),n.append("text").attr("class","nv-xValue").attr("x",-6).attr("y",-a.top).attr("text-anchor","end").attr("dy",".9em"),E.select(".nv-hoverValue .nv-xValue").text(f(i.x()(v[u[0]],u[0]))),n.append("text").attr("class","nv-yValue").attr("x",6).attr("y",-a.top).attr("text-anchor","start").attr("dy",".9em"),E.select(".nv-hoverValue .nv-yValue").text(d(i.y()(v[u[0]],u[0]))))}}function y(){function t(t,e){for(var n=Math.abs(i.x()(t[0],0)-e),r=0,o=0;o<t.length;o++)Math.abs(i.x()(t[o],o)-e)<n&&(n=Math.abs(i.x()(t[o],o)-e),r=o);return r}if(!c){var n=r.mouse(this)[0]-a.left;u=[t(v,Math.round(e.invert(n)))],m()}}var b=r.select(this);o.utils.initSVG(b);var x=o.utils.availableWidth(s,b,a),_=o.utils.availableHeight(l,b,a);if(t.update=function(){b.call(t)},t.container=this,!v||!v.length)return o.utils.noData(t,b),t;b.selectAll(".nv-noData").remove();var w=i.y()(v[v.length-1],v.length-1);e=i.xScale(),n=i.yScale();var T=b.selectAll("g.nv-wrap.nv-sparklineplus").data([v]),C=T.enter().append("g").attr("class","nvd3 nv-wrap nv-sparklineplus"),k=C.append("g"),E=T.select("g");k.append("g").attr("class","nv-sparklineWrap"),k.append("g").attr("class","nv-valueWrap"),k.append("g").attr("class","nv-hoverArea"),T.attr("transform","translate("+a.left+","+a.top+")");var P=E.select(".nv-sparklineWrap");if(i.width(x).height(_),P.call(i),p){var S=E.select(".nv-valueWrap"),M=S.selectAll(".nv-currentValue").data([w]);M.enter().append("text").attr("class","nv-currentValue").attr("dx",g?-8:8).attr("dy",".9em").style("text-anchor",g?"end":"start"),M.attr("x",x+(g?a.right:0)).attr("y",h?function(t){return n(t)}:0).style("fill",i.color()(v[v.length-1],v.length-1)).text(d(w))}k.select(".nv-hoverArea").append("rect").on("mousemove",y).on("click",function(){c=!c}).on("mouseout",function(){u=[],m()}),E.select(".nv-hoverArea rect").attr("transform",function(t){return"translate("+-a.left+","+-a.top+")"}).attr("width",x+a.left+a.right).attr("height",_+a.top)}),y.renderEnd("sparklinePlus immediate"),t}var e,n,i=o.models.sparkline(),a={top:15,right:100,bottom:10,left:50},s=null,l=null,u=[],c=!1,f=r.format(",r"),d=r.format(",.2f"),p=!0,h=!0,g=!1,v=null,m=r.dispatch("renderEnd"),y=o.utils.renderWatch(m);return t.dispatch=m,t.sparkline=i,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return s},set:function(t){s=t}},height:{get:function(){return l},set:function(t){l=t}},xTickFormat:{get:function(){return f},set:function(t){f=t}},yTickFormat:{get:function(){return d},set:function(t){d=t}},showLastValue:{get:function(){return p},set:function(t){p=t}},alignValue:{get:function(){return h},set:function(t){h=t}},rightAlignValue:{get:function(){return g},set:function(t){g=t}},noData:{get:function(){return v},set:function(t){v=t}},margin:{get:function(){return a},set:function(t){a.top=void 0!==t.top?t.top:a.top,a.right=void 0!==t.right?t.right:a.right,a.bottom=void 0!==t.bottom?t.bottom:a.bottom,a.left=void 0!==t.left?t.left:a.left}}}),o.utils.inheritOptions(t,i),o.utils.initOptions(t),t},o.models.stackedArea=function(){"use strict";function t(h){return w.reset(),w.models(b),h.each(function(h){var x=a-i.left-i.right,T=s-i.top-i.bottom;c=r.select(this),o.utils.initSVG(c),e=b.xScale(),n=b.yScale();var C=h;h.forEach(function(t,e){t.seriesIndex=e,t.values=t.values.map(function(t,n){return t.index=n,t.seriesIndex=e,t})});var k=h.filter(function(t){return!t.disabled});h=r.layout.stack().order(v).offset(g).values(function(t){return t.values}).x(f).y(d).out(function(t,e,n){t.display={y:n,y0:e}})(k);var E=c.selectAll("g.nv-wrap.nv-stackedarea").data([h]),P=E.enter().append("g").attr("class","nvd3 nv-wrap nv-stackedarea"),S=P.append("defs"),M=P.append("g"),N=E.select("g");M.append("g").attr("class","nv-areaWrap"),M.append("g").attr("class","nv-scatterWrap"),E.attr("transform","translate("+i.left+","+i.top+")"),0==b.forceY().length&&b.forceY().push(0),b.width(x).height(T).x(f).y(function(t){if(void 0!==t.display)return t.display.y+t.display.y0}).color(h.map(function(t,e){return t.color=t.color||l(t,t.seriesIndex),t.color}));var A=N.select(".nv-scatterWrap").datum(h);A.call(b),S.append("clipPath").attr("id","nv-edge-clip-"+u).append("rect"),E.select("#nv-edge-clip-"+u+" rect").attr("width",x).attr("height",T),N.attr("clip-path",y?"url(#nv-edge-clip-"+u+")":"");var O=r.svg.area().defined(p).x(function(t,n){return e(f(t,n))}).y0(function(t){return n(t.display.y0)}).y1(function(t){return n(t.display.y+t.display.y0)}).interpolate(m),D=r.svg.area().defined(p).x(function(t,n){return e(f(t,n))}).y0(function(t){return n(t.display.y0)}).y1(function(t){return n(t.display.y0)}),I=N.select(".nv-areaWrap").selectAll("path.nv-area").data(function(t){return t});I.enter().append("path").attr("class",function(t,e){return"nv-area nv-area-"+e}).attr("d",function(t,e){return D(t.values,t.seriesIndex)}).on("mouseover",function(t,e){r.select(this).classed("hover",!0),_.areaMouseover({point:t,series:t.key,pos:[r.event.pageX,r.event.pageY],seriesIndex:t.seriesIndex})}).on("mouseout",function(t,e){r.select(this).classed("hover",!1),_.areaMouseout({point:t,series:t.key,pos:[r.event.pageX,r.event.pageY],seriesIndex:t.seriesIndex})}).on("click",function(t,e){r.select(this).classed("hover",!1),_.areaClick({point:t,series:t.key,pos:[r.event.pageX,r.event.pageY],seriesIndex:t.seriesIndex})}),I.exit().remove(),I.style("fill",function(t,e){return t.color||l(t,t.seriesIndex)}).style("stroke",function(t,e){return t.color||l(t,t.seriesIndex)}),I.watchTransition(w,"stackedArea path").attr("d",function(t,e){return O(t.values,e)}),b.dispatch.on("elementMouseover.area",function(t){N.select(".nv-chart-"+u+" .nv-area-"+t.seriesIndex).classed("hover",!0)}),b.dispatch.on("elementMouseout.area",function(t){N.select(".nv-chart-"+u+" .nv-area-"+t.seriesIndex).classed("hover",!1)}),t.d3_stackedOffset_stackPercent=function(t){var e,n,r,o=t.length,i=t[0].length,a=[];for(n=0;n<i;++n){for(e=0,r=0;e<C.length;e++)r+=d(C[e].values[n]);if(r)for(e=0;e<o;e++)t[e][n][1]/=r;else for(e=0;e<o;e++)t[e][n][1]=0}for(n=0;n<i;++n)a[n]=0;return a}}),w.renderEnd("stackedArea immediate"),t}var e,n,i={top:0,right:0,bottom:0,left:0},a=960,s=500,l=o.utils.defaultColor(),u=Math.floor(1e5*Math.random()),c=null,f=function(t){return t.x},d=function(t){return t.y},p=function(t,e){return!isNaN(d(t,e))&&null!==d(t,e)},h="stack",g="zero",v="default",m="linear",y=!1,b=o.models.scatter(),x=250,_=r.dispatch("areaClick","areaMouseover","areaMouseout","renderEnd","elementClick","elementMouseover","elementMouseout");b.pointSize(2.2).pointDomain([2.2,2.2]);var w=o.utils.renderWatch(_,x);return t.dispatch=_,t.scatter=b,b.dispatch.on("elementClick",function(){_.elementClick.apply(this,arguments)}),b.dispatch.on("elementMouseover",function(){_.elementMouseover.apply(this,arguments)}),b.dispatch.on("elementMouseout",function(){_.elementMouseout.apply(this,arguments)}),t.interpolate=function(e){return arguments.length?(m=e,t):m},t.duration=function(e){return arguments.length?(x=e,w.reset(x),b.duration(x),t):x},t.dispatch=_,t.scatter=b,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return a},set:function(t){a=t}},height:{get:function(){return s},set:function(t){s=t}},defined:{get:function(){return p},set:function(t){p=t}},clipEdge:{get:function(){return y},set:function(t){y=t}},offset:{get:function(){return g},set:function(t){g=t}},order:{get:function(){return v},set:function(t){v=t}},interpolate:{get:function(){return m},set:function(t){m=t}},x:{get:function(){return f},set:function(t){f=r.functor(t)}},y:{get:function(){return d},set:function(t){d=r.functor(t)}},margin:{get:function(){return i},set:function(t){i.top=void 0!==t.top?t.top:i.top,i.right=void 0!==t.right?t.right:i.right,i.bottom=void 0!==t.bottom?t.bottom:i.bottom,i.left=void 0!==t.left?t.left:i.left}},color:{get:function(){return l},set:function(t){l=o.utils.getColor(t)}},style:{get:function(){return h},set:function(e){switch(h=e){case"stack":t.offset("zero"),t.order("default");break;case"stream":t.offset("wiggle"),t.order("inside-out");break;case"stream-center":t.offset("silhouette"),t.order("inside-out");break;case"expand":t.offset("expand"),t.order("default");break;case"stack_percent":t.offset(t.d3_stackedOffset_stackPercent),t.order("default")}}},duration:{get:function(){return x},set:function(t){x=t,w.reset(x),b.duration(x)}}}),o.utils.inheritOptions(t,b),o.utils.initOptions(t),t},o.models.stackedAreaChart=function(){"use strict";function t(f){return j.reset(),j.models(i),_&&j.models(a),w&&j.models(s),f.each(function(f){function N(){_&&$.select(".nv-focus .nv-x.nv-axis").attr("transform","translate(0,"+K+")").transition().duration(R).call(a)}function j(){if(w){if("expand"===i.style()||"stack_percent"===i.style()){var t=s.tickFormat();L&&t===z||(L=t),s.tickFormat(z)}else L&&(s.tickFormat(L),L=null);$.select(".nv-focus .nv-y.nv-axis").transition().duration(0).call(s)}}function W(t){var e=$.select(".nv-focus .nv-stackedWrap").datum(f.filter(function(t){return!t.disabled}).map(function(e,n){return{key:e.key,area:e.area,classed:e.classed,values:e.values.filter(function(e,n){return i.x()(e,n)>=t[0]&&i.x()(e,n)<=t[1]}),disableTooltip:e.disableTooltip}}));e.transition().duration(R).call(i),N(),j()}var q=r.select(this);o.utils.initSVG(q);var V=o.utils.availableWidth(g,q,p),K=o.utils.availableHeight(v,q,p)-(C?d.height():0);if(t.update=function(){q.transition().duration(R).call(t)},t.container=this,S.setter(H(f),t.update).getter(U(f)).update(),S.disabled=f.map(function(t){return!!t.disabled}),!M){var Y;M={};for(Y in S)S[Y]instanceof Array?M[Y]=S[Y].slice(0):M[Y]=S[Y]}if(!(f&&f.length&&f.filter(function(t){return t.values.length}).length))return o.utils.noData(t,q),t;q.selectAll(".nv-noData").remove(),e=i.xScale(),n=i.yScale();var G=q.selectAll("g.nv-wrap.nv-stackedAreaChart").data([f]),X=G.enter().append("g").attr("class","nvd3 nv-wrap nv-stackedAreaChart").append("g"),$=G.select("g");X.append("g").attr("class","nv-legendWrap"),X.append("g").attr("class","nv-controlsWrap");var Z=X.append("g").attr("class","nv-focus");Z.append("g").attr("class","nv-background").append("rect"),Z.append("g").attr("class","nv-x nv-axis"),Z.append("g").attr("class","nv-y nv-axis"),Z.append("g").attr("class","nv-stackedWrap"),Z.append("g").attr("class","nv-interactive");X.append("g").attr("class","nv-focusWrap");if(b){var J=y&&"top"===x?V-O:V;if(l.width(J),$.select(".nv-legendWrap").datum(f).call(l),"bottom"===x){var Q=(_?12:0)+10;p.bottom=Math.max(l.height()+Q,p.bottom),K=o.utils.availableHeight(v,q,p)-(C?d.height():0);var tt=K+Q;$.select(".nv-legendWrap").attr("transform","translate(0,"+tt+")")}else"top"===x&&(h||p.top==l.height()||(p.top=l.height(),K=o.utils.availableHeight(v,q,p)-(C?d.height():0)),$.select(".nv-legendWrap").attr("transform","translate("+(V-J)+","+-p.top+")"))}else $.select(".nv-legendWrap").selectAll("*").remove();if(y){var et=[{key:I.stacked||"Stacked",metaKey:"Stacked",disabled:"stack"!=i.style(),style:"stack"},{key:I.stream||"Stream",metaKey:"Stream",disabled:"stream"!=i.style(),style:"stream"},{key:I.expanded||"Expanded",metaKey:"Expanded",disabled:"expand"!=i.style(),style:"expand"},{key:I.stack_percent||"Stack %",metaKey:"Stack_Percent",disabled:"stack_percent"!=i.style(),style:"stack_percent"}];O=D.length/3*260,et=et.filter(function(t){return D.indexOf(t.metaKey)!==-1}),u.width(O).color(["#444","#444","#444"]),$.select(".nv-controlsWrap").datum(et).call(u);var nt=Math.max(u.height(),b&&"top"===x?l.height():0);p.top!=nt&&(p.top=nt,K=o.utils.availableHeight(v,q,p)-(C?d.height():0)),$.select(".nv-controlsWrap").attr("transform","translate(0,"+-p.top+")")}else $.select(".nv-controlsWrap").selectAll("*").remove();G.attr("transform","translate("+p.left+","+p.top+")"),T&&$.select(".nv-y.nv-axis").attr("transform","translate("+V+",0)"),k&&(c.width(V).height(K).margin({left:p.left,top:p.top}).svgContainer(q).xScale(e),G.select(".nv-interactive").call(c)),$.select(".nv-focus .nv-background rect").attr("width",V).attr("height",K),i.width(V).height(K).color(f.map(function(t,e){return t.color||m(t,e)}).filter(function(t,e){return!f[e].disabled}));var rt=$.select(".nv-focus .nv-stackedWrap").datum(f.filter(function(t){return!t.disabled}));if(_&&a.scale(e)._ticks(o.utils.calcTicksX(V/100,f)).tickSize(-K,0),w){var ot;ot="wiggle"===i.offset()?0:o.utils.calcTicksY(K/36,f),s.scale(n)._ticks(ot).tickSize(-V,0)}if(C){d.width(V),$.select(".nv-focusWrap").attr("transform","translate(0,"+(K+p.bottom+d.margin().top)+")").datum(f.filter(function(t){return!t.disabled})).call(d);var it=d.brush.empty()?d.xDomain():d.brush.extent();null!==it&&W(it)}else rt.transition().call(i),N(),j();i.dispatch.on("areaClick.toggle",function(e){1===f.filter(function(t){return!t.disabled}).length?f.forEach(function(t){t.disabled=!1}):f.forEach(function(t,n){t.disabled=n!=e.seriesIndex}),S.disabled=f.map(function(t){return!!t.disabled}),A.stateChange(S),t.update()}),l.dispatch.on("stateChange",function(e){for(var n in e)S[n]=e[n];A.stateChange(S),t.update()}),u.dispatch.on("legendClick",function(e,n){e.disabled&&(et=et.map(function(t){return t.disabled=!0,t}),e.disabled=!1,i.style(e.style),S.style=i.style(),A.stateChange(S),t.update())}),c.dispatch.on("elementMousemove",function(e){i.clearHighlights();var n,a,s,l=[],u=0,d=!0;if(f.filter(function(t,e){return t.seriesIndex=e,!t.disabled}).forEach(function(r,c){a=o.interactiveBisect(r.values,e.pointXValue,t.x());var f=r.values[a],p=t.y()(f,a);if(null!=p&&i.highlightPoint(c,a,!0),"undefined"!=typeof f){"undefined"==typeof n&&(n=f),"undefined"==typeof s&&(s=t.xScale()(t.x()(f,a)));var h="expand"==i.style()?f.display.y:t.y()(f,a);l.push({key:r.key,value:h,color:m(r,r.seriesIndex),point:f}),E&&"expand"!=i.style()&&null!=h&&(u+=h,d=!1)}}),l.reverse(),l.length>2){var p=t.yScale().invert(e.mouseY),h=null;l.forEach(function(t,e){p=Math.abs(p);var n=Math.abs(t.point.display.y0),r=Math.abs(t.point.display.y);if(p>=n&&p<=r+n)return void(h=e)}),null!=h&&(l[h].highlight=!0)}E&&"expand"!=i.style()&&l.length>=2&&!d&&l.push({key:P,value:u,total:!0});var g=t.x()(n,a),v=c.tooltip.valueFormatter();"expand"===i.style()||"stack_percent"===i.style()?(F||(F=v),v=r.format(".1%")):F&&(v=F,F=null),c.tooltip.valueFormatter(v).data({value:g,series:l})(),c.renderGuideLine(s)}),c.dispatch.on("elementMouseout",function(t){i.clearHighlights()}),d.dispatch.on("onBrush",function(t){W(t)}),A.on("changeState",function(e){"undefined"!=typeof e.disabled&&f.length===e.disabled.length&&(f.forEach(function(t,n){t.disabled=e.disabled[n]}),S.disabled=e.disabled),"undefined"!=typeof e.style&&(i.style(e.style),B=e.style),t.update()})}),j.renderEnd("stacked Area chart immediate"),t}var e,n,i=o.models.stackedArea(),a=o.models.axis(),s=o.models.axis(),l=o.models.legend(),u=o.models.legend(),c=o.interactiveGuideline(),f=o.models.tooltip(),d=o.models.focus(o.models.stackedArea()),p={top:10,right:25,bottom:50,left:60},h=null,g=null,v=null,m=o.utils.defaultColor(),y=!0,b=!0,x="top",_=!0,w=!0,T=!1,C=!1,k=!1,E=!0,P="TOTAL",S=o.utils.state(),M=null,N=null,A=r.dispatch("stateChange","changeState","renderEnd"),O=250,D=["Stacked","Stream","Expanded"],I={},R=250;S.style=i.style(),a.orient("bottom").tickPadding(7),s.orient(T?"right":"left"),f.headerFormatter(function(t,e){return a.tickFormat()(t,e)}).valueFormatter(function(t,e){return s.tickFormat()(t,e)}),c.tooltip.headerFormatter(function(t,e){return a.tickFormat()(t,e)}).valueFormatter(function(t,e){return null==t?"N/A":s.tickFormat()(t,e)});var L=null,F=null;u.updateState(!1);var j=o.utils.renderWatch(A),B=i.style(),U=function(t){return function(){return{active:t.map(function(t){return!t.disabled}),style:i.style()}}},H=function(t){return function(e){void 0!==e.style&&(B=e.style),void 0!==e.active&&t.forEach(function(t,n){t.disabled=!e.active[n]})}},z=r.format("%");return i.dispatch.on("elementMouseover.tooltip",function(t){t.point.x=i.x()(t.point),t.point.y=i.y()(t.point),f.data(t).hidden(!1)}),i.dispatch.on("elementMouseout.tooltip",function(t){f.hidden(!0)}),t.dispatch=A,t.stacked=i,t.legend=l,t.controls=u,t.xAxis=a,t.x2Axis=d.xAxis,t.yAxis=s,t.y2Axis=d.yAxis,t.interactiveLayer=c,t.tooltip=f,t.focus=d,t.dispatch=A,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{width:{get:function(){return g},set:function(t){g=t}},height:{get:function(){return v},set:function(t){v=t}},showLegend:{get:function(){return b},set:function(t){b=t}},legendPosition:{get:function(){return x},set:function(t){x=t}},showXAxis:{get:function(){return _},set:function(t){_=t}},showYAxis:{get:function(){return w},set:function(t){w=t}},defaultState:{get:function(){return M},set:function(t){M=t}},noData:{get:function(){return N},set:function(t){N=t}},showControls:{get:function(){return y},set:function(t){y=t}},controlLabels:{get:function(){return I},set:function(t){I=t}},controlOptions:{get:function(){return D},set:function(t){D=t}},showTotalInTooltip:{get:function(){return E},set:function(t){E=t}},totalLabel:{get:function(){return P},set:function(t){P=t}},focusEnable:{get:function(){return C},set:function(t){C=t}},focusHeight:{get:function(){return d.height()},set:function(t){d.height(t)}},brushExtent:{get:function(){return d.brushExtent()},set:function(t){d.brushExtent(t)}},margin:{get:function(){return p},set:function(t){void 0!==t.top&&(p.top=t.top,h=t.top),p.right=void 0!==t.right?t.right:p.right,p.bottom=void 0!==t.bottom?t.bottom:p.bottom,p.left=void 0!==t.left?t.left:p.left}},focusMargin:{get:function(){return d.margin},set:function(t){d.margin.top=void 0!==t.top?t.top:d.margin.top,d.margin.right=void 0!==t.right?t.right:d.margin.right,d.margin.bottom=void 0!==t.bottom?t.bottom:d.margin.bottom,d.margin.left=void 0!==t.left?t.left:d.margin.left}},duration:{get:function(){return R},set:function(t){R=t,j.reset(R),i.duration(R),a.duration(R),s.duration(R)}},color:{get:function(){return m},set:function(t){m=o.utils.getColor(t),l.color(m),i.color(m),d.color(m)}},x:{get:function(){return i.x()},set:function(t){i.x(t),d.x(t)}},y:{get:function(){return i.y()},set:function(t){i.y(t),d.y(t)}},rightAlignYAxis:{get:function(){return T},set:function(t){T=t,s.orient(T?"right":"left")}},useInteractiveGuideline:{get:function(){return k},set:function(e){k=!!e,t.interactive(!e),t.useVoronoi(!e),i.scatter.interactive(!e)}}}),o.utils.inheritOptions(t,i),o.utils.initOptions(t),t},o.models.stackedAreaWithFocusChart=function(){return o.models.stackedAreaChart().margin({bottom:30}).focusEnable(!0)},o.models.sunburst=function(){"use strict";function t(t){var n=e(t);return n>90?180:0}function e(t){var e=Math.max(0,Math.min(2*Math.PI,O(t.x))),n=Math.max(0,Math.min(2*Math.PI,O(t.x+t.dx))),r=(e+n)/2*(180/Math.PI)-90;return r}function n(t){var e=Math.max(0,Math.min(2*Math.PI,O(t.x))),n=Math.max(0,Math.min(2*Math.PI,O(t.x+t.dx)));return(n-e)/(2*Math.PI)}function i(t){var e=Math.max(0,Math.min(2*Math.PI,O(t.x))),n=Math.max(0,Math.min(2*Math.PI,O(t.x+t.dx))),r=n-e;return r>E}function a(t,e){var n=r.interpolate(O.domain(),[d.x,d.x+d.dx]),o=r.interpolate(D.domain(),[d.y,1]),i=r.interpolate(D.range(),[d.y?20:0,g]);return 0===e?function(){return L(t)}:function(e){return O.domain(n(e)),D.domain(o(e)).range(i(e)),L(t)}}function s(t){var e=r.interpolate({x:t.x0,dx:t.dx0,y:t.y0,dy:t.dy0},t);return function(n){var r=e(n);return t.x0=r.x,t.dx0=r.dx,t.y0=r.y,t.dy0=r.dy,L(r)}}function l(t){var e=S(t);R[e]||(R[e]={});var n=R[e];n.dx=t.dx,n.x=t.x,n.dy=t.dy,n.y=t.y}function u(t){t.forEach(function(t){var e=S(t),n=R[e];n?(t.dx0=n.dx,t.x0=n.x,t.dy0=n.dy,t.y0=n.y):(t.dx0=t.dx,t.x0=t.x,t.dy0=t.dy,t.y0=t.y),l(t)})}function c(n){var o=w.selectAll("text"),s=w.selectAll("path");o.transition().attr("opacity",0),d=n,s.transition().duration(N).attrTween("d",a).each("end",function(o){if(o.x>=n.x&&o.x<n.x+n.dx&&o.depth>=n.depth){var a=r.select(this.parentNode),s=a.select("text");s.transition().duration(N).text(function(t){return k(t)}).attr("opacity",function(t){return i(t)?1:0}).attr("transform",function(){var r=this.getBBox().width;if(0===o.depth)return"translate("+r/2*-1+",0)";if(o.depth===n.depth)return"translate("+(D(o.y)+5)+",0)";var i=e(o),a=t(o);return 0===a?"rotate("+i+")translate("+(D(o.y)+5)+",0)":"rotate("+i+")translate("+(D(o.y)+r+5)+",0)rotate("+a+")"})}})}function f(a){return F.reset(),a.each(function(a){w=r.select(this),p=o.utils.availableWidth(m,w,v),h=o.utils.availableHeight(y,w,v),g=Math.min(p,h)/2,D.range([0,g]);var l=w.select("g.nvd3.nv-wrap.nv-sunburst");l[0][0]?l.attr("transform","translate("+(p/2+v.left+v.right)+","+(h/2+v.top+v.bottom)+")"):l=w.append("g").attr("class","nvd3 nv-wrap nv-sunburst nv-chart-"+_).attr("transform","translate("+(p/2+v.left+v.right)+","+(h/2+v.top+v.bottom)+")"),w.on("click",function(t,e){A.chartClick({data:t,index:e,pos:r.event,id:_})}),I.value(x[b]||x.count);var f=I.nodes(a[0]).reverse();u(f);var d=l.selectAll(".arc-container").data(f,S),E=d.enter().append("g").attr("class","arc-container");E.append("path").attr("d",L).style("fill",function(t){return t.color?t.color:T(M?(t.children?t:t.parent).name:t.name)}).style("stroke","#FFF").on("click",function(t,e){c(t),A.elementClick({data:t,index:e})}).on("mouseover",function(t,e){r.select(this).classed("hover",!0).style("opacity",.8),A.elementMouseover({data:t,color:r.select(this).style("fill"),percent:n(t)})}).on("mouseout",function(t,e){r.select(this).classed("hover",!1).style("opacity",1),A.elementMouseout({data:t})}).on("mousemove",function(t,e){A.elementMousemove({data:t})}),d.each(function(t){r.select(this).select("path").transition().duration(N).attrTween("d",s)}),C&&(d.selectAll("text").remove(),d.append("text").text(function(t){return k(t)}).transition().duration(N).attr("opacity",function(t){return i(t)?1:0}).attr("transform",function(n){var r=this.getBBox().width;if(0===n.depth)return"rotate(0)translate("+r/2*-1+",0)";var o=e(n),i=t(n);return 0===i?"rotate("+o+")translate("+(D(n.y)+5)+",0)":"rotate("+o+")translate("+(D(n.y)+r+5)+",0)rotate("+i+")"})),c(f[f.length-1]),d.exit().transition().duration(N).attr("opacity",0).each("end",function(t){var e=S(t);R[e]=void 0}).remove()}),F.renderEnd("sunburst immediate"),f}var d,p,h,g,v={top:0,right:0,bottom:0,left:0},m=600,y=600,b="count",x={count:function(t){return 1},value:function(t){return t.value||t.size},size:function(t){return t.value||t.size}},_=Math.floor(1e4*Math.random()),w=null,T=o.utils.defaultColor(),C=!1,k=function(t){return"count"===b?t.name+" #"+t.value:t.name+" "+(t.value||t.size)},E=.02,P=function(t,e){return t.name>e.name},S=function(t,e){return t.name},M=!0,N=500,A=r.dispatch("chartClick","elementClick","elementDblClick","elementMousemove","elementMouseover","elementMouseout","renderEnd"),O=r.scale.linear().range([0,2*Math.PI]),D=r.scale.sqrt(),I=r.layout.partition().sort(P),R={},L=r.svg.arc().startAngle(function(t){return Math.max(0,Math.min(2*Math.PI,O(t.x)))}).endAngle(function(t){return Math.max(0,Math.min(2*Math.PI,O(t.x+t.dx)))}).innerRadius(function(t){return Math.max(0,D(t.y))}).outerRadius(function(t){return Math.max(0,D(t.y+t.dy))}),F=o.utils.renderWatch(A);return f.dispatch=A,f.options=o.utils.optionsFunc.bind(f),f._options=Object.create({},{width:{get:function(){return m},set:function(t){m=t}},height:{get:function(){return y},set:function(t){y=t}},mode:{get:function(){return b},set:function(t){b=t}},id:{get:function(){return _},set:function(t){_=t}},duration:{get:function(){return N},set:function(t){N=t}},groupColorByParent:{get:function(){return M},set:function(t){M=!!t}},showLabels:{get:function(){return C},set:function(t){C=!!t}},labelFormat:{get:function(){return k},set:function(t){k=t}},labelThreshold:{get:function(){return E},set:function(t){E=t}},sort:{get:function(){return P},set:function(t){P=t}},key:{get:function(){return S},set:function(t){S=t}},margin:{get:function(){return v},set:function(t){v.top=void 0!=t.top?t.top:v.top,
v.right=void 0!=t.right?t.right:v.right,v.bottom=void 0!=t.bottom?t.bottom:v.bottom,v.left=void 0!=t.left?t.left:v.left}},color:{get:function(){return T},set:function(t){T=o.utils.getColor(t)}}}),o.utils.initOptions(f),f},o.models.sunburstChart=function(){"use strict";function t(n){return h.reset(),h.models(e),n.each(function(n){var l=r.select(this);o.utils.initSVG(l);var u=o.utils.availableWidth(a,l,i),c=o.utils.availableHeight(s,l,i);return t.update=function(){0===d?l.call(t):l.transition().duration(d).call(t)},t.container=l,n&&n.length?(l.selectAll(".nv-noData").remove(),e.width(u).height(c).margin(i),void l.call(e)):(o.utils.noData(t,l),t)}),h.renderEnd("sunburstChart immediate"),t}var e=o.models.sunburst(),n=o.models.tooltip(),i={top:30,right:20,bottom:20,left:20},a=null,s=null,l=o.utils.defaultColor(),u=!1,c=(Math.round(1e5*Math.random()),null),f=null,d=250,p=r.dispatch("stateChange","changeState","renderEnd"),h=o.utils.renderWatch(p);return n.duration(0).headerEnabled(!1).valueFormatter(function(t){return t}),e.dispatch.on("elementMouseover.tooltip",function(t){t.series={key:t.data.name,value:t.data.value||t.data.size,color:t.color,percent:t.percent},u||(delete t.percent,delete t.series.percent),n.data(t).hidden(!1)}),e.dispatch.on("elementMouseout.tooltip",function(t){n.hidden(!0)}),e.dispatch.on("elementMousemove.tooltip",function(t){n()}),t.dispatch=p,t.sunburst=e,t.tooltip=n,t.options=o.utils.optionsFunc.bind(t),t._options=Object.create({},{noData:{get:function(){return f},set:function(t){f=t}},defaultState:{get:function(){return c},set:function(t){c=t}},showTooltipPercent:{get:function(){return u},set:function(t){u=t}},color:{get:function(){return l},set:function(t){l=t,e.color(l)}},duration:{get:function(){return d},set:function(t){d=t,h.reset(d),e.duration(d)}},margin:{get:function(){return i},set:function(t){i.top=void 0!==t.top?t.top:i.top,i.right=void 0!==t.right?t.right:i.right,i.bottom=void 0!==t.bottom?t.bottom:i.bottom,i.left=void 0!==t.left?t.left:i.left,e.margin(i)}}}),o.utils.inheritOptions(t,e),o.utils.initOptions(t),t},o.version="1.8.5"}()}).call(e,n(170))},function(t,e,n){"use strict";t.exports=n(177)},function(t,e,n){"use strict";var r=n(178),o=n(183),i=n(308),a=n(207),s=n(204),l=n(313),u=n(314),c=n(315),f=n(316);n(191);o.inject();var d={findDOMNode:u,render:i.render,unmountComponentAtNode:i.unmountComponentAtNode,version:l,unstable_batchedUpdates:s.batchedUpdates,unstable_renderSubtreeIntoContainer:f};"undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.inject&&__REACT_DEVTOOLS_GLOBAL_HOOK__.inject({ComponentTree:{getClosestInstanceFromNode:r.getClosestInstanceFromNode,getNodeFromInstance:function(t){return t._renderedComponent&&(t=c(t)),t?r.getNodeFromInstance(t):null}},Mount:i,Reconciler:a});t.exports=d},function(t,e,n){"use strict";function r(t,e){return 1===t.nodeType&&t.getAttribute(h)===String(e)||8===t.nodeType&&t.nodeValue===" react-text: "+e+" "||8===t.nodeType&&t.nodeValue===" react-empty: "+e+" "}function o(t){for(var e;e=t._renderedComponent;)t=e;return t}function i(t,e){var n=o(t);n._hostNode=e,e[v]=n}function a(t){var e=t._hostNode;e&&(delete e[v],t._hostNode=null)}function s(t,e){if(!(t._flags&g.hasCachedChildNodes)){var n=t._renderedChildren,a=e.firstChild;t:for(var s in n)if(n.hasOwnProperty(s)){var l=n[s],u=o(l)._domID;if(0!==u){for(;null!==a;a=a.nextSibling)if(r(a,u)){i(l,a);continue t}f("32",u)}}t._flags|=g.hasCachedChildNodes}}function l(t){if(t[v])return t[v];for(var e=[];!t[v];){if(e.push(t),!t.parentNode)return null;t=t.parentNode}for(var n,r;t&&(r=t[v]);t=e.pop())n=r,e.length&&s(r,t);return n}function u(t){var e=l(t);return null!=e&&e._hostNode===t?e:null}function c(t){if(void 0===t._hostNode?f("33"):void 0,t._hostNode)return t._hostNode;for(var e=[];!t._hostNode;)e.push(t),t._hostParent?void 0:f("34"),t=t._hostParent;for(;e.length;t=e.pop())s(t,t._hostNode);return t._hostNode}var f=n(179),d=n(180),p=n(182),h=(n(181),d.ID_ATTRIBUTE_NAME),g=p,v="__reactInternalInstance$"+Math.random().toString(36).slice(2),m={getClosestInstanceFromNode:l,getInstanceFromNode:u,getNodeFromInstance:c,precacheChildNodes:s,precacheNode:i,uncacheNode:a};t.exports=m},function(t,e){"use strict";function n(t){for(var e=arguments.length-1,n="Minified React error #"+t+"; visit http://facebook.github.io/react/docs/error-decoder.html?invariant="+t,r=0;r<e;r++)n+="&args[]="+encodeURIComponent(arguments[r+1]);n+=" for the full message or use the non-minified dev environment for full errors and additional helpful warnings.";var o=new Error(n);throw o.name="Invariant Violation",o.framesToPop=1,o}t.exports=n},function(t,e,n){"use strict";function r(t,e){return(t&e)===e}var o=n(179),i=(n(181),{MUST_USE_PROPERTY:1,HAS_BOOLEAN_VALUE:4,HAS_NUMERIC_VALUE:8,HAS_POSITIVE_NUMERIC_VALUE:24,HAS_OVERLOADED_BOOLEAN_VALUE:32,injectDOMPropertyConfig:function(t){var e=i,n=t.Properties||{},a=t.DOMAttributeNamespaces||{},l=t.DOMAttributeNames||{},u=t.DOMPropertyNames||{},c=t.DOMMutationMethods||{};t.isCustomAttribute&&s._isCustomAttributeFunctions.push(t.isCustomAttribute);for(var f in n){s.properties.hasOwnProperty(f)?o("48",f):void 0;var d=f.toLowerCase(),p=n[f],h={attributeName:d,attributeNamespace:null,propertyName:f,mutationMethod:null,mustUseProperty:r(p,e.MUST_USE_PROPERTY),hasBooleanValue:r(p,e.HAS_BOOLEAN_VALUE),hasNumericValue:r(p,e.HAS_NUMERIC_VALUE),hasPositiveNumericValue:r(p,e.HAS_POSITIVE_NUMERIC_VALUE),hasOverloadedBooleanValue:r(p,e.HAS_OVERLOADED_BOOLEAN_VALUE)};if(h.hasBooleanValue+h.hasNumericValue+h.hasOverloadedBooleanValue<=1?void 0:o("50",f),l.hasOwnProperty(f)){var g=l[f];h.attributeName=g}a.hasOwnProperty(f)&&(h.attributeNamespace=a[f]),u.hasOwnProperty(f)&&(h.propertyName=u[f]),c.hasOwnProperty(f)&&(h.mutationMethod=c[f]),s.properties[f]=h}}}),a=":A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD",s={ID_ATTRIBUTE_NAME:"data-reactid",ROOT_ATTRIBUTE_NAME:"data-reactroot",ATTRIBUTE_NAME_START_CHAR:a,ATTRIBUTE_NAME_CHAR:a+"\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040",properties:{},getPossibleStandardName:null,_isCustomAttributeFunctions:[],isCustomAttribute:function(t){for(var e=0;e<s._isCustomAttributeFunctions.length;e++){var n=s._isCustomAttributeFunctions[e];if(n(t))return!0}return!1},injection:i};t.exports=s},function(t,e,n){"use strict";function r(t,e,n,r,i,a,s,l){if(o(e),!t){var u;if(void 0===e)u=new Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var c=[n,r,i,a,s,l],f=0;u=new Error(e.replace(/%s/g,function(){return c[f++]})),u.name="Invariant Violation"}throw u.framesToPop=1,u}}var o=function(t){};t.exports=r},function(t,e){"use strict";var n={hasCachedChildNodes:1};t.exports=n},function(t,e,n){"use strict";function r(){T||(T=!0,y.EventEmitter.injectReactEventListener(m),y.EventPluginHub.injectEventPluginOrder(s),y.EventPluginUtils.injectComponentTree(d),y.EventPluginUtils.injectTreeTraversal(h),y.EventPluginHub.injectEventPluginsByName({SimpleEventPlugin:w,EnterLeaveEventPlugin:l,ChangeEventPlugin:a,SelectEventPlugin:_,BeforeInputEventPlugin:i}),y.HostComponent.injectGenericComponentClass(f),y.HostComponent.injectTextComponentClass(g),y.DOMProperty.injectDOMPropertyConfig(o),y.DOMProperty.injectDOMPropertyConfig(u),y.DOMProperty.injectDOMPropertyConfig(x),y.EmptyComponent.injectEmptyComponentFactory(function(t){return new p(t)}),y.Updates.injectReconcileTransaction(b),y.Updates.injectBatchingStrategy(v),y.Component.injectEnvironment(c))}var o=n(184),i=n(185),a=n(203),s=n(215),l=n(216),u=n(221),c=n(222),f=n(235),d=n(178),p=n(279),h=n(280),g=n(281),v=n(282),m=n(283),y=n(286),b=n(287),x=n(295),_=n(296),w=n(297),T=!1;t.exports={inject:r}},function(t,e){"use strict";var n={Properties:{"aria-current":0,"aria-details":0,"aria-disabled":0,"aria-hidden":0,"aria-invalid":0,"aria-keyshortcuts":0,"aria-label":0,"aria-roledescription":0,"aria-autocomplete":0,"aria-checked":0,"aria-expanded":0,"aria-haspopup":0,"aria-level":0,"aria-modal":0,"aria-multiline":0,"aria-multiselectable":0,"aria-orientation":0,"aria-placeholder":0,"aria-pressed":0,"aria-readonly":0,"aria-required":0,"aria-selected":0,"aria-sort":0,"aria-valuemax":0,"aria-valuemin":0,"aria-valuenow":0,"aria-valuetext":0,"aria-atomic":0,"aria-busy":0,"aria-live":0,"aria-relevant":0,"aria-dropeffect":0,"aria-grabbed":0,"aria-activedescendant":0,"aria-colcount":0,"aria-colindex":0,"aria-colspan":0,"aria-controls":0,"aria-describedby":0,"aria-errormessage":0,"aria-flowto":0,"aria-labelledby":0,"aria-owns":0,"aria-posinset":0,"aria-rowcount":0,"aria-rowindex":0,"aria-rowspan":0,"aria-setsize":0},DOMAttributeNames:{},DOMPropertyNames:{}};t.exports=n},function(t,e,n){"use strict";function r(){var t=window.opera;return"object"==typeof t&&"function"==typeof t.version&&parseInt(t.version(),10)<=12}function o(t){return(t.ctrlKey||t.altKey||t.metaKey)&&!(t.ctrlKey&&t.altKey)}function i(t){switch(t){case"topCompositionStart":return E.compositionStart;case"topCompositionEnd":return E.compositionEnd;case"topCompositionUpdate":return E.compositionUpdate}}function a(t,e){return"topKeyDown"===t&&e.keyCode===b}function s(t,e){switch(t){case"topKeyUp":return y.indexOf(e.keyCode)!==-1;case"topKeyDown":return e.keyCode!==b;case"topKeyPress":case"topMouseDown":case"topBlur":return!0;default:return!1}}function l(t){var e=t.detail;return"object"==typeof e&&"data"in e?e.data:null}function u(t,e,n,r){var o,u;if(x?o=i(t):S?s(t,n)&&(o=E.compositionEnd):a(t,n)&&(o=E.compositionStart),!o)return null;T&&(S||o!==E.compositionStart?o===E.compositionEnd&&S&&(u=S.getData()):S=g.getPooled(r));var c=v.getPooled(o,e,n,r);if(u)c.data=u;else{var f=l(n);null!==f&&(c.data=f)}return p.accumulateTwoPhaseDispatches(c),c}function c(t,e){switch(t){case"topCompositionEnd":return l(e);case"topKeyPress":var n=e.which;return n!==C?null:(P=!0,k);case"topTextInput":var r=e.data;return r===k&&P?null:r;default:return null}}function f(t,e){if(S){if("topCompositionEnd"===t||!x&&s(t,e)){var n=S.getData();return g.release(S),S=null,n}return null}switch(t){case"topPaste":return null;case"topKeyPress":return e.which&&!o(e)?String.fromCharCode(e.which):null;case"topCompositionEnd":return T?null:e.data;default:return null}}function d(t,e,n,r){var o;if(o=w?c(t,n):f(t,n),!o)return null;var i=m.getPooled(E.beforeInput,e,n,r);return i.data=o,p.accumulateTwoPhaseDispatches(i),i}var p=n(186),h=n(195),g=n(196),v=n(200),m=n(202),y=[9,13,27,32],b=229,x=h.canUseDOM&&"CompositionEvent"in window,_=null;h.canUseDOM&&"documentMode"in document&&(_=document.documentMode);var w=h.canUseDOM&&"TextEvent"in window&&!_&&!r(),T=h.canUseDOM&&(!x||_&&_>8&&_<=11),C=32,k=String.fromCharCode(C),E={beforeInput:{phasedRegistrationNames:{bubbled:"onBeforeInput",captured:"onBeforeInputCapture"},dependencies:["topCompositionEnd","topKeyPress","topTextInput","topPaste"]},compositionEnd:{phasedRegistrationNames:{bubbled:"onCompositionEnd",captured:"onCompositionEndCapture"},dependencies:["topBlur","topCompositionEnd","topKeyDown","topKeyPress","topKeyUp","topMouseDown"]},compositionStart:{phasedRegistrationNames:{bubbled:"onCompositionStart",captured:"onCompositionStartCapture"},dependencies:["topBlur","topCompositionStart","topKeyDown","topKeyPress","topKeyUp","topMouseDown"]},compositionUpdate:{phasedRegistrationNames:{bubbled:"onCompositionUpdate",captured:"onCompositionUpdateCapture"},dependencies:["topBlur","topCompositionUpdate","topKeyDown","topKeyPress","topKeyUp","topMouseDown"]}},P=!1,S=null,M={eventTypes:E,extractEvents:function(t,e,n,r){return[u(t,e,n,r),d(t,e,n,r)]}};t.exports=M},function(t,e,n){"use strict";function r(t,e,n){var r=e.dispatchConfig.phasedRegistrationNames[n];return m(t,r)}function o(t,e,n){var o=r(t,n,e);o&&(n._dispatchListeners=g(n._dispatchListeners,o),n._dispatchInstances=g(n._dispatchInstances,t))}function i(t){t&&t.dispatchConfig.phasedRegistrationNames&&h.traverseTwoPhase(t._targetInst,o,t)}function a(t){if(t&&t.dispatchConfig.phasedRegistrationNames){var e=t._targetInst,n=e?h.getParentInstance(e):null;h.traverseTwoPhase(n,o,t)}}function s(t,e,n){if(n&&n.dispatchConfig.registrationName){var r=n.dispatchConfig.registrationName,o=m(t,r);o&&(n._dispatchListeners=g(n._dispatchListeners,o),n._dispatchInstances=g(n._dispatchInstances,t))}}function l(t){t&&t.dispatchConfig.registrationName&&s(t._targetInst,null,t)}function u(t){v(t,i)}function c(t){v(t,a)}function f(t,e,n,r){h.traverseEnterLeave(n,r,s,t,e)}function d(t){v(t,l)}var p=n(187),h=n(189),g=n(193),v=n(194),m=(n(191),p.getListener),y={accumulateTwoPhaseDispatches:u,accumulateTwoPhaseDispatchesSkipTarget:c,accumulateDirectDispatches:d,accumulateEnterLeaveDispatches:f};t.exports=y},function(t,e,n){"use strict";function r(t){return"button"===t||"input"===t||"select"===t||"textarea"===t}function o(t,e,n){switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":return!(!n.disabled||!r(e));default:return!1}}var i=n(179),a=n(188),s=n(189),l=n(190),u=n(193),c=n(194),f=(n(181),{}),d=null,p=function(t,e){t&&(s.executeDispatchesInOrder(t,e),t.isPersistent()||t.constructor.release(t))},h=function(t){return p(t,!0)},g=function(t){return p(t,!1)},v=function(t){return"."+t._rootNodeID},m={injection:{injectEventPluginOrder:a.injectEventPluginOrder,injectEventPluginsByName:a.injectEventPluginsByName},putListener:function(t,e,n){"function"!=typeof n?i("94",e,typeof n):void 0;var r=v(t),o=f[e]||(f[e]={});o[r]=n;var s=a.registrationNameModules[e];s&&s.didPutListener&&s.didPutListener(t,e,n)},getListener:function(t,e){var n=f[e];if(o(e,t._currentElement.type,t._currentElement.props))return null;var r=v(t);return n&&n[r]},deleteListener:function(t,e){var n=a.registrationNameModules[e];n&&n.willDeleteListener&&n.willDeleteListener(t,e);var r=f[e];if(r){var o=v(t);delete r[o]}},deleteAllListeners:function(t){var e=v(t);for(var n in f)if(f.hasOwnProperty(n)&&f[n][e]){var r=a.registrationNameModules[n];r&&r.willDeleteListener&&r.willDeleteListener(t,n),delete f[n][e]}},extractEvents:function(t,e,n,r){for(var o,i=a.plugins,s=0;s<i.length;s++){var l=i[s];if(l){var c=l.extractEvents(t,e,n,r);c&&(o=u(o,c))}}return o},enqueueEvents:function(t){t&&(d=u(d,t))},processEventQueue:function(t){var e=d;d=null,t?c(e,h):c(e,g),d?i("95"):void 0,l.rethrowCaughtError()},__purge:function(){f={}},__getListenerBank:function(){return f}};t.exports=m},function(t,e,n){"use strict";function r(){if(s)for(var t in l){var e=l[t],n=s.indexOf(t);if(n>-1?void 0:a("96",t),!u.plugins[n]){e.extractEvents?void 0:a("97",t),u.plugins[n]=e;var r=e.eventTypes;for(var i in r)o(r[i],e,i)?void 0:a("98",i,t)}}}function o(t,e,n){u.eventNameDispatchConfigs.hasOwnProperty(n)?a("99",n):void 0,u.eventNameDispatchConfigs[n]=t;var r=t.phasedRegistrationNames;if(r){for(var o in r)if(r.hasOwnProperty(o)){var s=r[o];i(s,e,n)}return!0}return!!t.registrationName&&(i(t.registrationName,e,n),!0)}function i(t,e,n){u.registrationNameModules[t]?a("100",t):void 0,u.registrationNameModules[t]=e,u.registrationNameDependencies[t]=e.eventTypes[n].dependencies}var a=n(179),s=(n(181),null),l={},u={plugins:[],eventNameDispatchConfigs:{},registrationNameModules:{},registrationNameDependencies:{},possibleRegistrationNames:null,injectEventPluginOrder:function(t){s?a("101"):void 0,s=Array.prototype.slice.call(t),r()},injectEventPluginsByName:function(t){var e=!1;for(var n in t)if(t.hasOwnProperty(n)){var o=t[n];l.hasOwnProperty(n)&&l[n]===o||(l[n]?a("102",n):void 0,l[n]=o,e=!0)}e&&r()},getPluginModuleForEvent:function(t){var e=t.dispatchConfig;if(e.registrationName)return u.registrationNameModules[e.registrationName]||null;if(void 0!==e.phasedRegistrationNames){var n=e.phasedRegistrationNames;for(var r in n)if(n.hasOwnProperty(r)){var o=u.registrationNameModules[n[r]];if(o)return o}}return null},_resetEventPlugins:function(){s=null;for(var t in l)l.hasOwnProperty(t)&&delete l[t];u.plugins.length=0;var e=u.eventNameDispatchConfigs;for(var n in e)e.hasOwnProperty(n)&&delete e[n];var r=u.registrationNameModules;for(var o in r)r.hasOwnProperty(o)&&delete r[o]}};t.exports=u},function(t,e,n){"use strict";function r(t){return"topMouseUp"===t||"topTouchEnd"===t||"topTouchCancel"===t}function o(t){return"topMouseMove"===t||"topTouchMove"===t}function i(t){return"topMouseDown"===t||"topTouchStart"===t}function a(t,e,n,r){var o=t.type||"unknown-event";t.currentTarget=m.getNodeFromInstance(r),e?g.invokeGuardedCallbackWithCatch(o,n,t):g.invokeGuardedCallback(o,n,t),t.currentTarget=null}function s(t,e){var n=t._dispatchListeners,r=t._dispatchInstances;if(Array.isArray(n))for(var o=0;o<n.length&&!t.isPropagationStopped();o++)a(t,e,n[o],r[o]);else n&&a(t,e,n,r);t._dispatchListeners=null,t._dispatchInstances=null}function l(t){var e=t._dispatchListeners,n=t._dispatchInstances;if(Array.isArray(e)){for(var r=0;r<e.length&&!t.isPropagationStopped();r++)if(e[r](t,n[r]))return n[r]}else if(e&&e(t,n))return n;return null}function u(t){var e=l(t);return t._dispatchInstances=null,t._dispatchListeners=null,e}function c(t){var e=t._dispatchListeners,n=t._dispatchInstances;Array.isArray(e)?h("103"):void 0,t.currentTarget=e?m.getNodeFromInstance(n):null;var r=e?e(t):null;return t.currentTarget=null,t._dispatchListeners=null,t._dispatchInstances=null,r}function f(t){return!!t._dispatchListeners}var d,p,h=n(179),g=n(190),v=(n(181),n(191),{injectComponentTree:function(t){d=t},injectTreeTraversal:function(t){p=t}}),m={isEndish:r,isMoveish:o,isStartish:i,executeDirectDispatch:c,executeDispatchesInOrder:s,executeDispatchesInOrderStopAtTrue:u,hasDispatches:f,getInstanceFromNode:function(t){return d.getInstanceFromNode(t)},getNodeFromInstance:function(t){return d.getNodeFromInstance(t)},isAncestor:function(t,e){return p.isAncestor(t,e)},getLowestCommonAncestor:function(t,e){return p.getLowestCommonAncestor(t,e)},getParentInstance:function(t){return p.getParentInstance(t)},traverseTwoPhase:function(t,e,n){return p.traverseTwoPhase(t,e,n)},traverseEnterLeave:function(t,e,n,r,o){return p.traverseEnterLeave(t,e,n,r,o)},injection:v};t.exports=m},function(t,e,n){"use strict";function r(t,e,n){try{e(n)}catch(t){null===o&&(o=t)}}var o=null,i={invokeGuardedCallback:r,invokeGuardedCallbackWithCatch:r,rethrowCaughtError:function(){if(o){var t=o;throw o=null,t}}};t.exports=i},function(t,e,n){"use strict";var r=n(192),o=r;t.exports=o},function(t,e){"use strict";function n(t){return function(){return t}}var r=function(){};r.thatReturns=n,r.thatReturnsFalse=n(!1),r.thatReturnsTrue=n(!0),r.thatReturnsNull=n(null),r.thatReturnsThis=function(){return this},r.thatReturnsArgument=function(t){return t},t.exports=r},function(t,e,n){"use strict";function r(t,e){return null==e?o("30"):void 0,null==t?e:Array.isArray(t)?Array.isArray(e)?(t.push.apply(t,e),t):(t.push(e),t):Array.isArray(e)?[t].concat(e):[t,e]}var o=n(179);n(181);t.exports=r},function(t,e){"use strict";function n(t,e,n){Array.isArray(t)?t.forEach(e,n):t&&e.call(n,t)}t.exports=n},function(t,e){"use strict";var n=!("undefined"==typeof window||!window.document||!window.document.createElement),r={canUseDOM:n,canUseWorkers:"undefined"!=typeof Worker,canUseEventListeners:n&&!(!window.addEventListener&&!window.attachEvent),canUseViewport:n&&!!window.screen,isInWorker:!n};t.exports=r},function(t,e,n){"use strict";function r(t){this._root=t,this._startText=this.getText(),this._fallbackText=null}var o=n(197),i=n(198),a=n(199);o(r.prototype,{destructor:function(){this._root=null,this._startText=null,this._fallbackText=null},getText:function(){return"value"in this._root?this._root.value:this._root[a()]},getData:function(){if(this._fallbackText)return this._fallbackText;var t,e,n=this._startText,r=n.length,o=this.getText(),i=o.length;for(t=0;t<r&&n[t]===o[t];t++);var a=r-t;for(e=1;e<=a&&n[r-e]===o[i-e];e++);var s=e>1?1-e:void 0;return this._fallbackText=o.slice(t,s),this._fallbackText}}),i.addPoolingTo(r),t.exports=r},function(t,e){"use strict";function n(t){if(null===t||void 0===t)throw new TypeError("Object.assign cannot be called with null or undefined");return Object(t)}function r(){try{if(!Object.assign)return!1;var t=new String("abc");if(t[5]="de","5"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},n=0;n<10;n++)e["_"+String.fromCharCode(n)]=n;var r=Object.getOwnPropertyNames(e).map(function(t){return e[t]});if("0123456789"!==r.join(""))return!1;var o={};return"abcdefghijklmnopqrst".split("").forEach(function(t){o[t]=t}),"abcdefghijklmnopqrst"===Object.keys(Object.assign({},o)).join("")}catch(t){return!1}}var o=Object.prototype.hasOwnProperty,i=Object.prototype.propertyIsEnumerable;t.exports=r()?Object.assign:function(t,e){for(var r,a,s=n(t),l=1;l<arguments.length;l++){r=Object(arguments[l]);for(var u in r)o.call(r,u)&&(s[u]=r[u]);if(Object.getOwnPropertySymbols){a=Object.getOwnPropertySymbols(r);for(var c=0;c<a.length;c++)i.call(r,a[c])&&(s[a[c]]=r[a[c]])}}return s}},function(t,e,n){"use strict";var r=n(179),o=(n(181),function(t){var e=this;if(e.instancePool.length){var n=e.instancePool.pop();return e.call(n,t),n}return new e(t)}),i=function(t,e){var n=this;if(n.instancePool.length){var r=n.instancePool.pop();return n.call(r,t,e),r}return new n(t,e)},a=function(t,e,n){var r=this;if(r.instancePool.length){var o=r.instancePool.pop();return r.call(o,t,e,n),o}return new r(t,e,n)},s=function(t,e,n,r){var o=this;if(o.instancePool.length){var i=o.instancePool.pop();return o.call(i,t,e,n,r),i}return new o(t,e,n,r)},l=function(t){var e=this;t instanceof e?void 0:r("25"),t.destructor(),e.instancePool.length<e.poolSize&&e.instancePool.push(t)},u=10,c=o,f=function(t,e){var n=t;return n.instancePool=[],n.getPooled=e||c,n.poolSize||(n.poolSize=u),n.release=l,n},d={addPoolingTo:f,oneArgumentPooler:o,twoArgumentPooler:i,threeArgumentPooler:a,fourArgumentPooler:s};t.exports=d},function(t,e,n){"use strict";function r(){return!i&&o.canUseDOM&&(i="textContent"in document.documentElement?"textContent":"innerText"),i}var o=n(195),i=null;t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(201),i={data:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){this.dispatchConfig=t,this._targetInst=e,this.nativeEvent=n;var o=this.constructor.Interface;for(var i in o)if(o.hasOwnProperty(i)){var s=o[i];s?this[i]=s(n):"target"===i?this.target=r:this[i]=n[i]}var l=null!=n.defaultPrevented?n.defaultPrevented:n.returnValue===!1;return l?this.isDefaultPrevented=a.thatReturnsTrue:this.isDefaultPrevented=a.thatReturnsFalse,this.isPropagationStopped=a.thatReturnsFalse,this}var o=n(197),i=n(198),a=n(192),s=(n(191),"function"==typeof Proxy,["dispatchConfig","_targetInst","nativeEvent","isDefaultPrevented","isPropagationStopped","_dispatchListeners","_dispatchInstances"]),l={type:null,target:null,currentTarget:a.thatReturnsNull,eventPhase:null,bubbles:null,cancelable:null,timeStamp:function(t){return t.timeStamp||Date.now()},defaultPrevented:null,isTrusted:null};o(r.prototype,{preventDefault:function(){this.defaultPrevented=!0;var t=this.nativeEvent;t&&(t.preventDefault?t.preventDefault():"unknown"!=typeof t.returnValue&&(t.returnValue=!1),this.isDefaultPrevented=a.thatReturnsTrue)},stopPropagation:function(){var t=this.nativeEvent;t&&(t.stopPropagation?t.stopPropagation():"unknown"!=typeof t.cancelBubble&&(t.cancelBubble=!0),this.isPropagationStopped=a.thatReturnsTrue)},persist:function(){this.isPersistent=a.thatReturnsTrue},isPersistent:a.thatReturnsFalse,destructor:function(){var t=this.constructor.Interface;for(var e in t)this[e]=null;for(var n=0;n<s.length;n++)this[s[n]]=null}}),r.Interface=l,r.augmentClass=function(t,e){var n=this,r=function(){};r.prototype=n.prototype;var a=new r;o(a,t.prototype),t.prototype=a,t.prototype.constructor=t,t.Interface=o({},n.Interface,e),t.augmentClass=n.augmentClass,i.addPoolingTo(t,i.fourArgumentPooler)},i.addPoolingTo(r,i.fourArgumentPooler),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(201),i={data:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t){var e=t.nodeName&&t.nodeName.toLowerCase();return"select"===e||"input"===e&&"file"===t.type}function o(t){var e=T.getPooled(P.change,M,t,C(t));b.accumulateTwoPhaseDispatches(e),w.batchedUpdates(i,e)}function i(t){y.enqueueEvents(t),y.processEventQueue(!1)}function a(t,e){S=t,M=e,S.attachEvent("onchange",o)}function s(){S&&(S.detachEvent("onchange",o),S=null,M=null)}function l(t,e){if("topChange"===t)return e}function u(t,e,n){"topFocus"===t?(s(),a(e,n)):"topBlur"===t&&s()}function c(t,e){S=t,M=e,N=t.value,A=Object.getOwnPropertyDescriptor(t.constructor.prototype,"value"),Object.defineProperty(S,"value",I),S.attachEvent?S.attachEvent("onpropertychange",d):S.addEventListener("propertychange",d,!1)}function f(){S&&(delete S.value,S.detachEvent?S.detachEvent("onpropertychange",d):S.removeEventListener("propertychange",d,!1),S=null,M=null,N=null,A=null)}function d(t){if("value"===t.propertyName){var e=t.srcElement.value;e!==N&&(N=e,o(t))}}function p(t,e){if("topInput"===t)return e}function h(t,e,n){"topFocus"===t?(f(),c(e,n)):"topBlur"===t&&f()}function g(t,e){if(("topSelectionChange"===t||"topKeyUp"===t||"topKeyDown"===t)&&S&&S.value!==N)return N=S.value,M}function v(t){return t.nodeName&&"input"===t.nodeName.toLowerCase()&&("checkbox"===t.type||"radio"===t.type)}function m(t,e){if("topClick"===t)return e}var y=n(187),b=n(186),x=n(195),_=n(178),w=n(204),T=n(201),C=n(212),k=n(213),E=n(214),P={change:{phasedRegistrationNames:{bubbled:"onChange",captured:"onChangeCapture"},dependencies:["topBlur","topChange","topClick","topFocus","topInput","topKeyDown","topKeyUp","topSelectionChange"]}},S=null,M=null,N=null,A=null,O=!1;x.canUseDOM&&(O=k("change")&&(!document.documentMode||document.documentMode>8));var D=!1;x.canUseDOM&&(D=k("input")&&(!document.documentMode||document.documentMode>11));var I={get:function(){return A.get.call(this)},set:function(t){N=""+t,A.set.call(this,t)}},R={eventTypes:P,extractEvents:function(t,e,n,o){var i,a,s=e?_.getNodeFromInstance(e):window;if(r(s)?O?i=l:a=u:E(s)?D?i=p:(i=g,a=h):v(s)&&(i=m),i){var c=i(t,e);if(c){var f=T.getPooled(P.change,c,n,o);return f.type="change",b.accumulateTwoPhaseDispatches(f),f}}a&&a(t,s,e)}};t.exports=R},function(t,e,n){"use strict";function r(){P.ReactReconcileTransaction&&_?void 0:c("123")}function o(){this.reinitializeTransaction(),this.dirtyComponentsLength=null,this.callbackQueue=d.getPooled(),this.reconcileTransaction=P.ReactReconcileTransaction.getPooled(!0)}function i(t,e,n,o,i,a){return r(),_.batchedUpdates(t,e,n,o,i,a)}function a(t,e){return t._mountOrder-e._mountOrder}function s(t){var e=t.dirtyComponentsLength;e!==m.length?c("124",e,m.length):void 0,m.sort(a),y++;for(var n=0;n<e;n++){var r=m[n],o=r._pendingCallbacks;r._pendingCallbacks=null;var i;if(h.logTopLevelRenders){var s=r;r._currentElement.type.isReactTopLevelWrapper&&(s=r._renderedComponent),i="React update: "+s.getName(),console.time(i)}if(g.performUpdateIfNecessary(r,t.reconcileTransaction,y),i&&console.timeEnd(i),o)for(var l=0;l<o.length;l++)t.callbackQueue.enqueue(o[l],r.getPublicInstance())}}function l(t){return r(),_.isBatchingUpdates?(m.push(t),void(null==t._updateBatchNumber&&(t._updateBatchNumber=y+1))):void _.batchedUpdates(l,t)}function u(t,e){_.isBatchingUpdates?void 0:c("125"),b.enqueue(t,e),x=!0}var c=n(179),f=n(197),d=n(205),p=n(198),h=n(206),g=n(207),v=n(211),m=(n(181),[]),y=0,b=d.getPooled(),x=!1,_=null,w={initialize:function(){this.dirtyComponentsLength=m.length},close:function(){this.dirtyComponentsLength!==m.length?(m.splice(0,this.dirtyComponentsLength),k()):m.length=0}},T={initialize:function(){this.callbackQueue.reset()},close:function(){this.callbackQueue.notifyAll()}},C=[w,T];f(o.prototype,v,{getTransactionWrappers:function(){return C},destructor:function(){this.dirtyComponentsLength=null,d.release(this.callbackQueue),this.callbackQueue=null,P.ReactReconcileTransaction.release(this.reconcileTransaction),this.reconcileTransaction=null},perform:function(t,e,n){return v.perform.call(this,this.reconcileTransaction.perform,this.reconcileTransaction,t,e,n)}}),p.addPoolingTo(o);var k=function(){for(;m.length||x;){if(m.length){var t=o.getPooled();t.perform(s,null,t),o.release(t)}if(x){x=!1;var e=b;b=d.getPooled(),e.notifyAll(),d.release(e)}}},E={injectReconcileTransaction:function(t){t?void 0:c("126"),P.ReactReconcileTransaction=t},injectBatchingStrategy:function(t){t?void 0:c("127"),"function"!=typeof t.batchedUpdates?c("128"):void 0,"boolean"!=typeof t.isBatchingUpdates?c("129"):void 0,_=t}},P={ReactReconcileTransaction:null,batchedUpdates:i,enqueueUpdate:l,flushBatchedUpdates:k,injection:E,asap:u};t.exports=P},function(t,e,n){"use strict";function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}var o=n(179),i=n(198),a=(n(181),function(){function t(e){r(this,t),this._callbacks=null,this._contexts=null,this._arg=e}return t.prototype.enqueue=function(t,e){this._callbacks=this._callbacks||[],this._callbacks.push(t),this._contexts=this._contexts||[],this._contexts.push(e)},t.prototype.notifyAll=function(){var t=this._callbacks,e=this._contexts,n=this._arg;if(t&&e){t.length!==e.length?o("24"):void 0,this._callbacks=null,this._contexts=null;for(var r=0;r<t.length;r++)t[r].call(e[r],n);t.length=0,e.length=0}},t.prototype.checkpoint=function(){return this._callbacks?this._callbacks.length:0},t.prototype.rollback=function(t){this._callbacks&&this._contexts&&(this._callbacks.length=t,this._contexts.length=t)},t.prototype.reset=function(){this._callbacks=null,this._contexts=null},t.prototype.destructor=function(){this.reset()},t}());t.exports=i.addPoolingTo(a)},function(t,e){"use strict";var n={logTopLevelRenders:!1};t.exports=n},function(t,e,n){"use strict";function r(){o.attachRefs(this,this._currentElement)}var o=n(208),i=(n(210),n(191),{mountComponent:function(t,e,n,o,i,a){var s=t.mountComponent(e,n,o,i,a);return t._currentElement&&null!=t._currentElement.ref&&e.getReactMountReady().enqueue(r,t),s},getHostNode:function(t){return t.getHostNode()},unmountComponent:function(t,e){o.detachRefs(t,t._currentElement),t.unmountComponent(e)},receiveComponent:function(t,e,n,i){var a=t._currentElement;if(e!==a||i!==t._context){var s=o.shouldUpdateRefs(a,e);s&&o.detachRefs(t,a),t.receiveComponent(e,n,i),s&&t._currentElement&&null!=t._currentElement.ref&&n.getReactMountReady().enqueue(r,t)}},performUpdateIfNecessary:function(t,e,n){t._updateBatchNumber===n&&t.performUpdateIfNecessary(e)}});t.exports=i},function(t,e,n){"use strict";function r(t,e,n){"function"==typeof t?t(e.getPublicInstance()):i.addComponentAsRefTo(e,t,n)}function o(t,e,n){"function"==typeof t?t(null):i.removeComponentAsRefFrom(e,t,n)}var i=n(209),a={};a.attachRefs=function(t,e){if(null!==e&&"object"==typeof e){var n=e.ref;null!=n&&r(n,t,e._owner)}},a.shouldUpdateRefs=function(t,e){var n=null,r=null;null!==t&&"object"==typeof t&&(n=t.ref,r=t._owner);var o=null,i=null;return null!==e&&"object"==typeof e&&(o=e.ref,i=e._owner),n!==o||"string"==typeof o&&i!==r},a.detachRefs=function(t,e){if(null!==e&&"object"==typeof e){var n=e.ref;null!=n&&o(n,t,e._owner)}},t.exports=a},function(t,e,n){"use strict";function r(t){return!(!t||"function"!=typeof t.attachRef||"function"!=typeof t.detachRef)}var o=n(179),i=(n(181),{addComponentAsRefTo:function(t,e,n){r(n)?void 0:o("119"),n.attachRef(e,t)},removeComponentAsRefFrom:function(t,e,n){r(n)?void 0:o("120");var i=n.getPublicInstance();i&&i.refs[e]===t.getPublicInstance()&&n.detachRef(e)}});t.exports=i},function(t,e,n){"use strict";var r=null;t.exports={debugTool:r}},function(t,e,n){"use strict";var r=n(179),o=(n(181),{}),i={reinitializeTransaction:function(){
this.transactionWrappers=this.getTransactionWrappers(),this.wrapperInitData?this.wrapperInitData.length=0:this.wrapperInitData=[],this._isInTransaction=!1},_isInTransaction:!1,getTransactionWrappers:null,isInTransaction:function(){return!!this._isInTransaction},perform:function(t,e,n,o,i,a,s,l){this.isInTransaction()?r("27"):void 0;var u,c;try{this._isInTransaction=!0,u=!0,this.initializeAll(0),c=t.call(e,n,o,i,a,s,l),u=!1}finally{try{if(u)try{this.closeAll(0)}catch(t){}else this.closeAll(0)}finally{this._isInTransaction=!1}}return c},initializeAll:function(t){for(var e=this.transactionWrappers,n=t;n<e.length;n++){var r=e[n];try{this.wrapperInitData[n]=o,this.wrapperInitData[n]=r.initialize?r.initialize.call(this):null}finally{if(this.wrapperInitData[n]===o)try{this.initializeAll(n+1)}catch(t){}}}},closeAll:function(t){this.isInTransaction()?void 0:r("28");for(var e=this.transactionWrappers,n=t;n<e.length;n++){var i,a=e[n],s=this.wrapperInitData[n];try{i=!0,s!==o&&a.close&&a.close.call(this,s),i=!1}finally{if(i)try{this.closeAll(n+1)}catch(t){}}}this.wrapperInitData.length=0}};t.exports=i},function(t,e){"use strict";function n(t){var e=t.target||t.srcElement||window;return e.correspondingUseElement&&(e=e.correspondingUseElement),3===e.nodeType?e.parentNode:e}t.exports=n},function(t,e,n){"use strict";/**
	 * Checks if an event is supported in the current execution environment.
	 *
	 * NOTE: This will not work correctly for non-generic events such as `change`,
	 * `reset`, `load`, `error`, and `select`.
	 *
	 * Borrows from Modernizr.
	 *
	 * @param {string} eventNameSuffix Event name, e.g. "click".
	 * @param {?boolean} capture Check if the capture phase is supported.
	 * @return {boolean} True if the event is supported.
	 * @internal
	 * @license Modernizr 3.0.0pre (Custom Build) | MIT
	 */
function r(t,e){if(!i.canUseDOM||e&&!("addEventListener"in document))return!1;var n="on"+t,r=n in document;if(!r){var a=document.createElement("div");a.setAttribute(n,"return;"),r="function"==typeof a[n]}return!r&&o&&"wheel"===t&&(r=document.implementation.hasFeature("Events.wheel","3.0")),r}var o,i=n(195);i.canUseDOM&&(o=document.implementation&&document.implementation.hasFeature&&document.implementation.hasFeature("","")!==!0),t.exports=r},function(t,e){"use strict";function n(t){var e=t&&t.nodeName&&t.nodeName.toLowerCase();return"input"===e?!!r[t.type]:"textarea"===e}var r={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};t.exports=n},function(t,e){"use strict";var n=["ResponderEventPlugin","SimpleEventPlugin","TapEventPlugin","EnterLeaveEventPlugin","ChangeEventPlugin","SelectEventPlugin","BeforeInputEventPlugin"];t.exports=n},function(t,e,n){"use strict";var r=n(186),o=n(178),i=n(217),a={mouseEnter:{registrationName:"onMouseEnter",dependencies:["topMouseOut","topMouseOver"]},mouseLeave:{registrationName:"onMouseLeave",dependencies:["topMouseOut","topMouseOver"]}},s={eventTypes:a,extractEvents:function(t,e,n,s){if("topMouseOver"===t&&(n.relatedTarget||n.fromElement))return null;if("topMouseOut"!==t&&"topMouseOver"!==t)return null;var l;if(s.window===s)l=s;else{var u=s.ownerDocument;l=u?u.defaultView||u.parentWindow:window}var c,f;if("topMouseOut"===t){c=e;var d=n.relatedTarget||n.toElement;f=d?o.getClosestInstanceFromNode(d):null}else c=null,f=e;if(c===f)return null;var p=null==c?l:o.getNodeFromInstance(c),h=null==f?l:o.getNodeFromInstance(f),g=i.getPooled(a.mouseLeave,c,n,s);g.type="mouseleave",g.target=p,g.relatedTarget=h;var v=i.getPooled(a.mouseEnter,f,n,s);return v.type="mouseenter",v.target=h,v.relatedTarget=p,r.accumulateEnterLeaveDispatches(g,v,c,f),[g,v]}};t.exports=s},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(218),i=n(219),a=n(220),s={screenX:null,screenY:null,clientX:null,clientY:null,ctrlKey:null,shiftKey:null,altKey:null,metaKey:null,getModifierState:a,button:function(t){var e=t.button;return"which"in t?e:2===e?2:4===e?1:0},buttons:null,relatedTarget:function(t){return t.relatedTarget||(t.fromElement===t.srcElement?t.toElement:t.fromElement)},pageX:function(t){return"pageX"in t?t.pageX:t.clientX+i.currentScrollLeft},pageY:function(t){return"pageY"in t?t.pageY:t.clientY+i.currentScrollTop}};o.augmentClass(r,s),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(201),i=n(212),a={view:function(t){if(t.view)return t.view;var e=i(t);if(e.window===e)return e;var n=e.ownerDocument;return n?n.defaultView||n.parentWindow:window},detail:function(t){return t.detail||0}};o.augmentClass(r,a),t.exports=r},function(t,e){"use strict";var n={currentScrollLeft:0,currentScrollTop:0,refreshScrollValues:function(t){n.currentScrollLeft=t.x,n.currentScrollTop=t.y}};t.exports=n},function(t,e){"use strict";function n(t){var e=this,n=e.nativeEvent;if(n.getModifierState)return n.getModifierState(t);var r=o[t];return!!r&&!!n[r]}function r(t){return n}var o={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};t.exports=r},function(t,e,n){"use strict";var r=n(180),o=r.injection.MUST_USE_PROPERTY,i=r.injection.HAS_BOOLEAN_VALUE,a=r.injection.HAS_NUMERIC_VALUE,s=r.injection.HAS_POSITIVE_NUMERIC_VALUE,l=r.injection.HAS_OVERLOADED_BOOLEAN_VALUE,u={isCustomAttribute:RegExp.prototype.test.bind(new RegExp("^(data|aria)-["+r.ATTRIBUTE_NAME_CHAR+"]*$")),Properties:{accept:0,acceptCharset:0,accessKey:0,action:0,allowFullScreen:i,allowTransparency:0,alt:0,as:0,async:i,autoComplete:0,autoPlay:i,capture:i,cellPadding:0,cellSpacing:0,charSet:0,challenge:0,checked:o|i,cite:0,classID:0,className:0,cols:s,colSpan:0,content:0,contentEditable:0,contextMenu:0,controls:i,coords:0,crossOrigin:0,data:0,dateTime:0,default:i,defer:i,dir:0,disabled:i,download:l,draggable:0,encType:0,form:0,formAction:0,formEncType:0,formMethod:0,formNoValidate:i,formTarget:0,frameBorder:0,headers:0,height:0,hidden:i,high:0,href:0,hrefLang:0,htmlFor:0,httpEquiv:0,icon:0,id:0,inputMode:0,integrity:0,is:0,keyParams:0,keyType:0,kind:0,label:0,lang:0,list:0,loop:i,low:0,manifest:0,marginHeight:0,marginWidth:0,max:0,maxLength:0,media:0,mediaGroup:0,method:0,min:0,minLength:0,multiple:o|i,muted:o|i,name:0,nonce:0,noValidate:i,open:i,optimum:0,pattern:0,placeholder:0,playsInline:i,poster:0,preload:0,profile:0,radioGroup:0,readOnly:i,referrerPolicy:0,rel:0,required:i,reversed:i,role:0,rows:s,rowSpan:a,sandbox:0,scope:0,scoped:i,scrolling:0,seamless:i,selected:o|i,shape:0,size:s,sizes:0,span:s,spellCheck:0,src:0,srcDoc:0,srcLang:0,srcSet:0,start:a,step:0,style:0,summary:0,tabIndex:0,target:0,title:0,type:0,useMap:0,value:0,width:0,wmode:0,wrap:0,about:0,datatype:0,inlist:0,prefix:0,property:0,resource:0,typeof:0,vocab:0,autoCapitalize:0,autoCorrect:0,autoSave:0,color:0,itemProp:0,itemScope:i,itemType:0,itemID:0,itemRef:0,results:0,security:0,unselectable:0},DOMAttributeNames:{acceptCharset:"accept-charset",className:"class",htmlFor:"for",httpEquiv:"http-equiv"},DOMPropertyNames:{}};t.exports=u},function(t,e,n){"use strict";var r=n(223),o=n(234),i={processChildrenUpdates:o.dangerouslyProcessChildrenUpdates,replaceNodeWithMarkup:r.dangerouslyReplaceNodeWithMarkup};t.exports=i},function(t,e,n){"use strict";function r(t,e){return Array.isArray(e)&&(e=e[1]),e?e.nextSibling:t.firstChild}function o(t,e,n){c.insertTreeBefore(t,e,n)}function i(t,e,n){Array.isArray(e)?s(t,e[0],e[1],n):g(t,e,n)}function a(t,e){if(Array.isArray(e)){var n=e[1];e=e[0],l(t,e,n),t.removeChild(n)}t.removeChild(e)}function s(t,e,n,r){for(var o=e;;){var i=o.nextSibling;if(g(t,o,r),o===n)break;o=i}}function l(t,e,n){for(;;){var r=e.nextSibling;if(r===n)break;t.removeChild(r)}}function u(t,e,n){var r=t.parentNode,o=t.nextSibling;o===e?n&&g(r,document.createTextNode(n),o):n?(h(o,n),l(r,o,e)):l(r,t,e)}var c=n(224),f=n(230),d=(n(178),n(210),n(227)),p=n(226),h=n(228),g=d(function(t,e,n){t.insertBefore(e,n)}),v=f.dangerouslyReplaceNodeWithMarkup,m={dangerouslyReplaceNodeWithMarkup:v,replaceDelimitedText:u,processUpdates:function(t,e){for(var n=0;n<e.length;n++){var s=e[n];switch(s.type){case"INSERT_MARKUP":o(t,s.content,r(t,s.afterNode));break;case"MOVE_EXISTING":i(t,s.fromNode,r(t,s.afterNode));break;case"SET_MARKUP":p(t,s.content);break;case"TEXT_CONTENT":h(t,s.content);break;case"REMOVE_NODE":a(t,s.fromNode)}}}};t.exports=m},function(t,e,n){"use strict";function r(t){if(v){var e=t.node,n=t.children;if(n.length)for(var r=0;r<n.length;r++)m(e,n[r],null);else null!=t.html?f(e,t.html):null!=t.text&&p(e,t.text)}}function o(t,e){t.parentNode.replaceChild(e.node,t),r(e)}function i(t,e){v?t.children.push(e):t.node.appendChild(e.node)}function a(t,e){v?t.html=e:f(t.node,e)}function s(t,e){v?t.text=e:p(t.node,e)}function l(){return this.node.nodeName}function u(t){return{node:t,children:[],html:null,text:null,toString:l}}var c=n(225),f=n(226),d=n(227),p=n(228),h=1,g=11,v="undefined"!=typeof document&&"number"==typeof document.documentMode||"undefined"!=typeof navigator&&"string"==typeof navigator.userAgent&&/\bEdge\/\d/.test(navigator.userAgent),m=d(function(t,e,n){e.node.nodeType===g||e.node.nodeType===h&&"object"===e.node.nodeName.toLowerCase()&&(null==e.node.namespaceURI||e.node.namespaceURI===c.html)?(r(e),t.insertBefore(e.node,n)):(t.insertBefore(e.node,n),r(e))});u.insertTreeBefore=m,u.replaceChildWithTree=o,u.queueChild=i,u.queueHTML=a,u.queueText=s,t.exports=u},function(t,e){"use strict";var n={html:"http://www.w3.org/1999/xhtml",mathml:"http://www.w3.org/1998/Math/MathML",svg:"http://www.w3.org/2000/svg"};t.exports=n},function(t,e,n){"use strict";var r,o=n(195),i=n(225),a=/^[ \r\n\t\f]/,s=/<(!--|link|noscript|meta|script|style)[ \r\n\t\f\/>]/,l=n(227),u=l(function(t,e){if(t.namespaceURI!==i.svg||"innerHTML"in t)t.innerHTML=e;else{r=r||document.createElement("div"),r.innerHTML="<svg>"+e+"</svg>";for(var n=r.firstChild;n.firstChild;)t.appendChild(n.firstChild)}});if(o.canUseDOM){var c=document.createElement("div");c.innerHTML=" ",""===c.innerHTML&&(u=function(t,e){if(t.parentNode&&t.parentNode.replaceChild(t,t),a.test(e)||"<"===e[0]&&s.test(e)){t.innerHTML=String.fromCharCode(65279)+e;var n=t.firstChild;1===n.data.length?t.removeChild(n):n.deleteData(0,1)}else t.innerHTML=e}),c=null}t.exports=u},function(t,e){"use strict";var n=function(t){return"undefined"!=typeof MSApp&&MSApp.execUnsafeLocalFunction?function(e,n,r,o){MSApp.execUnsafeLocalFunction(function(){return t(e,n,r,o)})}:t};t.exports=n},function(t,e,n){"use strict";var r=n(195),o=n(229),i=n(226),a=function(t,e){if(e){var n=t.firstChild;if(n&&n===t.lastChild&&3===n.nodeType)return void(n.nodeValue=e)}t.textContent=e};r.canUseDOM&&("textContent"in document.documentElement||(a=function(t,e){return 3===t.nodeType?void(t.nodeValue=e):void i(t,o(e))})),t.exports=a},function(t,e){"use strict";function n(t){var e=""+t,n=o.exec(e);if(!n)return e;var r,i="",a=0,s=0;for(a=n.index;a<e.length;a++){switch(e.charCodeAt(a)){case 34:r="&quot;";break;case 38:r="&amp;";break;case 39:r="&#x27;";break;case 60:r="&lt;";break;case 62:r="&gt;";break;default:continue}s!==a&&(i+=e.substring(s,a)),s=a+1,i+=r}return s!==a?i+e.substring(s,a):i}function r(t){return"boolean"==typeof t||"number"==typeof t?""+t:n(t)}var o=/["'&<>]/;t.exports=r},function(t,e,n){"use strict";var r=n(179),o=n(224),i=n(195),a=n(231),s=n(192),l=(n(181),{dangerouslyReplaceNodeWithMarkup:function(t,e){if(i.canUseDOM?void 0:r("56"),e?void 0:r("57"),"HTML"===t.nodeName?r("58"):void 0,"string"==typeof e){var n=a(e,s)[0];t.parentNode.replaceChild(n,t)}else o.replaceChildWithTree(t,e)}});t.exports=l},function(t,e,n){"use strict";function r(t){var e=t.match(c);return e&&e[1].toLowerCase()}function o(t,e){var n=u;u?void 0:l(!1);var o=r(t),i=o&&s(o);if(i){n.innerHTML=i[1]+t+i[2];for(var c=i[0];c--;)n=n.lastChild}else n.innerHTML=t;var f=n.getElementsByTagName("script");f.length&&(e?void 0:l(!1),a(f).forEach(e));for(var d=Array.from(n.childNodes);n.lastChild;)n.removeChild(n.lastChild);return d}var i=n(195),a=n(232),s=n(233),l=n(181),u=i.canUseDOM?document.createElement("div"):null,c=/^\s*<(\w+)/;t.exports=o},function(t,e,n){"use strict";function r(t){var e=t.length;if(Array.isArray(t)||"object"!=typeof t&&"function"!=typeof t?a(!1):void 0,"number"!=typeof e?a(!1):void 0,0===e||e-1 in t?void 0:a(!1),"function"==typeof t.callee?a(!1):void 0,t.hasOwnProperty)try{return Array.prototype.slice.call(t)}catch(t){}for(var n=Array(e),r=0;r<e;r++)n[r]=t[r];return n}function o(t){return!!t&&("object"==typeof t||"function"==typeof t)&&"length"in t&&!("setInterval"in t)&&"number"!=typeof t.nodeType&&(Array.isArray(t)||"callee"in t||"item"in t)}function i(t){return o(t)?Array.isArray(t)?t.slice():r(t):[t]}var a=n(181);t.exports=i},function(t,e,n){"use strict";function r(t){return a?void 0:i(!1),d.hasOwnProperty(t)||(t="*"),s.hasOwnProperty(t)||("*"===t?a.innerHTML="<link />":a.innerHTML="<"+t+"></"+t+">",s[t]=!a.firstChild),s[t]?d[t]:null}var o=n(195),i=n(181),a=o.canUseDOM?document.createElement("div"):null,s={},l=[1,'<select multiple="true">',"</select>"],u=[1,"<table>","</table>"],c=[3,"<table><tbody><tr>","</tr></tbody></table>"],f=[1,'<svg xmlns="http://www.w3.org/2000/svg">',"</svg>"],d={"*":[1,"?<div>","</div>"],area:[1,"<map>","</map>"],col:[2,"<table><tbody></tbody><colgroup>","</colgroup></table>"],legend:[1,"<fieldset>","</fieldset>"],param:[1,"<object>","</object>"],tr:[2,"<table><tbody>","</tbody></table>"],optgroup:l,option:l,caption:u,colgroup:u,tbody:u,tfoot:u,thead:u,td:c,th:c},p=["circle","clipPath","defs","ellipse","g","image","line","linearGradient","mask","path","pattern","polygon","polyline","radialGradient","rect","stop","text","tspan"];p.forEach(function(t){d[t]=f,s[t]=!0}),t.exports=r},function(t,e,n){"use strict";var r=n(223),o=n(178),i={dangerouslyProcessChildrenUpdates:function(t,e){var n=o.getNodeFromInstance(t);r.processUpdates(n,e)}};t.exports=i},function(t,e,n){"use strict";function r(t){if(t){var e=t._currentElement._owner||null;if(e){var n=e.getName();if(n)return" This DOM node was rendered by `"+n+"`."}}return""}function o(t,e){e&&(G[t._tag]&&(null!=e.children||null!=e.dangerouslySetInnerHTML?g("137",t._tag,t._currentElement._owner?" Check the render method of "+t._currentElement._owner.getName()+".":""):void 0),null!=e.dangerouslySetInnerHTML&&(null!=e.children?g("60"):void 0,"object"==typeof e.dangerouslySetInnerHTML&&z in e.dangerouslySetInnerHTML?void 0:g("61")),null!=e.style&&"object"!=typeof e.style?g("62",r(t)):void 0)}function i(t,e,n,r){if(!(r instanceof D)){var o=t._hostContainerInfo,i=o._node&&o._node.nodeType===q,s=i?o._node:o._ownerDocument;j(e,s),r.getReactMountReady().enqueue(a,{inst:t,registrationName:e,listener:n})}}function a(){var t=this;T.putListener(t.inst,t.registrationName,t.listener)}function s(){var t=this;S.postMountWrapper(t)}function l(){var t=this;A.postMountWrapper(t)}function u(){var t=this;M.postMountWrapper(t)}function c(){var t=this;t._rootNodeID?void 0:g("63");var e=F(t);switch(e?void 0:g("64"),t._tag){case"iframe":case"object":t._wrapperState.listeners=[k.trapBubbledEvent("topLoad","load",e)];break;case"video":case"audio":t._wrapperState.listeners=[];for(var n in V)V.hasOwnProperty(n)&&t._wrapperState.listeners.push(k.trapBubbledEvent(n,V[n],e));break;case"source":t._wrapperState.listeners=[k.trapBubbledEvent("topError","error",e)];break;case"img":t._wrapperState.listeners=[k.trapBubbledEvent("topError","error",e),k.trapBubbledEvent("topLoad","load",e)];break;case"form":t._wrapperState.listeners=[k.trapBubbledEvent("topReset","reset",e),k.trapBubbledEvent("topSubmit","submit",e)];break;case"input":case"select":case"textarea":t._wrapperState.listeners=[k.trapBubbledEvent("topInvalid","invalid",e)]}}function f(){N.postUpdateWrapper(this)}function d(t){Z.call($,t)||(X.test(t)?void 0:g("65",t),$[t]=!0)}function p(t,e){return t.indexOf("-")>=0||null!=e.is}function h(t){var e=t.type;d(e),this._currentElement=t,this._tag=e.toLowerCase(),this._namespaceURI=null,this._renderedChildren=null,this._previousStyle=null,this._previousStyleCopy=null,this._hostNode=null,this._hostParent=null,this._rootNodeID=0,this._domID=0,this._hostContainerInfo=null,this._wrapperState=null,this._topLevelWrapper=null,this._flags=0}var g=n(179),v=n(197),m=n(236),y=n(238),b=n(224),x=n(225),_=n(180),w=n(246),T=n(187),C=n(188),k=n(248),E=n(182),P=n(178),S=n(251),M=n(254),N=n(255),A=n(256),O=(n(210),n(257)),D=n(275),I=(n(192),n(229)),R=(n(181),n(213),n(265),n(278),n(191),E),L=T.deleteListener,F=P.getNodeFromInstance,j=k.listenTo,B=C.registrationNameModules,U={string:!0,number:!0},H="style",z="__html",W={children:null,dangerouslySetInnerHTML:null,suppressContentEditableWarning:null},q=11,V={topAbort:"abort",topCanPlay:"canplay",topCanPlayThrough:"canplaythrough",topDurationChange:"durationchange",topEmptied:"emptied",topEncrypted:"encrypted",topEnded:"ended",topError:"error",topLoadedData:"loadeddata",topLoadedMetadata:"loadedmetadata",topLoadStart:"loadstart",topPause:"pause",topPlay:"play",topPlaying:"playing",topProgress:"progress",topRateChange:"ratechange",topSeeked:"seeked",topSeeking:"seeking",topStalled:"stalled",topSuspend:"suspend",topTimeUpdate:"timeupdate",topVolumeChange:"volumechange",topWaiting:"waiting"},K={area:!0,base:!0,br:!0,col:!0,embed:!0,hr:!0,img:!0,input:!0,keygen:!0,link:!0,meta:!0,param:!0,source:!0,track:!0,wbr:!0},Y={listing:!0,pre:!0,textarea:!0},G=v({menuitem:!0},K),X=/^[a-zA-Z][a-zA-Z:_\.\-\d]*$/,$={},Z={}.hasOwnProperty,J=1;h.displayName="ReactDOMComponent",h.Mixin={mountComponent:function(t,e,n,r){this._rootNodeID=J++,this._domID=n._idCounter++,this._hostParent=e,this._hostContainerInfo=n;var i=this._currentElement.props;switch(this._tag){case"audio":case"form":case"iframe":case"img":case"link":case"object":case"source":case"video":this._wrapperState={listeners:null},t.getReactMountReady().enqueue(c,this);break;case"input":S.mountWrapper(this,i,e),i=S.getHostProps(this,i),t.getReactMountReady().enqueue(c,this);break;case"option":M.mountWrapper(this,i,e),i=M.getHostProps(this,i);break;case"select":N.mountWrapper(this,i,e),i=N.getHostProps(this,i),t.getReactMountReady().enqueue(c,this);break;case"textarea":A.mountWrapper(this,i,e),i=A.getHostProps(this,i),t.getReactMountReady().enqueue(c,this)}o(this,i);var a,f;null!=e?(a=e._namespaceURI,f=e._tag):n._tag&&(a=n._namespaceURI,f=n._tag),(null==a||a===x.svg&&"foreignobject"===f)&&(a=x.html),a===x.html&&("svg"===this._tag?a=x.svg:"math"===this._tag&&(a=x.mathml)),this._namespaceURI=a;var d;if(t.useCreateElement){var p,h=n._ownerDocument;if(a===x.html)if("script"===this._tag){var g=h.createElement("div"),v=this._currentElement.type;g.innerHTML="<"+v+"></"+v+">",p=g.removeChild(g.firstChild)}else p=i.is?h.createElement(this._currentElement.type,i.is):h.createElement(this._currentElement.type);else p=h.createElementNS(a,this._currentElement.type);P.precacheNode(this,p),this._flags|=R.hasCachedChildNodes,this._hostParent||w.setAttributeForRoot(p),this._updateDOMProperties(null,i,t);var y=b(p);this._createInitialChildren(t,i,r,y),d=y}else{var _=this._createOpenTagMarkupAndPutListeners(t,i),T=this._createContentMarkup(t,i,r);d=!T&&K[this._tag]?_+"/>":_+">"+T+"</"+this._currentElement.type+">"}switch(this._tag){case"input":t.getReactMountReady().enqueue(s,this),i.autoFocus&&t.getReactMountReady().enqueue(m.focusDOMComponent,this);break;case"textarea":t.getReactMountReady().enqueue(l,this),i.autoFocus&&t.getReactMountReady().enqueue(m.focusDOMComponent,this);break;case"select":i.autoFocus&&t.getReactMountReady().enqueue(m.focusDOMComponent,this);break;case"button":i.autoFocus&&t.getReactMountReady().enqueue(m.focusDOMComponent,this);break;case"option":t.getReactMountReady().enqueue(u,this)}return d},_createOpenTagMarkupAndPutListeners:function(t,e){var n="<"+this._currentElement.type;for(var r in e)if(e.hasOwnProperty(r)){var o=e[r];if(null!=o)if(B.hasOwnProperty(r))o&&i(this,r,o,t);else{r===H&&(o&&(o=this._previousStyleCopy=v({},e.style)),o=y.createMarkupForStyles(o,this));var a=null;null!=this._tag&&p(this._tag,e)?W.hasOwnProperty(r)||(a=w.createMarkupForCustomAttribute(r,o)):a=w.createMarkupForProperty(r,o),a&&(n+=" "+a)}}return t.renderToStaticMarkup?n:(this._hostParent||(n+=" "+w.createMarkupForRoot()),n+=" "+w.createMarkupForID(this._domID))},_createContentMarkup:function(t,e,n){var r="",o=e.dangerouslySetInnerHTML;if(null!=o)null!=o.__html&&(r=o.__html);else{var i=U[typeof e.children]?e.children:null,a=null!=i?null:e.children;if(null!=i)r=I(i);else if(null!=a){var s=this.mountChildren(a,t,n);r=s.join("")}}return Y[this._tag]&&"\n"===r.charAt(0)?"\n"+r:r},_createInitialChildren:function(t,e,n,r){var o=e.dangerouslySetInnerHTML;if(null!=o)null!=o.__html&&b.queueHTML(r,o.__html);else{var i=U[typeof e.children]?e.children:null,a=null!=i?null:e.children;if(null!=i)""!==i&&b.queueText(r,i);else if(null!=a)for(var s=this.mountChildren(a,t,n),l=0;l<s.length;l++)b.queueChild(r,s[l])}},receiveComponent:function(t,e,n){var r=this._currentElement;this._currentElement=t,this.updateComponent(e,r,t,n)},updateComponent:function(t,e,n,r){var i=e.props,a=this._currentElement.props;switch(this._tag){case"input":i=S.getHostProps(this,i),a=S.getHostProps(this,a);break;case"option":i=M.getHostProps(this,i),a=M.getHostProps(this,a);break;case"select":i=N.getHostProps(this,i),a=N.getHostProps(this,a);break;case"textarea":i=A.getHostProps(this,i),a=A.getHostProps(this,a)}switch(o(this,a),this._updateDOMProperties(i,a,t),this._updateDOMChildren(i,a,t,r),this._tag){case"input":S.updateWrapper(this);break;case"textarea":A.updateWrapper(this);break;case"select":t.getReactMountReady().enqueue(f,this)}},_updateDOMProperties:function(t,e,n){var r,o,a;for(r in t)if(!e.hasOwnProperty(r)&&t.hasOwnProperty(r)&&null!=t[r])if(r===H){var s=this._previousStyleCopy;for(o in s)s.hasOwnProperty(o)&&(a=a||{},a[o]="");this._previousStyleCopy=null}else B.hasOwnProperty(r)?t[r]&&L(this,r):p(this._tag,t)?W.hasOwnProperty(r)||w.deleteValueForAttribute(F(this),r):(_.properties[r]||_.isCustomAttribute(r))&&w.deleteValueForProperty(F(this),r);for(r in e){var l=e[r],u=r===H?this._previousStyleCopy:null!=t?t[r]:void 0;if(e.hasOwnProperty(r)&&l!==u&&(null!=l||null!=u))if(r===H)if(l?l=this._previousStyleCopy=v({},l):this._previousStyleCopy=null,u){for(o in u)!u.hasOwnProperty(o)||l&&l.hasOwnProperty(o)||(a=a||{},a[o]="");for(o in l)l.hasOwnProperty(o)&&u[o]!==l[o]&&(a=a||{},a[o]=l[o])}else a=l;else if(B.hasOwnProperty(r))l?i(this,r,l,n):u&&L(this,r);else if(p(this._tag,e))W.hasOwnProperty(r)||w.setValueForAttribute(F(this),r,l);else if(_.properties[r]||_.isCustomAttribute(r)){var c=F(this);null!=l?w.setValueForProperty(c,r,l):w.deleteValueForProperty(c,r)}}a&&y.setValueForStyles(F(this),a,this)},_updateDOMChildren:function(t,e,n,r){var o=U[typeof t.children]?t.children:null,i=U[typeof e.children]?e.children:null,a=t.dangerouslySetInnerHTML&&t.dangerouslySetInnerHTML.__html,s=e.dangerouslySetInnerHTML&&e.dangerouslySetInnerHTML.__html,l=null!=o?null:t.children,u=null!=i?null:e.children,c=null!=o||null!=a,f=null!=i||null!=s;null!=l&&null==u?this.updateChildren(null,n,r):c&&!f&&this.updateTextContent(""),null!=i?o!==i&&this.updateTextContent(""+i):null!=s?a!==s&&this.updateMarkup(""+s):null!=u&&this.updateChildren(u,n,r)},getHostNode:function(){return F(this)},unmountComponent:function(t){switch(this._tag){case"audio":case"form":case"iframe":case"img":case"link":case"object":case"source":case"video":var e=this._wrapperState.listeners;if(e)for(var n=0;n<e.length;n++)e[n].remove();break;case"html":case"head":case"body":g("66",this._tag)}this.unmountChildren(t),P.uncacheNode(this),T.deleteAllListeners(this),this._rootNodeID=0,this._domID=0,this._wrapperState=null},getPublicInstance:function(){return F(this)}},v(h.prototype,h.Mixin,O.Mixin),t.exports=h},function(t,e,n){"use strict";var r=n(178),o=n(237),i={focusDOMComponent:function(){o(r.getNodeFromInstance(this))}};t.exports=i},function(t,e){"use strict";function n(t){try{t.focus()}catch(t){}}t.exports=n},function(t,e,n){"use strict";var r=n(239),o=n(195),i=(n(210),n(240),n(242)),a=n(243),s=n(245),l=(n(191),s(function(t){return a(t)})),u=!1,c="cssFloat";if(o.canUseDOM){var f=document.createElement("div").style;try{f.font=""}catch(t){u=!0}void 0===document.documentElement.style.cssFloat&&(c="styleFloat")}var d={createMarkupForStyles:function(t,e){var n="";for(var r in t)if(t.hasOwnProperty(r)){var o=t[r];null!=o&&(n+=l(r)+":",n+=i(r,o,e)+";")}return n||null},setValueForStyles:function(t,e,n){var o=t.style;for(var a in e)if(e.hasOwnProperty(a)){var s=i(a,e[a],n);if("float"!==a&&"cssFloat"!==a||(a=c),s)o[a]=s;else{var l=u&&r.shorthandPropertyExpansions[a];if(l)for(var f in l)o[f]="";else o[a]=""}}}};t.exports=d},function(t,e){"use strict";function n(t,e){return t+e.charAt(0).toUpperCase()+e.substring(1)}var r={animationIterationCount:!0,borderImageOutset:!0,borderImageSlice:!0,borderImageWidth:!0,boxFlex:!0,boxFlexGroup:!0,boxOrdinalGroup:!0,columnCount:!0,flex:!0,flexGrow:!0,flexPositive:!0,flexShrink:!0,flexNegative:!0,flexOrder:!0,gridRow:!0,gridColumn:!0,fontWeight:!0,lineClamp:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,tabSize:!0,widows:!0,zIndex:!0,zoom:!0,fillOpacity:!0,floodOpacity:!0,stopOpacity:!0,strokeDasharray:!0,strokeDashoffset:!0,strokeMiterlimit:!0,strokeOpacity:!0,strokeWidth:!0},o=["Webkit","ms","Moz","O"];Object.keys(r).forEach(function(t){o.forEach(function(e){r[n(e,t)]=r[t]})});var i={background:{backgroundAttachment:!0,backgroundColor:!0,backgroundImage:!0,backgroundPositionX:!0,backgroundPositionY:!0,backgroundRepeat:!0},backgroundPosition:{backgroundPositionX:!0,backgroundPositionY:!0},border:{borderWidth:!0,borderStyle:!0,borderColor:!0},borderBottom:{borderBottomWidth:!0,borderBottomStyle:!0,borderBottomColor:!0},borderLeft:{borderLeftWidth:!0,borderLeftStyle:!0,borderLeftColor:!0},borderRight:{borderRightWidth:!0,borderRightStyle:!0,borderRightColor:!0},borderTop:{borderTopWidth:!0,borderTopStyle:!0,borderTopColor:!0},font:{fontStyle:!0,fontVariant:!0,fontWeight:!0,fontSize:!0,lineHeight:!0,fontFamily:!0},outline:{outlineWidth:!0,outlineStyle:!0,outlineColor:!0}},a={isUnitlessNumber:r,shorthandPropertyExpansions:i};t.exports=a},function(t,e,n){"use strict";function r(t){return o(t.replace(i,"ms-"))}var o=n(241),i=/^-ms-/;t.exports=r},function(t,e){"use strict";function n(t){return t.replace(r,function(t,e){return e.toUpperCase()})}var r=/-(.)/g;t.exports=n},function(t,e,n){"use strict";function r(t,e,n){var r=null==e||"boolean"==typeof e||""===e;if(r)return"";var o=isNaN(e);if(o||0===e||i.hasOwnProperty(t)&&i[t])return""+e;if("string"==typeof e){e=e.trim()}return e+"px"}var o=n(239),i=(n(191),o.isUnitlessNumber);t.exports=r},function(t,e,n){"use strict";function r(t){return o(t).replace(i,"-ms-")}var o=n(244),i=/^ms-/;t.exports=r},function(t,e){"use strict";function n(t){return t.replace(r,"-$1").toLowerCase()}var r=/([A-Z])/g;t.exports=n},function(t,e){"use strict";function n(t){var e={};return function(n){return e.hasOwnProperty(n)||(e[n]=t.call(this,n)),e[n]}}t.exports=n},function(t,e,n){"use strict";function r(t){return!!u.hasOwnProperty(t)||!l.hasOwnProperty(t)&&(s.test(t)?(u[t]=!0,!0):(l[t]=!0,!1))}function o(t,e){return null==e||t.hasBooleanValue&&!e||t.hasNumericValue&&isNaN(e)||t.hasPositiveNumericValue&&e<1||t.hasOverloadedBooleanValue&&e===!1}var i=n(180),a=(n(178),n(210),n(247)),s=(n(191),new RegExp("^["+i.ATTRIBUTE_NAME_START_CHAR+"]["+i.ATTRIBUTE_NAME_CHAR+"]*$")),l={},u={},c={createMarkupForID:function(t){return i.ID_ATTRIBUTE_NAME+"="+a(t)},setAttributeForID:function(t,e){t.setAttribute(i.ID_ATTRIBUTE_NAME,e)},createMarkupForRoot:function(){return i.ROOT_ATTRIBUTE_NAME+'=""'},setAttributeForRoot:function(t){t.setAttribute(i.ROOT_ATTRIBUTE_NAME,"")},createMarkupForProperty:function(t,e){var n=i.properties.hasOwnProperty(t)?i.properties[t]:null;if(n){if(o(n,e))return"";var r=n.attributeName;return n.hasBooleanValue||n.hasOverloadedBooleanValue&&e===!0?r+'=""':r+"="+a(e)}return i.isCustomAttribute(t)?null==e?"":t+"="+a(e):null},createMarkupForCustomAttribute:function(t,e){return r(t)&&null!=e?t+"="+a(e):""},setValueForProperty:function(t,e,n){var r=i.properties.hasOwnProperty(e)?i.properties[e]:null;if(r){var a=r.mutationMethod;if(a)a(t,n);else{if(o(r,n))return void this.deleteValueForProperty(t,e);if(r.mustUseProperty)t[r.propertyName]=n;else{var s=r.attributeName,l=r.attributeNamespace;l?t.setAttributeNS(l,s,""+n):r.hasBooleanValue||r.hasOverloadedBooleanValue&&n===!0?t.setAttribute(s,""):t.setAttribute(s,""+n)}}}else if(i.isCustomAttribute(e))return void c.setValueForAttribute(t,e,n)},setValueForAttribute:function(t,e,n){if(r(e)){null==n?t.removeAttribute(e):t.setAttribute(e,""+n)}},deleteValueForAttribute:function(t,e){t.removeAttribute(e)},deleteValueForProperty:function(t,e){var n=i.properties.hasOwnProperty(e)?i.properties[e]:null;if(n){var r=n.mutationMethod;if(r)r(t,void 0);else if(n.mustUseProperty){var o=n.propertyName;n.hasBooleanValue?t[o]=!1:t[o]=""}else t.removeAttribute(n.attributeName)}else i.isCustomAttribute(e)&&t.removeAttribute(e)}};t.exports=c},function(t,e,n){"use strict";function r(t){return'"'+o(t)+'"'}var o=n(229);t.exports=r},function(t,e,n){"use strict";function r(t){return Object.prototype.hasOwnProperty.call(t,g)||(t[g]=p++,f[t[g]]={}),f[t[g]]}var o,i=n(197),a=n(188),s=n(249),l=n(219),u=n(250),c=n(213),f={},d=!1,p=0,h={topAbort:"abort",topAnimationEnd:u("animationend")||"animationend",topAnimationIteration:u("animationiteration")||"animationiteration",topAnimationStart:u("animationstart")||"animationstart",topBlur:"blur",topCanPlay:"canplay",topCanPlayThrough:"canplaythrough",topChange:"change",topClick:"click",topCompositionEnd:"compositionend",topCompositionStart:"compositionstart",topCompositionUpdate:"compositionupdate",topContextMenu:"contextmenu",topCopy:"copy",topCut:"cut",topDoubleClick:"dblclick",topDrag:"drag",topDragEnd:"dragend",topDragEnter:"dragenter",topDragExit:"dragexit",topDragLeave:"dragleave",topDragOver:"dragover",topDragStart:"dragstart",topDrop:"drop",topDurationChange:"durationchange",topEmptied:"emptied",topEncrypted:"encrypted",topEnded:"ended",topError:"error",topFocus:"focus",topInput:"input",topKeyDown:"keydown",topKeyPress:"keypress",topKeyUp:"keyup",topLoadedData:"loadeddata",topLoadedMetadata:"loadedmetadata",topLoadStart:"loadstart",topMouseDown:"mousedown",topMouseMove:"mousemove",topMouseOut:"mouseout",topMouseOver:"mouseover",topMouseUp:"mouseup",topPaste:"paste",topPause:"pause",topPlay:"play",topPlaying:"playing",topProgress:"progress",topRateChange:"ratechange",topScroll:"scroll",topSeeked:"seeked",topSeeking:"seeking",topSelectionChange:"selectionchange",topStalled:"stalled",topSuspend:"suspend",topTextInput:"textInput",topTimeUpdate:"timeupdate",topTouchCancel:"touchcancel",topTouchEnd:"touchend",topTouchMove:"touchmove",topTouchStart:"touchstart",topTransitionEnd:u("transitionend")||"transitionend",topVolumeChange:"volumechange",topWaiting:"waiting",topWheel:"wheel"},g="_reactListenersID"+String(Math.random()).slice(2),v=i({},s,{ReactEventListener:null,injection:{injectReactEventListener:function(t){t.setHandleTopLevel(v.handleTopLevel),v.ReactEventListener=t}},setEnabled:function(t){v.ReactEventListener&&v.ReactEventListener.setEnabled(t)},isEnabled:function(){return!(!v.ReactEventListener||!v.ReactEventListener.isEnabled())},listenTo:function(t,e){for(var n=e,o=r(n),i=a.registrationNameDependencies[t],s=0;s<i.length;s++){var l=i[s];o.hasOwnProperty(l)&&o[l]||("topWheel"===l?c("wheel")?v.ReactEventListener.trapBubbledEvent("topWheel","wheel",n):c("mousewheel")?v.ReactEventListener.trapBubbledEvent("topWheel","mousewheel",n):v.ReactEventListener.trapBubbledEvent("topWheel","DOMMouseScroll",n):"topScroll"===l?c("scroll",!0)?v.ReactEventListener.trapCapturedEvent("topScroll","scroll",n):v.ReactEventListener.trapBubbledEvent("topScroll","scroll",v.ReactEventListener.WINDOW_HANDLE):"topFocus"===l||"topBlur"===l?(c("focus",!0)?(v.ReactEventListener.trapCapturedEvent("topFocus","focus",n),v.ReactEventListener.trapCapturedEvent("topBlur","blur",n)):c("focusin")&&(v.ReactEventListener.trapBubbledEvent("topFocus","focusin",n),v.ReactEventListener.trapBubbledEvent("topBlur","focusout",n)),o.topBlur=!0,o.topFocus=!0):h.hasOwnProperty(l)&&v.ReactEventListener.trapBubbledEvent(l,h[l],n),o[l]=!0)}},trapBubbledEvent:function(t,e,n){return v.ReactEventListener.trapBubbledEvent(t,e,n)},trapCapturedEvent:function(t,e,n){return v.ReactEventListener.trapCapturedEvent(t,e,n)},supportsEventPageXY:function(){if(!document.createEvent)return!1;var t=document.createEvent("MouseEvent");return null!=t&&"pageX"in t},ensureScrollValueMonitoring:function(){if(void 0===o&&(o=v.supportsEventPageXY()),!o&&!d){var t=l.refreshScrollValues;v.ReactEventListener.monitorScrollValue(t),d=!0}}});t.exports=v},function(t,e,n){"use strict";function r(t){o.enqueueEvents(t),o.processEventQueue(!1)}var o=n(187),i={handleTopLevel:function(t,e,n,i){var a=o.extractEvents(t,e,n,i);r(a)}};t.exports=i},function(t,e,n){"use strict";function r(t,e){var n={};return n[t.toLowerCase()]=e.toLowerCase(),n["Webkit"+t]="webkit"+e,n["Moz"+t]="moz"+e,n["ms"+t]="MS"+e,n["O"+t]="o"+e.toLowerCase(),n}function o(t){if(s[t])return s[t];if(!a[t])return t;var e=a[t];for(var n in e)if(e.hasOwnProperty(n)&&n in l)return s[t]=e[n];return""}var i=n(195),a={animationend:r("Animation","AnimationEnd"),animationiteration:r("Animation","AnimationIteration"),animationstart:r("Animation","AnimationStart"),transitionend:r("Transition","TransitionEnd")},s={},l={};i.canUseDOM&&(l=document.createElement("div").style,"AnimationEvent"in window||(delete a.animationend.animation,delete a.animationiteration.animation,delete a.animationstart.animation),"TransitionEvent"in window||delete a.transitionend.transition),
t.exports=o},function(t,e,n){"use strict";function r(){this._rootNodeID&&f.updateWrapper(this)}function o(t){var e=this._currentElement.props,n=l.executeOnChange(e,t);c.asap(r,this);var o=e.name;if("radio"===e.type&&null!=o){for(var a=u.getNodeFromInstance(this),s=a;s.parentNode;)s=s.parentNode;for(var f=s.querySelectorAll("input[name="+JSON.stringify(""+o)+'][type="radio"]'),d=0;d<f.length;d++){var p=f[d];if(p!==a&&p.form===a.form){var h=u.getInstanceFromNode(p);h?void 0:i("90"),c.asap(r,h)}}}return n}var i=n(179),a=n(197),s=n(246),l=n(252),u=n(178),c=n(204),f=(n(181),n(191),{getHostProps:function(t,e){var n=l.getValue(e),r=l.getChecked(e),o=a({type:void 0,step:void 0,min:void 0,max:void 0},e,{defaultChecked:void 0,defaultValue:void 0,value:null!=n?n:t._wrapperState.initialValue,checked:null!=r?r:t._wrapperState.initialChecked,onChange:t._wrapperState.onChange});return o},mountWrapper:function(t,e){var n=e.defaultValue;t._wrapperState={initialChecked:null!=e.checked?e.checked:e.defaultChecked,initialValue:null!=e.value?e.value:n,listeners:null,onChange:o.bind(t)}},updateWrapper:function(t){var e=t._currentElement.props,n=e.checked;null!=n&&s.setValueForProperty(u.getNodeFromInstance(t),"checked",n||!1);var r=u.getNodeFromInstance(t),o=l.getValue(e);if(null!=o){var i=""+o;i!==r.value&&(r.value=i)}else null==e.value&&null!=e.defaultValue&&r.defaultValue!==""+e.defaultValue&&(r.defaultValue=""+e.defaultValue),null==e.checked&&null!=e.defaultChecked&&(r.defaultChecked=!!e.defaultChecked)},postMountWrapper:function(t){var e=t._currentElement.props,n=u.getNodeFromInstance(t);switch(e.type){case"submit":case"reset":break;case"color":case"date":case"datetime":case"datetime-local":case"month":case"time":case"week":n.value="",n.value=n.defaultValue;break;default:n.value=n.value}var r=n.name;""!==r&&(n.name=""),n.defaultChecked=!n.defaultChecked,n.defaultChecked=!n.defaultChecked,""!==r&&(n.name=r)}});t.exports=f},function(t,e,n){"use strict";function r(t){null!=t.checkedLink&&null!=t.valueLink?s("87"):void 0}function o(t){r(t),null!=t.value||null!=t.onChange?s("88"):void 0}function i(t){r(t),null!=t.checked||null!=t.onChange?s("89"):void 0}function a(t){if(t){var e=t.getName();if(e)return" Check the render method of `"+e+"`."}return""}var s=n(179),l=n(4),u=n(253),c=(n(181),n(191),{button:!0,checkbox:!0,image:!0,hidden:!0,radio:!0,reset:!0,submit:!0}),f={value:function(t,e,n){return!t[e]||c[t.type]||t.onChange||t.readOnly||t.disabled?null:new Error("You provided a `value` prop to a form field without an `onChange` handler. This will render a read-only field. If the field should be mutable use `defaultValue`. Otherwise, set either `onChange` or `readOnly`.")},checked:function(t,e,n){return!t[e]||t.onChange||t.readOnly||t.disabled?null:new Error("You provided a `checked` prop to a form field without an `onChange` handler. This will render a read-only field. If the field should be mutable use `defaultChecked`. Otherwise, set either `onChange` or `readOnly`.")},onChange:l.PropTypes.func},d={},p={checkPropTypes:function(t,e,n){for(var r in f){if(f.hasOwnProperty(r))var o=f[r](e,r,t,"prop",null,u);if(o instanceof Error&&!(o.message in d)){d[o.message]=!0;a(n)}}},getValue:function(t){return t.valueLink?(o(t),t.valueLink.value):t.value},getChecked:function(t){return t.checkedLink?(i(t),t.checkedLink.value):t.checked},executeOnChange:function(t,e){return t.valueLink?(o(t),t.valueLink.requestChange(e.target.value)):t.checkedLink?(i(t),t.checkedLink.requestChange(e.target.checked)):t.onChange?t.onChange.call(void 0,e):void 0}};t.exports=p},function(t,e){"use strict";var n="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED";t.exports=n},function(t,e,n){"use strict";function r(t){var e="";return i.Children.forEach(t,function(t){null!=t&&("string"==typeof t||"number"==typeof t?e+=t:l||(l=!0))}),e}var o=n(197),i=n(4),a=n(178),s=n(255),l=(n(191),!1),u={mountWrapper:function(t,e,n){var o=null;if(null!=n){var i=n;"optgroup"===i._tag&&(i=i._hostParent),null!=i&&"select"===i._tag&&(o=s.getSelectValueContext(i))}var a=null;if(null!=o){var l;if(l=null!=e.value?e.value+"":r(e.children),a=!1,Array.isArray(o)){for(var u=0;u<o.length;u++)if(""+o[u]===l){a=!0;break}}else a=""+o===l}t._wrapperState={selected:a}},postMountWrapper:function(t){var e=t._currentElement.props;if(null!=e.value){var n=a.getNodeFromInstance(t);n.setAttribute("value",e.value)}},getHostProps:function(t,e){var n=o({selected:void 0,children:void 0},e);null!=t._wrapperState.selected&&(n.selected=t._wrapperState.selected);var i=r(e.children);return i&&(n.children=i),n}};t.exports=u},function(t,e,n){"use strict";function r(){if(this._rootNodeID&&this._wrapperState.pendingUpdate){this._wrapperState.pendingUpdate=!1;var t=this._currentElement.props,e=s.getValue(t);null!=e&&o(this,Boolean(t.multiple),e)}}function o(t,e,n){var r,o,i=l.getNodeFromInstance(t).options;if(e){for(r={},o=0;o<n.length;o++)r[""+n[o]]=!0;for(o=0;o<i.length;o++){var a=r.hasOwnProperty(i[o].value);i[o].selected!==a&&(i[o].selected=a)}}else{for(r=""+n,o=0;o<i.length;o++)if(i[o].value===r)return void(i[o].selected=!0);i.length&&(i[0].selected=!0)}}function i(t){var e=this._currentElement.props,n=s.executeOnChange(e,t);return this._rootNodeID&&(this._wrapperState.pendingUpdate=!0),u.asap(r,this),n}var a=n(197),s=n(252),l=n(178),u=n(204),c=(n(191),!1),f={getHostProps:function(t,e){return a({},e,{onChange:t._wrapperState.onChange,value:void 0})},mountWrapper:function(t,e){var n=s.getValue(e);t._wrapperState={pendingUpdate:!1,initialValue:null!=n?n:e.defaultValue,listeners:null,onChange:i.bind(t),wasMultiple:Boolean(e.multiple)},void 0===e.value||void 0===e.defaultValue||c||(c=!0)},getSelectValueContext:function(t){return t._wrapperState.initialValue},postUpdateWrapper:function(t){var e=t._currentElement.props;t._wrapperState.initialValue=void 0;var n=t._wrapperState.wasMultiple;t._wrapperState.wasMultiple=Boolean(e.multiple);var r=s.getValue(e);null!=r?(t._wrapperState.pendingUpdate=!1,o(t,Boolean(e.multiple),r)):n!==Boolean(e.multiple)&&(null!=e.defaultValue?o(t,Boolean(e.multiple),e.defaultValue):o(t,Boolean(e.multiple),e.multiple?[]:""))}};t.exports=f},function(t,e,n){"use strict";function r(){this._rootNodeID&&c.updateWrapper(this)}function o(t){var e=this._currentElement.props,n=s.executeOnChange(e,t);return u.asap(r,this),n}var i=n(179),a=n(197),s=n(252),l=n(178),u=n(204),c=(n(181),n(191),{getHostProps:function(t,e){null!=e.dangerouslySetInnerHTML?i("91"):void 0;var n=a({},e,{value:void 0,defaultValue:void 0,children:""+t._wrapperState.initialValue,onChange:t._wrapperState.onChange});return n},mountWrapper:function(t,e){var n=s.getValue(e),r=n;if(null==n){var a=e.defaultValue,l=e.children;null!=l&&(null!=a?i("92"):void 0,Array.isArray(l)&&(l.length<=1?void 0:i("93"),l=l[0]),a=""+l),null==a&&(a=""),r=a}t._wrapperState={initialValue:""+r,listeners:null,onChange:o.bind(t)}},updateWrapper:function(t){var e=t._currentElement.props,n=l.getNodeFromInstance(t),r=s.getValue(e);if(null!=r){var o=""+r;o!==n.value&&(n.value=o),null==e.defaultValue&&(n.defaultValue=o)}null!=e.defaultValue&&(n.defaultValue=e.defaultValue)},postMountWrapper:function(t){var e=l.getNodeFromInstance(t),n=e.textContent;n===t._wrapperState.initialValue&&(e.value=n)}});t.exports=c},function(t,e,n){"use strict";function r(t,e,n){return{type:"INSERT_MARKUP",content:t,fromIndex:null,fromNode:null,toIndex:n,afterNode:e}}function o(t,e,n){return{type:"MOVE_EXISTING",content:null,fromIndex:t._mountIndex,fromNode:d.getHostNode(t),toIndex:n,afterNode:e}}function i(t,e){return{type:"REMOVE_NODE",content:null,fromIndex:t._mountIndex,fromNode:e,toIndex:null,afterNode:null}}function a(t){return{type:"SET_MARKUP",content:t,fromIndex:null,fromNode:null,toIndex:null,afterNode:null}}function s(t){return{type:"TEXT_CONTENT",content:t,fromIndex:null,fromNode:null,toIndex:null,afterNode:null}}function l(t,e){return e&&(t=t||[],t.push(e)),t}function u(t,e){f.processChildrenUpdates(t,e)}var c=n(179),f=n(258),d=(n(259),n(210),n(11),n(207)),p=n(260),h=(n(192),n(274)),g=(n(181),{Mixin:{_reconcilerInstantiateChildren:function(t,e,n){return p.instantiateChildren(t,e,n)},_reconcilerUpdateChildren:function(t,e,n,r,o,i){var a,s=0;return a=h(e,s),p.updateChildren(t,a,n,r,o,this,this._hostContainerInfo,i,s),a},mountChildren:function(t,e,n){var r=this._reconcilerInstantiateChildren(t,e,n);this._renderedChildren=r;var o=[],i=0;for(var a in r)if(r.hasOwnProperty(a)){var s=r[a],l=0,u=d.mountComponent(s,e,this,this._hostContainerInfo,n,l);s._mountIndex=i++,o.push(u)}return o},updateTextContent:function(t){var e=this._renderedChildren;p.unmountChildren(e,!1);for(var n in e)e.hasOwnProperty(n)&&c("118");var r=[s(t)];u(this,r)},updateMarkup:function(t){var e=this._renderedChildren;p.unmountChildren(e,!1);for(var n in e)e.hasOwnProperty(n)&&c("118");var r=[a(t)];u(this,r)},updateChildren:function(t,e,n){this._updateChildren(t,e,n)},_updateChildren:function(t,e,n){var r=this._renderedChildren,o={},i=[],a=this._reconcilerUpdateChildren(r,t,i,o,e,n);if(a||r){var s,c=null,f=0,p=0,h=0,g=null;for(s in a)if(a.hasOwnProperty(s)){var v=r&&r[s],m=a[s];v===m?(c=l(c,this.moveChild(v,g,f,p)),p=Math.max(v._mountIndex,p),v._mountIndex=f):(v&&(p=Math.max(v._mountIndex,p)),c=l(c,this._mountChildAtIndex(m,i[h],g,f,e,n)),h++),f++,g=d.getHostNode(m)}for(s in o)o.hasOwnProperty(s)&&(c=l(c,this._unmountChild(r[s],o[s])));c&&u(this,c),this._renderedChildren=a}},unmountChildren:function(t){var e=this._renderedChildren;p.unmountChildren(e,t),this._renderedChildren=null},moveChild:function(t,e,n,r){if(t._mountIndex<r)return o(t,e,n)},createChild:function(t,e,n){return r(n,e,t._mountIndex)},removeChild:function(t,e){return i(t,e)},_mountChildAtIndex:function(t,e,n,r,o,i){return t._mountIndex=r,this.createChild(t,n,e)},_unmountChild:function(t,e){var n=this.removeChild(t,e);return t._mountIndex=null,n}}});t.exports=g},function(t,e,n){"use strict";var r=n(179),o=(n(181),!1),i={replaceNodeWithMarkup:null,processChildrenUpdates:null,injection:{injectEnvironment:function(t){o?r("104"):void 0,i.replaceNodeWithMarkup=t.replaceNodeWithMarkup,i.processChildrenUpdates=t.processChildrenUpdates,o=!0}}};t.exports=i},function(t,e){"use strict";var n={remove:function(t){t._reactInternalInstance=void 0},get:function(t){return t._reactInternalInstance},has:function(t){return void 0!==t._reactInternalInstance},set:function(t,e){t._reactInternalInstance=e}};t.exports=n},function(t,e,n){(function(e){"use strict";function r(t,e,n,r){var o=void 0===t[n];null!=e&&o&&(t[n]=i(e,!0))}var o=n(207),i=n(261),a=(n(270),n(266)),s=n(271),l=(n(191),{instantiateChildren:function(t,e,n,o){if(null==t)return null;var i={};return s(t,r,i),i},updateChildren:function(t,e,n,r,s,l,u,c,f){if(e||t){var d,p;for(d in e)if(e.hasOwnProperty(d)){p=t&&t[d];var h=p&&p._currentElement,g=e[d];if(null!=p&&a(h,g))o.receiveComponent(p,g,s,c),e[d]=p;else{p&&(r[d]=o.getHostNode(p),o.unmountComponent(p,!1));var v=i(g,!0);e[d]=v;var m=o.mountComponent(v,s,l,u,c,f);n.push(m)}}for(d in t)!t.hasOwnProperty(d)||e&&e.hasOwnProperty(d)||(p=t[d],r[d]=o.getHostNode(p),o.unmountComponent(p,!1))}},unmountChildren:function(t,e){for(var n in t)if(t.hasOwnProperty(n)){var r=t[n];o.unmountComponent(r,e)}}});t.exports=l}).call(e,n(111))},function(t,e,n){"use strict";function r(t){if(t){var e=t.getName();if(e)return" Check the render method of `"+e+"`."}return""}function o(t){return"function"==typeof t&&"undefined"!=typeof t.prototype&&"function"==typeof t.prototype.mountComponent&&"function"==typeof t.prototype.receiveComponent}function i(t,e){var n;if(null===t||t===!1)n=u.create(i);else if("object"==typeof t){var s=t,l=s.type;if("function"!=typeof l&&"string"!=typeof l){var d="";d+=r(s._owner),a("130",null==l?l:typeof l,d)}"string"==typeof s.type?n=c.createInternalComponent(s):o(s.type)?(n=new s.type(s),n.getHostNode||(n.getHostNode=n.getNativeNode)):n=new f(s)}else"string"==typeof t||"number"==typeof t?n=c.createInstanceForText(t):a("131",typeof t);return n._mountIndex=0,n._mountImage=null,n}var a=n(179),s=n(197),l=n(262),u=n(267),c=n(268),f=(n(269),n(181),n(191),function(t){this.construct(t)});s(f.prototype,l,{_instantiateReactComponent:i}),t.exports=i},function(t,e,n){"use strict";function r(t){}function o(t,e){}function i(t){return!(!t.prototype||!t.prototype.isReactComponent)}function a(t){return!(!t.prototype||!t.prototype.isPureReactComponent)}var s=n(179),l=n(197),u=n(4),c=n(258),f=n(11),d=n(190),p=n(259),h=(n(210),n(263)),g=n(207),v=n(264),m=(n(181),n(265)),y=n(266),b=(n(191),{ImpureClass:0,PureClass:1,StatelessFunctional:2});r.prototype.render=function(){var t=p.get(this)._currentElement.type,e=t(this.props,this.context,this.updater);return o(t,e),e};var x=1,_={construct:function(t){this._currentElement=t,this._rootNodeID=0,this._compositeType=null,this._instance=null,this._hostParent=null,this._hostContainerInfo=null,this._updateBatchNumber=null,this._pendingElement=null,this._pendingStateQueue=null,this._pendingReplaceState=!1,this._pendingForceUpdate=!1,this._renderedNodeType=null,this._renderedComponent=null,this._context=null,this._mountOrder=0,this._topLevelWrapper=null,this._pendingCallbacks=null,this._calledComponentWillUnmount=!1},mountComponent:function(t,e,n,l){this._context=l,this._mountOrder=x++,this._hostParent=e,this._hostContainerInfo=n;var c,f=this._currentElement.props,d=this._processContext(l),h=this._currentElement.type,g=t.getUpdateQueue(),m=i(h),y=this._constructComponent(m,f,d,g);m||null!=y&&null!=y.render?a(h)?this._compositeType=b.PureClass:this._compositeType=b.ImpureClass:(c=y,o(h,c),null===y||y===!1||u.isValidElement(y)?void 0:s("105",h.displayName||h.name||"Component"),y=new r(h),this._compositeType=b.StatelessFunctional);y.props=f,y.context=d,y.refs=v,y.updater=g,this._instance=y,p.set(y,this);var _=y.state;void 0===_&&(y.state=_=null),"object"!=typeof _||Array.isArray(_)?s("106",this.getName()||"ReactCompositeComponent"):void 0,this._pendingStateQueue=null,this._pendingReplaceState=!1,this._pendingForceUpdate=!1;var w;return w=y.unstable_handleError?this.performInitialMountWithErrorHandling(c,e,n,t,l):this.performInitialMount(c,e,n,t,l),y.componentDidMount&&t.getReactMountReady().enqueue(y.componentDidMount,y),w},_constructComponent:function(t,e,n,r){return this._constructComponentWithoutOwner(t,e,n,r)},_constructComponentWithoutOwner:function(t,e,n,r){var o=this._currentElement.type;return t?new o(e,n,r):o(e,n,r)},performInitialMountWithErrorHandling:function(t,e,n,r,o){var i,a=r.checkpoint();try{i=this.performInitialMount(t,e,n,r,o)}catch(s){r.rollback(a),this._instance.unstable_handleError(s),this._pendingStateQueue&&(this._instance.state=this._processPendingState(this._instance.props,this._instance.context)),a=r.checkpoint(),this._renderedComponent.unmountComponent(!0),r.rollback(a),i=this.performInitialMount(t,e,n,r,o)}return i},performInitialMount:function(t,e,n,r,o){var i=this._instance,a=0;i.componentWillMount&&(i.componentWillMount(),this._pendingStateQueue&&(i.state=this._processPendingState(i.props,i.context))),void 0===t&&(t=this._renderValidatedComponent());var s=h.getType(t);this._renderedNodeType=s;var l=this._instantiateReactComponent(t,s!==h.EMPTY);this._renderedComponent=l;var u=g.mountComponent(l,r,e,n,this._processChildContext(o),a);return u},getHostNode:function(){return g.getHostNode(this._renderedComponent)},unmountComponent:function(t){if(this._renderedComponent){var e=this._instance;if(e.componentWillUnmount&&!e._calledComponentWillUnmount)if(e._calledComponentWillUnmount=!0,t){var n=this.getName()+".componentWillUnmount()";d.invokeGuardedCallback(n,e.componentWillUnmount.bind(e))}else e.componentWillUnmount();this._renderedComponent&&(g.unmountComponent(this._renderedComponent,t),this._renderedNodeType=null,this._renderedComponent=null,this._instance=null),this._pendingStateQueue=null,this._pendingReplaceState=!1,this._pendingForceUpdate=!1,this._pendingCallbacks=null,this._pendingElement=null,this._context=null,this._rootNodeID=0,this._topLevelWrapper=null,p.remove(e)}},_maskContext:function(t){var e=this._currentElement.type,n=e.contextTypes;if(!n)return v;var r={};for(var o in n)r[o]=t[o];return r},_processContext:function(t){var e=this._maskContext(t);return e},_processChildContext:function(t){var e,n=this._currentElement.type,r=this._instance;if(r.getChildContext&&(e=r.getChildContext()),e){"object"!=typeof n.childContextTypes?s("107",this.getName()||"ReactCompositeComponent"):void 0;for(var o in e)o in n.childContextTypes?void 0:s("108",this.getName()||"ReactCompositeComponent",o);return l({},t,e)}return t},_checkContextTypes:function(t,e,n){},receiveComponent:function(t,e,n){var r=this._currentElement,o=this._context;this._pendingElement=null,this.updateComponent(e,r,t,o,n)},performUpdateIfNecessary:function(t){null!=this._pendingElement?g.receiveComponent(this,this._pendingElement,t,this._context):null!==this._pendingStateQueue||this._pendingForceUpdate?this.updateComponent(t,this._currentElement,this._currentElement,this._context,this._context):this._updateBatchNumber=null},updateComponent:function(t,e,n,r,o){var i=this._instance;null==i?s("136",this.getName()||"ReactCompositeComponent"):void 0;var a,l=!1;this._context===o?a=i.context:(a=this._processContext(o),l=!0);var u=e.props,c=n.props;e!==n&&(l=!0),l&&i.componentWillReceiveProps&&i.componentWillReceiveProps(c,a);var f=this._processPendingState(c,a),d=!0;this._pendingForceUpdate||(i.shouldComponentUpdate?d=i.shouldComponentUpdate(c,f,a):this._compositeType===b.PureClass&&(d=!m(u,c)||!m(i.state,f))),this._updateBatchNumber=null,d?(this._pendingForceUpdate=!1,this._performComponentUpdate(n,c,f,a,t,o)):(this._currentElement=n,this._context=o,i.props=c,i.state=f,i.context=a)},_processPendingState:function(t,e){var n=this._instance,r=this._pendingStateQueue,o=this._pendingReplaceState;if(this._pendingReplaceState=!1,this._pendingStateQueue=null,!r)return n.state;if(o&&1===r.length)return r[0];for(var i=l({},o?r[0]:n.state),a=o?1:0;a<r.length;a++){var s=r[a];l(i,"function"==typeof s?s.call(n,i,t,e):s)}return i},_performComponentUpdate:function(t,e,n,r,o,i){var a,s,l,u=this._instance,c=Boolean(u.componentDidUpdate);c&&(a=u.props,s=u.state,l=u.context),u.componentWillUpdate&&u.componentWillUpdate(e,n,r),this._currentElement=t,this._context=i,u.props=e,u.state=n,u.context=r,this._updateRenderedComponent(o,i),c&&o.getReactMountReady().enqueue(u.componentDidUpdate.bind(u,a,s,l),u)},_updateRenderedComponent:function(t,e){var n=this._renderedComponent,r=n._currentElement,o=this._renderValidatedComponent(),i=0;if(y(r,o))g.receiveComponent(n,o,t,this._processChildContext(e));else{var a=g.getHostNode(n);g.unmountComponent(n,!1);var s=h.getType(o);this._renderedNodeType=s;var l=this._instantiateReactComponent(o,s!==h.EMPTY);this._renderedComponent=l;var u=g.mountComponent(l,t,this._hostParent,this._hostContainerInfo,this._processChildContext(e),i);this._replaceNodeWithMarkup(a,u,n)}},_replaceNodeWithMarkup:function(t,e,n){c.replaceNodeWithMarkup(t,e,n)},_renderValidatedComponentWithoutOwnerOrContext:function(){var t,e=this._instance;return t=e.render()},_renderValidatedComponent:function(){var t;if(this._compositeType!==b.StatelessFunctional){f.current=this;try{t=this._renderValidatedComponentWithoutOwnerOrContext()}finally{f.current=null}}else t=this._renderValidatedComponentWithoutOwnerOrContext();return null===t||t===!1||u.isValidElement(t)?void 0:s("109",this.getName()||"ReactCompositeComponent"),t},attachRef:function(t,e){var n=this.getPublicInstance();null==n?s("110"):void 0;var r=e.getPublicInstance(),o=n.refs===v?n.refs={}:n.refs;o[t]=r},detachRef:function(t){var e=this.getPublicInstance().refs;delete e[t]},getName:function(){var t=this._currentElement.type,e=this._instance&&this._instance.constructor;return t.displayName||e&&e.displayName||t.name||e&&e.name||null},getPublicInstance:function(){var t=this._instance;return this._compositeType===b.StatelessFunctional?null:t},_instantiateReactComponent:null};t.exports=_},function(t,e,n){"use strict";var r=n(179),o=n(4),i=(n(181),{HOST:0,COMPOSITE:1,EMPTY:2,getType:function(t){return null===t||t===!1?i.EMPTY:o.isValidElement(t)?"function"==typeof t.type?i.COMPOSITE:i.HOST:void r("26",t)}});t.exports=i},function(t,e,n){"use strict";var r={};t.exports=r},function(t,e){"use strict";function n(t,e){return t===e?0!==t||0!==e||1/t===1/e:t!==t&&e!==e}function r(t,e){if(n(t,e))return!0;if("object"!=typeof t||null===t||"object"!=typeof e||null===e)return!1;var r=Object.keys(t),i=Object.keys(e);if(r.length!==i.length)return!1;for(var a=0;a<r.length;a++)if(!o.call(e,r[a])||!n(t[r[a]],e[r[a]]))return!1;return!0}var o=Object.prototype.hasOwnProperty;t.exports=r},function(t,e){"use strict";function n(t,e){var n=null===t||t===!1,r=null===e||e===!1;if(n||r)return n===r;var o=typeof t,i=typeof e;return"string"===o||"number"===o?"string"===i||"number"===i:"object"===i&&t.type===e.type&&t.key===e.key}t.exports=n},function(t,e){"use strict";var n,r={injectEmptyComponentFactory:function(t){n=t}},o={create:function(t){return n(t)}};o.injection=r,t.exports=o},function(t,e,n){"use strict";function r(t){return s?void 0:a("111",t.type),new s(t)}function o(t){return new l(t)}function i(t){return t instanceof l}var a=n(179),s=(n(181),null),l=null,u={injectGenericComponentClass:function(t){s=t},injectTextComponentClass:function(t){l=t}},c={createInternalComponent:r,createInstanceForText:o,isTextComponent:i,injection:u};t.exports=c},function(t,e){"use strict";function n(){return r++}var r=1;t.exports=n},function(t,e){"use strict";function n(t){var e=/[=:]/g,n={"=":"=0",":":"=2"},r=(""+t).replace(e,function(t){return n[t]});return"$"+r}function r(t){var e=/(=0|=2)/g,n={"=0":"=","=2":":"},r="."===t[0]&&"$"===t[1]?t.substring(2):t.substring(1);return(""+r).replace(e,function(t){return n[t]})}var o={escape:n,unescape:r};t.exports=o},function(t,e,n){"use strict";function r(t,e){return t&&"object"==typeof t&&null!=t.key?u.escape(t.key):e.toString(36)}function o(t,e,n,i){var d=typeof t;if("undefined"!==d&&"boolean"!==d||(t=null),null===t||"string"===d||"number"===d||"object"===d&&t.$$typeof===s)return n(i,t,""===e?c+r(t,0):e),1;var p,h,g=0,v=""===e?c:e+f;if(Array.isArray(t))for(var m=0;m<t.length;m++)p=t[m],h=v+r(p,m),g+=o(p,h,n,i);else{var y=l(t);if(y){var b,x=y.call(t);if(y!==t.entries)for(var _=0;!(b=x.next()).done;)p=b.value,h=v+r(p,_++),g+=o(p,h,n,i);else for(;!(b=x.next()).done;){var w=b.value;w&&(p=w[1],h=v+u.escape(w[0])+f+r(p,0),g+=o(p,h,n,i))}}else if("object"===d){var T="",C=String(t);a("31","[object Object]"===C?"object with keys {"+Object.keys(t).join(", ")+"}":C,T)}}return g}function i(t,e,n){return null==t?0:o(t,"",e,n)}var a=n(179),s=(n(11),n(272)),l=n(273),u=(n(181),n(270)),c=(n(191),"."),f=":";t.exports=i},function(t,e){"use strict";var n="function"==typeof Symbol&&Symbol.for&&Symbol.for("react.element")||60103;t.exports=n},function(t,e){"use strict";function n(t){var e=t&&(r&&t[r]||t[o]);if("function"==typeof e)return e}var r="function"==typeof Symbol&&Symbol.iterator,o="@@iterator";t.exports=n},function(t,e,n){(function(e){"use strict";function r(t,e,n,r){if(t&&"object"==typeof t){var o=t,i=void 0===o[n];i&&null!=e&&(o[n]=e)}}function o(t,e){if(null==t)return t;var n={};return i(t,r,n),n}var i=(n(270),n(271));n(191);t.exports=o}).call(e,n(111))},function(t,e,n){"use strict";function r(t){this.reinitializeTransaction(),this.renderToStaticMarkup=t,this.useCreateElement=!1,this.updateQueue=new s(this)}var o=n(197),i=n(198),a=n(211),s=(n(210),n(276)),l=[],u={enqueue:function(){}},c={getTransactionWrappers:function(){return l},getReactMountReady:function(){return u},getUpdateQueue:function(){return this.updateQueue},destructor:function(){},checkpoint:function(){},rollback:function(){}};o(r.prototype,a,c),i.addPoolingTo(r),t.exports=r},function(t,e,n){"use strict";function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function o(t,e){}var i=n(277),a=(n(191),function(){function t(e){r(this,t),this.transaction=e}return t.prototype.isMounted=function(t){return!1},t.prototype.enqueueCallback=function(t,e,n){this.transaction.isInTransaction()&&i.enqueueCallback(t,e,n)},t.prototype.enqueueForceUpdate=function(t){this.transaction.isInTransaction()?i.enqueueForceUpdate(t):o(t,"forceUpdate")},t.prototype.enqueueReplaceState=function(t,e){this.transaction.isInTransaction()?i.enqueueReplaceState(t,e):o(t,"replaceState")},t.prototype.enqueueSetState=function(t,e){this.transaction.isInTransaction()?i.enqueueSetState(t,e):o(t,"setState")},t}());t.exports=a},function(t,e,n){"use strict";function r(t){l.enqueueUpdate(t)}function o(t){var e=typeof t;if("object"!==e)return e;var n=t.constructor&&t.constructor.name||e,r=Object.keys(t);return r.length>0&&r.length<20?n+" (keys: "+r.join(", ")+")":n}function i(t,e){var n=s.get(t);if(!n){return null}return n}var a=n(179),s=(n(11),n(259)),l=(n(210),n(204)),u=(n(181),n(191),{isMounted:function(t){var e=s.get(t);return!!e&&!!e._renderedComponent},enqueueCallback:function(t,e,n){u.validateCallback(e,n);var o=i(t);return o?(o._pendingCallbacks?o._pendingCallbacks.push(e):o._pendingCallbacks=[e],void r(o)):null},enqueueCallbackInternal:function(t,e){t._pendingCallbacks?t._pendingCallbacks.push(e):t._pendingCallbacks=[e],r(t)},enqueueForceUpdate:function(t){var e=i(t,"forceUpdate");e&&(e._pendingForceUpdate=!0,r(e))},enqueueReplaceState:function(t,e){var n=i(t,"replaceState");n&&(n._pendingStateQueue=[e],n._pendingReplaceState=!0,r(n))},enqueueSetState:function(t,e){var n=i(t,"setState");if(n){var o=n._pendingStateQueue||(n._pendingStateQueue=[]);o.push(e),r(n)}},enqueueElementInternal:function(t,e,n){t._pendingElement=e,t._context=n,r(t)},validateCallback:function(t,e){t&&"function"!=typeof t?a("122",e,o(t)):void 0}});t.exports=u},function(t,e,n){"use strict";var r=(n(197),n(192)),o=(n(191),r);t.exports=o},function(t,e,n){"use strict";var r=n(197),o=n(224),i=n(178),a=function(t){this._currentElement=null,this._hostNode=null,this._hostParent=null,this._hostContainerInfo=null,this._domID=0};r(a.prototype,{mountComponent:function(t,e,n,r){var a=n._idCounter++;this._domID=a,this._hostParent=e,this._hostContainerInfo=n;var s=" react-empty: "+this._domID+" ";if(t.useCreateElement){var l=n._ownerDocument,u=l.createComment(s);return i.precacheNode(this,u),o(u)}return t.renderToStaticMarkup?"":"<!--"+s+"-->"},receiveComponent:function(){},getHostNode:function(){return i.getNodeFromInstance(this)},unmountComponent:function(){i.uncacheNode(this)}}),t.exports=a},function(t,e,n){"use strict";function r(t,e){"_hostNode"in t?void 0:l("33"),"_hostNode"in e?void 0:l("33");for(var n=0,r=t;r;r=r._hostParent)n++;for(var o=0,i=e;i;i=i._hostParent)o++;for(;n-o>0;)t=t._hostParent,n--;for(;o-n>0;)e=e._hostParent,o--;for(var a=n;a--;){if(t===e)return t;t=t._hostParent,e=e._hostParent}return null}function o(t,e){"_hostNode"in t?void 0:l("35"),"_hostNode"in e?void 0:l("35");for(;e;){if(e===t)return!0;e=e._hostParent}return!1}function i(t){return"_hostNode"in t?void 0:l("36"),t._hostParent}function a(t,e,n){for(var r=[];t;)r.push(t),t=t._hostParent;var o;for(o=r.length;o-- >0;)e(r[o],"captured",n);for(o=0;o<r.length;o++)e(r[o],"bubbled",n)}function s(t,e,n,o,i){for(var a=t&&e?r(t,e):null,s=[];t&&t!==a;)s.push(t),t=t._hostParent;for(var l=[];e&&e!==a;)l.push(e),e=e._hostParent;var u;for(u=0;u<s.length;u++)n(s[u],"bubbled",o);for(u=l.length;u-- >0;)n(l[u],"captured",i)}var l=n(179);n(181);t.exports={isAncestor:o,getLowestCommonAncestor:r,getParentInstance:i,traverseTwoPhase:a,traverseEnterLeave:s}},function(t,e,n){"use strict";var r=n(179),o=n(197),i=n(223),a=n(224),s=n(178),l=n(229),u=(n(181),n(278),function(t){this._currentElement=t,this._stringText=""+t,this._hostNode=null,this._hostParent=null,this._domID=0,this._mountIndex=0,this._closingComment=null,this._commentNodes=null});o(u.prototype,{mountComponent:function(t,e,n,r){var o=n._idCounter++,i=" react-text: "+o+" ",u=" /react-text ";if(this._domID=o,this._hostParent=e,t.useCreateElement){var c=n._ownerDocument,f=c.createComment(i),d=c.createComment(u),p=a(c.createDocumentFragment());return a.queueChild(p,a(f)),this._stringText&&a.queueChild(p,a(c.createTextNode(this._stringText))),a.queueChild(p,a(d)),s.precacheNode(this,f),this._closingComment=d,p}var h=l(this._stringText);return t.renderToStaticMarkup?h:"<!--"+i+"-->"+h+"<!--"+u+"-->"},receiveComponent:function(t,e){if(t!==this._currentElement){this._currentElement=t;var n=""+t;if(n!==this._stringText){this._stringText=n;var r=this.getHostNode();i.replaceDelimitedText(r[0],r[1],n)}}},getHostNode:function(){var t=this._commentNodes;if(t)return t;if(!this._closingComment)for(var e=s.getNodeFromInstance(this),n=e.nextSibling;;){if(null==n?r("67",this._domID):void 0,8===n.nodeType&&" /react-text "===n.nodeValue){this._closingComment=n;break}n=n.nextSibling}return t=[this._hostNode,this._closingComment],this._commentNodes=t,t},unmountComponent:function(){this._closingComment=null,this._commentNodes=null,s.uncacheNode(this)}}),t.exports=u},function(t,e,n){"use strict";function r(){this.reinitializeTransaction()}var o=n(197),i=n(204),a=n(211),s=n(192),l={initialize:s,close:function(){d.isBatchingUpdates=!1}},u={initialize:s,close:i.flushBatchedUpdates.bind(i)},c=[u,l];o(r.prototype,a,{getTransactionWrappers:function(){return c}});var f=new r,d={isBatchingUpdates:!1,batchedUpdates:function(t,e,n,r,o,i){var a=d.isBatchingUpdates;return d.isBatchingUpdates=!0,a?t(e,n,r,o,i):f.perform(t,null,e,n,r,o,i)}};t.exports=d},function(t,e,n){"use strict";function r(t){for(;t._hostParent;)t=t._hostParent;var e=f.getNodeFromInstance(t),n=e.parentNode;return f.getClosestInstanceFromNode(n)}function o(t,e){this.topLevelType=t,this.nativeEvent=e,this.ancestors=[]}function i(t){var e=p(t.nativeEvent),n=f.getClosestInstanceFromNode(e),o=n;do t.ancestors.push(o),o=o&&r(o);while(o);for(var i=0;i<t.ancestors.length;i++)n=t.ancestors[i],g._handleTopLevel(t.topLevelType,n,t.nativeEvent,p(t.nativeEvent))}function a(t){var e=h(window);t(e)}var s=n(197),l=n(284),u=n(195),c=n(198),f=n(178),d=n(204),p=n(212),h=n(285);s(o.prototype,{destructor:function(){this.topLevelType=null,this.nativeEvent=null,this.ancestors.length=0}}),c.addPoolingTo(o,c.twoArgumentPooler);var g={_enabled:!0,_handleTopLevel:null,WINDOW_HANDLE:u.canUseDOM?window:null,setHandleTopLevel:function(t){g._handleTopLevel=t},setEnabled:function(t){g._enabled=!!t},isEnabled:function(){return g._enabled},trapBubbledEvent:function(t,e,n){return n?l.listen(n,e,g.dispatchEvent.bind(null,t)):null},trapCapturedEvent:function(t,e,n){return n?l.capture(n,e,g.dispatchEvent.bind(null,t)):null},monitorScrollValue:function(t){var e=a.bind(null,t);l.listen(window,"scroll",e)},dispatchEvent:function(t,e){if(g._enabled){var n=o.getPooled(t,e);try{d.batchedUpdates(i,n)}finally{o.release(n)}}}};t.exports=g},function(t,e,n){"use strict";var r=n(192),o={listen:function(t,e,n){return t.addEventListener?(t.addEventListener(e,n,!1),{remove:function(){t.removeEventListener(e,n,!1)}}):t.attachEvent?(t.attachEvent("on"+e,n),{remove:function(){t.detachEvent("on"+e,n)}}):void 0},capture:function(t,e,n){return t.addEventListener?(t.addEventListener(e,n,!0),{remove:function(){t.removeEventListener(e,n,!0)}}):{remove:r}},registerDefault:function(){}};t.exports=o},function(t,e){"use strict";function n(t){return t===window?{x:window.pageXOffset||document.documentElement.scrollLeft,y:window.pageYOffset||document.documentElement.scrollTop}:{x:t.scrollLeft,y:t.scrollTop}}t.exports=n},function(t,e,n){"use strict";var r=n(180),o=n(187),i=n(189),a=n(258),s=n(267),l=n(248),u=n(268),c=n(204),f={Component:a.injection,DOMProperty:r.injection,EmptyComponent:s.injection,EventPluginHub:o.injection,EventPluginUtils:i.injection,EventEmitter:l.injection,HostComponent:u.injection,Updates:c.injection};t.exports=f},function(t,e,n){"use strict";function r(t){this.reinitializeTransaction(),this.renderToStaticMarkup=!1,
this.reactMountReady=i.getPooled(null),this.useCreateElement=t}var o=n(197),i=n(205),a=n(198),s=n(248),l=n(288),u=(n(210),n(211)),c=n(277),f={initialize:l.getSelectionInformation,close:l.restoreSelection},d={initialize:function(){var t=s.isEnabled();return s.setEnabled(!1),t},close:function(t){s.setEnabled(t)}},p={initialize:function(){this.reactMountReady.reset()},close:function(){this.reactMountReady.notifyAll()}},h=[f,d,p],g={getTransactionWrappers:function(){return h},getReactMountReady:function(){return this.reactMountReady},getUpdateQueue:function(){return c},checkpoint:function(){return this.reactMountReady.checkpoint()},rollback:function(t){this.reactMountReady.rollback(t)},destructor:function(){i.release(this.reactMountReady),this.reactMountReady=null}};o(r.prototype,u,g),a.addPoolingTo(r),t.exports=r},function(t,e,n){"use strict";function r(t){return i(document.documentElement,t)}var o=n(289),i=n(291),a=n(237),s=n(294),l={hasSelectionCapabilities:function(t){var e=t&&t.nodeName&&t.nodeName.toLowerCase();return e&&("input"===e&&"text"===t.type||"textarea"===e||"true"===t.contentEditable)},getSelectionInformation:function(){var t=s();return{focusedElem:t,selectionRange:l.hasSelectionCapabilities(t)?l.getSelection(t):null}},restoreSelection:function(t){var e=s(),n=t.focusedElem,o=t.selectionRange;e!==n&&r(n)&&(l.hasSelectionCapabilities(n)&&l.setSelection(n,o),a(n))},getSelection:function(t){var e;if("selectionStart"in t)e={start:t.selectionStart,end:t.selectionEnd};else if(document.selection&&t.nodeName&&"input"===t.nodeName.toLowerCase()){var n=document.selection.createRange();n.parentElement()===t&&(e={start:-n.moveStart("character",-t.value.length),end:-n.moveEnd("character",-t.value.length)})}else e=o.getOffsets(t);return e||{start:0,end:0}},setSelection:function(t,e){var n=e.start,r=e.end;if(void 0===r&&(r=n),"selectionStart"in t)t.selectionStart=n,t.selectionEnd=Math.min(r,t.value.length);else if(document.selection&&t.nodeName&&"input"===t.nodeName.toLowerCase()){var i=t.createTextRange();i.collapse(!0),i.moveStart("character",n),i.moveEnd("character",r-n),i.select()}else o.setOffsets(t,e)}};t.exports=l},function(t,e,n){"use strict";function r(t,e,n,r){return t===n&&e===r}function o(t){var e=document.selection,n=e.createRange(),r=n.text.length,o=n.duplicate();o.moveToElementText(t),o.setEndPoint("EndToStart",n);var i=o.text.length,a=i+r;return{start:i,end:a}}function i(t){var e=window.getSelection&&window.getSelection();if(!e||0===e.rangeCount)return null;var n=e.anchorNode,o=e.anchorOffset,i=e.focusNode,a=e.focusOffset,s=e.getRangeAt(0);try{s.startContainer.nodeType,s.endContainer.nodeType}catch(t){return null}var l=r(e.anchorNode,e.anchorOffset,e.focusNode,e.focusOffset),u=l?0:s.toString().length,c=s.cloneRange();c.selectNodeContents(t),c.setEnd(s.startContainer,s.startOffset);var f=r(c.startContainer,c.startOffset,c.endContainer,c.endOffset),d=f?0:c.toString().length,p=d+u,h=document.createRange();h.setStart(n,o),h.setEnd(i,a);var g=h.collapsed;return{start:g?p:d,end:g?d:p}}function a(t,e){var n,r,o=document.selection.createRange().duplicate();void 0===e.end?(n=e.start,r=n):e.start>e.end?(n=e.end,r=e.start):(n=e.start,r=e.end),o.moveToElementText(t),o.moveStart("character",n),o.setEndPoint("EndToStart",o),o.moveEnd("character",r-n),o.select()}function s(t,e){if(window.getSelection){var n=window.getSelection(),r=t[c()].length,o=Math.min(e.start,r),i=void 0===e.end?o:Math.min(e.end,r);if(!n.extend&&o>i){var a=i;i=o,o=a}var s=u(t,o),l=u(t,i);if(s&&l){var f=document.createRange();f.setStart(s.node,s.offset),n.removeAllRanges(),o>i?(n.addRange(f),n.extend(l.node,l.offset)):(f.setEnd(l.node,l.offset),n.addRange(f))}}}var l=n(195),u=n(290),c=n(199),f=l.canUseDOM&&"selection"in document&&!("getSelection"in window),d={getOffsets:f?o:i,setOffsets:f?a:s};t.exports=d},function(t,e){"use strict";function n(t){for(;t&&t.firstChild;)t=t.firstChild;return t}function r(t){for(;t;){if(t.nextSibling)return t.nextSibling;t=t.parentNode}}function o(t,e){for(var o=n(t),i=0,a=0;o;){if(3===o.nodeType){if(a=i+o.textContent.length,i<=e&&a>=e)return{node:o,offset:e-i};i=a}o=n(r(o))}}t.exports=o},function(t,e,n){"use strict";function r(t,e){return!(!t||!e)&&(t===e||!o(t)&&(o(e)?r(t,e.parentNode):"contains"in t?t.contains(e):!!t.compareDocumentPosition&&!!(16&t.compareDocumentPosition(e))))}var o=n(292);t.exports=r},function(t,e,n){"use strict";function r(t){return o(t)&&3==t.nodeType}var o=n(293);t.exports=r},function(t,e){"use strict";function n(t){return!(!t||!("function"==typeof Node?t instanceof Node:"object"==typeof t&&"number"==typeof t.nodeType&&"string"==typeof t.nodeName))}t.exports=n},function(t,e){"use strict";function n(){if("undefined"==typeof document)return null;try{return document.activeElement||document.body}catch(t){return document.body}}t.exports=n},function(t,e){"use strict";var n={xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace"},r={accentHeight:"accent-height",accumulate:0,additive:0,alignmentBaseline:"alignment-baseline",allowReorder:"allowReorder",alphabetic:0,amplitude:0,arabicForm:"arabic-form",ascent:0,attributeName:"attributeName",attributeType:"attributeType",autoReverse:"autoReverse",azimuth:0,baseFrequency:"baseFrequency",baseProfile:"baseProfile",baselineShift:"baseline-shift",bbox:0,begin:0,bias:0,by:0,calcMode:"calcMode",capHeight:"cap-height",clip:0,clipPath:"clip-path",clipRule:"clip-rule",clipPathUnits:"clipPathUnits",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",contentScriptType:"contentScriptType",contentStyleType:"contentStyleType",cursor:0,cx:0,cy:0,d:0,decelerate:0,descent:0,diffuseConstant:"diffuseConstant",direction:0,display:0,divisor:0,dominantBaseline:"dominant-baseline",dur:0,dx:0,dy:0,edgeMode:"edgeMode",elevation:0,enableBackground:"enable-background",end:0,exponent:0,externalResourcesRequired:"externalResourcesRequired",fill:0,fillOpacity:"fill-opacity",fillRule:"fill-rule",filter:0,filterRes:"filterRes",filterUnits:"filterUnits",floodColor:"flood-color",floodOpacity:"flood-opacity",focusable:0,fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",format:0,from:0,fx:0,fy:0,g1:0,g2:0,glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",glyphRef:"glyphRef",gradientTransform:"gradientTransform",gradientUnits:"gradientUnits",hanging:0,horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",ideographic:0,imageRendering:"image-rendering",in:0,in2:0,intercept:0,k:0,k1:0,k2:0,k3:0,k4:0,kernelMatrix:"kernelMatrix",kernelUnitLength:"kernelUnitLength",kerning:0,keyPoints:"keyPoints",keySplines:"keySplines",keyTimes:"keyTimes",lengthAdjust:"lengthAdjust",letterSpacing:"letter-spacing",lightingColor:"lighting-color",limitingConeAngle:"limitingConeAngle",local:0,markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",markerHeight:"markerHeight",markerUnits:"markerUnits",markerWidth:"markerWidth",mask:0,maskContentUnits:"maskContentUnits",maskUnits:"maskUnits",mathematical:0,mode:0,numOctaves:"numOctaves",offset:0,opacity:0,operator:0,order:0,orient:0,orientation:0,origin:0,overflow:0,overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pathLength:"pathLength",patternContentUnits:"patternContentUnits",patternTransform:"patternTransform",patternUnits:"patternUnits",pointerEvents:"pointer-events",points:0,pointsAtX:"pointsAtX",pointsAtY:"pointsAtY",pointsAtZ:"pointsAtZ",preserveAlpha:"preserveAlpha",preserveAspectRatio:"preserveAspectRatio",primitiveUnits:"primitiveUnits",r:0,radius:0,refX:"refX",refY:"refY",renderingIntent:"rendering-intent",repeatCount:"repeatCount",repeatDur:"repeatDur",requiredExtensions:"requiredExtensions",requiredFeatures:"requiredFeatures",restart:0,result:0,rotate:0,rx:0,ry:0,scale:0,seed:0,shapeRendering:"shape-rendering",slope:0,spacing:0,specularConstant:"specularConstant",specularExponent:"specularExponent",speed:0,spreadMethod:"spreadMethod",startOffset:"startOffset",stdDeviation:"stdDeviation",stemh:0,stemv:0,stitchTiles:"stitchTiles",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",string:0,stroke:0,strokeDasharray:"stroke-dasharray",strokeDashoffset:"stroke-dashoffset",strokeLinecap:"stroke-linecap",strokeLinejoin:"stroke-linejoin",strokeMiterlimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",surfaceScale:"surfaceScale",systemLanguage:"systemLanguage",tableValues:"tableValues",targetX:"targetX",targetY:"targetY",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",textLength:"textLength",to:0,transform:0,u1:0,u2:0,underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicode:0,unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",values:0,vectorEffect:"vector-effect",version:0,vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",viewBox:"viewBox",viewTarget:"viewTarget",visibility:0,widths:0,wordSpacing:"word-spacing",writingMode:"writing-mode",x:0,xHeight:"x-height",x1:0,x2:0,xChannelSelector:"xChannelSelector",xlinkActuate:"xlink:actuate",xlinkArcrole:"xlink:arcrole",xlinkHref:"xlink:href",xlinkRole:"xlink:role",xlinkShow:"xlink:show",xlinkTitle:"xlink:title",xlinkType:"xlink:type",xmlBase:"xml:base",xmlns:0,xmlnsXlink:"xmlns:xlink",xmlLang:"xml:lang",xmlSpace:"xml:space",y:0,y1:0,y2:0,yChannelSelector:"yChannelSelector",z:0,zoomAndPan:"zoomAndPan"},o={Properties:{},DOMAttributeNamespaces:{xlinkActuate:n.xlink,xlinkArcrole:n.xlink,xlinkHref:n.xlink,xlinkRole:n.xlink,xlinkShow:n.xlink,xlinkTitle:n.xlink,xlinkType:n.xlink,xmlBase:n.xml,xmlLang:n.xml,xmlSpace:n.xml},DOMAttributeNames:{}};Object.keys(r).forEach(function(t){o.Properties[t]=0,r[t]&&(o.DOMAttributeNames[t]=r[t])}),t.exports=o},function(t,e,n){"use strict";function r(t){if("selectionStart"in t&&l.hasSelectionCapabilities(t))return{start:t.selectionStart,end:t.selectionEnd};if(window.getSelection){var e=window.getSelection();return{anchorNode:e.anchorNode,anchorOffset:e.anchorOffset,focusNode:e.focusNode,focusOffset:e.focusOffset}}if(document.selection){var n=document.selection.createRange();return{parentElement:n.parentElement(),text:n.text,top:n.boundingTop,left:n.boundingLeft}}}function o(t,e){if(y||null==g||g!==c())return null;var n=r(g);if(!m||!d(m,n)){m=n;var o=u.getPooled(h.select,v,t,e);return o.type="select",o.target=g,i.accumulateTwoPhaseDispatches(o),o}return null}var i=n(186),a=n(195),s=n(178),l=n(288),u=n(201),c=n(294),f=n(214),d=n(265),p=a.canUseDOM&&"documentMode"in document&&document.documentMode<=11,h={select:{phasedRegistrationNames:{bubbled:"onSelect",captured:"onSelectCapture"},dependencies:["topBlur","topContextMenu","topFocus","topKeyDown","topKeyUp","topMouseDown","topMouseUp","topSelectionChange"]}},g=null,v=null,m=null,y=!1,b=!1,x={eventTypes:h,extractEvents:function(t,e,n,r){if(!b)return null;var i=e?s.getNodeFromInstance(e):window;switch(t){case"topFocus":(f(i)||"true"===i.contentEditable)&&(g=i,v=e,m=null);break;case"topBlur":g=null,v=null,m=null;break;case"topMouseDown":y=!0;break;case"topContextMenu":case"topMouseUp":return y=!1,o(n,r);case"topSelectionChange":if(p)break;case"topKeyDown":case"topKeyUp":return o(n,r)}return null},didPutListener:function(t,e,n){"onSelect"===e&&(b=!0)}};t.exports=x},function(t,e,n){"use strict";function r(t){return"."+t._rootNodeID}function o(t){return"button"===t||"input"===t||"select"===t||"textarea"===t}var i=n(179),a=n(284),s=n(186),l=n(178),u=n(298),c=n(299),f=n(201),d=n(300),p=n(301),h=n(217),g=n(304),v=n(305),m=n(306),y=n(218),b=n(307),x=n(192),_=n(302),w=(n(181),{}),T={};["abort","animationEnd","animationIteration","animationStart","blur","canPlay","canPlayThrough","click","contextMenu","copy","cut","doubleClick","drag","dragEnd","dragEnter","dragExit","dragLeave","dragOver","dragStart","drop","durationChange","emptied","encrypted","ended","error","focus","input","invalid","keyDown","keyPress","keyUp","load","loadedData","loadedMetadata","loadStart","mouseDown","mouseMove","mouseOut","mouseOver","mouseUp","paste","pause","play","playing","progress","rateChange","reset","scroll","seeked","seeking","stalled","submit","suspend","timeUpdate","touchCancel","touchEnd","touchMove","touchStart","transitionEnd","volumeChange","waiting","wheel"].forEach(function(t){var e=t[0].toUpperCase()+t.slice(1),n="on"+e,r="top"+e,o={phasedRegistrationNames:{bubbled:n,captured:n+"Capture"},dependencies:[r]};w[t]=o,T[r]=o});var C={},k={eventTypes:w,extractEvents:function(t,e,n,r){var o=T[t];if(!o)return null;var a;switch(t){case"topAbort":case"topCanPlay":case"topCanPlayThrough":case"topDurationChange":case"topEmptied":case"topEncrypted":case"topEnded":case"topError":case"topInput":case"topInvalid":case"topLoad":case"topLoadedData":case"topLoadedMetadata":case"topLoadStart":case"topPause":case"topPlay":case"topPlaying":case"topProgress":case"topRateChange":case"topReset":case"topSeeked":case"topSeeking":case"topStalled":case"topSubmit":case"topSuspend":case"topTimeUpdate":case"topVolumeChange":case"topWaiting":a=f;break;case"topKeyPress":if(0===_(n))return null;case"topKeyDown":case"topKeyUp":a=p;break;case"topBlur":case"topFocus":a=d;break;case"topClick":if(2===n.button)return null;case"topDoubleClick":case"topMouseDown":case"topMouseMove":case"topMouseUp":case"topMouseOut":case"topMouseOver":case"topContextMenu":a=h;break;case"topDrag":case"topDragEnd":case"topDragEnter":case"topDragExit":case"topDragLeave":case"topDragOver":case"topDragStart":case"topDrop":a=g;break;case"topTouchCancel":case"topTouchEnd":case"topTouchMove":case"topTouchStart":a=v;break;case"topAnimationEnd":case"topAnimationIteration":case"topAnimationStart":a=u;break;case"topTransitionEnd":a=m;break;case"topScroll":a=y;break;case"topWheel":a=b;break;case"topCopy":case"topCut":case"topPaste":a=c}a?void 0:i("86",t);var l=a.getPooled(o,e,n,r);return s.accumulateTwoPhaseDispatches(l),l},didPutListener:function(t,e,n){if("onClick"===e&&!o(t._tag)){var i=r(t),s=l.getNodeFromInstance(t);C[i]||(C[i]=a.listen(s,"click",x))}},willDeleteListener:function(t,e){if("onClick"===e&&!o(t._tag)){var n=r(t);C[n].remove(),delete C[n]}}};t.exports=k},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(201),i={animationName:null,elapsedTime:null,pseudoElement:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(201),i={clipboardData:function(t){return"clipboardData"in t?t.clipboardData:window.clipboardData}};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(218),i={relatedTarget:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(218),i=n(302),a=n(303),s=n(220),l={key:a,location:null,ctrlKey:null,shiftKey:null,altKey:null,metaKey:null,repeat:null,locale:null,getModifierState:s,charCode:function(t){return"keypress"===t.type?i(t):0},keyCode:function(t){return"keydown"===t.type||"keyup"===t.type?t.keyCode:0},which:function(t){return"keypress"===t.type?i(t):"keydown"===t.type||"keyup"===t.type?t.keyCode:0}};o.augmentClass(r,l),t.exports=r},function(t,e){"use strict";function n(t){var e,n=t.keyCode;return"charCode"in t?(e=t.charCode,0===e&&13===n&&(e=13)):e=n,e>=32||13===e?e:0}t.exports=n},function(t,e,n){"use strict";function r(t){if(t.key){var e=i[t.key]||t.key;if("Unidentified"!==e)return e}if("keypress"===t.type){var n=o(t);return 13===n?"Enter":String.fromCharCode(n)}return"keydown"===t.type||"keyup"===t.type?a[t.keyCode]||"Unidentified":""}var o=n(302),i={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},a={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"};t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(217),i={dataTransfer:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(218),i=n(220),a={touches:null,targetTouches:null,changedTouches:null,altKey:null,metaKey:null,ctrlKey:null,shiftKey:null,getModifierState:i};o.augmentClass(r,a),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(201),i={propertyName:null,elapsedTime:null,pseudoElement:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e,n,r){return o.call(this,t,e,n,r)}var o=n(217),i={deltaX:function(t){return"deltaX"in t?t.deltaX:"wheelDeltaX"in t?-t.wheelDeltaX:0},deltaY:function(t){return"deltaY"in t?t.deltaY:"wheelDeltaY"in t?-t.wheelDeltaY:"wheelDelta"in t?-t.wheelDelta:0},deltaZ:null,deltaMode:null};o.augmentClass(r,i),t.exports=r},function(t,e,n){"use strict";function r(t,e){for(var n=Math.min(t.length,e.length),r=0;r<n;r++)if(t.charAt(r)!==e.charAt(r))return r;return t.length===e.length?-1:n}function o(t){return t?t.nodeType===I?t.documentElement:t.firstChild:null}function i(t){return t.getAttribute&&t.getAttribute(A)||""}function a(t,e,n,r,o){var i;if(_.logTopLevelRenders){var a=t._currentElement.props.child,s=a.type;i="React mount: "+("string"==typeof s?s:s.displayName||s.name),console.time(i)}var l=C.mountComponent(t,n,null,b(t,e),o,0);i&&console.timeEnd(i),t._renderedComponent._topLevelWrapper=t,B._mountImageIntoNode(l,e,t,r,n)}function s(t,e,n,r){var o=E.ReactReconcileTransaction.getPooled(!n&&x.useCreateElement);o.perform(a,null,t,e,o,n,r),E.ReactReconcileTransaction.release(o)}function l(t,e,n){for(C.unmountComponent(t,n),e.nodeType===I&&(e=e.documentElement);e.lastChild;)e.removeChild(e.lastChild)}function u(t){var e=o(t);if(e){var n=y.getInstanceFromNode(e);return!(!n||!n._hostParent)}}function c(t){return!(!t||t.nodeType!==D&&t.nodeType!==I&&t.nodeType!==R)}function f(t){var e=o(t),n=e&&y.getInstanceFromNode(e);return n&&!n._hostParent?n:null}function d(t){var e=f(t);return e?e._hostContainerInfo._topLevelWrapper:null}var p=n(179),h=n(224),g=n(180),v=n(4),m=n(248),y=(n(11),n(178)),b=n(309),x=n(310),_=n(206),w=n(259),T=(n(210),n(311)),C=n(207),k=n(277),E=n(204),P=n(264),S=n(261),M=(n(181),n(226)),N=n(266),A=(n(191),g.ID_ATTRIBUTE_NAME),O=g.ROOT_ATTRIBUTE_NAME,D=1,I=9,R=11,L={},F=1,j=function(){this.rootID=F++};j.prototype.isReactComponent={},j.prototype.render=function(){return this.props.child},j.isReactTopLevelWrapper=!0;var B={TopLevelWrapper:j,_instancesByReactRootID:L,scrollMonitor:function(t,e){e()},_updateRootComponent:function(t,e,n,r,o){return B.scrollMonitor(r,function(){k.enqueueElementInternal(t,e,n),o&&k.enqueueCallbackInternal(t,o)}),t},_renderNewRootComponent:function(t,e,n,r){c(e)?void 0:p("37"),m.ensureScrollValueMonitoring();var o=S(t,!1);E.batchedUpdates(s,o,e,n,r);var i=o._instance.rootID;return L[i]=o,o},renderSubtreeIntoContainer:function(t,e,n,r){return null!=t&&w.has(t)?void 0:p("38"),B._renderSubtreeIntoContainer(t,e,n,r)},_renderSubtreeIntoContainer:function(t,e,n,r){k.validateCallback(r,"ReactDOM.render"),v.isValidElement(e)?void 0:p("39","string"==typeof e?" Instead of passing a string like 'div', pass React.createElement('div') or <div />.":"function"==typeof e?" Instead of passing a class like Foo, pass React.createElement(Foo) or <Foo />.":null!=e&&void 0!==e.props?" This may be caused by unintentionally loading two independent copies of React.":"");var a,s=v.createElement(j,{child:e});if(t){var l=w.get(t);a=l._processChildContext(l._context)}else a=P;var c=d(n);if(c){var f=c._currentElement,h=f.props.child;if(N(h,e)){var g=c._renderedComponent.getPublicInstance(),m=r&&function(){r.call(g)};return B._updateRootComponent(c,s,a,n,m),g}B.unmountComponentAtNode(n)}var y=o(n),b=y&&!!i(y),x=u(n),_=b&&!c&&!x,T=B._renderNewRootComponent(s,n,_,a)._renderedComponent.getPublicInstance();return r&&r.call(T),T},render:function(t,e,n){return B._renderSubtreeIntoContainer(null,t,e,n)},unmountComponentAtNode:function(t){c(t)?void 0:p("40");var e=d(t);if(!e){u(t),1===t.nodeType&&t.hasAttribute(O);return!1}return delete L[e._instance.rootID],E.batchedUpdates(l,e,t,!1),!0},_mountImageIntoNode:function(t,e,n,i,a){if(c(e)?void 0:p("41"),i){var s=o(e);if(T.canReuseMarkup(t,s))return void y.precacheNode(n,s);var l=s.getAttribute(T.CHECKSUM_ATTR_NAME);s.removeAttribute(T.CHECKSUM_ATTR_NAME);var u=s.outerHTML;s.setAttribute(T.CHECKSUM_ATTR_NAME,l);var f=t,d=r(f,u),g=" (client) "+f.substring(d-20,d+20)+"\n (server) "+u.substring(d-20,d+20);e.nodeType===I?p("42",g):void 0}if(e.nodeType===I?p("43"):void 0,a.useCreateElement){for(;e.lastChild;)e.removeChild(e.lastChild);h.insertTreeBefore(e,t,null)}else M(e,t),y.precacheNode(n,e.firstChild)}};t.exports=B},function(t,e,n){"use strict";function r(t,e){var n={_topLevelWrapper:t,_idCounter:1,_ownerDocument:e?e.nodeType===o?e:e.ownerDocument:null,_node:e,_tag:e?e.nodeName.toLowerCase():null,_namespaceURI:e?e.namespaceURI:null};return n}var o=(n(278),9);t.exports=r},function(t,e){"use strict";var n={useCreateElement:!0,useFiber:!1};t.exports=n},function(t,e,n){"use strict";var r=n(312),o=/\/?>/,i=/^<\!\-\-/,a={CHECKSUM_ATTR_NAME:"data-react-checksum",addChecksumToMarkup:function(t){var e=r(t);return i.test(t)?t:t.replace(o," "+a.CHECKSUM_ATTR_NAME+'="'+e+'"$&')},canReuseMarkup:function(t,e){var n=e.getAttribute(a.CHECKSUM_ATTR_NAME);n=n&&parseInt(n,10);var o=r(t);return o===n}};t.exports=a},function(t,e){"use strict";function n(t){for(var e=1,n=0,o=0,i=t.length,a=i&-4;o<a;){for(var s=Math.min(o+4096,a);o<s;o+=4)n+=(e+=t.charCodeAt(o))+(e+=t.charCodeAt(o+1))+(e+=t.charCodeAt(o+2))+(e+=t.charCodeAt(o+3));e%=r,n%=r}for(;o<i;o++)n+=e+=t.charCodeAt(o);return e%=r,n%=r,e|n<<16}var r=65521;t.exports=n},function(t,e){"use strict";t.exports="15.4.2"},function(t,e,n){"use strict";function r(t){if(null==t)return null;if(1===t.nodeType)return t;var e=a.get(t);return e?(e=s(e),e?i.getNodeFromInstance(e):null):void("function"==typeof t.render?o("44"):o("45",Object.keys(t)))}var o=n(179),i=(n(11),n(178)),a=n(259),s=n(315);n(181),n(191);t.exports=r},function(t,e,n){"use strict";function r(t){for(var e;(e=t._renderedNodeType)===o.COMPOSITE;)t=t._renderedComponent;return e===o.HOST?t._renderedComponent:e===o.EMPTY?null:void 0}var o=n(263);t.exports=r},function(t,e,n){"use strict";var r=n(308);t.exports=r.renderSubtreeIntoContainer},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0}),e.ChartManager=void 0;var s=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),l=n(3),u=r(l),c=n(318),f=n(168),d=function(t){function e(t){return o(this,e),i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t))}return a(e,t),s(e,[{key:"render",value:function(){var t=[];return this.props.layouts.length>0&&(t=this.props.layouts.map(function(t,e){return u.default.createElement(c.Row,{key:"chart_row_".concat(e)},u.default.createElement("h1",null,t.title),u.default.createElement(f.Layout,{id:"pyxley_chart_".concat(e),key:"pyxley_chart_".concat(e),type:t.type,filters:t.filters,charts:t.charts}),u.default.createElement("br",null))}.bind(this))),u.default.createElement("div",null,u.default.createElement(c.Grid,{id:"chart_manager_base"},t))}}]),e}(u.default.Component);e.ChartManager=d},function(t,e,n){"use strict";function r(t){if(t&&t.__esModule)return t;var e={};if(null!=t)for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n]);return e.default=t,e}function o(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0,e.utils=e.Well=e.Tooltip=e.Thumbnail=e.Tabs=e.TabPane=e.Table=e.TabContent=e.TabContainer=e.Tab=e.SplitButton=e.SafeAnchor=e.Row=e.ResponsiveEmbed=e.Radio=e.ProgressBar=e.Popover=e.PanelGroup=e.Panel=e.Pagination=e.Pager=e.PageItem=e.PageHeader=e.OverlayTrigger=e.Overlay=e.NavItem=e.NavDropdown=e.NavbarBrand=e.Navbar=e.Nav=e.ModalTitle=e.ModalHeader=e.ModalFooter=e.ModalBody=e.Modal=e.MenuItem=e.Media=e.ListGroupItem=e.ListGroup=e.Label=e.Jumbotron=e.InputGroup=e.Image=e.HelpBlock=e.Grid=e.Glyphicon=e.FormGroup=e.FormControl=e.Form=e.Fade=e.DropdownButton=e.Dropdown=e.Collapse=e.Col=e.ControlLabel=e.Clearfix=e.Checkbox=e.CarouselItem=e.Carousel=e.ButtonToolbar=e.ButtonGroup=e.Button=e.BreadcrumbItem=e.Breadcrumb=e.Badge=e.Alert=e.Accordion=void 0;var i=n(319),a=o(i),s=n(415),l=o(s),u=n(419),c=o(u),f=n(420),d=o(f),p=n(421),h=o(p),g=n(425),v=o(g),m=n(426),y=o(m),b=n(428),x=o(b),_=n(429),w=o(_),T=n(431),C=o(T),k=n(434),E=o(k),P=n(436),S=o(P),M=n(438),N=o(M),A=n(439),O=o(A),D=n(440),I=o(D),R=n(453),L=o(R),F=n(478),j=o(F),B=n(480),U=o(B),H=n(481),z=o(H),W=n(482),q=o(W),V=n(485),K=o(V),Y=n(433),G=o(Y),X=n(486),$=o(X),Z=n(487),J=o(Z),Q=n(488),tt=o(Q),et=n(489),nt=o(et),rt=n(492),ot=o(rt),it=n(493),at=o(it),st=n(494),lt=o(st),ut=n(495),ct=o(ut),ft=n(496),dt=o(ft),pt=n(503),ht=o(pt),gt=n(504),vt=o(gt),mt=n(522),yt=o(mt),bt=n(524),xt=o(bt),_t=n(525),wt=o(_t),Tt=n(526),Ct=o(Tt),kt=n(527),Et=o(kt),Pt=n(528),St=o(Pt),Mt=n(529),Nt=o(Mt),At=n(533),Ot=o(At),Dt=n(534),It=o(Dt),Rt=n(535),Lt=o(Rt),Ft=n(544),jt=o(Ft),Bt=n(545),Ut=o(Bt),Ht=n(546),zt=o(Ht),Wt=n(549),qt=o(Wt),Vt=n(550),Kt=o(Vt),Yt=n(552),Gt=o(Yt),Xt=n(403),$t=o(Xt),Zt=n(553),Jt=o(Zt),Qt=n(554),te=o(Qt),ee=n(555),ne=o(ee),re=n(556),oe=o(re),ie=n(557),ae=o(ie),se=n(422),le=o(se),ue=n(558),ce=o(ue),fe=n(560),de=o(fe),pe=n(561),he=o(pe),ge=n(562),ve=o(ge),me=n(564),ye=o(me),be=n(563),xe=o(be),_e=n(565),we=o(_e),Te=n(566),Ce=o(Te),ke=n(567),Ee=o(ke),Pe=n(568),Se=o(Pe),Me=n(569),Ne=r(Me);e.Accordion=a.default,e.Alert=l.default,e.Badge=c.default,e.Breadcrumb=d.default,e.BreadcrumbItem=h.default,e.Button=v.default,e.ButtonGroup=y.default,e.ButtonToolbar=x.default,e.Carousel=w.default,e.CarouselItem=C.default,e.Checkbox=E.default,e.Clearfix=S.default,e.ControlLabel=N.default,e.Col=O.default,e.Collapse=I.default,e.Dropdown=L.default,e.DropdownButton=j.default,e.Fade=U.default,e.Form=z.default,e.FormControl=q.default,e.FormGroup=K.default,e.Glyphicon=G.default,e.Grid=$.default,e.HelpBlock=J.default,e.Image=tt.default,e.InputGroup=nt.default,e.Jumbotron=ot.default,e.Label=at.default,e.ListGroup=lt.default,e.ListGroupItem=ct.default,e.Media=dt.default,e.MenuItem=ht.default,e.Modal=vt.default,e.ModalBody=yt.default,e.ModalFooter=xt.default,e.ModalHeader=wt.default,e.ModalTitle=Ct.default,e.Nav=Et.default,e.Navbar=St.default,e.NavbarBrand=Nt.default,e.NavDropdown=Ot.default,e.NavItem=It.default,e.Overlay=Lt.default,e.OverlayTrigger=jt.default,e.PageHeader=Ut.default,e.PageItem=zt.default,e.Pager=qt.default,e.Pagination=Kt.default,e.Panel=Gt.default,e.PanelGroup=$t.default,e.Popover=Jt.default,e.ProgressBar=te.default,e.Radio=ne.default,e.ResponsiveEmbed=oe.default,e.Row=ae.default,e.SafeAnchor=le.default,e.SplitButton=ce.default,e.Tab=de.default,e.TabContainer=he.default,e.TabContent=ve.default,e.Table=ye.default,e.TabPane=xe.default,e.Tabs=we.default,e.Thumbnail=Ce.default,e.Tooltip=Ee.default,e.Well=Se.default,e.utils=Ne},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(3),p=r(d),h=n(403),g=r(h),v=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){return p.default.createElement(g.default,(0,i.default)({},this.props,{accordion:!0}),this.props.children)},e}(p.default.Component);e.default=v,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(321),i=r(o);e.default=i.default||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t}},function(t,e,n){t.exports={default:n(322),__esModule:!0}},function(t,e,n){n(323),t.exports=n(326).Object.assign},function(t,e,n){var r=n(324);r(r.S+r.F,"Object",{assign:n(339)})},function(t,e,n){var r=n(325),o=n(326),i=n(327),a=n(329),s="prototype",l=function(t,e,n){var u,c,f,d=t&l.F,p=t&l.G,h=t&l.S,g=t&l.P,v=t&l.B,m=t&l.W,y=p?o:o[e]||(o[e]={}),b=y[s],x=p?r:h?r[e]:(r[e]||{})[s];p&&(n=e);for(u in n)c=!d&&x&&void 0!==x[u],c&&u in y||(f=c?x[u]:n[u],y[u]=p&&"function"!=typeof x[u]?n[u]:v&&c?i(f,r):m&&x[u]==f?function(t){var e=function(e,n,r){if(this instanceof t){switch(arguments.length){case 0:return new t;case 1:return new t(e);case 2:return new t(e,n)}return new t(e,n,r)}return t.apply(this,arguments)};return e[s]=t[s],e}(f):g&&"function"==typeof f?i(Function.call,f):f,g&&((y.virtual||(y.virtual={}))[u]=f,t&l.R&&b&&!b[u]&&a(b,u,f)))};l.F=1,l.G=2,l.S=4,l.P=8,l.B=16,l.W=32,l.U=64,l.R=128,t.exports=l},function(t,e){var n=t.exports="undefined"!=typeof window&&window.Math==Math?window:"undefined"!=typeof self&&self.Math==Math?self:Function("return this")();"number"==typeof __g&&(__g=n)},function(t,e){var n=t.exports={version:"2.4.0"};"number"==typeof __e&&(__e=n)},function(t,e,n){var r=n(328);t.exports=function(t,e,n){if(r(t),void 0===e)return t;switch(n){case 1:return function(n){return t.call(e,n)};case 2:return function(n,r){return t.call(e,n,r)};case 3:return function(n,r,o){return t.call(e,n,r,o)}}return function(){return t.apply(e,arguments)}}},function(t,e){t.exports=function(t){if("function"!=typeof t)throw TypeError(t+" is not a function!");return t}},function(t,e,n){var r=n(330),o=n(338);t.exports=n(334)?function(t,e,n){return r.f(t,e,o(1,n))}:function(t,e,n){return t[e]=n,t}},function(t,e,n){var r=n(331),o=n(333),i=n(337),a=Object.defineProperty;e.f=n(334)?Object.defineProperty:function(t,e,n){if(r(t),e=i(e,!0),r(n),o)try{return a(t,e,n)}catch(t){}if("get"in n||"set"in n)throw TypeError("Accessors not supported!");return"value"in n&&(t[e]=n.value),t}},function(t,e,n){var r=n(332);t.exports=function(t){if(!r(t))throw TypeError(t+" is not an object!");return t}},function(t,e){t.exports=function(t){return"object"==typeof t?null!==t:"function"==typeof t}},function(t,e,n){t.exports=!n(334)&&!n(335)(function(){return 7!=Object.defineProperty(n(336)("div"),"a",{get:function(){return 7}}).a})},function(t,e,n){t.exports=!n(335)(function(){return 7!=Object.defineProperty({},"a",{get:function(){return 7}}).a})},function(t,e){t.exports=function(t){try{return!!t()}catch(t){return!0}}},function(t,e,n){var r=n(332),o=n(325).document,i=r(o)&&r(o.createElement);
t.exports=function(t){return i?o.createElement(t):{}}},function(t,e,n){var r=n(332);t.exports=function(t,e){if(!r(t))return t;var n,o;if(e&&"function"==typeof(n=t.toString)&&!r(o=n.call(t)))return o;if("function"==typeof(n=t.valueOf)&&!r(o=n.call(t)))return o;if(!e&&"function"==typeof(n=t.toString)&&!r(o=n.call(t)))return o;throw TypeError("Can't convert object to primitive value")}},function(t,e){t.exports=function(t,e){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:e}}},function(t,e,n){"use strict";var r=n(340),o=n(355),i=n(356),a=n(357),s=n(344),l=Object.assign;t.exports=!l||n(335)(function(){var t={},e={},n=Symbol(),r="abcdefghijklmnopqrst";return t[n]=7,r.split("").forEach(function(t){e[t]=t}),7!=l({},t)[n]||Object.keys(l({},e)).join("")!=r})?function(t,e){for(var n=a(t),l=arguments.length,u=1,c=o.f,f=i.f;l>u;)for(var d,p=s(arguments[u++]),h=c?r(p).concat(c(p)):r(p),g=h.length,v=0;g>v;)f.call(p,d=h[v++])&&(n[d]=p[d]);return n}:l},function(t,e,n){var r=n(341),o=n(354);t.exports=Object.keys||function(t){return r(t,o)}},function(t,e,n){var r=n(342),o=n(343),i=n(347)(!1),a=n(351)("IE_PROTO");t.exports=function(t,e){var n,s=o(t),l=0,u=[];for(n in s)n!=a&&r(s,n)&&u.push(n);for(;e.length>l;)r(s,n=e[l++])&&(~i(u,n)||u.push(n));return u}},function(t,e){var n={}.hasOwnProperty;t.exports=function(t,e){return n.call(t,e)}},function(t,e,n){var r=n(344),o=n(346);t.exports=function(t){return r(o(t))}},function(t,e,n){var r=n(345);t.exports=Object("z").propertyIsEnumerable(0)?Object:function(t){return"String"==r(t)?t.split(""):Object(t)}},function(t,e){var n={}.toString;t.exports=function(t){return n.call(t).slice(8,-1)}},function(t,e){t.exports=function(t){if(void 0==t)throw TypeError("Can't call method on  "+t);return t}},function(t,e,n){var r=n(343),o=n(348),i=n(350);t.exports=function(t){return function(e,n,a){var s,l=r(e),u=o(l.length),c=i(a,u);if(t&&n!=n){for(;u>c;)if(s=l[c++],s!=s)return!0}else for(;u>c;c++)if((t||c in l)&&l[c]===n)return t||c||0;return!t&&-1}}},function(t,e,n){var r=n(349),o=Math.min;t.exports=function(t){return t>0?o(r(t),9007199254740991):0}},function(t,e){var n=Math.ceil,r=Math.floor;t.exports=function(t){return isNaN(t=+t)?0:(t>0?r:n)(t)}},function(t,e,n){var r=n(349),o=Math.max,i=Math.min;t.exports=function(t,e){return t=r(t),t<0?o(t+e,0):i(t,e)}},function(t,e,n){var r=n(352)("keys"),o=n(353);t.exports=function(t){return r[t]||(r[t]=o(t))}},function(t,e,n){var r=n(325),o="__core-js_shared__",i=r[o]||(r[o]={});t.exports=function(t){return i[t]||(i[t]={})}},function(t,e){var n=0,r=Math.random();t.exports=function(t){return"Symbol(".concat(void 0===t?"":t,")_",(++n+r).toString(36))}},function(t,e){t.exports="constructor,hasOwnProperty,isPrototypeOf,propertyIsEnumerable,toLocaleString,toString,valueOf".split(",")},function(t,e){e.f=Object.getOwnPropertySymbols},function(t,e){e.f={}.propertyIsEnumerable},function(t,e,n){var r=n(346);t.exports=function(t){return Object(r(t))}},function(t,e){"use strict";e.__esModule=!0,e.default=function(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(360),i=r(o);e.default=function(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!==("undefined"==typeof e?"undefined":(0,i.default)(e))&&"function"!=typeof e?t:e}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(361),i=r(o),a=n(381),s=r(a),l="function"==typeof s.default&&"symbol"==typeof i.default?function(t){return typeof t}:function(t){return t&&"function"==typeof s.default&&t.constructor===s.default&&t!==s.default.prototype?"symbol":typeof t};e.default="function"==typeof s.default&&"symbol"===l(i.default)?function(t){return"undefined"==typeof t?"undefined":l(t)}:function(t){return t&&"function"==typeof s.default&&t.constructor===s.default&&t!==s.default.prototype?"symbol":"undefined"==typeof t?"undefined":l(t)}},function(t,e,n){t.exports={default:n(362),__esModule:!0}},function(t,e,n){n(363),n(376),t.exports=n(380).f("iterator")},function(t,e,n){"use strict";var r=n(364)(!0);n(365)(String,"String",function(t){this._t=String(t),this._i=0},function(){var t,e=this._t,n=this._i;return n>=e.length?{value:void 0,done:!0}:(t=r(e,n),this._i+=t.length,{value:t,done:!1})})},function(t,e,n){var r=n(349),o=n(346);t.exports=function(t){return function(e,n){var i,a,s=String(o(e)),l=r(n),u=s.length;return l<0||l>=u?t?"":void 0:(i=s.charCodeAt(l),i<55296||i>56319||l+1===u||(a=s.charCodeAt(l+1))<56320||a>57343?t?s.charAt(l):i:t?s.slice(l,l+2):(i-55296<<10)+(a-56320)+65536)}}},function(t,e,n){"use strict";var r=n(366),o=n(324),i=n(367),a=n(329),s=n(342),l=n(368),u=n(369),c=n(373),f=n(375),d=n(374)("iterator"),p=!([].keys&&"next"in[].keys()),h="@@iterator",g="keys",v="values",m=function(){return this};t.exports=function(t,e,n,y,b,x,_){u(n,e,y);var w,T,C,k=function(t){if(!p&&t in M)return M[t];switch(t){case g:return function(){return new n(this,t)};case v:return function(){return new n(this,t)}}return function(){return new n(this,t)}},E=e+" Iterator",P=b==v,S=!1,M=t.prototype,N=M[d]||M[h]||b&&M[b],A=N||k(b),O=b?P?k("entries"):A:void 0,D="Array"==e?M.entries||N:N;if(D&&(C=f(D.call(new t)),C!==Object.prototype&&(c(C,E,!0),r||s(C,d)||a(C,d,m))),P&&N&&N.name!==v&&(S=!0,A=function(){return N.call(this)}),r&&!_||!p&&!S&&M[d]||a(M,d,A),l[e]=A,l[E]=m,b)if(w={values:P?A:k(v),keys:x?A:k(g),entries:O},_)for(T in w)T in M||i(M,T,w[T]);else o(o.P+o.F*(p||S),e,w);return w}},function(t,e){t.exports=!0},function(t,e,n){t.exports=n(329)},function(t,e){t.exports={}},function(t,e,n){"use strict";var r=n(370),o=n(338),i=n(373),a={};n(329)(a,n(374)("iterator"),function(){return this}),t.exports=function(t,e,n){t.prototype=r(a,{next:o(1,n)}),i(t,e+" Iterator")}},function(t,e,n){var r=n(331),o=n(371),i=n(354),a=n(351)("IE_PROTO"),s=function(){},l="prototype",u=function(){var t,e=n(336)("iframe"),r=i.length,o="<",a=">";for(e.style.display="none",n(372).appendChild(e),e.src="javascript:",t=e.contentWindow.document,t.open(),t.write(o+"script"+a+"document.F=Object"+o+"/script"+a),t.close(),u=t.F;r--;)delete u[l][i[r]];return u()};t.exports=Object.create||function(t,e){var n;return null!==t?(s[l]=r(t),n=new s,s[l]=null,n[a]=t):n=u(),void 0===e?n:o(n,e)}},function(t,e,n){var r=n(330),o=n(331),i=n(340);t.exports=n(334)?Object.defineProperties:function(t,e){o(t);for(var n,a=i(e),s=a.length,l=0;s>l;)r.f(t,n=a[l++],e[n]);return t}},function(t,e,n){t.exports=n(325).document&&document.documentElement},function(t,e,n){var r=n(330).f,o=n(342),i=n(374)("toStringTag");t.exports=function(t,e,n){t&&!o(t=n?t:t.prototype,i)&&r(t,i,{configurable:!0,value:e})}},function(t,e,n){var r=n(352)("wks"),o=n(353),i=n(325).Symbol,a="function"==typeof i,s=t.exports=function(t){return r[t]||(r[t]=a&&i[t]||(a?i:o)("Symbol."+t))};s.store=r},function(t,e,n){var r=n(342),o=n(357),i=n(351)("IE_PROTO"),a=Object.prototype;t.exports=Object.getPrototypeOf||function(t){return t=o(t),r(t,i)?t[i]:"function"==typeof t.constructor&&t instanceof t.constructor?t.constructor.prototype:t instanceof Object?a:null}},function(t,e,n){n(377);for(var r=n(325),o=n(329),i=n(368),a=n(374)("toStringTag"),s=["NodeList","DOMTokenList","MediaList","StyleSheetList","CSSRuleList"],l=0;l<5;l++){var u=s[l],c=r[u],f=c&&c.prototype;f&&!f[a]&&o(f,a,u),i[u]=i.Array}},function(t,e,n){"use strict";var r=n(378),o=n(379),i=n(368),a=n(343);t.exports=n(365)(Array,"Array",function(t,e){this._t=a(t),this._i=0,this._k=e},function(){var t=this._t,e=this._k,n=this._i++;return!t||n>=t.length?(this._t=void 0,o(1)):"keys"==e?o(0,n):"values"==e?o(0,t[n]):o(0,[n,t[n]])},"values"),i.Arguments=i.Array,r("keys"),r("values"),r("entries")},function(t,e){t.exports=function(){}},function(t,e){t.exports=function(t,e){return{value:e,done:!!t}}},function(t,e,n){e.f=n(374)},function(t,e,n){t.exports={default:n(382),__esModule:!0}},function(t,e,n){n(383),n(392),n(393),n(394),t.exports=n(326).Symbol},function(t,e,n){"use strict";var r=n(325),o=n(342),i=n(334),a=n(324),s=n(367),l=n(384).KEY,u=n(335),c=n(352),f=n(373),d=n(353),p=n(374),h=n(380),g=n(385),v=n(386),m=n(387),y=n(388),b=n(331),x=n(343),_=n(337),w=n(338),T=n(370),C=n(389),k=n(391),E=n(330),P=n(340),S=k.f,M=E.f,N=C.f,A=r.Symbol,O=r.JSON,D=O&&O.stringify,I="prototype",R=p("_hidden"),L=p("toPrimitive"),F={}.propertyIsEnumerable,j=c("symbol-registry"),B=c("symbols"),U=c("op-symbols"),H=Object[I],z="function"==typeof A,W=r.QObject,q=!W||!W[I]||!W[I].findChild,V=i&&u(function(){return 7!=T(M({},"a",{get:function(){return M(this,"a",{value:7}).a}})).a})?function(t,e,n){var r=S(H,e);r&&delete H[e],M(t,e,n),r&&t!==H&&M(H,e,r)}:M,K=function(t){var e=B[t]=T(A[I]);return e._k=t,e},Y=z&&"symbol"==typeof A.iterator?function(t){return"symbol"==typeof t}:function(t){return t instanceof A},G=function(t,e,n){return t===H&&G(U,e,n),b(t),e=_(e,!0),b(n),o(B,e)?(n.enumerable?(o(t,R)&&t[R][e]&&(t[R][e]=!1),n=T(n,{enumerable:w(0,!1)})):(o(t,R)||M(t,R,w(1,{})),t[R][e]=!0),V(t,e,n)):M(t,e,n)},X=function(t,e){b(t);for(var n,r=m(e=x(e)),o=0,i=r.length;i>o;)G(t,n=r[o++],e[n]);return t},$=function(t,e){return void 0===e?T(t):X(T(t),e)},Z=function(t){var e=F.call(this,t=_(t,!0));return!(this===H&&o(B,t)&&!o(U,t))&&(!(e||!o(this,t)||!o(B,t)||o(this,R)&&this[R][t])||e)},J=function(t,e){if(t=x(t),e=_(e,!0),t!==H||!o(B,e)||o(U,e)){var n=S(t,e);return!n||!o(B,e)||o(t,R)&&t[R][e]||(n.enumerable=!0),n}},Q=function(t){for(var e,n=N(x(t)),r=[],i=0;n.length>i;)o(B,e=n[i++])||e==R||e==l||r.push(e);return r},tt=function(t){for(var e,n=t===H,r=N(n?U:x(t)),i=[],a=0;r.length>a;)!o(B,e=r[a++])||n&&!o(H,e)||i.push(B[e]);return i};z||(A=function(){if(this instanceof A)throw TypeError("Symbol is not a constructor!");var t=d(arguments.length>0?arguments[0]:void 0),e=function(n){this===H&&e.call(U,n),o(this,R)&&o(this[R],t)&&(this[R][t]=!1),V(this,t,w(1,n))};return i&&q&&V(H,t,{configurable:!0,set:e}),K(t)},s(A[I],"toString",function(){return this._k}),k.f=J,E.f=G,n(390).f=C.f=Q,n(356).f=Z,n(355).f=tt,i&&!n(366)&&s(H,"propertyIsEnumerable",Z,!0),h.f=function(t){return K(p(t))}),a(a.G+a.W+a.F*!z,{Symbol:A});for(var et="hasInstance,isConcatSpreadable,iterator,match,replace,search,species,split,toPrimitive,toStringTag,unscopables".split(","),nt=0;et.length>nt;)p(et[nt++]);for(var et=P(p.store),nt=0;et.length>nt;)g(et[nt++]);a(a.S+a.F*!z,"Symbol",{for:function(t){return o(j,t+="")?j[t]:j[t]=A(t)},keyFor:function(t){if(Y(t))return v(j,t);throw TypeError(t+" is not a symbol!")},useSetter:function(){q=!0},useSimple:function(){q=!1}}),a(a.S+a.F*!z,"Object",{create:$,defineProperty:G,defineProperties:X,getOwnPropertyDescriptor:J,getOwnPropertyNames:Q,getOwnPropertySymbols:tt}),O&&a(a.S+a.F*(!z||u(function(){var t=A();return"[null]"!=D([t])||"{}"!=D({a:t})||"{}"!=D(Object(t))})),"JSON",{stringify:function(t){if(void 0!==t&&!Y(t)){for(var e,n,r=[t],o=1;arguments.length>o;)r.push(arguments[o++]);return e=r[1],"function"==typeof e&&(n=e),!n&&y(e)||(e=function(t,e){if(n&&(e=n.call(this,t,e)),!Y(e))return e}),r[1]=e,D.apply(O,r)}}}),A[I][L]||n(329)(A[I],L,A[I].valueOf),f(A,"Symbol"),f(Math,"Math",!0),f(r.JSON,"JSON",!0)},function(t,e,n){var r=n(353)("meta"),o=n(332),i=n(342),a=n(330).f,s=0,l=Object.isExtensible||function(){return!0},u=!n(335)(function(){return l(Object.preventExtensions({}))}),c=function(t){a(t,r,{value:{i:"O"+ ++s,w:{}}})},f=function(t,e){if(!o(t))return"symbol"==typeof t?t:("string"==typeof t?"S":"P")+t;if(!i(t,r)){if(!l(t))return"F";if(!e)return"E";c(t)}return t[r].i},d=function(t,e){if(!i(t,r)){if(!l(t))return!0;if(!e)return!1;c(t)}return t[r].w},p=function(t){return u&&h.NEED&&l(t)&&!i(t,r)&&c(t),t},h=t.exports={KEY:r,NEED:!1,fastKey:f,getWeak:d,onFreeze:p}},function(t,e,n){var r=n(325),o=n(326),i=n(366),a=n(380),s=n(330).f;t.exports=function(t){var e=o.Symbol||(o.Symbol=i?{}:r.Symbol||{});"_"==t.charAt(0)||t in e||s(e,t,{value:a.f(t)})}},function(t,e,n){var r=n(340),o=n(343);t.exports=function(t,e){for(var n,i=o(t),a=r(i),s=a.length,l=0;s>l;)if(i[n=a[l++]]===e)return n}},function(t,e,n){var r=n(340),o=n(355),i=n(356);t.exports=function(t){var e=r(t),n=o.f;if(n)for(var a,s=n(t),l=i.f,u=0;s.length>u;)l.call(t,a=s[u++])&&e.push(a);return e}},function(t,e,n){var r=n(345);t.exports=Array.isArray||function(t){return"Array"==r(t)}},function(t,e,n){var r=n(343),o=n(390).f,i={}.toString,a="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],s=function(t){try{return o(t)}catch(t){return a.slice()}};t.exports.f=function(t){return a&&"[object Window]"==i.call(t)?s(t):o(r(t))}},function(t,e,n){var r=n(341),o=n(354).concat("length","prototype");e.f=Object.getOwnPropertyNames||function(t){return r(t,o)}},function(t,e,n){var r=n(356),o=n(338),i=n(343),a=n(337),s=n(342),l=n(333),u=Object.getOwnPropertyDescriptor;e.f=n(334)?u:function(t,e){if(t=i(t),e=a(e,!0),l)try{return u(t,e)}catch(t){}if(s(t,e))return o(!r.f.call(t,e),t[e])}},function(t,e){},function(t,e,n){n(385)("asyncIterator")},function(t,e,n){n(385)("observable")},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(396),i=r(o),a=n(400),s=r(a),l=n(360),u=r(l);e.default=function(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+("undefined"==typeof e?"undefined":(0,u.default)(e)));t.prototype=(0,s.default)(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(i.default?(0,i.default)(t,e):t.__proto__=e)}},function(t,e,n){t.exports={default:n(397),__esModule:!0}},function(t,e,n){n(398),t.exports=n(326).Object.setPrototypeOf},function(t,e,n){var r=n(324);r(r.S,"Object",{setPrototypeOf:n(399).set})},function(t,e,n){var r=n(332),o=n(331),i=function(t,e){if(o(t),!r(e)&&null!==e)throw TypeError(e+": can't set as prototype!")};t.exports={set:Object.setPrototypeOf||("__proto__"in{}?function(t,e,r){try{r=n(327)(Function.call,n(391).f(Object.prototype,"__proto__").set,2),r(t,[]),e=!(t instanceof Array)}catch(t){e=!0}return function(t,n){return i(t,n),e?t.__proto__=n:r(t,n),t}}({},!1):void 0),check:i}},function(t,e,n){t.exports={default:n(401),__esModule:!0}},function(t,e,n){n(402);var r=n(326).Object;t.exports=function(t,e){return r.create(t,e)}},function(t,e,n){var r=n(324);r(r.S,"Object",{create:n(370)})},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(321),s=r(a),l=n(404),u=r(l),c=n(358),f=r(c),d=n(359),p=r(d),h=n(395),g=r(h),v=n(405),m=r(v),y=n(3),b=r(y),x=n(406),_=n(413),w=r(_),T=n(414),C=r(T),k={accordion:b.default.PropTypes.bool,activeKey:b.default.PropTypes.any,defaultActiveKey:b.default.PropTypes.any,onSelect:b.default.PropTypes.func,role:b.default.PropTypes.string},E={accordion:!1},P=function(t){function e(n,r){(0,f.default)(this,e);var o=(0,p.default)(this,t.call(this,n,r));return o.handleSelect=o.handleSelect.bind(o),o.state={activeKey:n.defaultActiveKey},o}return(0,g.default)(e,t),e.prototype.handleSelect=function(t,e){e.preventDefault(),this.props.onSelect&&this.props.onSelect(t,e),this.state.activeKey===t&&(t=null),this.setState({activeKey:t})},e.prototype.render=function(){var t=this,e=this.props,n=e.accordion,r=e.activeKey,o=e.className,a=e.children,l=(0,u.default)(e,["accordion","activeKey","className","children"]),c=(0,x.splitBsPropsAndOmit)(l,["defaultActiveKey","onSelect"]),f=c[0],d=c[1],p=void 0;n&&(p=null!=r?r:this.state.activeKey,d.role=d.role||"tablist");var h=(0,x.getClassSet)(f);return b.default.createElement("div",(0,i.default)({},d,{className:(0,m.default)(o,h)}),C.default.map(a,function(e){var r={bsStyle:e.props.bsStyle||f.bsStyle};return n&&(0,s.default)(r,{headerRole:"tab",panelRole:"tabpanel",collapsible:!0,expanded:e.props.eventKey===p,onSelect:(0,w.default)(t.handleSelect,e.props.onSelect)}),(0,y.cloneElement)(e,r)}))},e}(b.default.Component);P.propTypes=k,P.defaultProps=E,e.default=(0,x.bsClass)("panel-group",P),t.exports=e.default},function(t,e){"use strict";e.__esModule=!0,e.default=function(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}},function(t,e,n){var r,o;/*!
	  Copyright (c) 2016 Jed Watson.
	  Licensed under the MIT License (MIT), see
	  http://jedwatson.github.io/classnames
	*/
!function(){"use strict";function n(){for(var t=[],e=0;e<arguments.length;e++){var r=arguments[e];if(r){var o=typeof r;if("string"===o||"number"===o)t.push(r);else if(Array.isArray(r))t.push(n.apply(null,r));else if("object"===o)for(var a in r)i.call(r,a)&&r[a]&&t.push(a)}}return t.join(" ")}var i={}.hasOwnProperty;"undefined"!=typeof t&&t.exports?t.exports=n:(r=[],o=function(){return n}.apply(e,r),!(void 0!==o&&(t.exports=o)))}()},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){return function(){for(var e=arguments.length,n=Array(e),r=0;r<e;r++)n[r]=arguments[r];var o=n[n.length-1];return"function"==typeof o?t.apply(void 0,n):function(e){return t.apply(void 0,n.concat([e]))}}}function i(t,e){return null==t.bsClass?(0,m.default)(!1):void 0,t.bsClass+(e?"-"+e:"")}function a(t){var e,n=(e={},e[i(t)]=!0,e);if(t.bsSize){var r=b.SIZE_MAP[t.bsSize]||t.bsSize;n[i(t,r)]=!0}return t.bsStyle&&(n[i(t,t.bsStyle)]=!0),n}function s(t){return{bsClass:t.bsClass,bsSize:t.bsSize,bsStyle:t.bsStyle,bsRole:t.bsRole}}function l(t){return"bsClass"===t||"bsSize"===t||"bsStyle"===t||"bsRole"===t}function u(t){var e={};return(0,p.default)(t).forEach(function(t){var n=t[0],r=t[1];l(n)||(e[n]=r)}),[s(t),e]}function c(t,e){var n={};e.forEach(function(t){n[t]=!0});var r={};return(0,p.default)(t).forEach(function(t){var e=t[0],o=t[1];l(e)||n[e]||(r[e]=o)}),[s(t),r]}function f(t){for(var e=arguments.length,n=Array(e>1?e-1:0),r=1;r<e;r++)n[r-1]=arguments[r];x(n,t)}e.__esModule=!0,e._curry=e.bsSizes=e.bsStyles=e.bsClass=void 0;var d=n(407),p=r(d),h=n(320),g=r(h);e.prefix=i,e.getClassSet=a,e.splitBsProps=u,e.splitBsPropsAndOmit=c,e.addStyle=f;var v=n(411),m=r(v),y=n(3),b=n(412),x=(e.bsClass=o(function(t,e){var n=e.propTypes||(e.propTypes={}),r=e.defaultProps||(e.defaultProps={});return n.bsClass=y.PropTypes.string,r.bsClass=t,e}),e.bsStyles=o(function(t,e,n){"string"!=typeof e&&(n=e,e=void 0);var r=n.STYLES||[],o=n.propTypes||{};t.forEach(function(t){r.indexOf(t)===-1&&r.push(t)});var i=y.PropTypes.oneOf(r);if(n.STYLES=i._values=r,n.propTypes=(0,g.default)({},o,{bsStyle:i}),void 0!==e){var a=n.defaultProps||(n.defaultProps={});a.bsStyle=e}return n}));e.bsSizes=o(function(t,e,n){"string"!=typeof e&&(n=e,e=void 0);var r=n.SIZES||[],o=n.propTypes||{};t.forEach(function(t){r.indexOf(t)===-1&&r.push(t)});var i=[];r.forEach(function(t){var e=b.SIZE_MAP[t];e&&e!==t&&i.push(e),i.push(t)});var a=y.PropTypes.oneOf(i);return a._values=i,n.SIZES=r,n.propTypes=(0,g.default)({},o,{bsSize:a}),void 0!==e&&(n.defaultProps||(n.defaultProps={}),n.defaultProps.bsSize=e),n}),e._curry=o},function(t,e,n){t.exports={default:n(408),__esModule:!0}},function(t,e,n){n(409),t.exports=n(326).Object.entries},function(t,e,n){var r=n(324),o=n(410)(!0);r(r.S,"Object",{entries:function(t){return o(t)}})},function(t,e,n){var r=n(340),o=n(343),i=n(356).f;t.exports=function(t){return function(e){for(var n,a=o(e),s=r(a),l=s.length,u=0,c=[];l>u;)i.call(a,n=s[u++])&&c.push(t?[n,a[n]]:a[n]);return c}}},function(t,e,n){"use strict";var r=function(t,e,n,r,o,i,a,s){if(!t){var l;if(void 0===e)l=new Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var u=[n,r,o,i,a,s],c=0;l=new Error(e.replace(/%s/g,function(){return u[c++]})),l.name="Invariant Violation"}throw l.framesToPop=1,l}};t.exports=r},function(t,e){"use strict";e.__esModule=!0;e.Size={LARGE:"large",SMALL:"small",XSMALL:"xsmall"},e.SIZE_MAP={large:"lg",medium:"md",small:"sm",xsmall:"xs",lg:"lg",md:"md",sm:"sm",xs:"xs"},e.DEVICE_SIZES=["lg","md","sm","xs"],e.State={SUCCESS:"success",WARNING:"warning",DANGER:"danger",INFO:"info"},e.Style={DEFAULT:"default",PRIMARY:"primary",LINK:"link",INVERSE:"inverse"}},function(t,e){"use strict";function n(){for(var t=arguments.length,e=Array(t),n=0;n<t;n++)e[n]=arguments[n];return e.filter(function(t){return null!=t}).reduce(function(t,e){if("function"!=typeof e)throw new Error("Invalid Argument Type, must only provide functions, undefined, or null.");return null===t?e:function(){for(var n=arguments.length,r=Array(n),o=0;o<n;o++)r[o]=arguments[o];t.apply(this,r),e.apply(this,r)}},null)}e.__esModule=!0,e.default=n,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r=0;return p.default.Children.map(t,function(t){return p.default.isValidElement(t)?e.call(n,t,r++):t})}function i(t,e,n){var r=0;p.default.Children.forEach(t,function(t){p.default.isValidElement(t)&&e.call(n,t,r++)})}function a(t){var e=0;return p.default.Children.forEach(t,function(t){p.default.isValidElement(t)&&++e}),e}function s(t,e,n){var r=0,o=[];return p.default.Children.forEach(t,function(t){p.default.isValidElement(t)&&e.call(n,t,r++)&&o.push(t)}),o}function l(t,e,n){var r=0,o=void 0;return p.default.Children.forEach(t,function(t){o||p.default.isValidElement(t)&&e.call(n,t,r++)&&(o=t)}),o}function u(t,e,n){var r=0,o=!0;return p.default.Children.forEach(t,function(t){o&&p.default.isValidElement(t)&&(e.call(n,t,r++)||(o=!1))}),o}function c(t,e,n){var r=0,o=!1;return p.default.Children.forEach(t,function(t){o||p.default.isValidElement(t)&&e.call(n,t,r++)&&(o=!0)}),o}function f(t){var e=[];return p.default.Children.forEach(t,function(t){p.default.isValidElement(t)&&e.push(t)}),e}e.__esModule=!0;var d=n(3),p=r(d);e.default={map:o,forEach:i,count:a,find:l,filter:s,every:u,some:c,toArray:f},t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(416),i=r(o),a=n(320),s=r(a),l=n(404),u=r(l),c=n(358),f=r(c),d=n(359),p=r(d),h=n(395),g=r(h),v=n(405),m=r(v),y=n(3),b=r(y),x=n(406),_=n(412),w={onDismiss:b.default.PropTypes.func,closeLabel:b.default.PropTypes.string},T={closeLabel:"Close alert"},C=function(t){function e(){return(0,f.default)(this,e),(0,p.default)(this,t.apply(this,arguments))}return(0,g.default)(e,t),e.prototype.renderDismissButton=function(t){return b.default.createElement("button",{type:"button",className:"close",onClick:t,"aria-hidden":"true",tabIndex:"-1"},b.default.createElement("span",null,"×"))},e.prototype.renderSrOnlyDismissButton=function(t,e){return b.default.createElement("button",{type:"button",className:"close sr-only",onClick:t},e)},e.prototype.render=function(){var t,e=this.props,n=e.onDismiss,r=e.closeLabel,o=e.className,i=e.children,a=(0,u.default)(e,["onDismiss","closeLabel","className","children"]),l=(0,x.splitBsProps)(a),c=l[0],f=l[1],d=!!n,p=(0,s.default)({},(0,x.getClassSet)(c),(t={},t[(0,x.prefix)(c,"dismissable")]=d,t));return b.default.createElement("div",(0,s.default)({},f,{role:"alert",className:(0,m.default)(o,p)}),d&&this.renderDismissButton(n),i,d&&this.renderSrOnlyDismissButton(n,r))},e}(b.default.Component);C.propTypes=w,C.defaultProps=T,e.default=(0,x.bsStyles)((0,i.default)(_.State),_.State.INFO,(0,x.bsClass)("alert",C)),t.exports=e.default},function(t,e,n){t.exports={default:n(417),__esModule:!0}},function(t,e,n){n(418),t.exports=n(326).Object.values},function(t,e,n){var r=n(324),o=n(410)(!1);r(r.S,"Object",{values:function(t){return o(t)}})},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b={pullRight:m.default.PropTypes.bool},x={pullRight:!1},_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.hasContent=function(t){var e=!1;return m.default.Children.forEach(t,function(t){e||(t||0===t)&&(e=!0)}),e},e.prototype.render=function(){var t=this.props,e=t.pullRight,n=t.className,r=t.children,o=(0,s.default)(t,["pullRight","className","children"]),a=(0,y.splitBsProps)(o),l=a[0],u=a[1],c=(0,i.default)({},(0,y.getClassSet)(l),{"pull-right":e,hidden:!this.hasContent(r)});return m.default.createElement("span",(0,i.default)({},u,{className:(0,g.default)(n,c)}),r)},e}(m.default.Component);_.propTypes=b,_.defaultProps=x,e.default=(0,y.bsClass)("badge",_),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(421),b=r(y),x=n(406),_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,x.splitBsProps)(n),o=r[0],a=r[1],l=(0,x.getClassSet)(o);return m.default.createElement("ol",(0,i.default)({},a,{role:"navigation","aria-label":"breadcrumbs",className:(0,g.default)(e,l)}))},e}(m.default.Component);_.Item=b.default,e.default=(0,x.bsClass)("breadcrumb",_),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(422),b=r(y),x={active:m.default.PropTypes.bool,href:m.default.PropTypes.string,title:m.default.PropTypes.node,target:m.default.PropTypes.string},_={active:!1},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.active,n=t.href,r=t.title,o=t.target,a=t.className,l=(0,s.default)(t,["active","href","title","target","className"]),u={href:n,title:r,target:o};return m.default.createElement("li",{className:(0,g.default)(a,{active:e})},e?m.default.createElement("span",l):m.default.createElement(b.default,(0,i.default)({},l,u)))},e}(m.default.Component);w.propTypes=x,w.defaultProps=_,e.default=w,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){return!t||"#"===t.trim()}e.__esModule=!0;var i=n(320),a=r(i),s=n(404),l=r(s),u=n(358),c=r(u),f=n(359),d=r(f),p=n(395),h=r(p),g=n(3),v=r(g),m=n(423),y=r(m),b={href:v.default.PropTypes.string,onClick:v.default.PropTypes.func,disabled:v.default.PropTypes.bool,role:v.default.PropTypes.string,tabIndex:v.default.PropTypes.oneOfType([v.default.PropTypes.number,v.default.PropTypes.string]),componentClass:y.default},x={componentClass:"a"},_=function(t){function e(n,r){(0,c.default)(this,e);var o=(0,d.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o}return(0,h.default)(e,t),e.prototype.handleClick=function(t){var e=this.props,n=e.disabled,r=e.href,i=e.onClick;return(n||o(r))&&t.preventDefault(),n?void t.stopPropagation():void(i&&i(t))},e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.disabled,r=(0,l.default)(t,["componentClass","disabled"]);return o(r.href)&&(r.role=r.role||"button",r.href=r.href||"#"),n&&(r.tabIndex=-1,r.style=(0,a.default)({pointerEvents:"none"},r.style)),v.default.createElement(e,(0,a.default)({},r,{onClick:this.handleClick}))},e}(v.default.Component);_.propTypes=b,_.defaultProps=x,e.default=_,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n,r,o){var a=t[e],l="undefined"==typeof a?"undefined":i(a);return s.default.isValidElement(a)?new Error("Invalid "+r+" `"+o+"` of type ReactElement "+("supplied to `"+n+"`, expected an element type (a string ")+"or a ReactClass)."):"function"!==l&&"string"!==l?new Error("Invalid "+r+" `"+o+"` of value `"+a+"` "+("supplied to `"+n+"`, expected an element type (a string ")+"or a ReactClass)."):null}e.__esModule=!0;var i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol?"symbol":typeof t},a=n(3),s=r(a),l=n(424),u=r(l);e.default=(0,u.default)(o)},function(t,e){"use strict";function n(t){function e(e,n,r,o,i,a){var s=o||"<<anonymous>>",l=a||r;if(null==n[r])return e?new Error("Required "+i+" `"+l+"` was not specified "+("in `"+s+"`.")):null;for(var u=arguments.length,c=Array(u>6?u-6:0),f=6;f<u;f++)c[f-6]=arguments[f];return t.apply(void 0,[n,r,s,i,l].concat(c))}var n=e.bind(null,!1);return n.isRequired=e.bind(null,!0),n}e.__esModule=!0,e.default=n},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(416),i=r(o),a=n(404),s=r(a),l=n(320),u=r(l),c=n(358),f=r(c),d=n(359),p=r(d),h=n(395),g=r(h),v=n(405),m=r(v),y=n(3),b=r(y),x=n(423),_=r(x),w=n(406),T=n(412),C=n(422),k=r(C),E={active:b.default.PropTypes.bool,disabled:b.default.PropTypes.bool,block:b.default.PropTypes.bool,onClick:b.default.PropTypes.func,componentClass:_.default,href:b.default.PropTypes.string,type:b.default.PropTypes.oneOf(["button","reset","submit"])},P={active:!1,block:!1,disabled:!1},S=function(t){function e(){return(0,f.default)(this,e),(0,p.default)(this,t.apply(this,arguments))}return(0,g.default)(e,t),e.prototype.renderAnchor=function(t,e){return b.default.createElement(k.default,(0,u.default)({},t,{className:(0,m.default)(e,t.disabled&&"disabled")}))},e.prototype.renderButton=function(t,e){var n=t.componentClass,r=(0,s.default)(t,["componentClass"]),o=n||"button";return b.default.createElement(o,(0,u.default)({},r,{type:r.type||"button",className:e}))},e.prototype.render=function(){var t,e=this.props,n=e.active,r=e.block,o=e.className,i=(0,s.default)(e,["active","block","className"]),a=(0,w.splitBsProps)(i),l=a[0],c=a[1],f=(0,u.default)({},(0,w.getClassSet)(l),(t={active:n},t[(0,w.prefix)(l,"block")]=r,t)),d=(0,m.default)(o,f);return c.href?this.renderAnchor(c,d):this.renderButton(c,d)},e}(b.default.Component);S.propTypes=E,S.defaultProps=P,e.default=(0,w.bsClass)("btn",(0,w.bsSizes)([T.Size.LARGE,T.Size.SMALL,T.Size.XSMALL],(0,w.bsStyles)([].concat((0,i.default)(T.State),[T.Style.DEFAULT,T.Style.PRIMARY,T.Style.LINK]),T.Style.DEFAULT,S))),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(427),b=r(y),x=n(425),_=r(x),w=n(406),T={vertical:m.default.PropTypes.bool,justified:m.default.PropTypes.bool,block:(0,b.default)(m.default.PropTypes.bool,function(t){var e=t.block,n=t.vertical;return e&&!n?new Error("`block` requires `vertical` to be set to have any effect"):null})},C={block:!1,justified:!1,vertical:!1},k=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.block,r=e.justified,o=e.vertical,a=e.className,l=(0,s.default)(e,["block","justified","vertical","className"]),u=(0,w.splitBsProps)(l),c=u[0],f=u[1],d=(0,i.default)({},(0,w.getClassSet)(c),(t={},t[(0,w.prefix)(c)]=!o,t[(0,w.prefix)(c,"vertical")]=o,t[(0,w.prefix)(c,"justified")]=r,t[(0,w.prefix)(_.default.defaultProps,"block")]=n,t));return m.default.createElement("div",(0,i.default)({},f,{className:(0,g.default)(a,d)}))},e}(m.default.Component);k.propTypes=T,k.defaultProps=C,e.default=(0,w.bsClass)("btn-group",k),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(){function t(){for(var t=arguments.length,e=Array(t),r=0;r<t;r++)e[r]=arguments[r];var o=null;return n.forEach(function(t){if(null==o){var n=t.apply(void 0,e);null!=n&&(o=n)}}),o}for(var e=arguments.length,n=Array(e),r=0;r<e;r++)n[r]=arguments[r];return(0,a.default)(t)}e.__esModule=!0,e.default=o;var i=n(424),a=r(i)},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(425),b=r(y),x=n(406),_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,x.splitBsProps)(n),o=r[0],a=r[1],l=(0,x.getClassSet)(o);return m.default.createElement("div",(0,i.default)({},a,{role:"toolbar",className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,x.bsClass)("btn-toolbar",(0,x.bsSizes)(b.default.SIZES,_)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(430),b=r(y),x=n(431),_=r(x),w=n(433),T=r(w),C=n(422),k=r(C),E=n(406),P=n(414),S=r(P),M={slide:m.default.PropTypes.bool,indicators:m.default.PropTypes.bool,interval:m.default.PropTypes.number,controls:m.default.PropTypes.bool,pauseOnHover:m.default.PropTypes.bool,wrap:m.default.PropTypes.bool,onSelect:m.default.PropTypes.func,onSlideEnd:m.default.PropTypes.func,activeIndex:m.default.PropTypes.number,defaultActiveIndex:m.default.PropTypes.number,direction:m.default.PropTypes.oneOf(["prev","next"]),prevIcon:m.default.PropTypes.node,prevLabel:m.default.PropTypes.string,nextIcon:m.default.PropTypes.node,nextLabel:m.default.PropTypes.string},N={slide:!0,interval:5e3,pauseOnHover:!0,wrap:!0,indicators:!0,controls:!0,prevIcon:m.default.createElement(T.default,{glyph:"chevron-left"}),prevLabel:"Previous",nextIcon:m.default.createElement(T.default,{glyph:"chevron-right"}),nextLabel:"Next"},A=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));o.handleMouseOver=o.handleMouseOver.bind(o),o.handleMouseOut=o.handleMouseOut.bind(o),o.handlePrev=o.handlePrev.bind(o),o.handleNext=o.handleNext.bind(o),o.handleItemAnimateOutEnd=o.handleItemAnimateOutEnd.bind(o);var i=n.defaultActiveIndex;return o.state={activeIndex:null!=i?i:0,previousActiveIndex:null,direction:null},o.isUnmounted=!1,o}return(0,p.default)(e,t),e.prototype.componentWillReceiveProps=function(t){var e=this.getActiveIndex();null!=t.activeIndex&&t.activeIndex!==e&&(clearTimeout(this.timeout),this.setState({previousActiveIndex:e,direction:null!=t.direction?t.direction:this.getDirection(e,t.activeIndex)}))},e.prototype.componentDidMount=function(){this.waitForNext()},e.prototype.componentWillUnmount=function(){clearTimeout(this.timeout),this.isUnmounted=!0},e.prototype.handleMouseOver=function(){this.props.pauseOnHover&&this.pause()},e.prototype.handleMouseOut=function(){this.isPaused&&this.play()},e.prototype.handlePrev=function(t){var e=this.getActiveIndex()-1;if(e<0){if(!this.props.wrap)return;e=S.default.count(this.props.children)-1}this.select(e,t,"prev")},e.prototype.handleNext=function(t){var e=this.getActiveIndex()+1,n=S.default.count(this.props.children);if(e>n-1){if(!this.props.wrap)return;e=0}this.select(e,t,"next")},e.prototype.handleItemAnimateOutEnd=function(){var t=this;this.setState({previousActiveIndex:null,direction:null},function(){t.waitForNext(),t.props.onSlideEnd&&t.props.onSlideEnd()})},e.prototype.getActiveIndex=function(){var t=this.props.activeIndex;return null!=t?t:this.state.activeIndex},e.prototype.getDirection=function(t,e){return t===e?null:t>e?"prev":"next"},e.prototype.select=function(t,e,n){if(clearTimeout(this.timeout),!this.isUnmounted){var r=this.getActiveIndex();n=n||this.getDirection(r,t);var o=this.props.onSelect;if(o&&(o.length>1?(e?(e.persist(),e.direction=n):e={direction:n},o(t,e)):o(t)),null==this.props.activeIndex&&t!==r){if(null!=this.state.previousActiveIndex)return;this.setState({activeIndex:t,previousActiveIndex:r,direction:n})}}},e.prototype.waitForNext=function(){var t=this.props,e=t.slide,n=t.interval,r=t.activeIndex;!this.isPaused&&e&&n&&null==r&&(this.timeout=setTimeout(this.handleNext,n))},e.prototype.pause=function(){this.isPaused=!0,clearTimeout(this.timeout)},e.prototype.play=function(){this.isPaused=!1,this.waitForNext()},e.prototype.renderIndicators=function(t,e,n){var r=this,o=[];return S.default.forEach(t,function(t,n){o.push(m.default.createElement("li",{key:n,className:n===e?"active":null,onClick:function(t){return r.select(n,t)}})," ")}),m.default.createElement("ol",{className:(0,E.prefix)(n,"indicators")},o)},e.prototype.renderControls=function(t){var e=t.wrap,n=t.children,r=t.activeIndex,o=t.prevIcon,i=t.nextIcon,a=t.bsProps,s=t.prevLabel,l=t.nextLabel,u=(0,E.prefix)(a,"control"),c=S.default.count(n);return[(e||0!==r)&&m.default.createElement(k.default,{key:"prev",className:(0,g.default)(u,"left"),onClick:this.handlePrev},o,s&&m.default.createElement("span",{className:"sr-only"},s)),(e||r!==c-1)&&m.default.createElement(k.default,{key:"next",className:(0,g.default)(u,"right"),onClick:this.handleNext},i,l&&m.default.createElement("span",{className:"sr-only"},l))]},e.prototype.render=function(){var t=this,e=this.props,n=e.slide,r=e.indicators,o=e.controls,a=e.wrap,l=e.prevIcon,u=e.prevLabel,c=e.nextIcon,f=e.nextLabel,d=e.className,p=e.children,h=(0,s.default)(e,["slide","indicators","controls","wrap","prevIcon","prevLabel","nextIcon","nextLabel","className","children"]),y=this.state,b=y.previousActiveIndex,x=y.direction,_=(0,E.splitBsPropsAndOmit)(h,["interval","pauseOnHover","onSelect","onSlideEnd","activeIndex","defaultActiveIndex","direction"]),w=_[0],T=_[1],C=this.getActiveIndex(),k=(0,i.default)({},(0,E.getClassSet)(w),{slide:n});return m.default.createElement("div",(0,i.default)({},T,{className:(0,g.default)(d,k),onMouseOver:this.handleMouseOver,onMouseOut:this.handleMouseOut}),r&&this.renderIndicators(p,C,w),m.default.createElement("div",{className:(0,E.prefix)(w,"inner")},S.default.map(p,function(e,r){var o=r===C,i=n&&r===b;return(0,v.cloneElement)(e,{active:o,index:r,animateOut:i,animateIn:o&&null!=b&&n,direction:x,onAnimateOutEnd:i?t.handleItemAnimateOutEnd:null})})),o&&this.renderControls({wrap:a,children:p,activeIndex:C,prevIcon:l,prevLabel:u,nextIcon:c,nextLabel:f,bsProps:w}))},e}(m.default.Component);A.propTypes=M,A.defaultProps=N,A.Caption=b.default,A.Item=_.default,e.default=(0,E.bsClass)("carousel",A),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("carousel-caption",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(30),b=r(y),x=n(432),_=r(x),w={direction:m.default.PropTypes.oneOf(["prev","next"]),onAnimateOutEnd:m.default.PropTypes.func,active:m.default.PropTypes.bool,animateIn:m.default.PropTypes.bool,animateOut:m.default.PropTypes.bool,index:m.default.PropTypes.number},T={active:!1,animateIn:!1,animateOut:!1},C=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleAnimateOutEnd=o.handleAnimateOutEnd.bind(o),o.state={direction:null},o.isUnmounted=!1,o}return(0,p.default)(e,t),e.prototype.componentWillReceiveProps=function(t){this.props.active!==t.active&&this.setState({direction:null})},e.prototype.componentDidUpdate=function(t){var e=this,n=this.props.active,r=t.active;!n&&r&&_.default.addEndEventListener(b.default.findDOMNode(this),this.handleAnimateOutEnd),n!==r&&setTimeout(function(){return e.startAnimation()},20)},e.prototype.componentWillUnmount=function(){this.isUnmounted=!0},e.prototype.handleAnimateOutEnd=function(){this.isUnmounted||this.props.onAnimateOutEnd&&this.props.onAnimateOutEnd(this.props.index)},e.prototype.startAnimation=function(){this.isUnmounted||this.setState({direction:"prev"===this.props.direction?"right":"left"})},e.prototype.render=function(){var t=this.props,e=t.direction,n=t.active,r=t.animateIn,o=t.animateOut,a=t.className,l=(0,s.default)(t,["direction","active","animateIn","animateOut","className"]);delete l.onAnimateOutEnd,delete l.index;var u={item:!0,active:n&&!r||o};return e&&n&&r&&(u[e]=!0),this.state.direction&&(r||o)&&(u[this.state.direction]=!0),m.default.createElement("div",(0,i.default)({},l,{className:(0,g.default)(a,u)}))},e}(m.default.Component);C.propTypes=w,C.defaultProps=T,e.default=C,t.exports=e.default},function(t,e){"use strict";function n(){var t=document.createElement("div"),e=t.style;"AnimationEvent"in window||delete a.animationend.animation,"TransitionEvent"in window||delete a.transitionend.transition;for(var n in a){var r=a[n];for(var o in r)if(o in e){s.push(r[o]);break}}}function r(t,e,n){t.addEventListener(e,n,!1)}function o(t,e,n){t.removeEventListener(e,n,!1)}e.__esModule=!0;var i=!("undefined"==typeof window||!window.document||!window.document.createElement),a={transitionend:{transition:"transitionend",WebkitTransition:"webkitTransitionEnd",MozTransition:"mozTransitionEnd",OTransition:"oTransitionEnd",msTransition:"MSTransitionEnd"},animationend:{animation:"animationend",WebkitAnimation:"webkitAnimationEnd",MozAnimation:"mozAnimationEnd",OAnimation:"oAnimationEnd",msAnimation:"MSAnimationEnd"}},s=[];i&&n();var l={addEndEventListener:function(t,e){return 0===s.length?void window.setTimeout(e,0):void s.forEach(function(n){r(t,n,e)})},removeEndEventListener:function(t,e){0!==s.length&&s.forEach(function(n){o(t,n,e)})}};e.default=l,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b={glyph:m.default.PropTypes.string.isRequired},x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.glyph,r=e.className,o=(0,s.default)(e,["glyph","className"]),a=(0,y.splitBsProps)(o),l=a[0],u=a[1],c=(0,i.default)({},(0,y.getClassSet)(l),(t={},t[(0,y.prefix)(l,n)]=!0,t));return m.default.createElement("span",(0,i.default)({},u,{className:(0,g.default)(r,c)}))},e}(m.default.Component);x.propTypes=b,e.default=(0,y.bsClass)("glyphicon",x),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(435),b=(r(y),n(406)),x={inline:m.default.PropTypes.bool,disabled:m.default.PropTypes.bool,validationState:m.default.PropTypes.oneOf(["success","warning","error",null]),inputRef:m.default.PropTypes.func},_={inline:!1,disabled:!1},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.inline,n=t.disabled,r=t.validationState,o=t.inputRef,a=t.className,l=t.style,u=t.children,c=(0,s.default)(t,["inline","disabled","validationState","inputRef","className","style","children"]),f=(0,b.splitBsProps)(c),d=f[0],p=f[1],h=m.default.createElement("input",(0,i.default)({},p,{ref:o,type:"checkbox",disabled:n}));if(e){var v,y=(v={},v[(0,b.prefix)(d,"inline")]=!0,v.disabled=n,v);return m.default.createElement("label",{className:(0,g.default)(a,y),style:l},h,u)}var x=(0,i.default)({},(0,b.getClassSet)(d),{disabled:n});return r&&(x["has-"+r]=!0),m.default.createElement("div",{className:(0,g.default)(a,x),style:l},m.default.createElement("label",null,h,u))},e}(m.default.Component);w.propTypes=x,w.defaultProps=_,e.default=(0,b.bsClass)("checkbox",w),t.exports=e.default},function(t,e,n){"use strict";var r=function(){};t.exports=r},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_=n(437),w=r(_),T=n(412),C={componentClass:b.default,visibleXsBlock:m.default.PropTypes.bool,visibleSmBlock:m.default.PropTypes.bool,visibleMdBlock:m.default.PropTypes.bool,visibleLgBlock:m.default.PropTypes.bool},k={componentClass:"div"},E=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return T.DEVICE_SIZES.forEach(function(t){var e="visible"+(0,w.default)(t)+"Block";l[e]&&(u["visible-"+t+"-block"]=!0),delete l[e]}),m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);E.propTypes=C,E.defaultProps=k,e.default=(0,x.bsClass)("clearfix",E),t.exports=e.default},function(t,e){"use strict";function n(t){return""+t.charAt(0).toUpperCase()+t.slice(1)}e.__esModule=!0,e.default=n,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(435),b=(r(y),n(406)),x={htmlFor:m.default.PropTypes.string,srOnly:m.default.PropTypes.bool},_={srOnly:!1},w={$bs_formGroup:m.default.PropTypes.object},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.context.$bs_formGroup,e=t&&t.controlId,n=this.props,r=n.htmlFor,o=void 0===r?e:r,a=n.srOnly,l=n.className,u=(0,s.default)(n,["htmlFor","srOnly","className"]),c=(0,b.splitBsProps)(u),f=c[0],d=c[1],p=(0,i.default)({},(0,b.getClassSet)(f),{"sr-only":a});return m.default.createElement("label",(0,i.default)({},d,{htmlFor:o,className:(0,g.default)(l,p)}))},e}(m.default.Component);T.propTypes=x,T.defaultProps=_,T.contextTypes=w,e.default=(0,b.bsClass)("control-label",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_=n(412),w={componentClass:b.default,xs:m.default.PropTypes.number,sm:m.default.PropTypes.number,md:m.default.PropTypes.number,lg:m.default.PropTypes.number,xsHidden:m.default.PropTypes.bool,smHidden:m.default.PropTypes.bool,mdHidden:m.default.PropTypes.bool,lgHidden:m.default.PropTypes.bool,xsOffset:m.default.PropTypes.number,smOffset:m.default.PropTypes.number,mdOffset:m.default.PropTypes.number,lgOffset:m.default.PropTypes.number,xsPush:m.default.PropTypes.number,smPush:m.default.PropTypes.number,mdPush:m.default.PropTypes.number,lgPush:m.default.PropTypes.number,xsPull:m.default.PropTypes.number,smPull:m.default.PropTypes.number,mdPull:m.default.PropTypes.number,lgPull:m.default.PropTypes.number},T={componentClass:"div"},C=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=[];return _.DEVICE_SIZES.forEach(function(t){function e(e,n){var r=""+t+e,o=l[r];null!=o&&u.push((0,x.prefix)(a,""+t+n+"-"+o)),delete l[r]}e("",""),e("Offset","-offset"),e("Push","-push"),e("Pull","-pull");var n=t+"Hidden";l[n]&&u.push("hidden-"+t),delete l[n]}),m.default.createElement(e,(0,i.default)({},l,{
className:(0,g.default)(n,u)}))},e}(m.default.Component);C.propTypes=w,C.defaultProps=T,e.default=(0,x.bsClass)("col",C),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){t.offsetHeight}function i(t,e){var n=e["offset"+(0,k.default)(t)],r=S[t];return n+parseInt((0,b.default)(e,r[0]),10)+parseInt((0,b.default)(e,r[1]),10)}e.__esModule=!0;var a=n(320),s=r(a),l=n(404),u=r(l),c=n(358),f=r(c),d=n(359),p=r(d),h=n(395),g=r(h),v=n(405),m=r(v),y=n(441),b=r(y),x=n(3),_=r(x),w=n(449),T=r(w),C=n(437),k=r(C),E=n(413),P=r(E),S={height:["marginTop","marginBottom"],width:["marginLeft","marginRight"]},M={in:_.default.PropTypes.bool,unmountOnExit:_.default.PropTypes.bool,transitionAppear:_.default.PropTypes.bool,timeout:_.default.PropTypes.number,onEnter:_.default.PropTypes.func,onEntering:_.default.PropTypes.func,onEntered:_.default.PropTypes.func,onExit:_.default.PropTypes.func,onExiting:_.default.PropTypes.func,onExited:_.default.PropTypes.func,dimension:_.default.PropTypes.oneOfType([_.default.PropTypes.oneOf(["height","width"]),_.default.PropTypes.func]),getDimensionValue:_.default.PropTypes.func,role:_.default.PropTypes.string},N={in:!1,timeout:300,unmountOnExit:!1,transitionAppear:!1,dimension:"height",getDimensionValue:i},A=function(t){function e(n,r){(0,f.default)(this,e);var o=(0,p.default)(this,t.call(this,n,r));return o.handleEnter=o.handleEnter.bind(o),o.handleEntering=o.handleEntering.bind(o),o.handleEntered=o.handleEntered.bind(o),o.handleExit=o.handleExit.bind(o),o.handleExiting=o.handleExiting.bind(o),o}return(0,g.default)(e,t),e.prototype.handleEnter=function(t){var e=this._dimension();t.style[e]="0"},e.prototype.handleEntering=function(t){var e=this._dimension();t.style[e]=this._getScrollDimensionValue(t,e)},e.prototype.handleEntered=function(t){var e=this._dimension();t.style[e]=null},e.prototype.handleExit=function(t){var e=this._dimension();t.style[e]=this.props.getDimensionValue(e,t)+"px",o(t)},e.prototype.handleExiting=function(t){var e=this._dimension();t.style[e]="0"},e.prototype._dimension=function(){return"function"==typeof this.props.dimension?this.props.dimension():this.props.dimension},e.prototype._getScrollDimensionValue=function(t,e){return t["scroll"+(0,k.default)(e)]+"px"},e.prototype.render=function(){var t=this.props,e=t.onEnter,n=t.onEntering,r=t.onEntered,o=t.onExit,i=t.onExiting,a=t.className,l=(0,u.default)(t,["onEnter","onEntering","onEntered","onExit","onExiting","className"]);delete l.dimension,delete l.getDimensionValue;var c=(0,P.default)(this.handleEnter,e),f=(0,P.default)(this.handleEntering,n),d=(0,P.default)(this.handleEntered,r),p=(0,P.default)(this.handleExit,o),h=(0,P.default)(this.handleExiting,i),g={width:"width"===this._dimension()};return _.default.createElement(T.default,(0,s.default)({},l,{"aria-expanded":l.role?l.in:null,className:(0,m.default)(a,g),exitedClassName:"collapse",exitingClassName:"collapsing",enteredClassName:"collapse in",enteringClassName:"collapsing",onEnter:c,onEntering:f,onEntered:d,onExit:p,onExiting:h}))},e}(_.default.Component);A.propTypes=M,A.defaultProps=N,e.default=A,t.exports=e.default},function(t,e,n){"use strict";var r=n(442),o=n(444),i=n(446),a=n(448),s=Object.prototype.hasOwnProperty;t.exports=function(t,e,n){var l="",u=e;if("string"==typeof e){if(void 0===n)return t.style[r(e)]||i(t).getPropertyValue(o(e));(u={})[e]=n}for(var c in u)s.call(u,c)&&(u[c]||0===u[c]?l+=o(c)+":"+u[c]+";":a(t,o(c)));t.style.cssText+=";"+l}},function(t,e,n){"use strict";var r=n(443),o=/^-ms-/;t.exports=function(t){return r(t.replace(o,"ms-"))}},function(t,e){"use strict";var n=/-(.)/g;t.exports=function(t){return t.replace(n,function(t,e){return e.toUpperCase()})}},function(t,e,n){"use strict";var r=n(445),o=/^ms-/;t.exports=function(t){return r(t).replace(o,"-ms-")}},function(t,e){"use strict";var n=/([A-Z])/g;t.exports=function(t){return t.replace(n,"-$1").toLowerCase()}},function(t,e,n){"use strict";var r=n(447),o=n(442),i=r.interopRequireDefault(o),a=/^(top|right|bottom|left)$/,s=/^([+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|))(?!px)[a-z%]+$/i;t.exports=function(t){if(!t)throw new TypeError("No Element passed to `getComputedStyle()`");var e=t.ownerDocument;return"defaultView"in e?e.defaultView.opener?t.ownerDocument.defaultView.getComputedStyle(t,null):window.getComputedStyle(t,null):{getPropertyValue:function(e){var n=t.style;e=(0,i.default)(e),"float"==e&&(e="styleFloat");var r=t.currentStyle[e]||null;if(null==r&&n&&n[e]&&(r=n[e]),s.test(r)&&!a.test(e)){var o=n.left,l=t.runtimeStyle,u=l&&l.left;u&&(l.left=t.currentStyle.left),n.left="fontSize"===e?"1em":r,r=n.pixelLeft+"px",n.left=o,u&&(l.left=u)}return r}}}},function(t,e,n){var r,o,i;!function(n,a){o=[e],r=a,i="function"==typeof r?r.apply(e,o):r,!(void 0!==i&&(t.exports=i))}(this,function(t){var e=t;e.interopRequireDefault=function(t){return t&&t.__esModule?t:{default:t}},e._extends=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t}})},function(t,e){"use strict";t.exports=function(t,e){return"removeProperty"in t.style?t.style.removeProperty(e):t.style.removeAttribute(e)}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}function i(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function a(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}function l(){}Object.defineProperty(e,"__esModule",{value:!0}),e.EXITING=e.ENTERED=e.ENTERING=e.EXITED=e.UNMOUNTED=void 0;var u=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},c=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),f=n(3),d=r(f),p=n(30),h=r(p),g=n(450),v=r(g),m=n(452),y=r(m),b=n(405),x=r(b),_=v.default.end,w=e.UNMOUNTED=0,T=e.EXITED=1,C=e.ENTERING=2,k=e.ENTERED=3,E=e.EXITING=4,P=function(t){function e(t,n){i(this,e);var r=a(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t,n)),o=void 0;return o=t.in?t.transitionAppear?T:k:t.unmountOnExit?w:T,r.state={status:o},r.nextCallback=null,r}return s(e,t),c(e,[{key:"componentDidMount",value:function(){this.props.transitionAppear&&this.props.in&&this.performEnter(this.props)}},{key:"componentWillReceiveProps",value:function(t){t.in&&this.props.unmountOnExit?this.state.status===w&&this.setState({status:T}):this._needsUpdate=!0}},{key:"componentDidUpdate",value:function(){var t=this.state.status;return this.props.unmountOnExit&&t===T?void(this.props.in?this.performEnter(this.props):this.setState({status:w})):void(this._needsUpdate&&(this._needsUpdate=!1,this.props.in?t===E?this.performEnter(this.props):t===T&&this.performEnter(this.props):t!==C&&t!==k||this.performExit(this.props)))}},{key:"componentWillUnmount",value:function(){this.cancelNextCallback()}},{key:"performEnter",value:function(t){var e=this;this.cancelNextCallback();var n=h.default.findDOMNode(this);t.onEnter(n),this.safeSetState({status:C},function(){e.props.onEntering(n),e.onTransitionEnd(n,function(){e.safeSetState({status:k},function(){e.props.onEntered(n)})})})}},{key:"performExit",value:function(t){var e=this;this.cancelNextCallback();var n=h.default.findDOMNode(this);t.onExit(n),this.safeSetState({status:E},function(){e.props.onExiting(n),e.onTransitionEnd(n,function(){e.safeSetState({status:T},function(){e.props.onExited(n)})})})}},{key:"cancelNextCallback",value:function(){null!==this.nextCallback&&(this.nextCallback.cancel(),this.nextCallback=null)}},{key:"safeSetState",value:function(t,e){this.setState(t,this.setNextCallback(e))}},{key:"setNextCallback",value:function(t){var e=this,n=!0;return this.nextCallback=function(r){n&&(n=!1,e.nextCallback=null,t(r))},this.nextCallback.cancel=function(){n=!1},this.nextCallback}},{key:"onTransitionEnd",value:function(t,e){this.setNextCallback(e),t?((0,y.default)(t,_,this.nextCallback),setTimeout(this.nextCallback,this.props.timeout)):setTimeout(this.nextCallback,0)}},{key:"render",value:function(){var t=this.state.status;if(t===w)return null;var n=this.props,r=n.children,i=n.className,a=o(n,["children","className"]);Object.keys(e.propTypes).forEach(function(t){return delete a[t]});var s=void 0;t===T?s=this.props.exitedClassName:t===C?s=this.props.enteringClassName:t===k?s=this.props.enteredClassName:t===E&&(s=this.props.exitingClassName);var l=d.default.Children.only(r);return d.default.cloneElement(l,u({},a,{className:(0,x.default)(l.props.className,i,s)}))}}]),e}(d.default.Component);P.propTypes={in:d.default.PropTypes.bool,unmountOnExit:d.default.PropTypes.bool,transitionAppear:d.default.PropTypes.bool,timeout:d.default.PropTypes.number,exitedClassName:d.default.PropTypes.string,exitingClassName:d.default.PropTypes.string,enteredClassName:d.default.PropTypes.string,enteringClassName:d.default.PropTypes.string,onEnter:d.default.PropTypes.func,onEntering:d.default.PropTypes.func,onEntered:d.default.PropTypes.func,onExit:d.default.PropTypes.func,onExiting:d.default.PropTypes.func,onExited:d.default.PropTypes.func},P.displayName="Transition",P.defaultProps={in:!1,unmountOnExit:!1,transitionAppear:!1,timeout:5e3,onEnter:l,onEntering:l,onEntered:l,onExit:l,onExiting:l,onExited:l},e.default=P},function(t,e,n){"use strict";function r(){var t,e="",n={O:"otransitionend",Moz:"transitionend",Webkit:"webkitTransitionEnd",ms:"MSTransitionEnd"},r=document.createElement("div");for(var o in n)if(u.call(n,o)&&void 0!==r.style[o+"TransitionProperty"]){e="-"+o.toLowerCase()+"-",t=n[o];break}return t||void 0===r.style.transitionProperty||(t="transitionend"),{end:t,prefix:e}}var o,i,a,s,l=n(451),u=Object.prototype.hasOwnProperty,c="transform",f={};l&&(f=r(),c=f.prefix+c,a=f.prefix+"transition-property",i=f.prefix+"transition-duration",s=f.prefix+"transition-delay",o=f.prefix+"transition-timing-function"),t.exports={transform:c,end:f.end,property:a,timing:o,delay:s,duration:i}},function(t,e){"use strict";t.exports=!("undefined"==typeof window||!window.document||!window.document.createElement)},function(t,e,n){"use strict";var r=n(451),o=function(){};r&&(o=function(){return document.addEventListener?function(t,e,n,r){return t.addEventListener(e,n,r||!1)}:document.attachEvent?function(t,e,n){return t.attachEvent("on"+e,n)}:void 0}()),t.exports=o},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(404),i=r(o),a=n(320),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(454),m=r(v),y=n(456),b=r(y),x=n(457),_=r(x),w=n(3),T=r(w),C=n(30),k=r(C),E=n(427),P=r(E),S=n(423),M=r(S),N=n(458),A=r(N),O=n(459),D=r(O),I=n(435),R=(r(I),n(426)),L=r(R),F=n(462),j=r(F),B=n(476),U=r(B),H=n(406),z=n(413),W=r(z),q=n(477),V=n(414),K=r(V),Y=U.default.defaultProps.bsRole,G=j.default.defaultProps.bsRole,X={dropup:T.default.PropTypes.bool,id:(0,A.default)(T.default.PropTypes.oneOfType([T.default.PropTypes.string,T.default.PropTypes.number])),componentClass:M.default,children:(0,P.default)((0,q.requiredRoles)(Y,G),(0,q.exclusiveRoles)(G)),disabled:T.default.PropTypes.bool,pullRight:T.default.PropTypes.bool,open:T.default.PropTypes.bool,onClose:T.default.PropTypes.func,onToggle:T.default.PropTypes.func,onSelect:T.default.PropTypes.func,role:T.default.PropTypes.string,rootCloseEvent:T.default.PropTypes.oneOf(["click","mousedown"]),onMouseEnter:T.default.PropTypes.func,onMouseLeave:T.default.PropTypes.func},$={componentClass:L.default},Z=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o.handleKeyDown=o.handleKeyDown.bind(o),o.handleClose=o.handleClose.bind(o),o._focusInDropdown=!1,o.lastOpenEventType=null,o}return(0,p.default)(e,t),e.prototype.componentDidMount=function(){this.focusNextOnOpen()},e.prototype.componentWillUpdate=function(t){!t.open&&this.props.open&&(this._focusInDropdown=(0,b.default)(k.default.findDOMNode(this.menu),(0,m.default)(document)))},e.prototype.componentDidUpdate=function(t){var e=this.props.open,n=t.open;e&&!n&&this.focusNextOnOpen(),!e&&n&&this._focusInDropdown&&(this._focusInDropdown=!1,this.focus())},e.prototype.handleClick=function(){this.props.disabled||this.toggleOpen("click")},e.prototype.handleKeyDown=function(t){if(!this.props.disabled)switch(t.keyCode){case _.default.codes.down:this.props.open?this.menu.focusNext&&this.menu.focusNext():this.toggleOpen("keydown"),t.preventDefault();break;case _.default.codes.esc:case _.default.codes.tab:this.handleClose(t)}},e.prototype.toggleOpen=function(t){var e=!this.props.open;e&&(this.lastOpenEventType=t),this.props.onToggle&&this.props.onToggle(e)},e.prototype.handleClose=function(){this.props.open&&this.toggleOpen(null)},e.prototype.focusNextOnOpen=function(){var t=this.menu;t.focusNext&&("keydown"!==this.lastOpenEventType&&"menuitem"!==this.props.role||t.focusNext())},e.prototype.focus=function(){var t=k.default.findDOMNode(this.toggle);t&&t.focus&&t.focus()},e.prototype.renderToggle=function(t,e){var n=this,r=function(t){n.toggle=t};return"string"==typeof t.ref||(r=(0,W.default)(t.ref,r)),(0,w.cloneElement)(t,(0,s.default)({},e,{ref:r,bsClass:(0,H.prefix)(e,"toggle"),onClick:(0,W.default)(t.props.onClick,this.handleClick),onKeyDown:(0,W.default)(t.props.onKeyDown,this.handleKeyDown)}))},e.prototype.renderMenu=function(t,e){var n=this,r=e.id,o=e.onClose,a=e.onSelect,l=e.rootCloseEvent,u=(0,i.default)(e,["id","onClose","onSelect","rootCloseEvent"]),c=function(t){n.menu=t};return"string"==typeof t.ref||(c=(0,W.default)(t.ref,c)),(0,w.cloneElement)(t,(0,s.default)({},u,{ref:c,labelledBy:r,bsClass:(0,H.prefix)(u,"menu"),onClose:(0,W.default)(t.props.onClose,o,this.handleClose),onSelect:(0,W.default)(t.props.onSelect,a,this.handleClose),rootCloseEvent:l}))},e.prototype.render=function(){var t,e=this,n=this.props,r=n.componentClass,o=n.id,a=n.dropup,l=n.disabled,u=n.pullRight,c=n.open,f=n.onClose,d=n.onSelect,p=n.role,h=n.bsClass,v=n.className,m=n.rootCloseEvent,y=n.children,b=(0,i.default)(n,["componentClass","id","dropup","disabled","pullRight","open","onClose","onSelect","role","bsClass","className","rootCloseEvent","children"]);delete b.onToggle;var x=(t={},t[h]=!0,t.open=c,t.disabled=l,t);return a&&(x[h]=!1,x.dropup=!0),T.default.createElement(r,(0,s.default)({},b,{className:(0,g.default)(v,x)}),K.default.map(y,function(t){switch(t.props.bsRole){case Y:return e.renderToggle(t,{id:o,disabled:l,open:c,role:p,bsClass:h});case G:return e.renderMenu(t,{id:o,open:c,pullRight:u,bsClass:h,onClose:f,onSelect:d,rootCloseEvent:m});default:return t}}))},e}(T.default.Component);Z.propTypes=X,Z.defaultProps=$,(0,H.bsClass)("dropdown",Z);var J=(0,D.default)(Z,{open:"onToggle"});J.Toggle=U.default,J.Menu=j.default,e.default=J,t.exports=e.default},function(t,e,n){"use strict";function r(){var t=void 0===arguments[0]?document:arguments[0];try{return t.activeElement}catch(t){}}var o=n(447);e.__esModule=!0,e.default=r;var i=n(455);o.interopRequireDefault(i);t.exports=e.default},function(t,e){"use strict";function n(t){return t&&t.ownerDocument||document}e.__esModule=!0,e.default=n,t.exports=e.default},function(t,e,n){"use strict";var r=n(451),o=function(){var t=r&&document.documentElement;return t&&t.contains?function(t,e){return t.contains(e)}:t&&t.compareDocumentPosition?function(t,e){return t===e||!!(16&t.compareDocumentPosition(e))}:function(t,e){if(e)do if(e===t)return!0;while(e=e.parentNode);return!1}}();t.exports=o},function(t,e){e=t.exports=function(t){if(t&&"object"==typeof t){var e=t.which||t.keyCode||t.charCode;e&&(t=e)}if("number"==typeof t)return i[t];var o=String(t),a=n[o.toLowerCase()];if(a)return a;var a=r[o.toLowerCase()];return a?a:1===o.length?o.charCodeAt(0):void 0};var n=e.code=e.codes={backspace:8,tab:9,enter:13,shift:16,ctrl:17,alt:18,"pause/break":19,"caps lock":20,esc:27,space:32,"page up":33,"page down":34,end:35,home:36,left:37,up:38,right:39,down:40,insert:45,delete:46,command:91,"left command":91,"right command":93,"numpad *":106,"numpad +":107,"numpad -":109,"numpad .":110,"numpad /":111,"num lock":144,"scroll lock":145,"my computer":182,"my calculator":183,";":186,"=":187,",":188,"-":189,".":190,"/":191,"`":192,"[":219,"\\":220,"]":221,"'":222},r=e.aliases={windows:91,"⇧":16,"⌥":18,"⌃":17,"⌘":91,ctl:17,control:17,option:18,pause:19,break:19,caps:20,return:13,escape:27,spc:32,pgup:33,pgdn:34,ins:45,del:46,cmd:91};/*!
	 * Programatically add the following
	 */
for(o=97;o<123;o++)n[String.fromCharCode(o)]=o-32;for(var o=48;o<58;o++)n[o-48]=o;for(o=1;o<13;o++)n["f"+o]=o+111;for(o=0;o<10;o++)n["numpad "+o]=o+96;var i=e.names=e.title={};for(o in n)i[n[o]]=o;for(var a in r)n[a]=r[a]},function(t,e){"use strict";function n(t){return function(e,n,r,o,i){var a=r||"<<anonymous>>",s=i||n;if(null==e[n])return new Error("The "+o+" `"+s+"` is required to make "+("`"+a+"` accessible for users of assistive ")+"technologies such as screen readers.");for(var l=arguments.length,u=Array(l>5?l-5:0),c=5;c<l;c++)u[c-5]=arguments[c];return t.apply(void 0,[e,n,r,o,i].concat(u))}}e.__esModule=!0,e.default=n},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n,r,o){n&&(t._notifying=!0,n.call.apply(n,[t,r].concat(o)),t._notifying=!1),t._values[e]=r,t.isMounted()&&t.forceUpdate()}e.__esModule=!0;var i=n(460),a=r(i),s={shouldComponentUpdate:function(){return!this._notifying}};e.default=(0,a.default)([s],o),t.exports=e.default},function(t,e,n){"use strict";function r(t){if(t&&t.__esModule)return t;var e={};if(null!=t)for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n]);return e.default=t,e}function o(t){return t&&t.__esModule?t:{default:t}}function i(t,e){function n(r,o){function i(t,n){var r=d.getLinkName(t),i=this.props[o[t]];r&&s(this.props,r)&&!i&&(i=this.props[r].requestChange);for(var a=arguments.length,l=Array(a>2?a-2:0),u=2;u<a;u++)l[u-2]=arguments[u];e(this,t,i,n,l)}function s(t,e){return void 0!==t[e]}function u(t){var e={};return d.each(t,function(t,n){y.indexOf(n)===-1&&(e[n]=t)}),e}var f,p=arguments.length<=2||void 0===arguments[2]?[]:arguments[2],h=r.displayName||r.name||"Component",g=d.getType(r).propTypes,v=d.isReactComponent(r),m=Object.keys(o),y=["valueLink","checkedLink"].concat(m.map(d.defaultKey));f=d.uncontrolledPropTypes(o,g,h),(0,c.default)(v||!p.length,"[uncontrollable] stateless function components cannot pass through methods because they have no associated instances. Check component: "+h+", attempting to pass through methods: "+p.join(", ")),p=d.transform(p,function(t,e){t[e]=function(){var t;return(t=this.refs.inner)[e].apply(t,arguments)}},{});var b=l.default.createClass(a({displayName:"Uncontrolled("+h+")",mixins:t,propTypes:f},p,{componentWillMount:function(){var t=this,e=this.props;this._values={},m.forEach(function(n){t._values[n]=e[d.defaultKey(n)]})},componentWillReceiveProps:function(t){var e=this,n=this.props;m.forEach(function(r){void 0===d.getValue(t,r)&&void 0!==d.getValue(n,r)&&(e._values[r]=t[d.defaultKey(r)])})},getControlledInstance:function(){return this.refs.inner},render:function(){var t=this,e={},n=u(this.props);return d.each(o,function(n,r){var o=d.getLinkName(r),a=t.props[r];o&&!s(t.props,r)&&s(t.props,o)&&(a=t.props[o].value),e[r]=void 0!==a?a:t._values[r],e[n]=i.bind(t,r)}),e=a({},n,e,{ref:v?"inner":null}),l.default.createElement(r,e)}}));return b.ControlledComponent=r,b.deferControlTo=function(t){var e=arguments.length<=1||void 0===arguments[1]?{}:arguments[1],r=arguments[2];return n(t,a({},o,e),r)},b}return n}e.__esModule=!0;var a=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t};e.default=i;var s=n(3),l=o(s),u=n(411),c=o(u),f=n(461),d=r(f);t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r={};return r}function i(t){return y[0]>=15||0===y[0]&&y[1]>=13?t:t.type}function a(t,e){var n=l(e);return n&&!s(t,e)&&s(t,n)?t[n].value:t[e]}function s(t,e){return void 0!==t[e]}function l(t){return"value"===t?"valueLink":"checked"===t?"checkedLink":null}function u(t){return"default"+t.charAt(0).toUpperCase()+t.substr(1)}function c(t,e,n){return function(){for(var r=arguments.length,o=Array(r),i=0;i<r;i++)o[i]=arguments[i];e&&e.call.apply(e,[t].concat(o)),n&&n.call.apply(n,[t].concat(o))}}function f(t,e,n){return d(t,e.bind(null,n=n||(Array.isArray(t)?[]:{}))),n}function d(t,e,n){if(Array.isArray(t))return t.forEach(e,n);for(var r in t)p(t,r)&&e.call(n,t[r],r,t)}function p(t,e){return!!t&&Object.prototype.hasOwnProperty.call(t,e)}function h(t){return!!(t&&t.prototype&&t.prototype.isReactComponent)}e.__esModule=!0,e.version=void 0,e.uncontrolledPropTypes=o,e.getType=i,e.getValue=a,e.getLinkName=l,e.defaultKey=u,e.chain=c,e.transform=f,e.each=d,e.has=p,e.isReactComponent=h;var g=n(3),v=r(g),m=n(411),y=(r(m),e.version=v.default.version.split(".").map(parseFloat))},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(463),u=r(l),c=n(358),f=r(c),d=n(359),p=r(d),h=n(395),g=r(h),v=n(405),m=r(v),y=n(457),b=r(y),x=n(3),_=r(x),w=n(30),T=r(w),C=n(472),k=r(C),E=n(406),P=n(413),S=r(P),M=n(414),N=r(M),A={open:_.default.PropTypes.bool,pullRight:_.default.PropTypes.bool,onClose:_.default.PropTypes.func,labelledBy:_.default.PropTypes.oneOfType([_.default.PropTypes.string,_.default.PropTypes.number]),onSelect:_.default.PropTypes.func,rootCloseEvent:_.default.PropTypes.oneOf(["click","mousedown"])},O={bsRole:"menu",pullRight:!1},D=function(t){function e(n){(0,f.default)(this,e);var r=(0,p.default)(this,t.call(this,n));return r.handleKeyDown=r.handleKeyDown.bind(r),r}return(0,g.default)(e,t),e.prototype.handleKeyDown=function(t){switch(t.keyCode){case b.default.codes.down:this.focusNext(),t.preventDefault();break;case b.default.codes.up:this.focusPrevious(),t.preventDefault();break;case b.default.codes.esc:case b.default.codes.tab:this.props.onClose(t)}},e.prototype.getItemsAndActiveIndex=function(){var t=this.getFocusableMenuItems(),e=t.indexOf(document.activeElement);return{items:t,activeIndex:e}},e.prototype.getFocusableMenuItems=function(){var t=T.default.findDOMNode(this);return t?(0,u.default)(t.querySelectorAll('[tabIndex="-1"]')):[]},e.prototype.focusNext=function(){var t=this.getItemsAndActiveIndex(),e=t.items,n=t.activeIndex;if(0!==e.length){var r=n===e.length-1?0:n+1;e[r].focus()}},e.prototype.focusPrevious=function(){var t=this.getItemsAndActiveIndex(),e=t.items,n=t.activeIndex;if(0!==e.length){var r=0===n?e.length-1:n-1;e[r].focus()}},e.prototype.render=function(){var t,e=this,n=this.props,r=n.open,o=n.pullRight,a=n.onClose,l=n.labelledBy,u=n.onSelect,c=n.className,f=n.rootCloseEvent,d=n.children,p=(0,s.default)(n,["open","pullRight","onClose","labelledBy","onSelect","className","rootCloseEvent","children"]),h=(0,E.splitBsProps)(p),g=h[0],v=h[1],y=(0,i.default)({},(0,E.getClassSet)(g),(t={},t[(0,E.prefix)(g,"right")]=o,t));return _.default.createElement(k.default,{disabled:!r,onRootClose:a,event:f},_.default.createElement("ul",(0,i.default)({},v,{role:"menu",className:(0,m.default)(c,y),"aria-labelledby":l}),N.default.map(d,function(t){return _.default.cloneElement(t,{onKeyDown:(0,S.default)(t.props.onKeyDown,e.handleKeyDown),onSelect:(0,S.default)(t.props.onSelect,u)})})))},e}(_.default.Component);D.propTypes=A,D.defaultProps=O,e.default=(0,E.bsClass)("dropdown-menu",D),t.exports=e.default},function(t,e,n){t.exports={default:n(464),__esModule:!0}},function(t,e,n){n(363),n(465),t.exports=n(326).Array.from},function(t,e,n){"use strict";var r=n(327),o=n(324),i=n(357),a=n(466),s=n(467),l=n(348),u=n(468),c=n(469);o(o.S+o.F*!n(471)(function(t){Array.from(t)}),"Array",{from:function(t){var e,n,o,f,d=i(t),p="function"==typeof this?this:Array,h=arguments.length,g=h>1?arguments[1]:void 0,v=void 0!==g,m=0,y=c(d);if(v&&(g=r(g,h>2?arguments[2]:void 0,2)),void 0==y||p==Array&&s(y))for(e=l(d.length),n=new p(e);e>m;m++)u(n,m,v?g(d[m],m):d[m]);else for(f=y.call(d),n=new p;!(o=f.next()).done;m++)u(n,m,v?a(f,g,[o.value,m],!0):o.value);return n.length=m,n}})},function(t,e,n){var r=n(331);t.exports=function(t,e,n,o){try{return o?e(r(n)[0],n[1]):e(n)}catch(e){var i=t.return;throw void 0!==i&&r(i.call(t)),e}}},function(t,e,n){var r=n(368),o=n(374)("iterator"),i=Array.prototype;t.exports=function(t){return void 0!==t&&(r.Array===t||i[o]===t)}},function(t,e,n){"use strict";var r=n(330),o=n(338);t.exports=function(t,e,n){e in t?r.f(t,e,o(0,n)):t[e]=n}},function(t,e,n){var r=n(470),o=n(374)("iterator"),i=n(368);t.exports=n(326).getIteratorMethod=function(t){if(void 0!=t)return t[o]||t["@@iterator"]||i[r(t)]}},function(t,e,n){var r=n(345),o=n(374)("toStringTag"),i="Arguments"==r(function(){return arguments}()),a=function(t,e){try{return t[e]}catch(t){}};t.exports=function(t){var e,n,s;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(n=a(e=Object(t),o))?n:i?r(e):"Object"==(s=r(e))&&"function"==typeof e.callee?"Arguments":s}},function(t,e,n){var r=n(374)("iterator"),o=!1;try{var i=[7][r]();i.return=function(){o=!0},Array.from(i,function(){throw 2})}catch(t){}t.exports=function(t,e){if(!e&&!o)return!1;var n=!1;try{var i=[7],a=i[r]();a.next=function(){return{done:n=!0}},i[r]=function(){return a},t(i)}catch(t){}return n}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function a(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}function s(t){return 0===t.button}function l(t){return!!(t.metaKey||t.altKey||t.ctrlKey||t.shiftKey)}Object.defineProperty(e,"__esModule",{value:!0});var u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),c=n(456),f=r(c),d=n(3),p=r(d),h=n(30),g=r(h),v=n(473),m=r(v),y=n(475),b=r(y),x=function(t){function e(t,n){o(this,e);var r=i(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t,n));return r.handleMouseCapture=function(t){r.preventMouseRootClose=l(t)||!s(t)||(0,f.default)(g.default.findDOMNode(r),t.target)},r.handleMouse=function(){!r.preventMouseRootClose&&r.props.onRootClose&&r.props.onRootClose()},r.handleKeyUp=function(t){27===t.keyCode&&r.props.onRootClose&&r.props.onRootClose()},r.preventMouseRootClose=!1,r}return a(e,t),u(e,[{key:"componentDidMount",value:function(){this.props.disabled||this.addEventListeners()}},{key:"componentDidUpdate",value:function(t){!this.props.disabled&&t.disabled?this.addEventListeners():this.props.disabled&&!t.disabled&&this.removeEventListeners()}},{key:"componentWillUnmount",value:function(){this.props.disabled||this.removeEventListeners()}},{key:"addEventListeners",value:function(){var t=this.props.event,e=(0,b.default)(this);this.documentMouseCaptureListener=(0,m.default)(e,t,this.handleMouseCapture,!0),this.documentMouseListener=(0,m.default)(e,t,this.handleMouse),this.documentKeyupListener=(0,m.default)(e,"keyup",this.handleKeyUp)}},{key:"removeEventListeners",value:function(){this.documentMouseCaptureListener&&this.documentMouseCaptureListener.remove(),this.documentMouseListener&&this.documentMouseListener.remove(),this.documentKeyupListener&&this.documentKeyupListener.remove()}},{key:"render",value:function(){return this.props.children}}]),e}(p.default.Component);e.default=x,x.displayName="RootCloseWrapper",x.propTypes={onRootClose:p.default.PropTypes.func,children:p.default.PropTypes.element,disabled:p.default.PropTypes.bool,event:p.default.PropTypes.oneOf(["click","mousedown"])},x.defaultProps={event:"click"},t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0}),e.default=function(t,e,n,r){return(0,i.default)(t,e,n,r),{remove:function(){(0,s.default)(t,e,n,r)}}};var o=n(452),i=r(o),a=n(474),s=r(a);t.exports=e.default},function(t,e,n){"use strict";var r=n(451),o=function(){};r&&(o=function(){return document.addEventListener?function(t,e,n,r){return t.removeEventListener(e,n,r||!1)}:document.attachEvent?function(t,e,n){return t.detachEvent("on"+e,n)}:void 0}()),t.exports=o},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0}),e.default=function(t){return(0,s.default)(i.default.findDOMNode(t))};var o=n(30),i=r(o),a=n(455),s=r(a);t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(3),g=r(h),v=n(405),m=r(v),y=n(425),b=r(y),x=n(422),_=r(x),w=n(406),T={noCaret:g.default.PropTypes.bool,open:g.default.PropTypes.bool,title:g.default.PropTypes.string,useAnchor:g.default.PropTypes.bool},C={open:!1,useAnchor:!1,bsRole:"toggle"},k=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.noCaret,n=t.open,r=t.useAnchor,o=t.bsClass,a=t.className,l=t.children,u=(0,s.default)(t,["noCaret","open","useAnchor","bsClass","className","children"]);delete u.bsRole;var c=r?_.default:b.default,f=!e;return g.default.createElement(c,(0,i.default)({},u,{role:"button",className:(0,m.default)(a,o),"aria-haspopup":!0,"aria-expanded":n}),l||u.title,f&&" ",f&&g.default.createElement("span",{className:"caret"}))},e}(g.default.Component);k.propTypes=T,k.defaultProps=C,e.default=(0,w.bsClass)("dropdown-toggle",k),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(){for(var t=arguments.length,e=Array(t),n=0;n<t;n++)e[n]=arguments[n];return(0,s.default)(function(t,n,r){var o=void 0;return e.every(function(e){return!!u.default.some(t.children,function(t){return t.props.bsRole===e})||(o=e,!1)}),o?new Error("(children) "+r+" - Missing a required child with bsRole: "+(o+". "+r+" must have at least one child of each of ")+("the following bsRoles: "+e.join(", "))):null})}function i(){for(var t=arguments.length,e=Array(t),n=0;n<t;n++)e[n]=arguments[n];return(0,s.default)(function(t,n,r){var o=void 0;return e.every(function(e){var n=u.default.filter(t.children,function(t){return t.props.bsRole===e});return!(n.length>1)||(o=e,!1)}),o?new Error("(children) "+r+" - Duplicate children detected of bsRole: "+(o+". Only one child each allowed with the following ")+("bsRoles: "+e.join(", "))):null})}e.__esModule=!0,e.requiredRoles=o,e.exclusiveRoles=i;var a=n(424),s=r(a),l=n(414),u=r(l)},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(404),i=r(o),a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(320),p=r(d),h=n(3),g=r(h),v=n(453),m=r(v),y=n(479),b=r(y),x=(0,p.default)({},m.default.propTypes,{bsStyle:g.default.PropTypes.string,bsSize:g.default.PropTypes.string,title:g.default.PropTypes.node.isRequired,noCaret:g.default.PropTypes.bool,children:g.default.PropTypes.node}),_=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.bsSize,n=t.bsStyle,r=t.title,o=t.children,a=(0,i.default)(t,["bsSize","bsStyle","title","children"]),s=(0,b.default)(a,m.default.ControlledComponent),l=s[0],u=s[1];return g.default.createElement(m.default,(0,p.default)({},l,{bsSize:e,bsStyle:n}),g.default.createElement(m.default.Toggle,(0,p.default)({},u,{bsSize:e,bsStyle:n}),r),g.default.createElement(m.default.Menu,null,o))},e}(g.default.Component);_.propTypes=x,e.default=_,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n=e.propTypes,r={},o={};return(0,a.default)(t).forEach(function(t){var e=t[0],i=t[1];n[e]?r[e]=i:o[e]=i}),[r,o]}e.__esModule=!0;var i=n(407),a=r(i);e.default=o,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(405),p=r(d),h=n(3),g=r(h),v=n(449),m=r(v),y={in:g.default.PropTypes.bool,unmountOnExit:g.default.PropTypes.bool,transitionAppear:g.default.PropTypes.bool,timeout:g.default.PropTypes.number,onEnter:g.default.PropTypes.func,onEntering:g.default.PropTypes.func,onEntered:g.default.PropTypes.func,onExit:g.default.PropTypes.func,onExiting:g.default.PropTypes.func,onExited:g.default.PropTypes.func},b={in:!1,timeout:300,unmountOnExit:!1,transitionAppear:!1},x=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){return g.default.createElement(m.default,(0,i.default)({},this.props,{className:(0,p.default)(this.props.className,"fade"),enteredClassName:"in",enteringClassName:"in"}))},e}(g.default.Component);x.propTypes=y,x.defaultProps=b,e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={horizontal:m.default.PropTypes.bool,inline:m.default.PropTypes.bool,componentClass:b.default},w={horizontal:!1,inline:!1,componentClass:"form"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.horizontal,n=t.inline,r=t.componentClass,o=t.className,a=(0,s.default)(t,["horizontal","inline","componentClass","className"]),l=(0,x.splitBsProps)(a),u=l[0],c=l[1],f=[];return e&&f.push((0,x.prefix)(u,"horizontal")),n&&f.push((0,x.prefix)(u,"inline")),m.default.createElement(r,(0,i.default)({},c,{className:(0,g.default)(o,f)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("form",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(435),_=(r(x),n(483)),w=r(_),T=n(484),C=r(T),k=n(406),E={componentClass:b.default,type:m.default.PropTypes.string,id:m.default.PropTypes.string,inputRef:m.default.PropTypes.func},P={componentClass:"input"},S={$bs_formGroup:m.default.PropTypes.object},M=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.context.$bs_formGroup,e=t&&t.controlId,n=this.props,r=n.componentClass,o=n.type,a=n.id,l=void 0===a?e:a,u=n.inputRef,c=n.className,f=(0,s.default)(n,["componentClass","type","id","inputRef","className"]),d=(0,k.splitBsProps)(f),p=d[0],h=d[1],v=void 0;return"file"!==o&&(v=(0,k.getClassSet)(p)),m.default.createElement(r,(0,i.default)({},h,{type:o,id:l,ref:u,className:(0,g.default)(c,v)}))},e}(m.default.Component);M.propTypes=E,M.defaultProps=P,M.contextTypes=S,M.Feedback=w.default,M.Static=C.default,e.default=(0,k.bsClass)("form-control",M),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(404),i=r(o),a=n(320),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(433),b=r(y),x=n(406),_={bsRole:"feedback"},w={$bs_formGroup:m.default.PropTypes.object},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.getGlyph=function(t){switch(t){case"success":return"ok";case"warning":return"warning-sign";case"error":return"remove";default:return null}},e.prototype.renderDefaultFeedback=function(t,e,n,r){var o=this.getGlyph(t&&t.validationState);return o?m.default.createElement(b.default,(0,s.default)({},r,{glyph:o,className:(0,g.default)(e,n)})):null},e.prototype.render=function(){var t=this.props,e=t.className,n=t.children,r=(0,i.default)(t,["className","children"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);if(!n)return this.renderDefaultFeedback(this.context.$bs_formGroup,e,u,l);var c=m.default.Children.only(n);return m.default.cloneElement(c,(0,s.default)({},l,{className:(0,g.default)(c.props.className,e,u)}))},e}(m.default.Component);T.defaultProps=_,T.contextTypes=w,e.default=(0,x.bsClass)("form-control-feedback",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default},w={componentClass:"p"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("form-control-static",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=n(412),x=n(414),_=r(x),w={controlId:m.default.PropTypes.string,validationState:m.default.PropTypes.oneOf(["success","warning","error",null])},T={$bs_formGroup:m.default.PropTypes.object.isRequired},C=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.getChildContext=function(){var t=this.props,e=t.controlId,n=t.validationState;return{$bs_formGroup:{controlId:e,validationState:n}}},e.prototype.hasFeedback=function(t){var e=this;return _.default.some(t,function(t){return"feedback"===t.props.bsRole||t.props.children&&e.hasFeedback(t.props.children)})},e.prototype.render=function(){var t=this.props,e=t.validationState,n=t.className,r=t.children,o=(0,s.default)(t,["validationState","className","children"]),a=(0,y.splitBsPropsAndOmit)(o,["controlId"]),l=a[0],u=a[1],c=(0,i.default)({},(0,y.getClassSet)(l),{"has-feedback":this.hasFeedback(r)});return e&&(c["has-"+e]=!0),m.default.createElement("div",(0,i.default)({},u,{className:(0,g.default)(n,c)}),r)},e}(m.default.Component);C.propTypes=w,C.childContextTypes=T,e.default=(0,y.bsClass)("form-group",(0,y.bsSizes)([b.Size.LARGE,b.Size.SMALL],C)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={fluid:m.default.PropTypes.bool,componentClass:b.default},w={componentClass:"div",fluid:!1},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.fluid,n=t.componentClass,r=t.className,o=(0,s.default)(t,["fluid","componentClass","className"]),a=(0,x.splitBsProps)(o),l=a[0],u=a[1],c=(0,x.prefix)(l,e&&"fluid");return m.default.createElement(n,(0,i.default)({},u,{className:(0,g.default)(r,c)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("container",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("span",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("help-block",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b={responsive:m.default.PropTypes.bool,rounded:m.default.PropTypes.bool,circle:m.default.PropTypes.bool,thumbnail:m.default.PropTypes.bool},x={responsive:!1,rounded:!1,circle:!1,thumbnail:!1},_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.responsive,r=e.rounded,o=e.circle,a=e.thumbnail,l=e.className,u=(0,s.default)(e,["responsive","rounded","circle","thumbnail","className"]),c=(0,y.splitBsProps)(u),f=c[0],d=c[1],p=(t={},t[(0,y.prefix)(f,"responsive")]=n,t[(0,y.prefix)(f,"rounded")]=r,t[(0,y.prefix)(f,"circle")]=o,t[(0,y.prefix)(f,"thumbnail")]=a,t);return m.default.createElement("img",(0,i.default)({},d,{className:(0,g.default)(l,p)}))},e}(m.default.Component);_.propTypes=b,_.defaultProps=x,e.default=(0,y.bsClass)("img",_),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(490),b=r(y),x=n(491),_=r(x),w=n(406),T=n(412),C=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,w.splitBsProps)(n),o=r[0],a=r[1],l=(0,w.getClassSet)(o);return m.default.createElement("span",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);C.Addon=b.default,C.Button=_.default,e.default=(0,w.bsClass)("input-group",(0,w.bsSizes)([T.Size.LARGE,T.Size.SMALL],C)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("span",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("input-group-addon",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("span",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("input-group-btn",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(3),g=r(h),v=n(405),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return g.default.createElement(e,(0,i.default)({},l,{className:(0,m.default)(n,u)}))},e}(g.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("jumbotron",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(416),i=r(o),a=n(320),s=r(a),l=n(404),u=r(l),c=n(358),f=r(c),d=n(359),p=r(d),h=n(395),g=r(h),v=n(405),m=r(v),y=n(3),b=r(y),x=n(406),_=n(412),w=function(t){function e(){return(0,f.default)(this,e),(0,p.default)(this,t.apply(this,arguments))}return(0,g.default)(e,t),e.prototype.hasContent=function(t){var e=!1;return b.default.Children.forEach(t,function(t){e||(t||0===t)&&(e=!0)}),e},e.prototype.render=function(){var t=this.props,e=t.className,n=t.children,r=(0,u.default)(t,["className","children"]),o=(0,x.splitBsProps)(r),i=o[0],a=o[1],l=(0,s.default)({},(0,x.getClassSet)(i),{hidden:!this.hasContent(n)});return b.default.createElement("span",(0,s.default)({},a,{className:(0,m.default)(e,l)}),n)},e}(b.default.Component);e.default=(0,x.bsClass)("label",(0,x.bsStyles)([].concat((0,i.default)(_.State),[_.Style.DEFAULT,_.Style.PRIMARY]),_.Style.DEFAULT,w)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){return t?k.default.some(t,function(t){return t.type!==w.default||t.props.href||t.props.onClick})?"div":"ul":"div"}e.__esModule=!0;var i=n(320),a=r(i),s=n(404),l=r(s),u=n(358),c=r(u),f=n(359),d=r(f),p=n(395),h=r(p),g=n(405),v=r(g),m=n(3),y=r(m),b=n(423),x=r(b),_=n(495),w=r(_),T=n(406),C=n(414),k=r(C),E={componentClass:x.default},P=function(t){function e(){return(0,c.default)(this,e),(0,d.default)(this,t.apply(this,arguments))}return(0,h.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.children,n=t.componentClass,r=void 0===n?o(e):n,i=t.className,s=(0,l.default)(t,["children","componentClass","className"]),u=(0,T.splitBsProps)(s),c=u[0],f=u[1],d=(0,T.getClassSet)(c),p="ul"===r&&k.default.every(e,function(t){return t.type===w.default});return y.default.createElement(r,(0,a.default)({},f,{className:(0,v.default)(i,d)}),p?k.default.map(e,function(t){return(0,m.cloneElement)(t,{listItem:!0})}):e)},e}(y.default.Component);P.propTypes=E,e.default=(0,T.bsClass)("list-group",P),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(416),i=r(o),a=n(320),s=r(a),l=n(404),u=r(l),c=n(358),f=r(c),d=n(359),p=r(d),h=n(395),g=r(h),v=n(405),m=r(v),y=n(3),b=r(y),x=n(406),_=n(412),w={active:b.default.PropTypes.any,disabled:b.default.PropTypes.any,header:b.default.PropTypes.node,listItem:b.default.PropTypes.bool,onClick:b.default.PropTypes.func,href:b.default.PropTypes.string,type:b.default.PropTypes.string},T={listItem:!1},C=function(t){function e(){return(0,f.default)(this,e),(0,p.default)(this,t.apply(this,arguments))}return(0,g.default)(e,t),e.prototype.renderHeader=function(t,e){return b.default.isValidElement(t)?(0,y.cloneElement)(t,{className:(0,m.default)(t.props.className,e)}):b.default.createElement("h4",{className:e},t)},e.prototype.render=function(){var t=this.props,e=t.active,n=t.disabled,r=t.className,o=t.header,i=t.listItem,a=t.children,l=(0,u.default)(t,["active","disabled","className","header","listItem","children"]),c=(0,x.splitBsProps)(l),f=c[0],d=c[1],p=(0,s.default)({},(0,x.getClassSet)(f),{active:e,disabled:n}),h=void 0;return d.href?h="a":d.onClick?(h="button",d.type=d.type||"button"):h=i?"li":"span",d.className=(0,m.default)(r,p),o?b.default.createElement(h,d,this.renderHeader(o,(0,x.prefix)(f,"heading")),b.default.createElement("p",{className:(0,x.prefix)(f,"text")},a)):b.default.createElement(h,d,a);
},e}(b.default.Component);C.propTypes=w,C.defaultProps=T,e.default=(0,x.bsClass)("list-group-item",(0,x.bsStyles)((0,i.default)(_.State),C)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(497),_=r(x),w=n(498),T=r(w),C=n(499),k=r(C),E=n(500),P=r(E),S=n(501),M=r(S),N=n(502),A=r(N),O=n(406),D={componentClass:b.default},I={componentClass:"div"},R=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,O.splitBsProps)(r),a=o[0],l=o[1],u=(0,O.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);R.propTypes=D,R.defaultProps=I,R.Heading=T.default,R.Body=_.default,R.Left=k.default,R.Right=A.default,R.List=P.default,R.ListItem=M.default,e.default=(0,O.bsClass)("media",R),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("media-body",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default},w={componentClass:"h4"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("media-heading",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(496),b=r(y),x=n(406),_={align:m.default.PropTypes.oneOf(["top","middle","bottom"])},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.align,n=t.className,r=(0,s.default)(t,["align","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return e&&(u[(0,x.prefix)(b.default.defaultProps,e)]=!0),m.default.createElement("div",(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);w.propTypes=_,e.default=(0,x.bsClass)("media-left",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("ul",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("media-list",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("li",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("media",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(496),b=r(y),x=n(406),_={align:m.default.PropTypes.oneOf(["top","middle","bottom"])},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.align,n=t.className,r=(0,s.default)(t,["align","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return e&&(u[(0,x.prefix)(b.default.defaultProps,e)]=!0),m.default.createElement("div",(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);w.propTypes=_,e.default=(0,x.bsClass)("media-right",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(427),b=r(y),x=n(422),_=r(x),w=n(406),T=n(413),C=r(T),k={active:m.default.PropTypes.bool,disabled:m.default.PropTypes.bool,divider:(0,b.default)(m.default.PropTypes.bool,function(t){var e=t.divider,n=t.children;return e&&n?new Error("Children will not be rendered for dividers"):null}),eventKey:m.default.PropTypes.any,header:m.default.PropTypes.bool,href:m.default.PropTypes.string,onClick:m.default.PropTypes.func,onSelect:m.default.PropTypes.func},E={divider:!1,disabled:!1,header:!1},P=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o}return(0,p.default)(e,t),e.prototype.handleClick=function(t){var e=this.props,n=e.href,r=e.disabled,o=e.onSelect,i=e.eventKey;n&&!r||t.preventDefault(),r||o&&o(i,t)},e.prototype.render=function(){var t=this.props,e=t.active,n=t.disabled,r=t.divider,o=t.header,a=t.onClick,l=t.className,u=t.style,c=(0,s.default)(t,["active","disabled","divider","header","onClick","className","style"]),f=(0,w.splitBsPropsAndOmit)(c,["eventKey","onSelect"]),d=f[0],p=f[1];return r?(p.children=void 0,m.default.createElement("li",(0,i.default)({},p,{role:"separator",className:(0,g.default)(l,"divider"),style:u}))):o?m.default.createElement("li",(0,i.default)({},p,{role:"heading",className:(0,g.default)(l,(0,w.prefix)(d,"header")),style:u})):m.default.createElement("li",{role:"presentation",className:(0,g.default)(l,{active:e,disabled:n}),style:u},m.default.createElement(_.default,(0,i.default)({},p,{role:"menuitem",tabIndex:"-1",onClick:(0,C.default)(a,this.handleClick)})))},e}(m.default.Component);P.propTypes=k,P.defaultProps=E,e.default=(0,w.bsClass)("dropdown",P),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(404),i=r(o),a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(320),p=r(d),h=n(405),g=r(h),v=n(505),m=r(v),y=n(455),b=r(y),x=n(451),_=r(x),w=n(508),T=r(w),C=n(3),k=r(C),E=n(30),P=r(E),S=n(509),M=r(S),N=n(518),A=r(N),O=n(423),D=r(O),I=n(480),R=r(I),L=n(522),F=r(L),j=n(523),B=r(j),U=n(524),H=r(U),z=n(525),W=r(z),q=n(526),V=r(q),K=n(406),Y=n(413),G=r(Y),X=n(479),$=r(X),Z=n(412),J=(0,p.default)({},M.default.propTypes,B.default.propTypes,{backdrop:k.default.PropTypes.oneOf(["static",!0,!1]),keyboard:k.default.PropTypes.bool,animation:k.default.PropTypes.bool,dialogComponentClass:D.default,autoFocus:k.default.PropTypes.bool,enforceFocus:k.default.PropTypes.bool,show:k.default.PropTypes.bool,onHide:k.default.PropTypes.func,onEnter:k.default.PropTypes.func,onEntering:k.default.PropTypes.func,onEntered:k.default.PropTypes.func,onExit:k.default.PropTypes.func,onExiting:k.default.PropTypes.func,onExited:k.default.PropTypes.func,container:M.default.propTypes.container}),Q=(0,p.default)({},M.default.defaultProps,{animation:!0,dialogComponentClass:B.default}),tt={$bs_modal:k.default.PropTypes.shape({onHide:k.default.PropTypes.func})},et=function(t){function e(n,r){(0,s.default)(this,e);var o=(0,u.default)(this,t.call(this,n,r));return o.handleEntering=o.handleEntering.bind(o),o.handleExited=o.handleExited.bind(o),o.handleWindowResize=o.handleWindowResize.bind(o),o.handleDialogClick=o.handleDialogClick.bind(o),o.state={style:{}},o}return(0,f.default)(e,t),e.prototype.getChildContext=function(){return{$bs_modal:{onHide:this.props.onHide}}},e.prototype.componentWillUnmount=function(){this.handleExited()},e.prototype.handleEntering=function(){m.default.on(window,"resize",this.handleWindowResize),this.updateStyle()},e.prototype.handleExited=function(){m.default.off(window,"resize",this.handleWindowResize)},e.prototype.handleWindowResize=function(){this.updateStyle()},e.prototype.handleDialogClick=function(t){t.target===t.currentTarget&&this.props.onHide()},e.prototype.updateStyle=function(){if(_.default){var t=this._modal.getDialogElement(),e=t.scrollHeight,n=(0,b.default)(t),r=(0,A.default)(P.default.findDOMNode(this.props.container||n.body)),o=e>n.documentElement.clientHeight;this.setState({style:{paddingRight:r&&!o?(0,T.default)():void 0,paddingLeft:!r&&o?(0,T.default)():void 0}})}},e.prototype.render=function(){var t=this,n=this.props,r=n.backdrop,o=n.animation,a=n.show,s=n.dialogComponentClass,l=n.className,u=n.style,c=n.children,f=n.onEntering,d=n.onExited,h=(0,i.default)(n,["backdrop","animation","show","dialogComponentClass","className","style","children","onEntering","onExited"]),v=(0,$.default)(h,M.default),m=v[0],y=v[1],b=a&&!o&&"in";return k.default.createElement(M.default,(0,p.default)({},m,{ref:function(e){t._modal=e},show:a,onEntering:(0,G.default)(f,this.handleEntering),onExited:(0,G.default)(d,this.handleExited),backdrop:r,backdropClassName:(0,g.default)((0,K.prefix)(h,"backdrop"),b),containerClassName:(0,K.prefix)(h,"open"),transition:o?R.default:void 0,dialogTransitionTimeout:e.TRANSITION_DURATION,backdropTransitionTimeout:e.BACKDROP_TRANSITION_DURATION}),k.default.createElement(s,(0,p.default)({},y,{style:(0,p.default)({},this.state.style,u),className:(0,g.default)(l,b),onClick:r===!0?this.handleDialogClick:null}),c))},e}(k.default.Component);et.propTypes=J,et.defaultProps=Q,et.childContextTypes=tt,et.Body=F.default,et.Header=W.default,et.Title=V.default,et.Footer=H.default,et.Dialog=B.default,et.TRANSITION_DURATION=300,et.BACKDROP_TRANSITION_DURATION=150,e.default=(0,K.bsClass)("modal",(0,K.bsSizes)([Z.Size.LARGE,Z.Size.SMALL],et)),t.exports=e.default},function(t,e,n){"use strict";var r=n(452),o=n(474),i=n(506);t.exports={on:r,off:o,filter:i}},function(t,e,n){"use strict";var r=n(456),o=n(507);t.exports=function(t,e){return function(n){var i=n.currentTarget,a=n.target,s=o(i,t);s.some(function(t){return r(t,a)})&&e.call(this,n)}}},function(t,e){"use strict";var n=/^[\w-]*$/,r=Function.prototype.bind.call(Function.prototype.call,[].slice);t.exports=function(t,e){var o,i="#"===e[0],a="."===e[0],s=i||a?e.slice(1):e,l=n.test(s);return l?i?(t=t.getElementById?t:document,(o=t.getElementById(s))?[o]:[]):r(t.getElementsByClassName&&a?t.getElementsByClassName(s):t.getElementsByTagName(e)):r(t.querySelectorAll(e))}},function(t,e,n){"use strict";var r,o=n(451);t.exports=function(t){if((!r||t)&&o){var e=document.createElement("div");e.style.position="absolute",e.style.top="-9999px",e.style.width="50px",e.style.height="50px",e.style.overflow="scroll",document.body.appendChild(e),r=e.offsetWidth-e.clientWidth,document.body.removeChild(e)}return r}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0});var o=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},i=n(3),a=r(i),s=n(435),l=r(s),u=n(510),c=r(u),f=n(423),d=r(f),p=n(511),h=r(p),g=n(513),v=r(g),m=n(475),y=r(m),b=n(473),x=r(b),_=n(521),w=r(_),T=n(451),C=r(T),k=n(454),E=r(k),P=n(456),S=r(P),M=n(512),N=r(M),A=new v.default,O=a.default.createClass({displayName:"Modal",propTypes:o({},h.default.propTypes,{show:a.default.PropTypes.bool,container:a.default.PropTypes.oneOfType([c.default,a.default.PropTypes.func]),onShow:a.default.PropTypes.func,onHide:a.default.PropTypes.func,backdrop:a.default.PropTypes.oneOfType([a.default.PropTypes.bool,a.default.PropTypes.oneOf(["static"])]),renderBackdrop:a.default.PropTypes.func,onEscapeKeyUp:a.default.PropTypes.func,onBackdropClick:a.default.PropTypes.func,backdropStyle:a.default.PropTypes.object,backdropClassName:a.default.PropTypes.string,containerClassName:a.default.PropTypes.string,keyboard:a.default.PropTypes.bool,transition:d.default,dialogTransitionTimeout:a.default.PropTypes.number,backdropTransitionTimeout:a.default.PropTypes.number,autoFocus:a.default.PropTypes.bool,enforceFocus:a.default.PropTypes.bool,onEnter:a.default.PropTypes.func,onEntering:a.default.PropTypes.func,onEntered:a.default.PropTypes.func,onExit:a.default.PropTypes.func,onExiting:a.default.PropTypes.func,onExited:a.default.PropTypes.func,manager:a.default.PropTypes.object.isRequired}),getDefaultProps:function(){var t=function(){};return{show:!1,backdrop:!0,keyboard:!0,autoFocus:!0,enforceFocus:!0,onHide:t,manager:A,renderBackdrop:function(t){return a.default.createElement("div",t)}}},getInitialState:function(){return{exited:!this.props.show}},render:function(){var t=this.props,e=t.show,n=t.container,r=t.children,o=t.transition,s=t.backdrop,l=t.dialogTransitionTimeout,u=t.className,c=t.style,f=t.onExit,d=t.onExiting,p=t.onEnter,g=t.onEntering,v=t.onEntered,m=a.default.Children.only(r),y=e||o&&!this.state.exited;if(!y)return null;var b=m.props,x=b.role,_=b.tabIndex;return void 0!==x&&void 0!==_||(m=(0,i.cloneElement)(m,{role:void 0===x?"document":x,tabIndex:null==_?"-1":_})),o&&(m=a.default.createElement(o,{transitionAppear:!0,unmountOnExit:!0,in:e,timeout:l,onExit:f,onExiting:d,onExited:this.handleHidden,onEnter:p,onEntering:g,onEntered:v},m)),a.default.createElement(h.default,{ref:this.setMountNode,container:n},a.default.createElement("div",{ref:"modal",role:x||"dialog",style:c,className:u},s&&this.renderBackdrop(),m))},renderBackdrop:function t(){var e=this,n=this.props,r=n.backdropStyle,o=n.backdropClassName,t=n.renderBackdrop,i=n.transition,s=n.backdropTransitionTimeout,l=function(t){return e.backdrop=t},u=a.default.createElement("div",{ref:l,style:this.props.backdropStyle,className:this.props.backdropClassName,onClick:this.handleBackdropClick});return i&&(u=a.default.createElement(i,{transitionAppear:!0,in:this.props.show,timeout:s},t({ref:l,style:r,className:o,onClick:this.handleBackdropClick}))),u},componentWillReceiveProps:function(t){t.show?this.setState({exited:!1}):t.transition||this.setState({exited:!0})},componentWillUpdate:function(t){!this.props.show&&t.show&&this.checkForFocus()},componentDidMount:function(){this.props.show&&this.onShow()},componentDidUpdate:function(t){var e=this.props.transition;!t.show||this.props.show||e?!t.show&&this.props.show&&this.onShow():this.onHide()},componentWillUnmount:function(){var t=this.props,e=t.show,n=t.transition;(e||n&&!this.state.exited)&&this.onHide()},onShow:function(){var t=(0,y.default)(this),e=(0,N.default)(this.props.container,t.body);this.props.manager.add(this,e,this.props.containerClassName),this._onDocumentKeyupListener=(0,x.default)(t,"keyup",this.handleDocumentKeyUp),this._onFocusinListener=(0,w.default)(this.enforceFocus),this.focus(),this.props.onShow&&this.props.onShow()},onHide:function(){this.props.manager.remove(this),this._onDocumentKeyupListener.remove(),this._onFocusinListener.remove(),this.restoreLastFocus()},setMountNode:function(t){this.mountNode=t?t.getMountNode():t},handleHidden:function(){if(this.setState({exited:!0}),this.onHide(),this.props.onExited){var t;(t=this.props).onExited.apply(t,arguments)}},handleBackdropClick:function(t){t.target===t.currentTarget&&(this.props.onBackdropClick&&this.props.onBackdropClick(t),this.props.backdrop===!0&&this.props.onHide())},handleDocumentKeyUp:function(t){this.props.keyboard&&27===t.keyCode&&this.isTopModal()&&(this.props.onEscapeKeyUp&&this.props.onEscapeKeyUp(t),this.props.onHide())},checkForFocus:function(){C.default&&(this.lastFocus=(0,E.default)())},focus:function(){var t=this.props.autoFocus,e=this.getDialogElement(),n=(0,E.default)((0,y.default)(this)),r=n&&(0,S.default)(e,n);e&&t&&!r&&(this.lastFocus=n,e.hasAttribute("tabIndex")||(e.setAttribute("tabIndex",-1),(0,l.default)(!1,'The modal content node does not accept focus. For the benefit of assistive technologies, the tabIndex of the node is being set to "-1".')),e.focus())},restoreLastFocus:function(){this.lastFocus&&this.lastFocus.focus&&(this.lastFocus.focus(),this.lastFocus=null)},enforceFocus:function t(){var t=this.props.enforceFocus;if(t&&this.isMounted()&&this.isTopModal()){var e=(0,E.default)((0,y.default)(this)),n=this.getDialogElement();n&&n!==e&&!(0,S.default)(n,e)&&n.focus()}},getDialogElement:function(){var t=this.refs.modal;return t&&t.lastChild},isTopModal:function(){return this.props.manager.isTopModal(this)}});O.Manager=v.default,e.default=O,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n,r,o){var a=t[e],l="undefined"==typeof a?"undefined":i(a);return s.default.isValidElement(a)?new Error("Invalid "+r+" `"+o+"` of type ReactElement "+("supplied to `"+n+"`, expected a ReactComponent or a ")+"DOMElement. You can usually obtain a ReactComponent or DOMElement from a ReactElement by attaching a ref to it."):"object"===l&&"function"==typeof a.render||1===a.nodeType?null:new Error("Invalid "+r+" `"+o+"` of value `"+a+"` "+("supplied to `"+n+"`, expected a ReactComponent or a ")+"DOMElement.")}e.__esModule=!0;var i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol?"symbol":typeof t},a=n(3),s=r(a),l=n(424),u=r(l);e.default=(0,u.default)(o)},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}Object.defineProperty(e,"__esModule",{value:!0});var o=n(3),i=r(o),a=n(30),s=r(a),l=n(510),u=r(l),c=n(475),f=r(c),d=n(512),p=r(d),h=i.default.createClass({displayName:"Portal",propTypes:{container:i.default.PropTypes.oneOfType([u.default,i.default.PropTypes.func])},componentDidMount:function(){this._renderOverlay()},componentDidUpdate:function(){this._renderOverlay()},componentWillReceiveProps:function(t){this._overlayTarget&&t.container!==this.props.container&&(this._portalContainerNode.removeChild(this._overlayTarget),this._portalContainerNode=(0,p.default)(t.container,(0,f.default)(this).body),this._portalContainerNode.appendChild(this._overlayTarget))},componentWillUnmount:function(){this._unrenderOverlay(),this._unmountOverlayTarget()},_mountOverlayTarget:function(){this._overlayTarget||(this._overlayTarget=document.createElement("div"),this._portalContainerNode=(0,p.default)(this.props.container,(0,f.default)(this).body),this._portalContainerNode.appendChild(this._overlayTarget))},_unmountOverlayTarget:function(){this._overlayTarget&&(this._portalContainerNode.removeChild(this._overlayTarget),this._overlayTarget=null),this._portalContainerNode=null},_renderOverlay:function(){var t=this.props.children?i.default.Children.only(this.props.children):null;null!==t?(this._mountOverlayTarget(),this._overlayInstance=s.default.unstable_renderSubtreeIntoContainer(this,t,this._overlayTarget)):(this._unrenderOverlay(),this._unmountOverlayTarget())},_unrenderOverlay:function(){this._overlayTarget&&(s.default.unmountComponentAtNode(this._overlayTarget),this._overlayInstance=null)},render:function(){return null},getMountNode:function(){return this._overlayTarget},getOverlayDOMNode:function(){if(!this.isMounted())throw new Error("getOverlayDOMNode(): A component must be mounted to have a DOM node.");return this._overlayInstance?s.default.findDOMNode(this._overlayInstance):null}});e.default=h,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){return t="function"==typeof t?t():t,a.default.findDOMNode(t)||e}Object.defineProperty(e,"__esModule",{value:!0}),e.default=o;var i=n(30),a=r(i);t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function i(t,e){var n=-1;return t.some(function(t,r){if(e(t,r))return n=r,!0}),n}function a(t,e){return i(t,function(t){return t.modals.indexOf(e)!==-1})}function s(t,e){var n={overflow:"hidden"};t.style={overflow:e.style.overflow,paddingRight:e.style.paddingRight},t.overflowing&&(n.paddingRight=parseInt((0,f.default)(e,"paddingRight")||0,10)+(0,g.default)()+"px"),(0,f.default)(e,n)}function l(t,e){var n=t.style;Object.keys(n).forEach(function(t){return e.style[t]=n[t]})}Object.defineProperty(e,"__esModule",{value:!0});var u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),c=n(441),f=r(c),d=n(514),p=r(d),h=n(508),g=r(h),v=n(518),m=r(v),y=n(520),b=function(){function t(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},n=e.hideSiblingNodes,r=void 0===n||n,i=e.handleContainerOverflow,a=void 0===i||i;o(this,t),this.hideSiblingNodes=r,this.handleContainerOverflow=a,this.modals=[],this.containers=[],this.data=[]}return u(t,[{key:"add",value:function(t,e,n){var r=this.modals.indexOf(t),o=this.containers.indexOf(e);if(r!==-1)return r;if(r=this.modals.length,this.modals.push(t),this.hideSiblingNodes&&(0,y.hideSiblings)(e,t.mountNode),o!==-1)return this.data[o].modals.push(t),r;var i={modals:[t],classes:n?n.split(/\s+/):[],overflowing:(0,m.default)(e)};return this.handleContainerOverflow&&s(i,e),i.classes.forEach(p.default.addClass.bind(null,e)),this.containers.push(e),this.data.push(i),r}},{key:"remove",value:function(t){var e=this.modals.indexOf(t);if(e!==-1){var n=a(this.data,t),r=this.data[n],o=this.containers[n];r.modals.splice(r.modals.indexOf(t),1),this.modals.splice(e,1),0===r.modals.length?(r.classes.forEach(p.default.removeClass.bind(null,o)),this.handleContainerOverflow&&l(r,o),this.hideSiblingNodes&&(0,y.showSiblings)(o,t.mountNode),this.containers.splice(n,1),this.data.splice(n,1)):this.hideSiblingNodes&&(0,y.ariaHidden)(!1,r.modals[r.modals.length-1].mountNode)}}},{key:"isTopModal",value:function(t){return!!this.modals.length&&this.modals[this.modals.length-1]===t}}]),t}();e.default=b,t.exports=e.default},function(t,e,n){"use strict";t.exports={addClass:n(515),removeClass:n(517),hasClass:n(516)}},function(t,e,n){"use strict";var r=n(516);t.exports=function(t,e){t.classList?t.classList.add(e):r(t)||(t.className=t.className+" "+e)}},function(t,e){"use strict";t.exports=function(t,e){return t.classList?!!e&&t.classList.contains(e):(" "+t.className+" ").indexOf(" "+e+" ")!==-1}},function(t,e){"use strict";t.exports=function(t,e){t.classList?t.classList.remove(e):t.className=t.className.replace(new RegExp("(^|\\s)"+e+"(?:\\s|$)","g"),"$1").replace(/\s+/g," ").replace(/^\s*|\s*$/g,"")}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){return t&&"body"===t.tagName.toLowerCase()}function i(t){var e=(0,c.default)(t),n=(0,l.default)(e),r=n.innerWidth;if(!r){var o=e.documentElement.getBoundingClientRect();r=o.right-Math.abs(o.left)}return e.body.clientWidth<r}function a(t){var e=(0,l.default)(t);return e||o(t)?i(t):t.scrollHeight>t.clientHeight}Object.defineProperty(e,"__esModule",{value:!0}),e.default=a;var s=n(519),l=r(s),u=n(455),c=r(u);t.exports=e.default},function(t,e){"use strict";t.exports=function(t){return t===t.window?t:9===t.nodeType&&(t.defaultView||t.parentWindow)}},function(t,e){"use strict";function n(t,e){e&&(t?e.setAttribute("aria-hidden","true"):e.removeAttribute("aria-hidden"))}function r(t,e){s(t,e,function(t){return n(!0,t)})}function o(t,e){s(t,e,function(t){return n(!1,t)})}Object.defineProperty(e,"__esModule",{value:!0}),e.ariaHidden=n,e.hideSiblings=r,e.showSiblings=o;var i=["template","script","style"],a=function(t){var e=t.nodeType,n=t.tagName;return 1===e&&i.indexOf(n.toLowerCase())===-1},s=function(t,e,n){e=[].concat(e),[].forEach.call(t.children,function(t){e.indexOf(t)===-1&&a(t)&&n(t)})}},function(t,e){"use strict";function n(t){var e=!document.addEventListener,n=void 0;return e?(document.attachEvent("onfocusin",t),n=function(){return document.detachEvent("onfocusin",t)}):(document.addEventListener("focus",t,!0),n=function(){return document.removeEventListener("focus",t,!0)}),{remove:n}}Object.defineProperty(e,"__esModule",{value:!0}),e.default=n,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("modal-body",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=n(412),x={dialogClassName:m.default.PropTypes.string},_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.dialogClassName,r=e.className,o=e.style,a=e.children,l=(0,s.default)(e,["dialogClassName","className","style","children"]),u=(0,y.splitBsProps)(l),c=u[0],f=u[1],d=(0,y.prefix)(c),p=(0,i.default)({display:"block"},o),h=(0,i.default)({},(0,y.getClassSet)(c),(t={},t[d]=!1,t[(0,y.prefix)(c,"dialog")]=!0,t));return m.default.createElement("div",(0,i.default)({},f,{tabIndex:"-1",role:"dialog",style:p,className:(0,g.default)(r,d)}),m.default.createElement("div",{className:(0,g.default)(n,h)},m.default.createElement("div",{className:(0,y.prefix)(c,"content"),role:"document"},a)))},e}(m.default.Component);_.propTypes=x,e.default=(0,y.bsClass)("modal",(0,y.bsSizes)([b.Size.LARGE,b.Size.SMALL],_)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("modal-footer",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=n(413),x=r(b),_={"aria-label":m.default.PropTypes.string,closeButton:m.default.PropTypes.bool,onHide:m.default.PropTypes.func},w={"aria-label":"Close",closeButton:!1},T={$bs_modal:m.default.PropTypes.shape({onHide:m.default.PropTypes.func})},C=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t["aria-label"],n=t.closeButton,r=t.onHide,o=t.className,a=t.children,l=(0,s.default)(t,["aria-label","closeButton","onHide","className","children"]),u=this.context.$bs_modal,c=(0,y.splitBsProps)(l),f=c[0],d=c[1],p=(0,y.getClassSet)(f);return m.default.createElement("div",(0,i.default)({},d,{className:(0,g.default)(o,p)}),n&&m.default.createElement("button",{type:"button",className:"close","aria-label":e,onClick:(0,x.default)(u.onHide,r)},m.default.createElement("span",{"aria-hidden":"true"},"×")),a)},e}(m.default.Component);C.propTypes=_,C.defaultProps=w,C.contextTypes=T,e.default=(0,y.bsClass)("modal-header",C),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default},w={componentClass:"h4"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("modal-title",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(457),m=r(v),y=n(3),b=r(y),x=n(30),_=r(x),w=n(427),T=r(w),C=n(435),k=(r(C),n(406)),E=n(413),P=r(E),S=n(414),M=r(S),N={activeKey:b.default.PropTypes.any,activeHref:b.default.PropTypes.string,stacked:b.default.PropTypes.bool,justified:(0,T.default)(b.default.PropTypes.bool,function(t){var e=t.justified,n=t.navbar;return e&&n?Error("justified navbar `Nav`s are not supported"):null}),onSelect:b.default.PropTypes.func,role:b.default.PropTypes.string,navbar:b.default.PropTypes.bool,pullRight:b.default.PropTypes.bool,pullLeft:b.default.PropTypes.bool},A={justified:!1,pullRight:!1,pullLeft:!1,stacked:!1},O={$bs_navbar:b.default.PropTypes.shape({bsClass:b.default.PropTypes.string,onSelect:b.default.PropTypes.func}),$bs_tabContainer:b.default.PropTypes.shape({activeKey:b.default.PropTypes.any,onSelect:b.default.PropTypes.func.isRequired,getTabId:b.default.PropTypes.func.isRequired,getPaneId:b.default.PropTypes.func.isRequired})},D=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.componentDidUpdate=function(){
var t=this;if(this._needsRefocus){this._needsRefocus=!1;var e=this.props.children,n=this.getActiveProps(),r=n.activeKey,o=n.activeHref,i=M.default.find(e,function(e){return t.isActive(e,r,o)}),a=M.default.toArray(e),s=a.indexOf(i),l=_.default.findDOMNode(this).children,u=l&&l[s];u&&u.firstChild&&u.firstChild.focus()}},e.prototype.handleTabKeyDown=function(t,e){var n=void 0;switch(e.keyCode){case m.default.codes.left:case m.default.codes.up:n=this.getNextActiveChild(-1);break;case m.default.codes.right:case m.default.codes.down:n=this.getNextActiveChild(1);break;default:return}e.preventDefault(),t&&n&&n.props.eventKey&&t(n.props.eventKey),this._needsRefocus=!0},e.prototype.getNextActiveChild=function(t){var e=this,n=this.props.children,r=n.filter(function(t){return t.props.eventKey&&!t.props.disabled}),o=this.getActiveProps(),i=o.activeKey,a=o.activeHref,s=M.default.find(n,function(t){return e.isActive(t,i,a)}),l=r.indexOf(s);if(l===-1)return r[0];var u=l+t,c=r.length;return u>=c?u=0:u<0&&(u=c-1),r[u]},e.prototype.getActiveProps=function(){var t=this.context.$bs_tabContainer;return t?t:this.props},e.prototype.isActive=function(t,e,n){var r=t.props;return!!(r.active||null!=e&&r.eventKey===e||n&&r.href===n)||r.active},e.prototype.getTabProps=function(t,e,n,r,o){var i=this;if(!e&&"tablist"!==n)return null;var a=t.props,s=a.id,l=a["aria-controls"],u=a.eventKey,c=a.role,f=a.onKeyDown,d=a.tabIndex;return e&&(s=e.getTabId(u),l=e.getPaneId(u)),"tablist"===n&&(c=c||"tab",f=(0,P.default)(function(t){return i.handleTabKeyDown(o,t)},f),d=r?d:-1),{id:s,role:c,onKeyDown:f,"aria-controls":l,tabIndex:d}},e.prototype.render=function(){var t,e=this,n=this.props,r=n.stacked,o=n.justified,a=n.onSelect,l=n.role,u=n.navbar,c=n.pullRight,f=n.pullLeft,d=n.className,p=n.children,h=(0,s.default)(n,["stacked","justified","onSelect","role","navbar","pullRight","pullLeft","className","children"]),v=this.context.$bs_tabContainer,m=l||(v?"tablist":null),x=this.getActiveProps(),_=x.activeKey,w=x.activeHref;delete h.activeKey,delete h.activeHref;var T=(0,k.splitBsProps)(h),C=T[0],E=T[1],S=(0,i.default)({},(0,k.getClassSet)(C),(t={},t[(0,k.prefix)(C,"stacked")]=r,t[(0,k.prefix)(C,"justified")]=o,t)),N=null!=u?u:this.context.$bs_navbar,A=void 0,O=void 0;if(N){var D=this.context.$bs_navbar||{bsClass:"navbar"};S[(0,k.prefix)(D,"nav")]=!0,O=(0,k.prefix)(D,"right"),A=(0,k.prefix)(D,"left")}else O="pull-right",A="pull-left";return S[O]=c,S[A]=f,b.default.createElement("ul",(0,i.default)({},E,{role:m,className:(0,g.default)(d,S)}),M.default.map(p,function(t){var n=e.isActive(t,_,w),r=(0,P.default)(t.props.onSelect,a,N&&N.onSelect,v&&v.onSelect);return(0,y.cloneElement)(t,(0,i.default)({},e.getTabProps(t,v,m,n,r),{active:n,activeKey:_,activeHref:w,onSelect:r}))}))},e}(b.default.Component);D.propTypes=N,D.defaultProps=A,D.contextTypes=O,e.default=(0,k.bsClass)("nav",(0,k.bsStyles)(["tabs","pills"],D)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r=function(t,n){var r=n.$bs_navbar,o=void 0===r?{bsClass:"navbar"}:r,i=t.componentClass,s=t.className,u=t.pullRight,c=t.pullLeft,f=(0,l.default)(t,["componentClass","className","pullRight","pullLeft"]);return y.default.createElement(i,(0,a.default)({},f,{className:(0,v.default)(s,(0,D.prefix)(o,e),u&&(0,D.prefix)(o,"right"),c&&(0,D.prefix)(o,"left"))}))};return r.displayName=n,r.propTypes={componentClass:x.default,pullRight:y.default.PropTypes.bool,pullLeft:y.default.PropTypes.bool},r.defaultProps={componentClass:t,pullRight:!1,pullLeft:!1},r.contextTypes={$bs_navbar:m.PropTypes.shape({bsClass:m.PropTypes.string})},r}e.__esModule=!0;var i=n(320),a=r(i),s=n(404),l=r(s),u=n(358),c=r(u),f=n(359),d=r(f),p=n(395),h=r(p),g=n(405),v=r(g),m=n(3),y=r(m),b=n(423),x=r(b),_=n(459),w=r(_),T=n(486),C=r(T),k=n(529),E=r(k),P=n(530),S=r(P),M=n(531),N=r(M),A=n(532),O=r(A),D=n(406),I=n(412),R=n(413),L=r(R),F={fixedTop:y.default.PropTypes.bool,fixedBottom:y.default.PropTypes.bool,staticTop:y.default.PropTypes.bool,inverse:y.default.PropTypes.bool,fluid:y.default.PropTypes.bool,componentClass:x.default,onToggle:y.default.PropTypes.func,onSelect:y.default.PropTypes.func,collapseOnSelect:y.default.PropTypes.bool,expanded:y.default.PropTypes.bool,role:y.default.PropTypes.string},j={componentClass:"nav",fixedTop:!1,fixedBottom:!1,staticTop:!1,inverse:!1,fluid:!1,collapseOnSelect:!1},B={$bs_navbar:m.PropTypes.shape({bsClass:m.PropTypes.string,expanded:m.PropTypes.bool,onToggle:m.PropTypes.func.isRequired,onSelect:m.PropTypes.func})},U=function(t){function e(n,r){(0,c.default)(this,e);var o=(0,d.default)(this,t.call(this,n,r));return o.handleToggle=o.handleToggle.bind(o),o.handleCollapse=o.handleCollapse.bind(o),o}return(0,h.default)(e,t),e.prototype.getChildContext=function(){var t=this.props,e=t.bsClass,n=t.expanded,r=t.onSelect,o=t.collapseOnSelect;return{$bs_navbar:{bsClass:e,expanded:n,onToggle:this.handleToggle,onSelect:(0,L.default)(r,o?this.handleCollapse:null)}}},e.prototype.handleCollapse=function(){var t=this.props,e=t.onToggle,n=t.expanded;n&&e(!1)},e.prototype.handleToggle=function(){var t=this.props,e=t.onToggle,n=t.expanded;e(!n)},e.prototype.render=function(){var t,e=this.props,n=e.componentClass,r=e.fixedTop,o=e.fixedBottom,i=e.staticTop,s=e.inverse,u=e.fluid,c=e.className,f=e.children,d=(0,l.default)(e,["componentClass","fixedTop","fixedBottom","staticTop","inverse","fluid","className","children"]),p=(0,D.splitBsPropsAndOmit)(d,["expanded","onToggle","onSelect","collapseOnSelect"]),h=p[0],g=p[1];void 0===g.role&&"nav"!==n&&(g.role="navigation"),s&&(h.bsStyle=I.Style.INVERSE);var m=(0,a.default)({},(0,D.getClassSet)(h),(t={},t[(0,D.prefix)(h,"fixed-top")]=r,t[(0,D.prefix)(h,"fixed-bottom")]=o,t[(0,D.prefix)(h,"static-top")]=i,t));return y.default.createElement(n,(0,a.default)({},g,{className:(0,v.default)(c,m)}),y.default.createElement(C.default,{fluid:u},f))},e}(y.default.Component);U.propTypes=F,U.defaultProps=j,U.childContextTypes=B,(0,D.bsClass)("navbar",U);var H=(0,w.default)(U,{expanded:"onToggle"});H.Brand=E.default,H.Header=N.default,H.Toggle=O.default,H.Collapse=S.default,H.Form=o("div","form","NavbarForm"),H.Text=o("p","text","NavbarText"),H.Link=o("a","link","NavbarLink"),e.default=(0,D.bsStyles)([I.Style.DEFAULT,I.Style.INVERSE],I.Style.DEFAULT,H),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b={$bs_navbar:m.default.PropTypes.shape({bsClass:m.default.PropTypes.string})},x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=t.children,r=(0,s.default)(t,["className","children"]),o=this.context.$bs_navbar||{bsClass:"navbar"},a=(0,y.prefix)(o,"brand");return m.default.isValidElement(n)?m.default.cloneElement(n,{className:(0,g.default)(n.props.className,e,a)}):m.default.createElement("span",(0,i.default)({},r,{className:(0,g.default)(e,a)}),n)},e}(m.default.Component);x.contextTypes=b,e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(3),g=r(h),v=n(440),m=r(v),y=n(406),b={$bs_navbar:h.PropTypes.shape({bsClass:h.PropTypes.string,expanded:h.PropTypes.bool})},x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.children,n=(0,s.default)(t,["children"]),r=this.context.$bs_navbar||{bsClass:"navbar"},o=(0,y.prefix)(r,"collapse");return g.default.createElement(m.default,(0,i.default)({in:r.expanded},n),g.default.createElement("div",{className:o},e))},e}(g.default.Component);x.contextTypes=b,e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b={$bs_navbar:m.default.PropTypes.shape({bsClass:m.default.PropTypes.string})},x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=this.context.$bs_navbar||{bsClass:"navbar"},o=(0,y.prefix)(r,"header");return m.default.createElement("div",(0,i.default)({},n,{className:(0,g.default)(e,o)}))},e}(m.default.Component);x.contextTypes=b,e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=n(413),x=r(b),_={onClick:v.PropTypes.func,children:v.PropTypes.node},w={$bs_navbar:v.PropTypes.shape({bsClass:v.PropTypes.string,expanded:v.PropTypes.bool,onToggle:v.PropTypes.func.isRequired})},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.onClick,n=t.className,r=t.children,o=(0,s.default)(t,["onClick","className","children"]),a=this.context.$bs_navbar||{bsClass:"navbar"},l=(0,i.default)({type:"button"},o,{onClick:(0,x.default)(e,a.onToggle),className:(0,g.default)(n,(0,y.prefix)(a,"toggle"),!a.expanded&&"collapsed")});return r?m.default.createElement("button",l,r):m.default.createElement("button",l,m.default.createElement("span",{className:"sr-only"},"Toggle navigation"),m.default.createElement("span",{className:"icon-bar"}),m.default.createElement("span",{className:"icon-bar"}),m.default.createElement("span",{className:"icon-bar"}))},e}(m.default.Component);T.propTypes=_,T.contextTypes=w,e.default=T,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(404),i=r(o),a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(320),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(453),b=r(y),x=n(479),_=r(x),w=n(414),T=r(w),C=(0,p.default)({},b.default.propTypes,{title:m.default.PropTypes.node.isRequired,noCaret:m.default.PropTypes.bool,active:m.default.PropTypes.bool,children:m.default.PropTypes.node}),k=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.isActive=function(t,e,n){var r=t.props,o=this;return!!(r.active||null!=e&&r.eventKey===e||n&&r.href===n)||(!!T.default.some(r.children,function(t){return o.isActive(t,e,n)})||r.active)},e.prototype.render=function(){var t=this,e=this.props,n=e.title,r=e.activeKey,o=e.activeHref,a=e.className,s=e.style,l=e.children,u=(0,i.default)(e,["title","activeKey","activeHref","className","style","children"]),c=this.isActive(this,r,o);delete u.active,delete u.eventKey;var f=(0,_.default)(u,b.default.ControlledComponent),d=f[0],h=f[1];return m.default.createElement(b.default,(0,p.default)({},d,{componentClass:"li",className:(0,g.default)(a,{active:c}),style:s}),m.default.createElement(b.default.Toggle,(0,p.default)({},h,{useAnchor:!0}),n),m.default.createElement(b.default.Menu,null,T.default.map(l,function(e){return m.default.cloneElement(e,{active:t.isActive(e,r,o)})})))},e}(m.default.Component);k.propTypes=C,e.default=k,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(422),b=r(y),x=n(413),_=r(x),w={active:m.default.PropTypes.bool,disabled:m.default.PropTypes.bool,role:m.default.PropTypes.string,href:m.default.PropTypes.string,onClick:m.default.PropTypes.func,onSelect:m.default.PropTypes.func,eventKey:m.default.PropTypes.any},T={active:!1,disabled:!1},C=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o}return(0,p.default)(e,t),e.prototype.handleClick=function(t){this.props.onSelect&&(t.preventDefault(),this.props.disabled||this.props.onSelect(this.props.eventKey,t))},e.prototype.render=function(){var t=this.props,e=t.active,n=t.disabled,r=t.onClick,o=t.className,a=t.style,l=(0,s.default)(t,["active","disabled","onClick","className","style"]);return delete l.onSelect,delete l.eventKey,delete l.activeKey,delete l.activeHref,l.role?"tab"===l.role&&(l["aria-selected"]=e):"#"===l.href&&(l.role="button"),m.default.createElement("li",{role:"presentation",className:(0,g.default)(o,{active:e,disabled:n}),style:a},m.default.createElement(b.default,(0,i.default)({},l,{disabled:n,onClick:(0,_.default)(r,this.handleClick)})))},e}(m.default.Component);C.propTypes=w,C.defaultProps=T,e.default=C,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(404),i=r(o),a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(320),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(536),b=r(y),x=n(423),_=r(x),w=n(480),T=r(w),C=(0,p.default)({},b.default.propTypes,{show:m.default.PropTypes.bool,rootClose:m.default.PropTypes.bool,onHide:m.default.PropTypes.func,animation:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,_.default]),onEnter:m.default.PropTypes.func,onEntering:m.default.PropTypes.func,onEntered:m.default.PropTypes.func,onExit:m.default.PropTypes.func,onExiting:m.default.PropTypes.func,onExited:m.default.PropTypes.func,placement:m.default.PropTypes.oneOf(["top","right","bottom","left"])}),k={animation:T.default,rootClose:!1,show:!1,placement:"right"},E=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.animation,n=t.children,r=(0,i.default)(t,["animation","children"]),o=e===!0?T.default:e||null,a=void 0;return a=o?n:(0,v.cloneElement)(n,{className:(0,g.default)(n.props.className,"in")}),m.default.createElement(b.default,(0,p.default)({},r,{transition:o}),a)},e}(m.default.Component);E.propTypes=C,E.defaultProps=k,e.default=E,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}function i(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function a(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0});var l=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),c=n(3),f=r(c),d=n(511),p=r(d),h=n(537),g=r(h),v=n(472),m=r(v),y=n(423),b=r(y),x=function(t){function e(t,n){i(this,e);var r=a(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t,n));return r.state={exited:!t.show},r.onHiddenListener=r.handleHidden.bind(r),r}return s(e,t),u(e,[{key:"componentWillReceiveProps",value:function(t){t.show?this.setState({exited:!1}):t.transition||this.setState({exited:!0})}},{key:"render",value:function(){var t=this.props,e=t.container,n=t.containerPadding,r=t.target,i=t.placement,a=t.shouldUpdatePosition,s=t.rootClose,l=t.children,u=t.transition,c=o(t,["container","containerPadding","target","placement","shouldUpdatePosition","rootClose","children","transition"]),d=c.show||u&&!this.state.exited;if(!d)return null;var h=l;if(h=f.default.createElement(g.default,{container:e,containerPadding:n,target:r,placement:i,shouldUpdatePosition:a},h),u){var v=c.onExit,y=c.onExiting,b=c.onEnter,x=c.onEntering,_=c.onEntered;h=f.default.createElement(u,{in:c.show,transitionAppear:!0,onExit:v,onExiting:y,onExited:this.onHiddenListener,onEnter:b,onEntering:x,onEntered:_},h)}return s&&(h=f.default.createElement(m.default,{onRootClose:c.onHide},h)),f.default.createElement(p.default,{container:e},h)}},{key:"handleHidden",value:function(){if(this.setState({exited:!0}),this.props.onExited){var t;(t=this.props).onExited.apply(t,arguments)}}}]),e}(f.default.Component);x.propTypes=l({},p.default.propTypes,g.default.propTypes,{show:f.default.PropTypes.bool,rootClose:f.default.PropTypes.bool,onHide:function(t){var e=f.default.PropTypes.func;t.rootClose&&(e=e.isRequired);for(var n=arguments.length,r=Array(n>1?n-1:0),o=1;o<n;o++)r[o-1]=arguments[o];return e.apply(void 0,[t].concat(r))},transition:b.default,onEnter:f.default.PropTypes.func,onEntering:f.default.PropTypes.func,onEntered:f.default.PropTypes.func,onExit:f.default.PropTypes.func,onExiting:f.default.PropTypes.func,onExited:f.default.PropTypes.func}),e.default=x,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){var n={};for(var r in t)e.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(t,r)&&(n[r]=t[r]);return n}function i(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function a(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(e,"__esModule",{value:!0});var l=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t},u=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),c=n(405),f=r(c),d=n(3),p=r(d),h=n(30),g=r(h),v=n(510),m=r(v),y=n(538),b=r(y),x=n(512),_=r(x),w=n(475),T=r(w),C=function(t){function e(t,n){i(this,e);var r=a(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t,n));return r.state={positionLeft:0,positionTop:0,arrowOffsetLeft:null,arrowOffsetTop:null},r._needsFlush=!1,r._lastTarget=null,r}return s(e,t),u(e,[{key:"componentDidMount",value:function(){this.updatePosition(this.getTarget())}},{key:"componentWillReceiveProps",value:function(){this._needsFlush=!0}},{key:"componentDidUpdate",value:function(t){this._needsFlush&&(this._needsFlush=!1,this.maybeUpdatePosition(this.props.placement!==t.placement))}},{key:"render",value:function(){var t=this.props,e=t.children,n=t.className,r=o(t,["children","className"]),i=this.state,a=i.positionLeft,s=i.positionTop,u=o(i,["positionLeft","positionTop"]);delete r.target,delete r.container,delete r.containerPadding,delete r.shouldUpdatePosition;var c=p.default.Children.only(e);return(0,d.cloneElement)(c,l({},r,u,{positionLeft:a,positionTop:s,className:(0,f.default)(n,c.props.className),style:l({},c.props.style,{left:a,top:s})}))}},{key:"getTarget",value:function(){var t=this.props.target,e="function"==typeof t?t():t;return e&&g.default.findDOMNode(e)||null}},{key:"maybeUpdatePosition",value:function(t){var e=this.getTarget();(this.props.shouldUpdatePosition||e!==this._lastTarget||t)&&this.updatePosition(e)}},{key:"updatePosition",value:function(t){if(this._lastTarget=t,!t)return void this.setState({positionLeft:0,positionTop:0,arrowOffsetLeft:null,arrowOffsetTop:null});var e=g.default.findDOMNode(this),n=(0,_.default)(this.props.container,(0,T.default)(this).body);this.setState((0,b.default)(this.props.placement,e,t,n,this.props.containerPadding))}}]),e}(p.default.Component);C.propTypes={target:p.default.PropTypes.oneOfType([m.default,p.default.PropTypes.func]),container:p.default.PropTypes.oneOfType([m.default,p.default.PropTypes.func]),containerPadding:p.default.PropTypes.number,placement:p.default.PropTypes.oneOf(["top","right","bottom","left"]),shouldUpdatePosition:p.default.PropTypes.bool},C.displayName="Position",C.defaultProps={containerPadding:0,placement:"right",shouldUpdatePosition:!1},e.default=C,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){var e=void 0,n=void 0,r=void 0;if("BODY"===t.tagName)e=window.innerWidth,n=window.innerHeight,r=(0,p.default)((0,g.default)(t).documentElement)||(0,p.default)(t);else{var o=(0,u.default)(t);e=o.width,n=o.height,r=(0,p.default)(t)}return{width:e,height:n,scroll:r}}function i(t,e,n,r){var i=o(n),a=i.scroll,s=i.height,l=t-r-a,u=t+r-a+e;return l<0?-l:u>s?s-u:0}function a(t,e,n,r){var i=o(n),a=i.width,s=t-r,l=t+r+e;return s<0?-s:l>a?a-l:0}function s(t,e,n,r,o){var s="BODY"===r.tagName?(0,u.default)(n):(0,f.default)(n,r),l=(0,u.default)(e),c=l.height,d=l.width,p=void 0,h=void 0,g=void 0,v=void 0;if("left"===t||"right"===t){h=s.top+(s.height-c)/2,p="left"===t?s.left-d:s.left+s.width;var m=i(h,c,r,o);h+=m,v=50*(1-2*m/c)+"%",g=void 0}else{if("top"!==t&&"bottom"!==t)throw new Error('calcOverlayPosition(): No such placement of "'+t+'" found.');p=s.left+(s.width-d)/2,h="top"===t?s.top-c:s.top+s.height;var y=a(p,d,r,o);p+=y,g=50*(1-2*y/d)+"%",v=void 0}return{positionLeft:p,positionTop:h,arrowOffsetLeft:g,arrowOffsetTop:v}}Object.defineProperty(e,"__esModule",{value:!0}),e.default=s;var l=n(539),u=r(l),c=n(540),f=r(c),d=n(542),p=r(d),h=n(475),g=r(h);t.exports=e.default},function(t,e,n){"use strict";var r=n(456),o=n(519),i=n(455);t.exports=function(t){var e=i(t),n=o(e),a=e&&e.documentElement,s={top:0,left:0,height:0,width:0};if(e)return r(a,t)?(void 0!==t.getBoundingClientRect&&(s=t.getBoundingClientRect()),(s.width||s.height)&&(s={top:s.top+(n.pageYOffset||a.scrollTop)-(a.clientTop||0),left:s.left+(n.pageXOffset||a.scrollLeft)-(a.clientLeft||0),width:(null==s.width?t.offsetWidth:s.width)||0,height:(null==s.height?t.offsetHeight:s.height)||0}),s):s}},function(t,e,n){"use strict";function r(t){return t.nodeName&&t.nodeName.toLowerCase()}function o(t,e){var n,o={top:0,left:0};return"fixed"===(0,g.default)(t,"position")?n=t.getBoundingClientRect():(e=e||(0,u.default)(t),n=(0,s.default)(t),"html"!==r(e)&&(o=(0,s.default)(e)),o.top+=parseInt((0,g.default)(e,"borderTopWidth"),10)-(0,f.default)(e)||0,o.left+=parseInt((0,g.default)(e,"borderLeftWidth"),10)-(0,p.default)(e)||0),i._extends({},n,{top:n.top-o.top-(parseInt((0,g.default)(t,"marginTop"),10)||0),left:n.left-o.left-(parseInt((0,g.default)(t,"marginLeft"),10)||0)})}var i=n(447);e.__esModule=!0,e.default=o;var a=n(539),s=i.interopRequireDefault(a),l=n(541),u=i.interopRequireDefault(l),c=n(542),f=i.interopRequireDefault(c),d=n(543),p=i.interopRequireDefault(d),h=n(441),g=i.interopRequireDefault(h);t.exports=e.default},function(t,e,n){"use strict";function r(t){return t.nodeName&&t.nodeName.toLowerCase()}function o(t){for(var e=(0,s.default)(t),n=t&&t.offsetParent;n&&"html"!==r(t)&&"static"===(0,u.default)(n,"position");)n=n.offsetParent;return n||e.documentElement}var i=n(447);e.__esModule=!0,e.default=o;var a=n(455),s=i.interopRequireDefault(a),l=n(441),u=i.interopRequireDefault(l);t.exports=e.default},function(t,e,n){"use strict";var r=n(519);t.exports=function(t,e){var n=r(t);return void 0===e?n?"pageYOffset"in n?n.pageYOffset:n.document.documentElement.scrollTop:t.scrollTop:void(n?n.scrollTo("pageXOffset"in n?n.pageXOffset:n.document.documentElement.scrollLeft,e):t.scrollTop=e)}},function(t,e,n){"use strict";var r=n(519);t.exports=function(t,e){var n=r(t);return void 0===e?n?"pageXOffset"in n?n.pageXOffset:n.document.documentElement.scrollLeft:t.scrollLeft:void(n?n.scrollTo(e,"pageYOffset"in n?n.pageYOffset:n.document.documentElement.scrollTop):t.scrollLeft=e)}},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e){return Array.isArray(e)?e.indexOf(t)>=0:t===e}e.__esModule=!0;var i=n(404),a=r(i),s=n(358),l=r(s),u=n(359),c=r(u),f=n(395),d=r(f),p=n(320),h=r(p),g=n(456),v=r(g),m=n(3),y=r(m),b=n(30),x=r(b),_=n(435),w=(r(_),n(535)),T=r(w),C=n(413),k=r(C),E=y.default.PropTypes.oneOf(["click","hover","focus"]),P=(0,h.default)({},T.default.propTypes,{trigger:y.default.PropTypes.oneOfType([E,y.default.PropTypes.arrayOf(E)]),delay:y.default.PropTypes.number,delayShow:y.default.PropTypes.number,delayHide:y.default.PropTypes.number,defaultOverlayShown:y.default.PropTypes.bool,overlay:y.default.PropTypes.node.isRequired,onBlur:y.default.PropTypes.func,onClick:y.default.PropTypes.func,onFocus:y.default.PropTypes.func,onMouseOut:y.default.PropTypes.func,onMouseOver:y.default.PropTypes.func,target:y.default.PropTypes.oneOf([null]),onHide:y.default.PropTypes.oneOf([null]),show:y.default.PropTypes.oneOf([null])}),S={defaultOverlayShown:!1,trigger:["hover","focus"]},M=function(t){function e(n,r){(0,l.default)(this,e);var o=(0,c.default)(this,t.call(this,n,r));return o.handleToggle=o.handleToggle.bind(o),o.handleDelayedShow=o.handleDelayedShow.bind(o),o.handleDelayedHide=o.handleDelayedHide.bind(o),o.handleHide=o.handleHide.bind(o),o.handleMouseOver=function(t){return o.handleMouseOverOut(o.handleDelayedShow,t)},o.handleMouseOut=function(t){return o.handleMouseOverOut(o.handleDelayedHide,t)},o._mountNode=null,o.state={show:n.defaultOverlayShown},o}return(0,d.default)(e,t),e.prototype.componentDidMount=function(){this._mountNode=document.createElement("div"),this.renderOverlay()},e.prototype.componentDidUpdate=function(){this.renderOverlay()},e.prototype.componentWillUnmount=function(){x.default.unmountComponentAtNode(this._mountNode),this._mountNode=null,clearTimeout(this._hoverShowDelay),clearTimeout(this._hoverHideDelay)},e.prototype.handleToggle=function(){this.state.show?this.hide():this.show()},e.prototype.handleDelayedShow=function(){var t=this;if(null!=this._hoverHideDelay)return clearTimeout(this._hoverHideDelay),void(this._hoverHideDelay=null);if(!this.state.show&&null==this._hoverShowDelay){var e=null!=this.props.delayShow?this.props.delayShow:this.props.delay;return e?void(this._hoverShowDelay=setTimeout(function(){t._hoverShowDelay=null,t.show()},e)):void this.show()}},e.prototype.handleDelayedHide=function(){var t=this;if(null!=this._hoverShowDelay)return clearTimeout(this._hoverShowDelay),void(this._hoverShowDelay=null);if(this.state.show&&null==this._hoverHideDelay){var e=null!=this.props.delayHide?this.props.delayHide:this.props.delay;return e?void(this._hoverHideDelay=setTimeout(function(){t._hoverHideDelay=null,t.hide()},e)):void this.hide()}},e.prototype.handleMouseOverOut=function(t,e){var n=e.currentTarget,r=e.relatedTarget||e.nativeEvent.toElement;r&&(r===n||(0,v.default)(n,r))||t(e)},e.prototype.handleHide=function(){this.hide()},e.prototype.show=function(){this.setState({show:!0})},e.prototype.hide=function(){this.setState({show:!1})},e.prototype.makeOverlay=function(t,e){return y.default.createElement(T.default,(0,h.default)({},e,{show:this.state.show,onHide:this.handleHide,target:this}),t)},e.prototype.renderOverlay=function(){x.default.unstable_renderSubtreeIntoContainer(this,this._overlay,this._mountNode)},e.prototype.render=function(){var t=this.props,e=t.trigger,n=t.overlay,r=t.children,i=t.onBlur,s=t.onClick,l=t.onFocus,u=t.onMouseOut,c=t.onMouseOver,f=(0,a.default)(t,["trigger","overlay","children","onBlur","onClick","onFocus","onMouseOut","onMouseOver"]);delete f.delay,delete f.delayShow,delete f.delayHide,delete f.defaultOverlayShown;var d=y.default.Children.only(r),p=d.props,h={"aria-describedby":n.props.id};return h.onClick=(0,k.default)(p.onClick,s),o("click",e)&&(h.onClick=(0,k.default)(h.onClick,this.handleToggle)),o("hover",e)&&(h.onMouseOver=(0,k.default)(p.onMouseOver,c,this.handleMouseOver),h.onMouseOut=(0,k.default)(p.onMouseOut,u,this.handleMouseOut)),o("focus",e)&&(h.onFocus=(0,k.default)(p.onFocus,l,this.handleDelayedShow),h.onBlur=(0,k.default)(p.onBlur,i,this.handleDelayedHide)),this._overlay=this.makeOverlay(n,f),(0,m.cloneElement)(d,h)},e}(y.default.Component);M.propTypes=P,M.defaultProps=S,e.default=M,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=t.children,r=(0,s.default)(t,["className","children"]),o=(0,y.splitBsProps)(r),a=o[0],l=o[1],u=(0,y.getClassSet)(a);return m.default.createElement("div",(0,i.default)({},l,{className:(0,g.default)(e,u)}),m.default.createElement("h1",null,n))},e}(m.default.Component);e.default=(0,y.bsClass)("page-header",b),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(547),i=r(o),a=n(548),s=r(a);e.default=s.default.wrapper(i.default,"`<PageItem>`","`<Pager.Item>`"),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(422),b=r(y),x=n(413),_=r(x),w={disabled:m.default.PropTypes.bool,previous:m.default.PropTypes.bool,next:m.default.PropTypes.bool,onClick:m.default.PropTypes.func,onSelect:m.default.PropTypes.func,eventKey:m.default.PropTypes.any},T={disabled:!1,previous:!1,next:!1},C=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleSelect=o.handleSelect.bind(o),o}return(0,p.default)(e,t),e.prototype.handleSelect=function(t){var e=this.props,n=e.disabled,r=e.onSelect,o=e.eventKey;(r||n)&&t.preventDefault(),n||r&&r(o,t)},e.prototype.render=function(){var t=this.props,e=t.disabled,n=t.previous,r=t.next,o=t.onClick,a=t.className,l=t.style,u=(0,s.default)(t,["disabled","previous","next","onClick","className","style"]);return delete u.onSelect,delete u.eventKey,m.default.createElement("li",{className:(0,g.default)(a,{disabled:e,previous:n,next:r}),style:l},m.default.createElement(b.default,(0,i.default)({},u,{disabled:e,onClick:(0,_.default)(o,this.handleSelect)})))},e}(m.default.Component);C.propTypes=w,C.defaultProps=T,e.default=C,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r=void 0;"object"===("undefined"==typeof t?"undefined":(0,p.default)(t))?r=t.message:(r=t+" is deprecated. Use "+e+" instead.",n&&(r+="\nYou can read more about it at "+n)),g[r]||(g[r]=!0)}function i(){g={}}e.__esModule=!0;var a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(360),p=r(d);e._resetWarned=i;var h=n(435),g=(r(h),{});o.wrapper=function(t){for(var e=arguments.length,n=Array(e>1?e-1:0),r=1;r<e;r++)n[r-1]=arguments[r];return function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.componentWillMount=function(){if(o.apply(void 0,n),t.prototype.componentWillMount){
for(var e,r=arguments.length,i=Array(r),a=0;a<r;a++)i[a]=arguments[a];(e=t.prototype.componentWillMount).call.apply(e,[this].concat(i))}},e}(t)},e.default=o},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(547),b=r(y),x=n(406),_=n(413),w=r(_),T=n(414),C=r(T),k={onSelect:m.default.PropTypes.func},E=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.onSelect,n=t.className,r=t.children,o=(0,s.default)(t,["onSelect","className","children"]),a=(0,x.splitBsProps)(o),l=a[0],u=a[1],c=(0,x.getClassSet)(l);return m.default.createElement("ul",(0,i.default)({},u,{className:(0,g.default)(n,c)}),C.default.map(r,function(t){return(0,v.cloneElement)(t,{onSelect:(0,w.default)(t.props.onSelect,e)})}))},e}(m.default.Component);E.propTypes=k,E.Item=b.default,e.default=(0,x.bsClass)("pager",E),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(404),i=r(o),a=n(320),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(551),_=r(x),w=n(406),T={activePage:m.default.PropTypes.number,items:m.default.PropTypes.number,maxButtons:m.default.PropTypes.number,boundaryLinks:m.default.PropTypes.bool,ellipsis:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),first:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),last:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),prev:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),next:m.default.PropTypes.oneOfType([m.default.PropTypes.bool,m.default.PropTypes.node]),onSelect:m.default.PropTypes.func,buttonComponentClass:b.default},C={activePage:1,items:1,maxButtons:0,first:!1,last:!1,prev:!1,next:!1,ellipsis:!0,boundaryLinks:!1},k=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.renderPageButtons=function(t,e,n,r,o,i){var a=[],l=void 0,u=void 0,c=void 0;if(n){var f=t-parseInt(n/2,10);l=Math.max(f,1),c=e>=l+n,c?u=l+n-1:(u=e,l=e-n+1,l<1&&(l=1))}else l=1,u=e;for(var d=l;d<=u;d++)a.push(m.default.createElement(_.default,(0,s.default)({},i,{key:d,eventKey:d,active:d===t}),d));return r&&o&&1!==l&&(a.unshift(m.default.createElement(_.default,{key:"ellipsisFirst",disabled:!0,componentClass:i.componentClass},m.default.createElement("span",{"aria-label":"More"},o===!0?"…":o))),a.unshift(m.default.createElement(_.default,(0,s.default)({},i,{key:1,eventKey:1,active:!1}),"1"))),n&&c&&o&&(a.push(m.default.createElement(_.default,{key:"ellipsis",disabled:!0,componentClass:i.componentClass},m.default.createElement("span",{"aria-label":"More"},o===!0?"…":o))),r&&u!==e&&a.push(m.default.createElement(_.default,(0,s.default)({},i,{key:e,eventKey:e,active:!1}),e))),a},e.prototype.render=function(){var t=this.props,e=t.activePage,n=t.items,r=t.maxButtons,o=t.boundaryLinks,a=t.ellipsis,l=t.first,u=t.last,c=t.prev,f=t.next,d=t.onSelect,p=t.buttonComponentClass,h=t.className,v=(0,i.default)(t,["activePage","items","maxButtons","boundaryLinks","ellipsis","first","last","prev","next","onSelect","buttonComponentClass","className"]),y=(0,w.splitBsProps)(v),b=y[0],x=y[1],T=(0,w.getClassSet)(b),C={onSelect:d,componentClass:p};return m.default.createElement("ul",(0,s.default)({},x,{className:(0,g.default)(h,T)}),l&&m.default.createElement(_.default,(0,s.default)({},C,{eventKey:1,disabled:1===e}),m.default.createElement("span",{"aria-label":"First"},l===!0?"«":l)),c&&m.default.createElement(_.default,(0,s.default)({},C,{eventKey:e-1,disabled:1===e}),m.default.createElement("span",{"aria-label":"Previous"},c===!0?"‹":c)),this.renderPageButtons(e,n,r,o,a,C),f&&m.default.createElement(_.default,(0,s.default)({},C,{eventKey:e+1,disabled:e>=n}),m.default.createElement("span",{"aria-label":"Next"},f===!0?"›":f)),u&&m.default.createElement(_.default,(0,s.default)({},C,{eventKey:n,disabled:e>=n}),m.default.createElement("span",{"aria-label":"Last"},u===!0?"»":u)))},e}(m.default.Component);k.propTypes=T,k.defaultProps=C,e.default=(0,w.bsClass)("pagination",k),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(422),_=r(x),w=n(413),T=r(w),C={componentClass:b.default,className:m.default.PropTypes.string,eventKey:m.default.PropTypes.any,onSelect:m.default.PropTypes.func,disabled:m.default.PropTypes.bool,active:m.default.PropTypes.bool,onClick:m.default.PropTypes.func},k={componentClass:_.default,active:!1,disabled:!1},E=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleClick=o.handleClick.bind(o),o}return(0,p.default)(e,t),e.prototype.handleClick=function(t){var e=this.props,n=e.disabled,r=e.onSelect,o=e.eventKey;n||r&&r(o,t)},e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.active,r=t.disabled,o=t.onClick,a=t.className,l=t.style,u=(0,s.default)(t,["componentClass","active","disabled","onClick","className","style"]);return e===_.default&&delete u.eventKey,delete u.onSelect,m.default.createElement("li",{className:(0,g.default)(a,{active:n,disabled:r}),style:l},m.default.createElement(e,(0,i.default)({},u,{disabled:r,onClick:(0,T.default)(o,this.handleClick)})))},e}(m.default.Component);E.propTypes=C,E.defaultProps=k,e.default=E,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(416),i=r(o),a=n(404),s=r(a),l=n(320),u=r(l),c=n(358),f=r(c),d=n(359),p=r(d),h=n(395),g=r(h),v=n(405),m=r(v),y=n(3),b=r(y),x=n(440),_=r(x),w=n(406),T=n(412),C={collapsible:b.default.PropTypes.bool,onSelect:b.default.PropTypes.func,header:b.default.PropTypes.node,id:b.default.PropTypes.oneOfType([b.default.PropTypes.string,b.default.PropTypes.number]),footer:b.default.PropTypes.node,defaultExpanded:b.default.PropTypes.bool,expanded:b.default.PropTypes.bool,eventKey:b.default.PropTypes.any,headerRole:b.default.PropTypes.string,panelRole:b.default.PropTypes.string,onEnter:b.default.PropTypes.func,onEntering:b.default.PropTypes.func,onEntered:b.default.PropTypes.func,onExit:b.default.PropTypes.func,onExiting:b.default.PropTypes.func,onExited:b.default.PropTypes.func},k={defaultExpanded:!1},E=function(t){function e(n,r){(0,f.default)(this,e);var o=(0,p.default)(this,t.call(this,n,r));return o.handleClickTitle=o.handleClickTitle.bind(o),o.state={expanded:o.props.defaultExpanded},o}return(0,g.default)(e,t),e.prototype.handleClickTitle=function(t){t.persist(),t.selected=!0,this.props.onSelect?this.props.onSelect(this.props.eventKey,t):t.preventDefault(),t.selected&&this.setState({expanded:!this.state.expanded})},e.prototype.renderHeader=function(t,e,n,r,o,i){var a=(0,w.prefix)(i,"title");return t?b.default.isValidElement(e)?(0,y.cloneElement)(e,{className:(0,m.default)(e.props.className,a),children:this.renderAnchor(e.props.children,n,r,o)}):b.default.createElement("h4",{role:"presentation",className:a},this.renderAnchor(e,n,r,o)):b.default.isValidElement(e)?(0,y.cloneElement)(e,{className:(0,m.default)(e.props.className,a)}):e},e.prototype.renderAnchor=function(t,e,n,r){return b.default.createElement("a",{role:n,href:e&&"#"+e,onClick:this.handleClickTitle,"aria-controls":e,"aria-expanded":r,"aria-selected":r,className:r?null:"collapsed"},t)},e.prototype.renderCollapsibleBody=function(t,e,n,r,o,i){return b.default.createElement(_.default,(0,u.default)({in:e},i),b.default.createElement("div",{id:t,role:n,className:(0,w.prefix)(o,"collapse"),"aria-hidden":!e},this.renderBody(r,o)))},e.prototype.renderBody=function(t,e){function n(){o.length&&(r.push(b.default.createElement("div",{key:r.length,className:i},o)),o=[])}var r=[],o=[],i=(0,w.prefix)(e,"body");return b.default.Children.toArray(t).forEach(function(t){return b.default.isValidElement(t)&&t.props.fill?(n(),void r.push((0,y.cloneElement)(t,{fill:void 0}))):void o.push(t)}),n(),r},e.prototype.render=function(){var t=this.props,e=t.collapsible,n=t.header,r=t.id,o=t.footer,i=t.expanded,a=t.headerRole,l=t.panelRole,c=t.className,f=t.children,d=t.onEnter,p=t.onEntering,h=t.onEntered,g=t.onExit,v=t.onExiting,y=t.onExited,x=(0,s.default)(t,["collapsible","header","id","footer","expanded","headerRole","panelRole","className","children","onEnter","onEntering","onEntered","onExit","onExiting","onExited"]),_=(0,w.splitBsPropsAndOmit)(x,["defaultExpanded","eventKey","onSelect"]),T=_[0],C=_[1],k=null!=i?i:this.state.expanded,E=(0,w.getClassSet)(T);return b.default.createElement("div",(0,u.default)({},C,{className:(0,m.default)(c,E),id:e?null:r}),n&&b.default.createElement("div",{className:(0,w.prefix)(T,"heading")},this.renderHeader(e,n,r,a,k,T)),e?this.renderCollapsibleBody(r,k,l,f,T,{onEnter:d,onEntering:p,onEntered:h,onExit:g,onExiting:v,onExited:y}):this.renderBody(f,T),o&&b.default.createElement("div",{className:(0,w.prefix)(T,"footer")},o))},e}(b.default.Component);E.propTypes=C,E.defaultProps=k,e.default=(0,w.bsClass)("panel",(0,w.bsStyles)([].concat((0,i.default)(T.State),[T.Style.DEFAULT,T.Style.PRIMARY]),T.Style.DEFAULT,E)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(458),b=r(y),x=n(406),_={id:(0,b.default)(m.default.PropTypes.oneOfType([m.default.PropTypes.string,m.default.PropTypes.number])),placement:m.default.PropTypes.oneOf(["top","right","bottom","left"]),positionTop:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),positionLeft:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),arrowOffsetTop:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),arrowOffsetLeft:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),title:m.default.PropTypes.node},w={placement:"right"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.placement,r=e.positionTop,o=e.positionLeft,a=e.arrowOffsetTop,l=e.arrowOffsetLeft,u=e.title,c=e.className,f=e.style,d=e.children,p=(0,s.default)(e,["placement","positionTop","positionLeft","arrowOffsetTop","arrowOffsetLeft","title","className","style","children"]),h=(0,x.splitBsProps)(p),v=h[0],y=h[1],b=(0,i.default)({},(0,x.getClassSet)(v),(t={},t[n]=!0,t)),_=(0,i.default)({display:"block",top:r,left:o},f),w={top:a,left:l};return m.default.createElement("div",(0,i.default)({},y,{role:"tooltip",className:(0,g.default)(c,b),style:_}),m.default.createElement("div",{className:"arrow",style:w}),u&&m.default.createElement("h3",{className:(0,x.prefix)(v,"title")},u),m.default.createElement("div",{className:(0,x.prefix)(v,"content")},d))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("popover",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t,e,n){var r=t[e];if(!r)return null;var o=null;return _.default.Children.forEach(r,function(t){if(!o&&t.type!==M){var e=_.default.isValidElement(t)?t.type.displayName||t.type.name||t.type:t;o=new Error("Children of "+n+" can contain only ProgressBar "+("components. Found "+e+"."))}}),o}function i(t,e,n){var r=(t-e)/(n-e)*100;return Math.round(r*E)/E}e.__esModule=!0;var a=n(416),s=r(a),l=n(320),u=r(l),c=n(404),f=r(c),d=n(358),p=r(d),h=n(359),g=r(h),v=n(395),m=r(v),y=n(405),b=r(y),x=n(3),_=r(x),w=n(406),T=n(412),C=n(414),k=r(C),E=1e3,P={min:x.PropTypes.number,now:x.PropTypes.number,max:x.PropTypes.number,label:x.PropTypes.node,srOnly:x.PropTypes.bool,striped:x.PropTypes.bool,active:x.PropTypes.bool,children:o,isChild:x.PropTypes.bool},S={min:0,max:100,active:!1,isChild:!1,srOnly:!1,striped:!1},M=function(t){function e(){return(0,p.default)(this,e),(0,g.default)(this,t.apply(this,arguments))}return(0,m.default)(e,t),e.prototype.renderProgressBar=function(t){var e,n=t.min,r=t.now,o=t.max,a=t.label,s=t.srOnly,l=t.striped,c=t.active,d=t.className,p=t.style,h=(0,f.default)(t,["min","now","max","label","srOnly","striped","active","className","style"]),g=(0,w.splitBsProps)(h),v=g[0],m=g[1],y=(0,u.default)({},(0,w.getClassSet)(v),(e={active:c},e[(0,w.prefix)(v,"striped")]=c||l,e));return _.default.createElement("div",(0,u.default)({},m,{role:"progressbar",className:(0,b.default)(d,y),style:(0,u.default)({width:i(r,n,o)+"%"},p),"aria-valuenow":r,"aria-valuemin":n,"aria-valuemax":o}),s?_.default.createElement("span",{className:"sr-only"},a):a)},e.prototype.render=function(){var t=this.props,e=t.isChild,n=(0,f.default)(t,["isChild"]);if(e)return this.renderProgressBar(n);var r=n.min,o=n.now,i=n.max,a=n.label,s=n.srOnly,l=n.striped,c=n.active,d=n.bsClass,p=n.bsStyle,h=n.className,g=n.children,v=(0,f.default)(n,["min","now","max","label","srOnly","striped","active","bsClass","bsStyle","className","children"]);return _.default.createElement("div",(0,u.default)({},v,{className:(0,b.default)(h,"progress")}),g?k.default.map(g,function(t){return(0,x.cloneElement)(t,{isChild:!0})}):this.renderProgressBar({min:r,now:o,max:i,label:a,srOnly:s,striped:l,active:c,bsClass:d,bsStyle:p}))},e}(_.default.Component);M.propTypes=P,M.defaultProps=S,e.default=(0,w.bsClass)("progress-bar",(0,w.bsStyles)((0,s.default)(T.State),M)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(435),b=(r(y),n(406)),x={inline:m.default.PropTypes.bool,disabled:m.default.PropTypes.bool,validationState:m.default.PropTypes.oneOf(["success","warning","error",null]),inputRef:m.default.PropTypes.func},_={inline:!1,disabled:!1},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.inline,n=t.disabled,r=t.validationState,o=t.inputRef,a=t.className,l=t.style,u=t.children,c=(0,s.default)(t,["inline","disabled","validationState","inputRef","className","style","children"]),f=(0,b.splitBsProps)(c),d=f[0],p=f[1],h=m.default.createElement("input",(0,i.default)({},p,{ref:o,type:"radio",disabled:n}));if(e){var v,y=(v={},v[(0,b.prefix)(d,"inline")]=!0,v.disabled=n,v);return m.default.createElement("label",{className:(0,g.default)(a,y),style:l},h,u)}var x=(0,i.default)({},(0,b.getClassSet)(d),{disabled:n});return r&&(x["has-"+r]=!0),m.default.createElement("div",{className:(0,g.default)(a,x),style:l},m.default.createElement("label",null,h,u))},e}(m.default.Component);w.propTypes=x,w.defaultProps=_,e.default=(0,b.bsClass)("radio",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(435),b=(r(y),n(406)),x={children:v.PropTypes.element.isRequired,a16by9:v.PropTypes.bool,a4by3:v.PropTypes.bool},_={a16by9:!1,a4by3:!1},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.a16by9,r=e.a4by3,o=e.className,a=e.children,l=(0,s.default)(e,["a16by9","a4by3","className","children"]),u=(0,b.splitBsProps)(l),c=u[0],f=u[1],d=(0,i.default)({},(0,b.getClassSet)(c),(t={},t[(0,b.prefix)(c,"16by9")]=n,t[(0,b.prefix)(c,"4by3")]=r,t));return m.default.createElement("div",{className:(0,g.default)(d)},(0,v.cloneElement)(a,(0,i.default)({},f,{className:(0,g.default)(o,(0,b.prefix)(c,"item"))})))},e}(m.default.Component);w.propTypes=x,w.defaultProps=_,e.default=(0,b.bsClass)("embed-responsive",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default},w={componentClass:"div"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsProps)(r),a=o[0],l=o[1],u=(0,x.getClassSet)(a);return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,u)}))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("row",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(404),i=r(o),a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(320),p=r(d),h=n(3),g=r(h),v=n(425),m=r(v),y=n(453),b=r(y),x=n(559),_=r(x),w=n(479),T=r(w),C=(0,p.default)({},b.default.propTypes,{bsStyle:g.default.PropTypes.string,bsSize:g.default.PropTypes.string,href:g.default.PropTypes.string,onClick:g.default.PropTypes.func,title:g.default.PropTypes.node.isRequired,toggleLabel:g.default.PropTypes.string,children:g.default.PropTypes.node}),k=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.bsSize,n=t.bsStyle,r=t.title,o=t.toggleLabel,a=t.children,s=(0,i.default)(t,["bsSize","bsStyle","title","toggleLabel","children"]),l=(0,T.default)(s,b.default.ControlledComponent),u=l[0],c=l[1];return g.default.createElement(b.default,(0,p.default)({},u,{bsSize:e,bsStyle:n}),g.default.createElement(m.default,(0,p.default)({},c,{disabled:s.disabled,bsSize:e,bsStyle:n}),r),g.default.createElement(_.default,{"aria-label":o||r,bsSize:e,bsStyle:n}),g.default.createElement(b.default.Menu,null,a))},e}(g.default.Component);k.propTypes=C,k.Toggle=_.default,e.default=k,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(3),p=r(d),h=n(476),g=r(h),v=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.render=function(){return p.default.createElement(g.default,(0,i.default)({},this.props,{useAnchor:!1,noCaret:!1}))},e}(p.default.Component);v.defaultProps=g.default.defaultProps,e.default=v,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(358),i=r(o),a=n(359),s=r(a),l=n(395),u=r(l),c=n(320),f=r(c),d=n(3),p=r(d),h=n(561),g=r(h),v=n(562),m=r(v),y=n(563),b=r(y),x=(0,f.default)({},b.default.propTypes,{disabled:p.default.PropTypes.bool,title:p.default.PropTypes.node,tabClassName:p.default.PropTypes.string}),_=function(t){function e(){return(0,i.default)(this,e),(0,s.default)(this,t.apply(this,arguments))}return(0,u.default)(e,t),e.prototype.render=function(){var t=(0,f.default)({},this.props);return delete t.title,delete t.disabled,delete t.tabClassName,p.default.createElement(b.default,t)},e}(p.default.Component);_.propTypes=x,_.Container=g.default,_.Content=m.default,_.Pane=b.default,e.default=_,t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(404),i=r(o),a=n(358),s=r(a),l=n(359),u=r(l),c=n(395),f=r(c),d=n(3),p=r(d),h=n(459),g=r(h),v="tab",m="pane",y=d.PropTypes.oneOfType([d.PropTypes.string,d.PropTypes.number]),b={id:function(t){var e=null;if(!t.generateChildId){for(var n=arguments.length,r=Array(n>1?n-1:0),o=1;o<n;o++)r[o-1]=arguments[o];e=y.apply(void 0,[t].concat(r)),e||t.id||(e=new Error("In order to properly initialize Tabs in a way that is accessible to assistive technologies (such as screen readers) an `id` or a `generateChildId` prop to TabContainer is required"))}return e},generateChildId:d.PropTypes.func,onSelect:d.PropTypes.func,activeKey:d.PropTypes.any},x={$bs_tabContainer:p.default.PropTypes.shape({activeKey:d.PropTypes.any,onSelect:d.PropTypes.func.isRequired,getTabId:d.PropTypes.func.isRequired,getPaneId:d.PropTypes.func.isRequired})},_=function(t){function e(){return(0,s.default)(this,e),(0,u.default)(this,t.apply(this,arguments))}return(0,f.default)(e,t),e.prototype.getChildContext=function(){var t=this.props,e=t.activeKey,n=t.onSelect,r=t.generateChildId,o=t.id,i=r||function(t,e){return o?o+"-"+e+"-"+t:null};return{$bs_tabContainer:{activeKey:e,onSelect:n,getTabId:function(t){return i(t,v)},getPaneId:function(t){return i(t,m)}}}},e.prototype.render=function(){var t=this.props,e=t.children,n=(0,i.default)(t,["children"]);return delete n.generateChildId,delete n.onSelect,delete n.activeKey,p.default.cloneElement(p.default.Children.only(e),n)},e}(p.default.Component);_.propTypes=b,_.childContextTypes=x,e.default=(0,g.default)(_,{activeKey:"onSelect"}),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(406),_={componentClass:b.default,animation:v.PropTypes.oneOfType([v.PropTypes.bool,b.default]),unmountOnExit:v.PropTypes.bool},w={componentClass:"div",animation:!0,unmountOnExit:!1},T={$bs_tabContainer:v.PropTypes.shape({activeKey:v.PropTypes.any})},C={$bs_tabContent:v.PropTypes.shape({bsClass:v.PropTypes.string,animation:v.PropTypes.oneOfType([v.PropTypes.bool,b.default]),activeKey:v.PropTypes.any,unmountOnExit:v.PropTypes.bool,onPaneEnter:v.PropTypes.func.isRequired,onPaneExited:v.PropTypes.func.isRequired,exiting:v.PropTypes.bool.isRequired})},k=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handlePaneEnter=o.handlePaneEnter.bind(o),o.handlePaneExited=o.handlePaneExited.bind(o),o.state={activeKey:null,activeChild:null},o}return(0,p.default)(e,t),e.prototype.getChildContext=function(){var t=this.props,e=t.bsClass,n=t.animation,r=t.unmountOnExit,o=this.state.activeKey,i=this.getContainerActiveKey(),a=null!=o?o:i,s=null!=o&&o!==i;return{$bs_tabContent:{bsClass:e,animation:n,activeKey:a,unmountOnExit:r,onPaneEnter:this.handlePaneEnter,onPaneExited:this.handlePaneExited,exiting:s}}},e.prototype.componentWillReceiveProps=function(t){!t.animation&&this.state.activeChild&&this.setState({activeKey:null,activeChild:null})},e.prototype.componentWillUnmount=function(){this.isUnmounted=!0},e.prototype.handlePaneEnter=function(t,e){return!!this.props.animation&&(e===this.getContainerActiveKey()&&(this.setState({activeKey:e,activeChild:t}),!0))},e.prototype.handlePaneExited=function(t){this.isUnmounted||this.setState(function(e){var n=e.activeChild;return n!==t?null:{activeKey:null,activeChild:null}})},e.prototype.getContainerActiveKey=function(){var t=this.context.$bs_tabContainer;return t&&t.activeKey},e.prototype.render=function(){var t=this.props,e=t.componentClass,n=t.className,r=(0,s.default)(t,["componentClass","className"]),o=(0,x.splitBsPropsAndOmit)(r,["animation","unmountOnExit"]),a=o[0],l=o[1];return m.default.createElement(e,(0,i.default)({},l,{className:(0,g.default)(n,(0,x.prefix)(a,"content"))}))},e}(m.default.Component);k.propTypes=_,k.defaultProps=w,k.contextTypes=T,k.childContextTypes=C,e.default=(0,x.bsClass)("tab",k),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(423),b=r(y),x=n(435),_=(r(x),n(406)),w=n(413),T=r(w),C=n(480),k=r(C),E={eventKey:v.PropTypes.any,animation:v.PropTypes.oneOfType([v.PropTypes.bool,b.default]),id:v.PropTypes.string,"aria-labelledby":v.PropTypes.string,bsClass:m.default.PropTypes.string,onEnter:v.PropTypes.func,onEntering:v.PropTypes.func,onEntered:v.PropTypes.func,onExit:v.PropTypes.func,onExiting:v.PropTypes.func,onExited:v.PropTypes.func,unmountOnExit:v.PropTypes.bool},P={$bs_tabContainer:v.PropTypes.shape({getId:v.PropTypes.func,unmountOnExit:v.PropTypes.bool}),$bs_tabContent:v.PropTypes.shape({bsClass:v.PropTypes.string,animation:v.PropTypes.oneOfType([v.PropTypes.bool,b.default]),activeKey:v.PropTypes.any,unmountOnExit:v.PropTypes.bool,onPaneEnter:v.PropTypes.func.isRequired,onPaneExited:v.PropTypes.func.isRequired,exiting:v.PropTypes.bool.isRequired})},S={$bs_tabContainer:v.PropTypes.oneOf([null])},M=function(t){function e(n,r){(0,u.default)(this,e);var o=(0,f.default)(this,t.call(this,n,r));return o.handleEnter=o.handleEnter.bind(o),o.handleExited=o.handleExited.bind(o),o.in=!1,o}return(0,p.default)(e,t),e.prototype.getChildContext=function(){return{$bs_tabContainer:null}},e.prototype.componentDidMount=function(){this.shouldBeIn()&&this.handleEnter()},e.prototype.componentDidUpdate=function(){this.in?this.shouldBeIn()||this.handleExited():this.shouldBeIn()&&this.handleEnter()},e.prototype.componentWillUnmount=function(){this.in&&this.handleExited()},e.prototype.handleEnter=function(){var t=this.context.$bs_tabContent;t&&(this.in=t.onPaneEnter(this,this.props.eventKey))},e.prototype.handleExited=function(){var t=this.context.$bs_tabContent;t&&(t.onPaneExited(this),this.in=!1)},e.prototype.getAnimation=function(){if(null!=this.props.animation)return this.props.animation;var t=this.context.$bs_tabContent;return t&&t.animation},e.prototype.isActive=function(){var t=this.context.$bs_tabContent,e=t&&t.activeKey;return this.props.eventKey===e},e.prototype.shouldBeIn=function(){return this.getAnimation()&&this.isActive()},e.prototype.render=function(){var t=this.props,e=t.eventKey,n=t.className,r=t.onEnter,o=t.onEntering,a=t.onEntered,l=t.onExit,u=t.onExiting,c=t.onExited,f=t.unmountOnExit,d=(0,s.default)(t,["eventKey","className","onEnter","onEntering","onEntered","onExit","onExiting","onExited","unmountOnExit"]),p=this.context,h=p.$bs_tabContent,v=p.$bs_tabContainer,y=(0,_.splitBsPropsAndOmit)(d,["animation"]),b=y[0],x=y[1],w=this.isActive(),C=this.getAnimation(),E=null!=f?f:h&&h.unmountOnExit;if(!w&&!C&&E)return null;var P=C===!0?k.default:C||null;h&&(b.bsClass=(0,_.prefix)(h,"pane"));var S=(0,i.default)({},(0,_.getClassSet)(b),{active:w});v&&(x.id=v.getPaneId(e),x["aria-labelledby"]=v.getTabId(e));var M=m.default.createElement("div",(0,i.default)({},x,{role:"tabpanel","aria-hidden":!w,className:(0,g.default)(n,S)}));if(P){var N=h&&h.exiting;return m.default.createElement(P,{in:w&&!N,onEnter:(0,T.default)(this.handleEnter,r),onEntering:o,onEntered:a,onExit:l,onExiting:u,onExited:(0,T.default)(this.handleExited,c),unmountOnExit:E},M)}return M},e}(m.default.Component);M.propTypes=E,M.contextTypes=P,M.childContextTypes=S,e.default=(0,_.bsClass)("tab-pane",M),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b={striped:m.default.PropTypes.bool,bordered:m.default.PropTypes.bool,condensed:m.default.PropTypes.bool,hover:m.default.PropTypes.bool,responsive:m.default.PropTypes.bool},x={bordered:!1,condensed:!1,hover:!1,responsive:!1,striped:!1},_=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.striped,r=e.bordered,o=e.condensed,a=e.hover,l=e.responsive,u=e.className,c=(0,s.default)(e,["striped","bordered","condensed","hover","responsive","className"]),f=(0,y.splitBsProps)(c),d=f[0],p=f[1],h=(0,i.default)({},(0,y.getClassSet)(d),(t={},t[(0,y.prefix)(d,"striped")]=n,t[(0,y.prefix)(d,"bordered")]=r,t[(0,y.prefix)(d,"condensed")]=o,t[(0,y.prefix)(d,"hover")]=a,t)),v=m.default.createElement("table",(0,i.default)({},p,{className:(0,g.default)(u,h)}));return l?m.default.createElement("div",{className:(0,y.prefix)(d,"responsive")},v):v},e}(m.default.Component);_.propTypes=b,_.defaultProps=x,e.default=(0,y.bsClass)("table",_),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){var e=void 0;return A.default.forEach(t,function(t){null==e&&(e=t.props.eventKey)}),e}e.__esModule=!0;var i=n(320),a=r(i),s=n(404),l=r(s),u=n(358),c=r(u),f=n(359),d=r(f),p=n(395),h=r(p),g=n(3),v=r(g),m=n(458),y=r(m),b=n(459),x=r(b),_=n(527),w=r(_),T=n(534),C=r(T),k=n(561),E=r(k),P=n(562),S=r(P),M=n(406),N=n(414),A=r(N),O=E.default.ControlledComponent,D={activeKey:v.default.PropTypes.any,bsStyle:v.default.PropTypes.oneOf(["tabs","pills"]),animation:v.default.PropTypes.bool,id:(0,y.default)(v.default.PropTypes.oneOfType([v.default.PropTypes.string,v.default.PropTypes.number])),onSelect:v.default.PropTypes.func,unmountOnExit:v.default.PropTypes.bool},I={bsStyle:"tabs",animation:!0,unmountOnExit:!1},R=function(t){function e(){return(0,c.default)(this,e),(0,d.default)(this,t.apply(this,arguments))}return(0,h.default)(e,t),e.prototype.renderTab=function(t){var e=t.props,n=e.title,r=e.eventKey,o=e.disabled,i=e.tabClassName;return null==n?null:v.default.createElement(C.default,{eventKey:r,disabled:o,className:i},n)},e.prototype.render=function(){var t=this.props,e=t.id,n=t.onSelect,r=t.animation,i=t.unmountOnExit,s=t.bsClass,u=t.className,c=t.style,f=t.children,d=t.activeKey,p=void 0===d?o(f):d,h=(0,l.default)(t,["id","onSelect","animation","unmountOnExit","bsClass","className","style","children","activeKey"]);return v.default.createElement(O,{id:e,activeKey:p,onSelect:n,className:u,style:c},v.default.createElement("div",null,v.default.createElement(w.default,(0,a.default)({},h,{role:"tablist"}),A.default.map(f,this.renderTab)),v.default.createElement(S.default,{bsClass:s,animation:r,unmountOnExit:i},f)))},e}(v.default.Component);R.propTypes=D,R.defaultProps=I,(0,M.bsClass)("tab",R),e.default=(0,x.default)(R,{activeKey:"onSelect"}),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(422),b=r(y),x=n(406),_={src:m.default.PropTypes.string,alt:m.default.PropTypes.string,href:m.default.PropTypes.string},w=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.src,n=t.alt,r=t.className,o=t.children,a=(0,s.default)(t,["src","alt","className","children"]),l=(0,x.splitBsProps)(a),u=l[0],c=l[1],f=c.href?b.default:"div",d=(0,x.getClassSet)(u);return m.default.createElement(f,(0,i.default)({},c,{className:(0,g.default)(r,d)}),m.default.createElement("img",{src:e,alt:n}),o&&m.default.createElement("div",{className:"caption"},o))},e}(m.default.Component);w.propTypes=_,e.default=(0,x.bsClass)("thumbnail",w),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(458),b=r(y),x=n(406),_={id:(0,b.default)(m.default.PropTypes.oneOfType([m.default.PropTypes.string,m.default.PropTypes.number])),placement:m.default.PropTypes.oneOf(["top","right","bottom","left"]),positionTop:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),
positionLeft:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),arrowOffsetTop:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string]),arrowOffsetLeft:m.default.PropTypes.oneOfType([m.default.PropTypes.number,m.default.PropTypes.string])},w={placement:"right"},T=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t,e=this.props,n=e.placement,r=e.positionTop,o=e.positionLeft,a=e.arrowOffsetTop,l=e.arrowOffsetLeft,u=e.className,c=e.style,f=e.children,d=(0,s.default)(e,["placement","positionTop","positionLeft","arrowOffsetTop","arrowOffsetLeft","className","style","children"]),p=(0,x.splitBsProps)(d),h=p[0],v=p[1],y=(0,i.default)({},(0,x.getClassSet)(h),(t={},t[n]=!0,t)),b=(0,i.default)({top:r,left:o},c),_={top:a,left:l};return m.default.createElement("div",(0,i.default)({},v,{role:"tooltip",className:(0,g.default)(u,y),style:b}),m.default.createElement("div",{className:(0,x.prefix)(h,"arrow"),style:_}),m.default.createElement("div",{className:(0,x.prefix)(h,"inner")},f))},e}(m.default.Component);T.propTypes=_,T.defaultProps=w,e.default=(0,x.bsClass)("tooltip",T),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}e.__esModule=!0;var o=n(320),i=r(o),a=n(404),s=r(a),l=n(358),u=r(l),c=n(359),f=r(c),d=n(395),p=r(d),h=n(405),g=r(h),v=n(3),m=r(v),y=n(406),b=n(412),x=function(t){function e(){return(0,u.default)(this,e),(0,f.default)(this,t.apply(this,arguments))}return(0,p.default)(e,t),e.prototype.render=function(){var t=this.props,e=t.className,n=(0,s.default)(t,["className"]),r=(0,y.splitBsProps)(n),o=r[0],a=r[1],l=(0,y.getClassSet)(o);return m.default.createElement("div",(0,i.default)({},a,{className:(0,g.default)(e,l)}))},e}(m.default.Component);e.default=(0,y.bsClass)("well",(0,y.bsSizes)([b.Size.LARGE,b.Size.SMALL],x)),t.exports=e.default},function(t,e,n){"use strict";function r(t){return t&&t.__esModule?t:{default:t}}function o(t){if(t&&t.__esModule)return t;var e={};if(null!=t)for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n]);return e.default=t,e}e.__esModule=!0,e.ValidComponentChildren=e.createChainedFunction=e.bootstrapUtils=void 0;var i=n(406),a=o(i),s=n(413),l=r(s),u=n(414),c=r(u);e.bootstrapUtils=a,e.createChainedFunction=l.default,e.ValidComponentChildren=c.default}]);